// P O S E R F R A M E S
//
// Version 3.4.1
//
// by Joakim Hertze (www.hertze.se)
//
// ---------------------------------------------------------------------

#target photoshop


// Script behaviour ---------------------------------------------------

var legacy = false;
var save = false;
var force_8_bit = true;


// General settings ----------------------------------------------------

var fancy = true;
var halation = true;

// Settings for fancy borders

var artifacts = true;

var mask_variant_35mm = 1;
var mask_variant_645 = 1;
var mask_variant_67 = 1;
var mask_variant_45 = 1;
var mask_variant_square = 1;
var negative_variant_square = 1;
var negative_variant_645 = 1;


// Settings for conservative (cropped) borders) ------------------------

var matted_crop = false;
var matted_border_size = 10;
var border_width_35mm = 20;
var border_width_645 = 20;
var border_width_67 = 20;
var border_width_45 = 20;
var border_width_square = 20;
var short_side_factor = 100;


// Hic sunt dracones (advanced user settings) --------------------------

var feather_factor_35mm = 1200;
var feather_factor_645 = 1800;
var feather_factor_67_square = 2400;
var feather_factor_45 = 5400;
var movement_min_long = 10;
var movement_max_long = 100;
var movement_min_short = 10;
var movement_max_short = 100;
var movement_direction = "random";
var mask_flip_probaility = 20;
var blue_artefacts_odds = 20;


// DO NOT EDIT BELOW THIS LINE -----------------------------------------

/*
// BEGIN__HARVEST_EXCEPTION_ZSTRING
<javascriptresource> 
<name>Poserframes</name> 
<menu>automate</menu>
<enableinfo>true</enableinfo>
<eventid>12116c93-b5f3-463f-90af-02d680e4fde6</eventid>
<terminology><![CDATA[<< /Version 1
					   /Events <<
					   /12116c93-b5f3-463f-90af-02d680e4fde6 [(Poserframes) <<
					   /recipe [(Recipe) /string]
					   /savestatus [(Save) /boolean]
					   >>]
						>>
					 >> ]]></terminology>
</javascriptresource>
// END__HARVEST_EXCEPTION_ZSTRING
*/


function displayDialog(thisRecipe, saveStatus, runmode) {
	// Display dialog box.
	var dialog = new Window("dialog");
	dialog.text = "Poserframes";
	dialog.orientation = "column";
	dialog.alignChildren = ["left", "top"];
	dialog.spacing = 10;
	dialog.margins = 20;

	dialog.statictext1 = dialog.add("statictext", undefined, undefined, { name: "label" });
	if (runmode != "edit") {
		dialog.statictext1.text = "Paste your recipe here:";
	} else {
		dialog.statictext1.text = "Edit your recipe here:";
	}
	dialog.statictext1.alignment = ["fill", "top"];

	dialog.edittext1 = dialog.add("edittext", undefined, undefined, { multiline: true });
	dialog.edittext1.alignment = ["fill", "top"];
	dialog.edittext1.size = [500, 50];
	dialog.edittext1.text = thisRecipe ? thisRecipe : '';
	
	dialog.savestatus = dialog.add("checkbox", undefined, "Save and close when done");
	if (saveStatus !== undefined) {
		dialog.savestatus.value = (saveStatus.toLowerCase() === "true");
	} else {
		dialog.savestatus.value
	}

	var buttons = dialog.add( "group" );
	var submit = buttons.add("button", undefined, undefined, { name: "submit" });
	submit.text = "Use this recipe";
	
	submit.onClick = function () {
		thisRecipe = dialog.edittext1.text;
		saveStatus = dialog.savestatus.value.toString();
		dialog.close();
	};
	
	if (runmode != "edit") {
		var without = buttons.add("button", undefined, undefined, { name: "without" });
		without.text = "Use default settings";
		
		without.onClick = function () {
			thisRecipe = "none";
			saveStatus = false;
			dialog.close();
		};
	}
	
	dialog.show();

	return {
		"recipe": thisRecipe,
		"savestatus": saveStatus
	};
}

function getRecipe() {
	// Retrieve recipe from action or dialog
	if (!app.playbackParameters.count) {
		//normal run (from scripts menu)

		var result = displayDialog();
		
		if (!result.recipe || result.recipe == '') { isCancelled = true; return } else {
			var d = new ActionDescriptor;
			d.putString(stringIDToTypeID('recipe'), result.recipe);
			d.putString(stringIDToTypeID('savestatus'), result.savestatus);
			app.playbackParameters = d;		
			return result;
		}
	}
	else {
		var recipe = app.playbackParameters.getString(stringIDToTypeID('recipe'));
		var savestatus = app.playbackParameters.getString(stringIDToTypeID('savestatus'));
		
		if (app.playbackDisplayDialogs == DialogModes.ALL) {
			// user run action in dialog mode (edit action step)
			var result = displayDialog(recipe, savestatus, "edit");
			if (!result.recipe || result.recipe == "") { isCancelled = true; return } else {
				var d = new ActionDescriptor;
				d.putString(stringIDToTypeID('recipe'), result.recipe);
				d.putString(stringIDToTypeID('savestatus'), result.savestatus);
				app.playbackParameters = d;
			}
			executeScript = false;
			return result;
		}
		if (app.playbackDisplayDialogs != DialogModes.ALL) {
			// user run script without recording
			return {
				"recipe": recipe,
				"savestatus": savestatus
			};
		}
	}
}

function processRecipe(runtimesettings) {
	// Process the recipe and change settings
	var thisRecipe = runtimesettings.recipe;
	var saveStatus = runtimesettings.savestatus;
	save = (saveStatus.toLowerCase() === "true");
	thisRecipe = thisRecipe.replace(/\s+/g, ""); // Removes spaces
	thisRecipe = thisRecipe.replace(/;+$/, ""); // Removes trailing ;
	
	// Check recipe against syntax
	const regex = new RegExp('^(true;|false;){2}[1-8];[1-5];[1-3];[1-2];[1-3];[1-2];[1-2];(true;|false;)([1-9][0-9]?;){5}([1-4][0-9]{0,2}|1000);([0-9]|([1-9][0-9])|100);([0-9]|([1-9][0-9])|100);([0-9]|([1-9][0-9])|100);([0-9]|([1-9][0-9])|100);(bottomright|topleft|random)(;true|;false){0,1}$', 'gm');
	
	if (regex.exec(thisRecipe) !== null) {
		thisRecipe = thisRecipe.split(";"); // Splits into array at ;
		fancy = (thisRecipe[0].toLowerCase() === "true");
		artifacts = (thisRecipe[1].toLowerCase() === "true");
		mask_variant_35mm = thisRecipe[2];
		mask_variant_645 = thisRecipe[3];
		mask_variant_67 = thisRecipe[4];
		mask_variant_45 = thisRecipe[5];
		mask_variant_square = thisRecipe[6];
		negative_variant_square = thisRecipe[7];
		negative_variant_645 = thisRecipe[8];
		matted_crop = (thisRecipe[9].toLowerCase() === "true");
		border_width_35mm = parseInt(thisRecipe[10]);
		border_width_645 = parseInt(thisRecipe[11]);
		border_width_67 = parseInt(thisRecipe[12]);
		border_width_45 = parseInt(thisRecipe[13]);
		border_width_square = parseInt(thisRecipe[14]);
		short_side_factor =  parseInt(thisRecipe[15]);
		movement_min_long = parseInt(thisRecipe[16]);
		movement_max_long = parseInt(thisRecipe[17]);
		movement_min_short = parseInt(thisRecipe[18]);
		movement_max_short = parseInt(thisRecipe[19]);
		movement_direction = thisRecipe[20];
	} else {
		executeScript = false;
		alert("Sorry, but that recipe is faulty! Please check it's syntax and it's settings and then try again.");
	}
}

function generateRandomInteger(min, max) {
	// Generate a number between min and max, including max
	return Math.floor(Math.random() * (max - min)) + min;
}

function thisDirection() {
    switch (movement_direction) {
        case "bottomright":
            return -1;
        case "topleft":
            return 1;
        default:
            return Math.random() < 0.3 ? -1 : 1;
    }
}

function colorCheck() {
	var do_bw = false;
	var do_color = false;

	var doc_keywords = doc.info.keywords;

	for (var a in doc_keywords) {
		if (doc_keywords[a].toString().match(/bw/i)) {
			do_bw = true;
		}
		if (doc_keywords[a].toString().match(/color/i)) {
			do_color = true;
		}
	}

	if (do_bw) {
		return "bw";
	} else if (do_color) {
		return "color";
	} else {
		var theSampler = doc.colorSamplers.add([Math.abs(doc.width / 2), Math.abs(doc.height / 2)]);
		if (theSampler.color.rgb.red === theSampler.color.rgb.green && theSampler.color.rgb.green === theSampler.color.rgb.blue) {
			return "bw";
		} else {
			return "color";
		}
	}
}

function format() {
    var aspectRatio = doc.height / doc.width;
    if (aspectRatio < 1) {
        aspectRatio = 1 / aspectRatio;
    }

    if (aspectRatio < 1.1) {
        return "square";
    } else if (aspectRatio < 1.2) {
        return "67";
    } else if (aspectRatio < 1.3) {
        return "45";
    } else if (aspectRatio < 1.4) {
        return "645";
    } else {
        return "35mm";
    }
}

function choosePath(pathKind) {
	var stagedPath;

	if (thisFormat == "square") {
		if (pathKind == "negative") {
			stagedPath = chooseRandomPath(negativeSquare);
		} else if (pathKind == "subshadow" && subshadowSquare.length > 0) {
			stagedPath = chooseRandomPath(subshadowSquare);
		} else if (pathKind == "shadow" && shadowSquare.length > 0) {
			stagedPath = chooseRandomPath(shadowSquare);
		} else {
			stagedPath = chooseRandomPath(maskSquare);
		}
	} else if (thisFormat == "67") {
		if (pathKind == "negative") {
			stagedPath = chooseRandomPath(negative67);
		} else if (pathKind == "subshadow" && subshadow67.length > 0) {
			stagedPath = chooseRandomPath(subshadow67);
		} else if (pathKind == "shadow" && shadow67.length > 0) {
			stagedPath = chooseRandomPath(shadow67);
		} else {
			stagedPath = chooseRandomPath(mask67);
		}
	} else if (thisFormat == "45") {
		if (pathKind == "negative") {
			stagedPath = chooseRandomPath(negative45);
		} else if (pathKind == "subshadow" && subshadow45.length > 0) {
			stagedPath = chooseRandomPath(subshadow45);
		} else if (pathKind == "shadow" && shadow45.length > 0) {
			stagedPath = chooseRandomPath(shadow45);
		} else {
			stagedPath = chooseRandomPath(mask45);
		}
	} else if (thisFormat == "645") {
		if (pathKind == "negative") {
			stagedPath = chooseRandomPath(negative645);
		} else if (pathKind == "subshadow" && subshadow645.length > 0) {
			stagedPath = chooseRandomPath(subshadow645);
		} else if (pathKind == "shadow" && shadow645.length > 0) {
			stagedPath = chooseRandomPath(shadow645);
		} else {
			stagedPath = chooseRandomPath(mask645);
		}
	} else if (thisFormat == "35mm") {
		if (pathKind == "negative") {
			stagedPath = chooseRandomPath(negative35mm);
		} else if (pathKind == "subshadow" && subshadow35mm.length > 0) {
			stagedPath = chooseRandomPath(subshadow35mm);
		} else if (pathKind == "shadow" && shadow35mm.length > 0) {
			stagedPath = chooseRandomPath(shadow35mm);
		} else {
			stagedPath = chooseRandomPath(mask35mm);
		}
	}

	return (stagedPath !== undefined) ? stagedPath : false;
}

function chooseRandomPath(pathArray) {
	if (pathArray && pathArray.length > 0) {
		var randomIndex = Math.floor(Math.random() * pathArray.length);
		return pathArray[randomIndex];
	}
	return undefined;
}

function createPath(thisPath, pathName) {
	var pathPoints = thisPath.split(";");
	var pathPointInfos = [];

	for (var i = 0; i < pathPoints.length; i++) {
		var pointInfo = pathPoints[i].split(" ");
		var anchor = pointInfo[1].split(",");
		var leftDirection = pointInfo[2].split(",");
		var rightDirection = pointInfo[3].split(",");

		var pathPoint = new PathPointInfo();
		pathPoint.kind = pointInfo[0];
		pathPoint.anchor = [parseFloat(anchor[0]), parseFloat(anchor[1])];
		pathPoint.leftDirection = [parseFloat(leftDirection[0]), parseFloat(leftDirection[1])];
		pathPoint.rightDirection = [parseFloat(rightDirection[0]), parseFloat(rightDirection[1])];
		pathPoint.pointType = pointInfo[4];

		pathPointInfos.push(pathPoint);
	}

	var subPathInfo = new SubPathInfo();
	subPathInfo.operation = ShapeOperation.SHAPEXOR;
	subPathInfo.closed = true;
	subPathInfo.entireSubPath = pathPointInfos;

	app.activeDocument.pathItems.add(pathName, [subPathInfo]);
}

function loadPaths() {
	var thisSubshadow = null;
	var thisShadow = null;

	// Create negative path
	var negativePath = choosePath("negative");
	createPath(negativePath, "negative");

	// Check if fancy mode is enabled and choose mask path
	if (fancy) {
		var maskPath = choosePath("mask");
		if (maskPath) {
			createPath(maskPath, "mask");
		}
	}

	// Check if fancy mode and artifacts are enabled to create subshadow path
	if (fancy && artifacts) {
		thisSubshadow = choosePath("subshadow");
		if (thisSubshadow) {
			createPath(thisSubshadow, "subshadow");
		}
	}

	// Check if fancy mode and artifacts are enabled to create shadow path
	if (fancy && artifacts) {
		thisShadow = choosePath("shadow");
		if (thisShadow) {
			createPath(thisShadow, "shadow");
		}
	}

	return { subshadow: thisSubshadow, shadow: thisShadow };
}

function createBackdropLayer() {
	// Create black backdrop and move to background
	var imageLayer = doc.activeLayer; // Save first layer to variable
	var backdrop = doc.artLayers.add();
	backdrop.name = "backdrop"; // Names backdrop layer
	doc.selection.selectAll();
	doc.selection.fill(myColor_black); // Fill the layer with black
	backdrop.moveAfter(imageLayer);
}

function doRotation(randRotation, flip, pathKind, rotateMask) {

	if (doc.height > doc.width) {
		// Portrait orientation
		if (pathKind === "negative") {
			// Random rotation or 180 flip for negative paths (if not in "45" format)
			if (flip) {
				doc.selection.rotateBoundary(270 + randRotation, AnchorPosition.MIDDLECENTER);
			} else {
				doc.selection.rotateBoundary(90 + randRotation, AnchorPosition.MIDDLECENTER);
			}
		} else if (rotateMask) {
			// Rotate mask
			doc.selection.rotateBoundary(270, AnchorPosition.MIDDLECENTER);
		} else {
			// Rotate non-negative path
			doc.selection.rotateBoundary(90, AnchorPosition.MIDDLECENTER);
		}
	} else {
		// Landscape orientation
		if (pathKind === "negative") {
			// Random rotation for negative paths
			doc.selection.rotateBoundary(randRotation, AnchorPosition.MIDDLECENTER);
		} else if (rotateMask) {
			// Rotate mask
			doc.selection.rotateBoundary(180, AnchorPosition.MIDDLECENTER);
		}
	}
}


function adjustSelection(side) {
    // Use conditional operator for direct assignment
    var scale = side > 0 ? side / 3600 : doc_scale;

    // Resize the selection boundary
    doc.selection.resizeBoundary(scale * 100, scale * 100, AnchorPosition.TOPLEFT);

    // Get the bounds of the selection
    var selectionBounds = doc.selection.bounds;

    // Calculate the middle horizontal and vertical positions of the selection
    var middleHorizontal = (selectionBounds[2] - selectionBounds[0]) / 2 + selectionBounds[0];
    var middleVertical = (selectionBounds[3] - selectionBounds[1]) / 2 + selectionBounds[1];

    // Calculate the delta values to translate the selection to the center of the document
    var deltaX = doc.width / 2 - middleHorizontal;
    var deltaY = doc.height / 2 - middleVertical;

    // Translate the selection boundary
    doc.selection.translateBoundary(UnitValue(deltaX, "px"), UnitValue(deltaY, "px"));
}


function MoveLayerTo(fLayer,fX,fY) {
  	var Position = fLayer.bounds;
  	Position[0] = fX - Position[0];
  	Position[1] = fY - Position[1];
  	fLayer.translate(-Position[0],-Position[1]);
}

function moveNeg() {
	var movement_horisontal = 0;
	var movement_vertical = 0;

	switch (thisFormat) {
		case "645":
			if (ratio > 1) {
				movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * (doc.width * border_width_645 * 0.006 + doc.width * 0.003);
			} else {
				movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * (doc.height * border_width_645 * 0.006 + doc.height * 0.003);
			}
			break;

		case "67":
			if (ratio > 1) {
				movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * (doc.width * border_width_67 * 0.008 + doc.width * 0.003);
				movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * (doc.height * border_width_67 * short_side_factor / ratio * 0.008 + doc.height * 0.003);
			} else {
				movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * (doc.width * border_width_67 * short_side_factor * ratio * 0.008 + doc.width * 0.003);
				movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * (border_width_67 * doc.height * 0.008 + doc.height * 0.003);
			}
			break;

		case "45":
			if (ratio > 1) {
				movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.01;
				movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * border_width_45 / ratio * 0.01;
			} else {
				movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * border_width_45 * ratio * 0.01;
				movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.01;
			}
			break;

		case "square":
			movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * (doc.height * border_width_square * 0.008 + doc.height * 0.01);
			movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * (doc.width * border_width_square * short_side_factor * 0.008 + doc.width * 0.01);
			break;

		default:
			if (ratio > 1) {
				movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * (doc.width * border_width_35mm * 0.01 + doc.width * 0.0015);
				movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * (doc.height * border_width_35mm * short_side_factor / ratio * 0.008 + doc.height * 0.002);
			} else {
				movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * (doc.width * border_width_35mm * short_side_factor * ratio * 0.008 + doc.width * 0.002);
				movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * (doc.height * border_width_35mm * 0.01 + doc.height * 0.0015);
			}
			break;
	}

	// Move the negative layer
	MoveLayerTo(doc.artLayers.getByName("negative"), movement_horisontal, movement_vertical);
}


function moveNeg_fancy() {
	var movement_horisontal, movement_vertical;

	switch (thisFormat) {
		case "645":
			if (ratio > 1) {
				// Portrait
				switch (mask_variant_645) {
					case "5":
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.02 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.004 * thisDirection();
						break;
					case "4":
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.028 * thisDirection();
						movement_vertical = 0;
						break;
					case "3":
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.006 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.004 * thisDirection();
						break;
					case "2":
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.008 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.004 * thisDirection();
						break;
					default:
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.022 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.004 * thisDirection();
				}
			} else {
				// Landscape
				switch (mask_variant_645) {
					case "5":
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.004 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.02 * thisDirection();
						break;
					case "4":
						movement_horisontal = 0;
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.028 * thisDirection();
						break;
					case "3":
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.004 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.006 * thisDirection();
						break;
					case "2":
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.004 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.008 * thisDirection();
						break;
					default:
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.004 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.022 * thisDirection();
				}
			}
			break;
		
		case "67":
			if (ratio > 1) {
				// Portrait
				switch (mask_variant_67) {
					case "3":
						movement_horisontal = 0;
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.018 * thisDirection();
						break;
					case "2":
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.006 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.005 * thisDirection();
						break;
					default:
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.02 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.005 * doc.height * 0.028 * thisDirection();
				}
			} else {
				// Landscape
				switch (mask_variant_67) {
					case "3":
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.018 * thisDirection();
						movement_vertical = 0;
						break;
					case "2":
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.005 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.007 * thisDirection();
						break;
					default:
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.005 * doc.width * 0.028 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.02 * thisDirection();
				}
			}
			break;
		
		case "45":
			if (ratio > 1) {
				switch (mask_variant_45) {
					case "2":
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.005 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.006 * thisDirection();
						break;
					default:
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.006 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.01 * thisDirection();
						break;
				}
			} else {
				switch (mask_variant_45) {
					case "2":
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.015 * doc.width * 0.006 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.005 * thisDirection();
						break;
					default:
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.01 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.006 * thisDirection();
						break;
				}
			}
			break;
		
		case "square":
			switch (mask_variant_square) {
				case "3":
					movement_horisontal = 0;
					movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.018 * thisDirection();
					break;
				case "2":
					movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.008 * thisDirection();
					movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.01 * thisDirection();
					break;
				default:
					movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.016 * thisDirection();
					movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.018 * thisDirection();
					break;
			}
			break;
		
		case "35mm":
			if (ratio > 1) {
				// Portrait
				switch (mask_variant_35mm) {
					case "8":
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.02 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.03 * thisDirection();
						break;
					case "7":
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.021 * thisDirection();
						movement_vertical = 0;
						break;
					case "6":
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.008 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.008 * thisDirection();
						break;
					case "5":
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.016 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.012 * thisDirection();
						break;
					case "4":
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.009 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.009 * thisDirection();
						break;
					case "3":
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.018 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.025 * thisDirection();
						break;
					case "2":
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.02 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.013 * thisDirection();
						break;
					default:
						movement_horisontal = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.width * 0.018 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.height * 0.012 * thisDirection();
				}
			} else {
				// Landscape
				switch (mask_variant_35mm) {
					case "8":
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.03 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.02 * thisDirection();
						break;
					case "7":
						movement_horisontal = 0;
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.021 * thisDirection();
						break;
					case "6":
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.008 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.008 * thisDirection();
						break;
					case "5":
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.012 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.016 * thisDirection();
						break;
					case "4":
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.009 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.009 * thisDirection();
						break;
					case "3":
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.025 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.018 * thisDirection();
						break;
					case "2":
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.013 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.02 * thisDirection();
						break;
					default:
						movement_horisontal = generateRandomInteger(movement_min_short, movement_max_short) * 0.01 * doc.width * 0.012 * thisDirection();
						movement_vertical = generateRandomInteger(movement_min_long, movement_max_long) * 0.01 * doc.height * 0.018 * thisDirection();
				}
			}
			break;
		
		default:
			// Default case
			movement_horisontal = 0;
			movement_vertical = 0;
	}

	// Move the negative layer
	MoveLayerTo(doc.artLayers.getByName("negative"), movement_horisontal, movement_vertical);
}

function spatterFilter(radiusValue, smoothnessValue) {
	// Spatter filter ID
	var spatterFilterID = stringIDToTypeID("spatter");

	// Create action descriptor
	var actionDescriptor = new ActionDescriptor();
	actionDescriptor.putEnumerated(charIDToTypeID("GEfk"), charIDToTypeID("GEft"), spatterFilterID);
	actionDescriptor.putInteger(stringIDToTypeID("sprayRadius"), radiusValue);
	actionDescriptor.putInteger(stringIDToTypeID("smoothness"), smoothnessValue);

	// Execute action
	executeAction(charIDToTypeID("GEfc"), actionDescriptor, DialogModes.NO);
}

function colorOverlay(myColor) {

	var desc = new ActionDescriptor();
	var ref = new ActionReference();
	ref.putProperty(stringIDToTypeID("property"), stringIDToTypeID("layerEffects"));
	ref.putEnumerated(stringIDToTypeID("layer"), stringIDToTypeID("ordinal"), stringIDToTypeID("targetEnum"));
	desc.putReference(stringIDToTypeID("null"), ref);

	var desc2 = new ActionDescriptor();
	var desc3 = new ActionDescriptor();
	desc3.putBoolean(stringIDToTypeID("enabled"), true);
	desc3.putBoolean(stringIDToTypeID("present"), true);
	desc3.putBoolean(stringIDToTypeID("showInDialog"), true);
	desc3.putEnumerated(stringIDToTypeID("mode"), stringIDToTypeID("blendMode"), stringIDToTypeID("multiply"));

	var desc4 = new ActionDescriptor();
	desc4.putDouble(stringIDToTypeID("red"), myColor.rgb.red);
	desc4.putDouble(stringIDToTypeID("grain"), myColor.rgb.green);
	desc4.putDouble(stringIDToTypeID("blue"), myColor.rgb.blue);
	desc3.putObject(stringIDToTypeID("color"), stringIDToTypeID("RGBColor"), desc4);

	desc3.putUnitDouble(stringIDToTypeID("opacity"), stringIDToTypeID("percentUnit"), 100.000000);
	desc2.putObject(stringIDToTypeID("solidFill"), stringIDToTypeID("solidFill"), desc3);
	desc2.putUnitDouble(stringIDToTypeID("scale"), stringIDToTypeID("percentUnit"), 416.666667);
	desc.putObject(stringIDToTypeID("to"), stringIDToTypeID("layerEffects"), desc2);

	executeAction(stringIDToTypeID("set"), desc, DialogModes.NO);
}


function rasterizeLayer() {
	var desc = new ActionDescriptor();
	var ref = new ActionReference();
	ref.putEnumerated(stringIDToTypeID("layer"), stringIDToTypeID("ordinal"), stringIDToTypeID("targetEnum"));
	desc.putReference(stringIDToTypeID("null"), ref);
	desc.putEnumerated(stringIDToTypeID("what"), stringIDToTypeID("rasterizeItem"), stringIDToTypeID("layerStyle"));
	executeAction(stringIDToTypeID("rasterizeLayer"), desc, DialogModes.NO);
}

function renderHalation(negativePath, delta, randRotation, flip) {

    doc.selection.deselect();

    var halationLayers = [];
    var thresholds = [250, 250, 245, 245, 235];
    var colors = [myColor_halation, myColor_halation_glow, myColor_halation, myColor_halation_glow, myColor_halation_glow];
    var blurs;

	switch (thisFormat) {
		case "35mm":
			blurs = [20, 60, 8, 16, 5];
			break;
		case "645":
			blurs = [11, 33, 5, 10, 3];
			break;
		default:
			blurs = [8, 16, 4, 8, 3];
			break;
	}

	for (var i = 0; i < 5; i++) {
		var layer = negativelayer.duplicate();
		layer.name = "halation" + (i + 1);
		halationLayers.push(layer);
		layer.threshold(thresholds[i]);
		doc.activeLayer = layer;
		colorOverlay(colors[i]);
		rasterizeLayer();
		layer.applyGaussianBlur(Math.round(doc_scale * blurs[i]));
	}

	// Set blend mode for first layer
	halationLayers[0].blendMode = BlendMode.SCREEN;

	for (var i = 1; i < halationLayers.length; i++) {
		halationLayers[i].blendMode = BlendMode.SCREEN;
		doc.activeLayer = halationLayers[i-1]; // Make the layer at index i-1 the active layer
		halationLayers[i-1].merge();
	}

	// Curve to darken the brightest parts
	halationLayers[4].adjustCurves([[0, 0], [65, 80], [generateRandomInteger(180, 190), 150], [255, 255]]);

    negativePath.makeSelection(feather, true);
    doRotation(randRotation, flip, "negative");
    adjustSelection();
    doc.selection.contract(new UnitValue(feather, 'px'));

    if (delta != 0) {
        doc.selection.translateBoundary(UnitValue(ratio > 1 ? 0 : delta, "px"), UnitValue(ratio > 1 ? delta : 0, "px"));
    }

    doc.selection.fill(myColor_black, ColorBlendMode.CLEAR);
    doc.selection.deselect();
    halationLayers[4].merge();

}

function run_fancy() {
    if (ratio > 1) {
        doc.resizeCanvas(UnitValue(110,"%"), UnitValue(10 / ratio + 100,"%"), AnchorPosition.MIDDLECENTER);
    } else {
        doc.resizeCanvas(UnitValue(10 * ratio + 100,"%"), UnitValue(110,"%"), AnchorPosition.MIDDLECENTER);
    }

	var randRotation = (Math.random() * 0.2 - 0.1) * 0.1; // Random rotation between -0.01 and 0.01 degrees
	var flip = Math.random() > 0.5 && thisFormat !== "45" ? true : false;

    var negativePath = doc.pathItems.getByName('negative');
    negativePath.makeSelection(feather, true);
    doRotation(randRotation, flip, "negative");
    adjustSelection();
    doc.selection.invert();
    doc.selection.fill(myColor_black);

	if (halation) {
		var delta = 0;
		renderHalation(negativePath, delta, randRotation, flip);
	}

    createBackdropLayer();

    var masklayer = doc.artLayers.add();
    masklayer.name = "mask";

    var shadowPath = thisShadow ? doc.pathItems.getByName('shadow') : null;
    var subshadowPath = thisSubshadow ? doc.pathItems.getByName('subshadow') : null;

    switch (artifacts) {
        case true:
			// Background fill with subshadow color
			doc.selection.selectAll();
			doc.selection.fill(myColor_subshadow);
            
            if (thisShadow) {
				// Add shadow
                shadowPath.makeSelection(feather * 2.5, true);
                doRotation(randRotation, flip, "shadow", rotate_mask);
                adjustSelection();
                doc.selection.fill(myColor_shadow);
				doc.selection.deselect();
            }
            
			// Add noise and blur it
			masklayer.applyAddNoise(20, NoiseDistribution.GAUSSIAN, true);
			masklayer.applyGaussianBlur(doc_scale*5);
			masklayer.adjustBrightnessContrast(5, 20);

			// Fill the outside of the subshadow with white, invert the selection back
			subshadowPath.makeSelection(0, true);
			doRotation(randRotation, flip, "subshadow", rotate_mask);
			adjustSelection();
			doc.selection.invert();
			doc.selection.fill(myColor_white);
			doc.selection.invert();

			// Blur perpendicular to short edge and use high pass to contrast edges
			var edgemask = masklayer.duplicate();
			edgemask.blendMode = BlendMode.HARDLIGHT;
			edgemask.applyHighPass(Math.round(doc_scale * 10));
			edgemask.applyMotionBlur(ratio > 1 ? 0 : 90, doc_scale * 80);
			masklayer.applyGaussianBlur(doc_scale*5);
			edgemask.adjustBrightnessContrast(0, generateRandomInteger(10, 30));
			edgemask.merge();

			// Soften edges in one direction
			doc.selection.expand(doc_scale * 10);
			doc.selection.feather(doc_scale * 40);
			masklayer.applyMotionBlur(ratio > 1 ? 0 : 90, doc_scale * 25);
			masklayer.applyMotionBlur(ratio > 1 ? 0 : 90, doc_scale * 50);
			doc.selection.contract(doc_scale * 10);

			// Add noise and fill the outside with white again
			subshadowPath.makeSelection(0, true);
			doRotation(randRotation, flip, "subshadow", rotate_mask);
			adjustSelection();
			masklayer.applyAddNoise(doc_scale*2, NoiseDistribution.GAUSSIAN, true);
			doc.selection.invert();
			doc.selection.fill(myColor_white);
			doc.selection.deselect();
            break;

        default:
            doc.selection.selectAll();
            doc.selection.fill(myColor_white);
            break;
    }

    var maskPath = doc.pathItems.getByName('mask');
    maskPath.makeSelection(feather, true);
    doRotation(randRotation, flip, "mask", rotate_mask);
    adjustSelection();
    doc.selection.fill(myColor_black, ColorBlendMode.CLEAR);
    doc.selection.deselect();

    if (movement_min_long + movement_max_long + movement_min_short + movement_max_short > 0) {
        moveNeg_fancy();
    }

    doc.flatten();

    if (doc.bitsPerChannel == BitsPerChannelType.EIGHT || doc.bitsPerChannel == BitsPerChannelType.SIXTEEN && force_8_bit) {
        doc.bitsPerChannel = BitsPerChannelType.EIGHT;
        maskPath.makeSelection(feather*2, true);
        doRotation(randRotation, flip, "mask", rotate_mask);
        adjustSelection();
        doc.selection.invert();
        spatterFilter(2, 4);
    }
}

function run_crop() {
    // Convert to decimal factor
    short_side_factor *= 0.01;

    // Decide new document width
    var finished_width = 100;
    var finished_height = 100;
    var border_width;

    switch (thisFormat) {
        case "35mm":
            border_width = border_width_35mm;
            break;
        case "645":
            border_width = border_width_645;
            break;
        case "67":
            border_width = border_width_67;
            break;
        case "45":
            border_width = border_width_45;
            break;
        case "square":
            border_width = border_width_square;
            break;
        default:
            break;
    }

	switch (thisFormat) {
		case "square":
			finished_width = border_width + 100;
			finished_height = border_width * short_side_factor + 100;
			break;
		case "645":
			finished_width = ratio > 1 ? border_width + 100 : 100;
			finished_height = ratio > 1 ? 100 : border_width + 100;
			break;
		case "45":
			finished_width = ratio > 1 ? 100.5 : border_width * ratio + 100;
			finished_height = ratio > 1 ? border_width / ratio + 100 : 100.5;
			break;
		default:
			finished_width = ratio > 1 ? border_width + 100 : border_width * short_side_factor * ratio + 100;
			finished_height = ratio > 1 ? border_width * short_side_factor / ratio + 100 : border_width + 100;
			break;
	}

	var randRotation = (Math.random() * 0.2 - 0.1) * 0.1; // Random rotation between -0.01 and 0.01 degrees
	var flip = Math.random() > 0.5 && thisFormat !== "45" ? true : false;

    // Calculate the new dimensions
	var newWidth = finished_width / 100 * doc.width;
	var newHeight = finished_height / 100 * doc.height;

	// Store the new dimensions
	var resizedWidth = UnitValue(newWidth ,"px");
	var resizedHeight = UnitValue(newHeight, "px");

	// Calculate the final dimensions
	var finalWidth = (ratio > 1 ? 100 + matted_border_size : matted_border_size * ratio + 100) / 100 * resizedWidth;
	var finalHeight = (ratio > 1 ? matted_border_size / ratio + 100 : matted_border_size + 100) / 100 * resizedHeight;

	// Resize the canvas
	doc.resizeCanvas(UnitValue(finalWidth,"px"), UnitValue(finalHeight,"px"), AnchorPosition.MIDDLECENTER);

    // Creates the negative layer content
    var negativePath = doc.pathItems.getByName('negative');
    negativePath.makeSelection(feather, true); // Make selection from path
    doRotation(randRotation, flip, "negative", rotate_mask);
    adjustSelection(); //Scales and centers the selection

    // For 645 we need to move the negative shape and not the entire layer
	var delta = 0;
    if (thisFormat == "645" && movement_min_long + movement_max_long + movement_min_short + movement_max_short > 0 ) {
        delta = generateRandomInteger(movement_min_short, movement_max_short) * -0.0001 * doc.height * thisDirection();
        doc.selection.translateBoundary(UnitValue(ratio > 1 ? 0 : delta, "px"), UnitValue(ratio > 1 ? delta : 0, "px"));
    }

    doc.selection.invert(); // Invert selection
    doc.selection.fill(myColor_black); // Fill with black

	if (halation) {
		renderHalation(negativePath, delta, randRotation, flip);
	}

    createBackdropLayer();

    if (movement_min_long + movement_max_long + movement_min_short + movement_max_short > 0) {
        moveNeg();
    }

	doc.resizeCanvas(resizedWidth, resizedHeight, AnchorPosition.MIDDLECENTER);

	doc.flatten(); // Flatten all layers

	if (matted_crop == true) {
        backgroundColor.rgb.hexValue = myColor_white.rgb.hexValue; // Sets background color to white
        doc.resizeCanvas(UnitValue(ratio > 1 ? 100 + matted_border_size : matted_border_size * ratio + 100,"%"), UnitValue(ratio > 1 ? matted_border_size / ratio + 100 : matted_border_size + 100,"%"), AnchorPosition.MIDDLECENTER); // Enlarge "negative" space
    }
	

}

function saveClose() {
	var file_ending = doc.name.split('.').pop().toLowerCase();
	var fPath = doc.path;
	
	if (file_ending == "tif" || file_ending == "tiff") {
		// Save out the image as tiff
		var tiffFile = new File(fPath);
		tiffSaveOptions = new TiffSaveOptions();
		tiffSaveOptions.imageCompression = TIFFEncoding.NONE;
		tiffSaveOptions.layers = false;
		tiffSaveOptions.embedColorProfile = true;
		doc.saveAs(tiffFile, tiffSaveOptions, false, Extension.LOWERCASE);
	} else {
		// Save out the image as jpeg
		var jpgFile = new File(fPath);
		jpgSaveOptions = new JPEGSaveOptions();
		jpgSaveOptions.formatOptions = FormatOptions.OPTIMIZEDBASELINE;
		jpgSaveOptions.embedColorProfile = true;
		jpgSaveOptions.matte = MatteType.NONE;
		jpgSaveOptions.quality = 12;
		doc.saveAs(jpgFile, jpgSaveOptions, false, Extension.LOWERCASE);
	}
	doc.close();
}

function cleanup() {
    doc.selection.deselect();
    doc.pathItems.getByName('negative').remove();

    if (fancy) {
        doc.pathItems.getByName('mask').remove();
    }
    if (fancy && artifacts) {
        if (thisSubshadow) {
            doc.pathItems.getByName('subshadow').remove();
        }
        if (thisShadow) {
            doc.pathItems.getByName('shadow').remove();
        }
    }
    if (save) {
        saveClose();
    }
}


// Run in recipe mode. This must be executed here, so mask variants are known before we get into the library.
if (legacy == false ) {
	var executeScript = true;
	var isCancelled = false;
	var runtimesettings = getRecipe();
	if (runtimesettings.recipe != "none") { processRecipe(runtimesettings); }
}



// PATH LIBRARY ------------------------------------------------------


// 35mm

var negative35mm = [];
var mask35mm = [];
var subshadow35mm = [];
var shadow35mm = [];

negative35mm[0] = "PointKind.CORNERPOINT 288.436452388763,212.980073928833 288.436452388763,212.980073928833 288.436452388763,212.980073928833 PathPoint;PointKind.SMOOTHPOINT 296.380661964417,197.326508998871 301.475818395615,193.179148674011 290.760092973709,201.901563644409 PathPoint;PointKind.SMOOTHPOINT 316.877416610718,191.144060134888 329.467491149902,190.766405105591 310.720105409622,191.328639030457 PathPoint;PointKind.CORNERPOINT 376.708240747452,191.416207790375 376.708240747452,191.416207790375 376.708240747452,191.416207790375 PathPoint;PointKind.SMOOTHPOINT 438.113886356354,191.695672512054 444.035753250122,191.680094242096 425.039823293686,191.730605602264 PathPoint;PointKind.SMOOTHPOINT 466.455008029938,191.824547290802 471.602918148041,192.266403675079 461.306743860245,191.382690906525 PathPoint;PointKind.SMOOTHPOINT 496.377678155899,190.391818523407 500.463433504105,190.910622119904 492.291922807693,189.873250961304 PathPoint;PointKind.SMOOTHPOINT 521.569510936737,190.506531238556 530.741571426392,191.522187232971 512.397804498672,189.490639209747 PathPoint;PointKind.SMOOTHPOINT 605.018054485321,190.886310577393 612.189723491669,190.790008544922 597.846031427383,190.982848644257 PathPoint;PointKind.SMOOTHPOINT 649.110931396484,189.518019199371 662.82936835289,188.940679073334 635.392494440079,190.095359325409 PathPoint;PointKind.CORNERPOINT 745.162649393082,188.386234283447 745.162649393082,188.386234283447 745.162649393082,188.386234283447 PathPoint;PointKind.SMOOTHPOINT 867.980313539505,187.376243114471 872.599978685379,187.233442306519 831.444313764572,188.505195617676 PathPoint;PointKind.SMOOTHPOINT 1022.28874230385,186.509524822235 1028.8709154129,187.578760623932 1016.13815808296,185.510155200958 PathPoint;PointKind.CORNERPOINT 1036.45186805725,188.142882823944 1036.45186805725,188.142882823944 1036.45186805725,188.142882823944 PathPoint;PointKind.CORNERPOINT 1053.7713637352,188.22171831131 1053.7713637352,188.22171831131 1053.7713637352,188.22171831131 PathPoint;PointKind.SMOOTHPOINT 1088.41743612289,186.810468673706 1097.04602742195,186.943120002747 1076.30603933334,186.624001502991 PathPoint;PointKind.SMOOTHPOINT 1115.1840903759,186.932262420654 1121.42354154587,188.067351818085 1109.80817103386,185.954135894775 PathPoint;PointKind.SMOOTHPOINT 1127.77274870872,188.558539390564 1128.31373953819,188.53186750412 1126.08321452141,188.641151428223 PathPoint;PointKind.SMOOTHPOINT 1140.37592315674,187.04673910141 1145.4193880558,185.990485191345 1136.06853151321,187.948862552643 PathPoint;PointKind.CORNERPOINT 1289.95316052437,187.727462291718 1289.95316052437,187.727462291718 1289.95316052437,187.727462291718 PathPoint;PointKind.SMOOTHPOINT 1516.69523382187,185.621563434601 1522.45565319061,185.893002986908 1508.05779123306,185.214640140533 PathPoint;PointKind.SMOOTHPOINT 1524.56084394455,187.226125240326 1533.36221241951,186.954921722412 1520.1132478714,187.363261222839 PathPoint;PointKind.CORNERPOINT 1534.01472949982,185.700398921967 1534.01472949982,185.700398921967 1534.01472949982,185.700398921967 PathPoint;PointKind.CORNERPOINT 1612.73951673508,186.058699131012 1612.73951673508,186.058699131012 1612.73951673508,186.058699131012 PathPoint;PointKind.SMOOTHPOINT 1620.60477280617,187.663260936737 1624.6083881855,188.292528629303 1616.60186553001,187.034465312958 PathPoint;PointKind.CORNERPOINT 1633.20830130577,186.15193271637 1633.20830130577,186.15193271637 1633.20830130577,186.15193271637 PathPoint;PointKind.CORNERPOINT 1771.76391267776,186.782380580902 1771.76391267776,186.782380580902 1771.76391267776,186.782380580902 PathPoint;PointKind.CORNERPOINT 1951.26417422295,186.030138969421 1951.26417422295,186.030138969421 1951.26417422295,186.030138969421 PathPoint;PointKind.CORNERPOINT 1959.12907624245,187.63493680954 1959.12907624245,187.63493680954 1959.12907624245,187.63493680954 PathPoint;PointKind.CORNERPOINT 1968.5833158493,186.10921049118 1968.5833158493,186.10921049118 1968.5833158493,186.10921049118 PathPoint;PointKind.CORNERPOINT 2159.10484933853,185.407244205475 2159.10484933853,185.407244205475 2159.10484933853,185.407244205475 PathPoint;PointKind.CORNERPOINT 2499.20362019539,185.386001110077 2499.20362019539,185.386001110077 2499.20362019539,185.386001110077 PathPoint;PointKind.SMOOTHPOINT 2511.79227852821,187.012278079987 2516.2526204586,187.100554943085 2504.67690372467,186.871601581573 PathPoint;PointKind.SMOOTHPOINT 2524.39580702782,185.500713825226 2534.13116359711,186.100477218628 2514.65974235535,184.90071439743 PathPoint;PointKind.CORNERPOINT 2770.02440834045,185.049652099609 2770.02440834045,185.049652099609 2770.02440834045,185.049652099609 PathPoint;PointKind.CORNERPOINT 2784.18788814545,186.683010101318 2784.18788814545,186.683010101318 2784.18788814545,186.683010101318 PathPoint;PointKind.CORNERPOINT 2795.21659517288,185.164128780365 2795.21659517288,185.164128780365 2795.21659517288,185.164128780365 PathPoint;PointKind.CORNERPOINT 2804.65596461296,186.776007652283 2804.65596461296,186.776007652283 2804.65596461296,186.776007652283 PathPoint;PointKind.CORNERPOINT 2821.9828953743,185.285922527313 2821.9828953743,185.285922527313 2821.9828953743,185.285922527313 PathPoint;PointKind.CORNERPOINT 2996.75196552277,186.08135843277 2996.75196552277,186.08135843277 2996.75196552277,186.08135843277 PathPoint;PointKind.CORNERPOINT 3506.90383934975,185.265151500702 3506.90383934975,185.265151500702 3506.90383934975,185.265151500702 PathPoint;PointKind.CORNERPOINT 3790.32072091103,184.986158847809 3790.32072091103,184.986158847809 3790.32072091103,184.986158847809 PathPoint;PointKind.SMOOTHPOINT 4010.75040841103,185.989305019379 4027.0952000618,185.93596124649 3928.56087231636,186.256968021393 PathPoint;PointKind.SMOOTHPOINT 4210.71166539192,186.899217605591 4216.31453180313,186.509524822235 4205.10879898071,187.288910388947 PathPoint;PointKind.SMOOTHPOINT 4333.52260255814,187.457911014557 4345.41200900078,186.888596057892 4321.6328420639,188.027462005615 PathPoint;PointKind.SMOOTHPOINT 4459.48247456551,188.031238555908 4473.17754411697,187.993237018585 4445.78705096245,188.069476127625 PathPoint;PointKind.SMOOTHPOINT 4517.74591231346,186.727620601654 4523.12855863571,186.990562915802 4512.3636200428,186.464442253113 PathPoint;PointKind.SMOOTHPOINT 4527.18563580513,188.339499473572 4532.29743266106,188.646344184875 4522.07419300079,188.032654762268 PathPoint;PointKind.SMOOTHPOINT 4542.93809914589,186.84209728241 4552.00429821014,186.688910961151 4533.87154603004,186.995283603668 PathPoint;PointKind.SMOOTHPOINT 4742.89935612679,187.752245903015 4729.44681191444,187.488123416901 4726.81514644623,187.436195850372 PathPoint;PointKind.SMOOTHPOINT 5062.52226138115,189.206689834595 5209.03447413445,188.714794158936 5018.35220122337,189.355155467987 PathPoint;PointKind.SMOOTHPOINT 5561.63799309731,191.478284835815 5561.63799309731,191.478284835815 5561.5816988945,194.060029029846 PathPoint;PointKind.SMOOTHPOINT 5612.02236676216,191.70747423172 5620.59112334251,191.874822616577 5603.45325613022,191.540361881256 PathPoint;PointKind.SMOOTHPOINT 5640.35605335236,193.405505657196 5642.49912762642,193.752004146576 5638.21297907829,193.059007167816 PathPoint;PointKind.SMOOTHPOINT 5649.78161478043,198.155225753784 5654.88739275932,204.325164794922 5644.67619085312,191.985286712646 PathPoint;PointKind.SMOOTHPOINT 5654.43385267258,213.866147041321 5655.17913126945,221.84788608551 5654.02350687981,209.472838878632 PathPoint;PointKind.SMOOTHPOINT 5655.82987809181,253.096715450287 5653.56642627716,267.759407997131 5656.18640804291,250.78688287735 PathPoint;PointKind.SMOOTHPOINT 5655.63691997528,295.457808017731 5656.24801301956,301.713663578033 5655.025826931,289.202188491821 PathPoint;PointKind.SMOOTHPOINT 5655.54415845871,315.854012012482 5654.09219288826,325.54464006424 5656.33227729797,310.595401763916 PathPoint;PointKind.SMOOTHPOINT 5656.96142697334,350.377818584442 5657.34592700005,363.00801897049 5656.63888597488,339.775861740112 PathPoint;PointKind.SMOOTHPOINT 5657.79344820976,513.554531574249 5657.76972675323,512.451070785522 5657.69643807411,509.066101551056 PathPoint;PointKind.CORNERPOINT 5659.85721492767,752.046987056732 5659.85721492767,752.046987056732 5659.85721492767,752.046987056732 PathPoint;PointKind.SMOOTHPOINT 5659.55025219917,819.511281490326 5657.20890903473,825.769969463348 5661.89124131203,813.252829551697 PathPoint;PointKind.SMOOTHPOINT 5659.4858148098,833.631803035736 5660.52955889702,838.516534805298 5658.44207072258,828.746835231781 PathPoint;PointKind.SMOOTHPOINT 5659.42881250381,846.183167934418 5659.03475308418,850.726593971252 5659.82251787186,841.639977931976 PathPoint;PointKind.CORNERPOINT 5659.26417851448,882.268814086914 5659.26417851448,882.268814086914 5659.26417851448,882.268814086914 PathPoint;PointKind.CORNERPOINT 5657.61854672432,897.950939178467 5657.61854672432,897.950939178467 5657.61854672432,897.950939178467 PathPoint;PointKind.SMOOTHPOINT 5659.11476874352,915.216382980347 5659.94324946404,918.764215946198 5658.0179169178,910.520006656647 PathPoint;PointKind.SMOOTHPOINT 5659.00749111176,938.750428199768 5660.86944842339,944.400855541229 5655.58381223679,928.361374378204 PathPoint;PointKind.SMOOTHPOINT 5658.94305372238,952.870949745178 5659.5810546875,959.592501163483 5658.30540680885,946.149398326874 PathPoint;PointKind.CORNERPOINT 5658.5861697197,1031.31768846512 5658.5861697197,1031.31768846512 5658.5861697197,1031.31768846512 PathPoint;PointKind.CORNERPOINT 5659.87491750717,1094.08230209351 5659.87491750717,1094.08230209351 5659.87491750717,1094.08230209351 PathPoint;PointKind.CORNERPOINT 5660.82837843895,1230.58689260483 5660.82837843895,1230.58689260483 5660.82837843895,1230.58689260483 PathPoint;PointKind.CORNERPOINT 5661.9029250145,1340.41959667206 5661.9029250145,1340.41959667206 5661.9029250145,1340.41959667206 PathPoint;PointKind.SMOOTHPOINT 5661.40442037582,1881.61837244034 5661.39981770515,1886.32914686203 5661.68199682236,1580.26547336578 PathPoint;PointKind.SMOOTHPOINT 5661.391320467,1895.79483413696 5661.93231129646,1899.36391019821 5660.71756029129,1891.35195875168 PathPoint;PointKind.SMOOTHPOINT 5661.38140702248,1906.64840364456 5661.30918049812,1984.94573259354 5661.38459348679,1903.02244329453 PathPoint;PointKind.SMOOTHPOINT 5661.15729236603,2149.72983980179 5661.15445995331,2152.99230718613 5661.23341345787,2066.98255443573 PathPoint;PointKind.SMOOTHPOINT 5661.14808702469,2159.52031040192 5660.24596357346,2163.9032330513 5661.80626893044,2156.32251644135 PathPoint;PointKind.SMOOTHPOINT 5661.13923573494,2169.18426656723 5661.03089594841,2287.15661668777 5661.14242219925,2165.96216106415 PathPoint;PointKind.SMOOTHPOINT 5660.81846499443,2517.23491811752 5660.8159866333,2520.01375102997 5660.92113995552,2406.0893907547 PathPoint;PointKind.SMOOTHPOINT 5660.81102991104,2525.55725479126 5662.34265708923,2532.6866736412 5660.22932314873,2522.84923219681 PathPoint;PointKind.SMOOTHPOINT 5660.79368138313,2544.02269744873 5660.64852023125,2701.66275167465 5660.79970026016,2537.89359235764 PathPoint;PointKind.SMOOTHPOINT 5660.43042445183,2938.57826137543 5660.42546772957,2943.5543384552 5660.5196454525,2841.80345201492 PathPoint;PointKind.SMOOTHPOINT 5660.41697049141,2953.15857791901 5659.72692394257,2958.6598315239 5661.00717449188,2948.45228815079 PathPoint;PointKind.SMOOTHPOINT 5660.40387058258,2967.41151475906 5660.34084939957,3035.52419567108 5660.40776515007,2962.7878370285 PathPoint;PointKind.CORNERPOINT 5660.30402803421,3075.69182062149 5660.30402803421,3075.69182062149 5660.30402803421,3075.69182062149 PathPoint;PointKind.CORNERPOINT 5659.91138482094,3161.9833984375 5659.91138482094,3161.9833984375 5659.91138482094,3161.9833984375 PathPoint;PointKind.SMOOTHPOINT 5658.30115818977,3169.82068443298 5657.68794083595,3175.69534444809 5658.914021492,3163.94649648666 PathPoint;PointKind.SMOOTHPOINT 5659.82570433617,3180.81044578552 5661.595962286,3186.4179148674 5658.05509233475,3175.20321273804 PathPoint;PointKind.CORNERPOINT 5659.53998470306,3243.56797838211 5659.53998470306,3243.56797838211 5659.53998470306,3243.56797838211 PathPoint;PointKind.CORNERPOINT 5658.80426549911,3405.16845369339 5658.80426549911,3405.16845369339 5658.80426549911,3405.16845369339 PathPoint;PointKind.CORNERPOINT 5658.5118188858,3469.49467086792 5658.5118188858,3469.49467086792 5658.5118188858,3469.49467086792 PathPoint;PointKind.CORNERPOINT 5659.62212467194,3571.48277187347 5659.62212467194,3571.48277187347 5659.62212467194,3571.48277187347 PathPoint;PointKind.CORNERPOINT 5656.7440392971,3729.50166130066 5656.7440392971,3729.50166130066 5656.7440392971,3729.50166130066 PathPoint;PointKind.SMOOTHPOINT 5656.65127778053,3749.89786529541 5656.64915347099,3754.87606668472 5656.65411019325,3743.49850082397 PathPoint;PointKind.SMOOTHPOINT 5651.84219503403,3768.70343351364 5648.26946043968,3771.30830907822 5655.4103269577,3766.10186243057 PathPoint;PointKind.SMOOTHPOINT 5640.79932594299,3773.36015605927 5635.79870128632,3773.96298789978 5651.65490174294,3772.05134534836 PathPoint;PointKind.SMOOTHPOINT 5529.48763036728,3773.39957380295 5526.60104775429,3773.37951087952 5583.95705127716,3773.77628469467 PathPoint;PointKind.SMOOTHPOINT 5520.81159615517,3773.33820486069 5519.18614530563,3774.12773990631 5523.41422939301,3772.07400465012 PathPoint;PointKind.SMOOTHPOINT 5514.27403354645,3773.29005384445 5455.44021868706,3772.85150194168 5516.45180487633,3773.30634021759 PathPoint;PointKind.CORNERPOINT 5398.32638645172,3772.25669527054 5398.32638645172,3772.25669527054 5398.32638645172,3772.25669527054 PathPoint;PointKind.SMOOTHPOINT 5199.62024235725,3771.87597179413 5195.12874388695,3771.86747455597 5309.03315925598,3772.08580636978 PathPoint;PointKind.SMOOTHPOINT 5186.04979896545,3771.85000801086 5178.04079794884,3773.13450717926 5190.54590010643,3771.12915897369 PathPoint;PointKind.SMOOTHPOINT 5163.68931674957,3771.80728578568 5080.52790904045,3771.64819860458 5171.20583200455,3771.82168388367 PathPoint;PointKind.SMOOTHPOINT 4921.20079898834,3771.34300613403 4852.20888996124,3771.90665626526 4990.49152755737,3770.77699565887 PathPoint;PointKind.CORNERPOINT 4803.15893673897,3771.11712121964 4803.15893673897,3771.11712121964 4803.15893673897,3771.11712121964 PathPoint;PointKind.SMOOTHPOINT 4750.3719689846,3771.03498125076 4692.10286641121,3770.94434404373 4783.80966329575,3771.08690881729 PathPoint;PointKind.SMOOTHPOINT 4475.05401754379,3770.60705089569 4461.47401475906,3770.58604383469 4591.05087780952,3770.78738117218 PathPoint;PointKind.SMOOTHPOINT 4433.74363207817,3770.54284954071 4423.53561663628,3771.37770318985 4447.64228129387,3769.40657997131 PathPoint;PointKind.SMOOTHPOINT 4406.27878808975,3770.50012731552 4302.43581080437,3770.33891582489 4415.4933347702,3770.51452541351 PathPoint;PointKind.SMOOTHPOINT 4094.24285435677,3774.00759840012 4091.26528048515,3774.00287771225 4194.51840782166,3774.1633810997 PathPoint;PointKind.SMOOTHPOINT 4085.33881092072,3773.99367237091 4082.44904184341,3773.28179264069 4087.58314394951,3774.54670095444 PathPoint;PointKind.SMOOTHPOINT 4076.43901610374,3773.9799823761 3898.95543241501,3773.70405817032 4079.39534687996,3773.98446702957 PathPoint;PointKind.CORNERPOINT 3755.10391736031,3771.48840332031 3755.10391736031,3771.48840332031 3755.10391736031,3771.48840332031 PathPoint;PointKind.SMOOTHPOINT 3443.17526125908,3772.06125879288 3437.10115218163,3772.07235240936 3636.43078112602,3771.70626306534 PathPoint;PointKind.SMOOTHPOINT 3424.73271393776,3772.09501171112 3420.2429857254,3771.08266019821 3430.38762593269,3773.37006950378 PathPoint;PointKind.SMOOTHPOINT 3410.80467844009,3772.12073945999 3262.53707790375,3772.39288711548 3415.48701071739,3772.11200618744 PathPoint;PointKind.SMOOTHPOINT 2866.1448123455,3773.12081718445 2861.67278671265,3773.12907838821 3075.10960125923,3772.73726129532 PathPoint;PointKind.SMOOTHPOINT 2852.69970321655,3773.14560079575 2850.04608654976,3773.09556150436 2857.19013953209,3773.23033714294 PathPoint;PointKind.SMOOTHPOINT 2837.85856866837,3773.17298078537 2603.72283601761,3773.60303544998 2842.81706118584,3773.16377544403 PathPoint;PointKind.SMOOTHPOINT 2082.84603142738,3774.55944681168 2075.94273352623,3774.57219266891 2344.01006245613,3774.07982492447 PathPoint;PointKind.SMOOTHPOINT 2062.1333053112,3774.597448349 2054.2896463871,3775.48895025253 2068.99376296997,3773.81806278229 PathPoint;PointKind.SMOOTHPOINT 2038.37325716019,3774.64111471176 1177.7825357914,3776.22160100937 2046.29339122772,3774.62671661377 PathPoint;PointKind.CORNERPOINT 315.3008248806,3770.80933237076 315.3008248806,3770.80933237076 315.3008248806,3770.80933237076 PathPoint;PointKind.SMOOTHPOINT 302.704731464386,3770.75197601318 299.616339445114,3770.55984401703 309.302482843399,3771.16267585754 PathPoint;PointKind.SMOOTHPOINT 286.988381385803,3764.40453910828 284.910806655884,3761.70288944244 289.71457862854,3767.94953966141 PathPoint;PointKind.SMOOTHPOINT 280.762030124664,3748.68653678894 281.250267267227,3741.07513570786 280.358057260513,3754.98133802414 PathPoint;PointKind.SMOOTHPOINT 282.010770082474,3700.76825046539 282.580793142319,3695.40366077423 281.441101074219,3706.13307619095 PathPoint;PointKind.SMOOTHPOINT 282.082288503647,3685.07904434204 281.047041654587,3680.19761705399 283.078235626221,3689.77306032181 PathPoint;PointKind.SMOOTHPOINT 282.15380692482,3669.3896021843 282.110612630844,3661.27072715759 282.197001218796,3677.47614049911 PathPoint;PointKind.SMOOTHPOINT 280.679182052612,3647.41739654541 281.091652154922,3641.48821258545 280.267066001892,3653.34634447098 PathPoint;PointKind.SMOOTHPOINT 282.446607589722,3605.06314897537 282.809510469437,3598.92295026779 282.070958852768,3611.41554260254 PathPoint;PointKind.CORNERPOINT 280.957820653915,3586.22878456116 280.957820653915,3586.22878456116 280.957820653915,3586.22878456116 PathPoint;PointKind.SMOOTHPOINT 281.01517701149,3573.67741966248 281.664153575897,3565.24674320221 280.298576593399,3582.97717475891 PathPoint;PointKind.SMOOTHPOINT 281.085987329483,3557.98821353912 282.499715328217,3551.25297212601 279.839371681213,3563.92967128754 PathPoint;PointKind.SMOOTHPOINT 281.150424718857,3543.86769199371 280.258214712143,3538.07564401627 282.042634725571,3549.65973997116 PathPoint;PointKind.SMOOTHPOINT 281.250621318817,3521.90256738663 280.728395223618,3516.77802467346 281.772493362427,3527.0268740654 PathPoint;PointKind.SMOOTHPOINT 281.3217856884,3506.21312522888 281.754790782928,3502.59259366989 280.639882326126,3511.9178404808 PathPoint;PointKind.SMOOTHPOINT 281.386223077774,3492.09260368347 280.277687549591,3487.90535354614 282.494758605957,3496.2798538208 PathPoint;PointKind.SMOOTHPOINT 281.443579435349,3479.54123878479 281.836576700211,3473.27688598633 281.049874067307,3485.80559158325 PathPoint;PointKind.SMOOTHPOINT 279.918679237366,3468.55147743225 278.63134765625,3459.54605722427 281.206364870071,3477.55689764023 PathPoint;PointKind.SMOOTHPOINT 278.622496366501,3407.35602045059 277.373756408691,3399.78474521637 279.8715903759,3414.92682361603 PathPoint;PointKind.SMOOTHPOINT 280.268482208252,3391.67365932465 280.088978052139,3387.01670074463 280.448340415955,3396.33085393906 PathPoint;PointKind.SMOOTHPOINT 278.829970598221,3361.85661458969 279.321040153503,3355.7520570755 278.338546991348,3367.96117210388 PathPoint;PointKind.SMOOTHPOINT 279.301213264465,3258.30691003799 280.002235412598,3253.82532501221 278.600191116333,3262.78825902939 PathPoint;PointKind.SMOOTHPOINT 279.379458665848,3241.04854726791 278.438743591309,3234.15964746475 280.361597776413,3248.24051523209 PathPoint;PointKind.CORNERPOINT 279.522495508194,3209.66989898682 279.522495508194,3209.66989898682 279.522495508194,3209.66989898682 PathPoint;PointKind.CORNERPOINT 278.104872941971,3175.14609241486 278.104872941971,3175.14609241486 278.104872941971,3175.14609241486 PathPoint;PointKind.SMOOTHPOINT 279.722534656525,3165.73964977264 280.324776411057,3159.45594215393 279.119584798813,3172.02335739136 PathPoint;PointKind.SMOOTHPOINT 278.21923160553,3150.0431265831 278.191615581512,3145.27239942551 278.246493577957,3154.81385374069 PathPoint;PointKind.SMOOTHPOINT 278.433432817459,3102.97503614426 278.84165430069,3098.77952480316 277.892441987991,3108.53222990036 PathPoint;PointKind.CORNERPOINT 280.08649969101,3085.72375440598 280.08649969101,3085.72375440598 280.08649969101,3085.72375440598 PathPoint;PointKind.SMOOTHPOINT 278.583196640015,3070.02746725082 279.220135450363,3061.6517868042 277.946611881256,3078.40291166306 PathPoint;PointKind.SMOOTHPOINT 279.111795663834,2953.92616176605 279.305107831955,2946.63954401016 278.957783222198,2959.73803663254 PathPoint;PointKind.SMOOTHPOINT 279.454517602921,2878.61726427078 279.626232624054,2868.9415063858 279.217303037643,2891.97515869141 PathPoint;PointKind.SMOOTHPOINT 278.293936491013,2787.61160755157 278.223126173019,2781.57408380508 278.365100860596,2793.64936733246 PathPoint;PointKind.SMOOTHPOINT 280.197317838669,2715.44763231277 280.800621747971,2708.98005390167 279.593659877777,2721.91544675827 PathPoint;PointKind.SMOOTHPOINT 278.786776304245,2679.35514116287 279.142952203751,2673.16820764542 278.430600404739,2685.54183864594 PathPoint;PointKind.SMOOTHPOINT 279.25801897049,2575.80520057678 278.990710020065,2583.32289600372 278.792441129684,2588.90086078644 PathPoint;PointKind.CORNERPOINT 279.757939815521,2465.97981357574 279.757939815521,2465.97981357574 279.757939815521,2465.97981357574 PathPoint;PointKind.SMOOTHPOINT 278.73296046257,2345.16442918777 278.613999128342,2338.0114068985 278.852275848389,2352.31768751144 PathPoint;PointKind.CORNERPOINT 280.464626789093,2310.6552567482 280.464626789093,2310.6552567482 280.464626789093,2310.6552567482 PathPoint;PointKind.CORNERPOINT 279.475760698318,2181.99526929855 279.475760698318,2181.99526929855 279.475760698318,2181.99526929855 PathPoint;PointKind.CORNERPOINT 278.922378063202,1957.63018035889 278.922378063202,1957.63018035889 278.922378063202,1957.63018035889 PathPoint;PointKind.CORNERPOINT 280.839567422867,1882.32836389542 280.839567422867,1882.32836389542 280.839567422867,1882.32836389542 PathPoint;PointKind.CORNERPOINT 280.007546186447,1719.15165090561 280.007546186447,1719.15165090561 280.007546186447,1719.15165090561 PathPoint;PointKind.SMOOTHPOINT 281.646096944809,1705.03844642639 281.348693609238,1696.50745534897 281.94350028038,1713.56943750381 PathPoint;PointKind.SMOOTHPOINT 280.136066913605,1690.91084384918 280.264941692352,1682.38598966599 280.007192134857,1699.43593406677 PathPoint;PointKind.CORNERPOINT 280.714233160019,1563.82709407806 280.714233160019,1563.82709407806 280.714233160019,1563.82709407806 PathPoint;PointKind.CORNERPOINT 281.093068361282,1480.67335748672 281.093068361282,1480.67335748672 281.093068361282,1480.67335748672 PathPoint;PointKind.CORNERPOINT 281.878354787827,1308.0904378891 281.878354787827,1308.0904378891 281.878354787827,1308.0904378891 PathPoint;PointKind.SMOOTHPOINT 281.949873209,1292.40099573135 282.822964429855,1284.3085565567 281.076427936554,1300.4936709404 PathPoint;PointKind.SMOOTHPOINT 282.028118610382,1275.14286899567 282.443067073822,1265.98591470718 281.613524198532,1284.29982328415 PathPoint;PointKind.CORNERPOINT 281.103689908981,1132.36236000061 281.103689908981,1132.36236000061 281.103689908981,1132.36236000061 PathPoint;PointKind.SMOOTHPOINT 282.870761394501,1090.00811243057 282.724892139435,1083.34108495712 283.016630649567,1096.67561197281 PathPoint;PointKind.SMOOTHPOINT 282.992201089859,1063.33622598648 282.382878303528,1057.56589317322 283.60152387619,1069.10679483414 PathPoint;PointKind.SMOOTHPOINT 281.610337734222,1020.96805238724 282.218952417374,1013.36042785645 281.001723051071,1028.57544088364 PathPoint;PointKind.SMOOTHPOINT 282.088661432266,915.849191188812 282.385356664658,909.327088832855 281.792674303055,922.371529579163 PathPoint;PointKind.SMOOTHPOINT 283.734647274017,900.16706609726 283.576386213303,895.317975521088 283.893262386322,905.016156673431 PathPoint;PointKind.SMOOTHPOINT 282.353137969971,857.798656463623 282.864388465881,849.974116325378 281.84188747406,865.623196601868 PathPoint;PointKind.SMOOTHPOINT 284.049045085907,831.133851051331 283.317574501038,826.032911777496 284.780161619186,836.234790325165 PathPoint;PointKind.SMOOTHPOINT 282.660100698471,790.334125995636 283.60329413414,782.193063735962 281.716907262802,798.475424289703 PathPoint;PointKind.SMOOTHPOINT 282.845623731613,749.541954040527 283.001406431198,740.547391414642 282.689841032028,758.536752700806 PathPoint;PointKind.SMOOTHPOINT 283.124262332916,688.353342056274 283.156126976013,675.043362617493 283.092397689819,701.663321495056 PathPoint;PointKind.SMOOTHPOINT 285.141294240952,591.086637020111 285.56934261322,586.516303062439 284.512144565582,597.805356025696 PathPoint;PointKind.SMOOTHPOINT 285.612536907196,487.536932468414 285.799122095108,481.667937278748 285.426305770874,493.405691623688 PathPoint;PointKind.SMOOTHPOINT 285.669893264771,474.985095500946 286.147508859634,469.093204975128 285.191923618317,480.877458095551 PathPoint;PointKind.SMOOTHPOINT 285.762654781342,454.589127540588 286.784093618393,448.135711193085 284.7408618927,461.042543888092 PathPoint;PointKind.SMOOTHPOINT 286.205573320389,357.314869403839 286.278507947922,351.159564495087 286.131930589676,363.470646381378 PathPoint;PointKind.SMOOTHPOINT 287.844124078751,343.201900959015 287.624966144562,336.419924736023 288.063282012939,349.983641147614 PathPoint;PointKind.SMOOTHPOINT 287.965209722519,316.530014514923 288.596483707428,307.623020648956 287.33464384079,325.436536312103 PathPoint;PointKind.SMOOTHPOINT 286.569538354874,277.299210071564 287.968042135239,270.896541118622 285.170680522919,283.702115058899 PathPoint;PointKind.SMOOTHPOINT 286.655218839645,258.472162723541 288.605689048767,247.973824977875 285.374614238739,265.364839076996 PathPoint;PointKind.SMOOTHPOINT 288.358206987381,230.238436698914 289.568709373474,224.664248466492 287.147704601288,235.812624931335 PathPoint";

negative35mm[1] = "PointKind.CORNERPOINT 288.436625003815,212.979969978333 288.436625003815,212.979969978333 288.436625003815,212.979969978333 PathPoint;PointKind.SMOOTHPOINT 296.380834579468,197.32640504837 301.475991010666,193.179044723511 290.76026558876,201.901459693909 PathPoint;PointKind.SMOOTHPOINT 316.877589225769,191.143956184387 329.467663764954,190.76630115509 310.720278024673,191.328535079956 PathPoint;PointKind.CORNERPOINT 376.708413362503,191.416103839874 376.708413362503,191.416103839874 376.708413362503,191.416103839874 PathPoint;PointKind.SMOOTHPOINT 438.114058971405,191.695568561554 444.035925865173,191.679990291595 425.039995908737,191.730501651764 PathPoint;PointKind.SMOOTHPOINT 466.455180644989,191.824443340302 471.603090763092,192.266299724579 461.306916475296,191.382586956024 PathPoint;PointKind.SMOOTHPOINT 496.37785077095,190.391714572906 500.463606119156,190.910518169403 492.292095422745,189.873147010803 PathPoint;PointKind.SMOOTHPOINT 521.569683551788,190.506427288055 530.741744041443,191.522083282471 512.397977113724,189.490535259247 PathPoint;PointKind.SMOOTHPOINT 605.018227100372,190.886206626892 612.18989610672,190.789904594421 597.846204042435,190.982744693756 PathPoint;PointKind.SMOOTHPOINT 649.111104011536,189.517915248871 662.829540967941,188.940575122833 635.39266705513,190.095255374908 PathPoint;PointKind.CORNERPOINT 745.162822008133,188.386130332947 745.162822008133,188.386130332947 745.162822008133,188.386130332947 PathPoint;PointKind.SMOOTHPOINT 867.980486154556,187.376139163971 872.60015130043,187.233338356018 831.444486379623,188.505091667175 PathPoint;PointKind.SMOOTHPOINT 1022.2889149189,186.509420871735 1028.87108802795,187.578656673431 1016.13833069801,185.510051250458 PathPoint;PointKind.CORNERPOINT 1036.4520406723,188.142778873444 1036.4520406723,188.142778873444 1036.4520406723,188.142778873444 PathPoint;PointKind.CORNERPOINT 1053.77153635025,188.221614360809 1053.77153635025,188.221614360809 1053.77153635025,188.221614360809 PathPoint;PointKind.SMOOTHPOINT 1088.41760873795,186.810364723206 1097.046200037,186.943016052246 1076.30621194839,186.62389755249 PathPoint;PointKind.SMOOTHPOINT 1115.18426299095,186.932158470154 1121.42371416092,188.067247867584 1109.80834364891,185.954031944275 PathPoint;PointKind.SMOOTHPOINT 1127.77292132378,188.558435440063 1128.31391215324,188.531763553619 1126.08338713646,188.641047477722 PathPoint;PointKind.SMOOTHPOINT 1140.37609577179,187.046635150909 1145.41956067085,185.990381240845 1136.06870412827,187.948758602142 PathPoint;PointKind.CORNERPOINT 1289.95333313942,187.727358341217 1289.95333313942,187.727358341217 1289.95333313942,187.727358341217 PathPoint;PointKind.SMOOTHPOINT 1516.69540643692,185.6214594841 1522.45582580566,185.892899036407 1508.05796384811,185.214536190033 PathPoint;PointKind.SMOOTHPOINT 1524.5610165596,187.226021289825 1533.36238503456,186.954817771912 1520.11342048645,187.363157272339 PathPoint;PointKind.CORNERPOINT 1534.01490211487,185.700294971466 1534.01490211487,185.700294971466 1534.01490211487,185.700294971466 PathPoint;PointKind.CORNERPOINT 1612.73968935013,186.058595180511 1612.73968935013,186.058595180511 1612.73968935013,186.058595180511 PathPoint;PointKind.SMOOTHPOINT 1620.60494542122,187.663156986237 1624.60856080055,188.292424678802 1616.60203814507,187.034361362457 PathPoint;PointKind.CORNERPOINT 1633.20847392082,186.151828765869 1633.20847392082,186.151828765869 1633.20847392082,186.151828765869 PathPoint;PointKind.CORNERPOINT 1771.76408529282,186.782276630402 1771.76408529282,186.782276630402 1771.76408529282,186.782276630402 PathPoint;PointKind.CORNERPOINT 1951.264346838,186.030035018921 1951.264346838,186.030035018921 1951.264346838,186.030035018921 PathPoint;PointKind.CORNERPOINT 1959.1292488575,187.634832859039 1959.1292488575,187.634832859039 1959.1292488575,187.634832859039 PathPoint;PointKind.CORNERPOINT 1968.58348846436,186.10910654068 1968.58348846436,186.10910654068 1968.58348846436,186.10910654068 PathPoint;PointKind.CORNERPOINT 2159.10502195358,185.407140254974 2159.10502195358,185.407140254974 2159.10502195358,185.407140254974 PathPoint;PointKind.CORNERPOINT 2499.20379281044,185.385897159576 2499.20379281044,185.385897159576 2499.20379281044,185.385897159576 PathPoint;PointKind.SMOOTHPOINT 2511.79245114326,187.012174129486 2516.25279307365,187.100450992584 2504.67707633972,186.871497631073 PathPoint;PointKind.SMOOTHPOINT 2524.39597964287,185.500609874725 2534.13133621216,186.100373268127 2514.6599149704,184.90061044693 PathPoint;PointKind.CORNERPOINT 2770.02458095551,185.049548149109 2770.02458095551,185.049548149109 2770.02458095551,185.049548149109 PathPoint;PointKind.CORNERPOINT 2784.1880607605,186.682906150818 2784.1880607605,186.682906150818 2784.1880607605,186.682906150818 PathPoint;PointKind.CORNERPOINT 2795.21676778793,185.164024829865 2795.21676778793,185.164024829865 2795.21676778793,185.164024829865 PathPoint;PointKind.CORNERPOINT 2804.65613722801,186.775903701782 2804.65613722801,186.775903701782 2804.65613722801,186.775903701782 PathPoint;PointKind.CORNERPOINT 2821.98306798935,185.285818576813 2821.98306798935,185.285818576813 2821.98306798935,185.285818576813 PathPoint;PointKind.CORNERPOINT 2996.75213813782,186.081254482269 2996.75213813782,186.081254482269 2996.75213813782,186.081254482269 PathPoint;PointKind.CORNERPOINT 3506.9040119648,185.265047550201 3506.9040119648,185.265047550201 3506.9040119648,185.265047550201 PathPoint;PointKind.CORNERPOINT 3790.32089352608,184.986054897308 3790.32089352608,184.986054897308 3790.32089352608,184.986054897308 PathPoint;PointKind.SMOOTHPOINT 4010.75058102608,185.989201068878 4027.09537267685,185.93585729599 3928.56104493141,186.256864070892 PathPoint;PointKind.SMOOTHPOINT 4210.71183800697,186.89911365509 4216.31470441818,186.509420871735 4205.10897159576,187.288806438446 PathPoint;PointKind.SMOOTHPOINT 4333.52277517319,187.457807064056 4345.41218161583,186.888492107391 4321.63301467896,188.027358055115 PathPoint;PointKind.SMOOTHPOINT 4459.48264718056,188.031134605408 4473.17771673203,187.993133068085 4445.7872235775,188.069372177124 PathPoint;PointKind.SMOOTHPOINT 4517.74608492851,186.727516651154 4523.12873125076,186.990458965302 4512.36379265785,186.464338302612 PathPoint;PointKind.SMOOTHPOINT 4527.18580842018,188.339395523071 4532.29760527611,188.646240234375 4522.07436561584,188.032550811768 PathPoint;PointKind.SMOOTHPOINT 4542.93827176094,186.841993331909 4552.0044708252,186.688807010651 4533.8717186451,186.995179653168 PathPoint;PointKind.SMOOTHPOINT 4742.89952874184,187.752141952515 4740.21699839222,187.699474102193 4726.81531906128,187.436091899872 PathPoint;PointKind.SMOOTHPOINT 4766.58209552392,187.815483475402 4767.54864895734,187.820248751482 4749.55716223944,187.731547601267 PathPoint;PointKind.SMOOTHPOINT 4770,189 4770.46780916307,190.41959869387 4769.68222783385,188.035698768598 PathPoint;PointKind.SMOOTHPOINT 4771.6021010914,188.934096504655 4772.45678213497,188.584484200854 4770.7714673906,189.273872101575 PathPoint;PointKind.SMOOTHPOINT 4774.21130889436,187.853894529462 4848.21316625413,188.233088569759 4773.39853926985,187.849729804295 PathPoint;PointKind.SMOOTHPOINT 5062.5224339962,189.206585884094 5209.0346467495,188.714690208435 5028.39924564178,189.321281692846 PathPoint;PointKind.SMOOTHPOINT 5561.63816571236,191.478180885315 5561.63816571236,191.478180885315 5561.58187150955,194.059925079346 PathPoint;PointKind.SMOOTHPOINT 5612.02253937721,191.707370281219 5620.59129595757,191.874718666077 5603.45342874527,191.540257930756 PathPoint;PointKind.SMOOTHPOINT 5640.35622596741,193.405401706696 5642.49930024147,193.751900196075 5638.21315169334,193.058903217316 PathPoint;PointKind.SMOOTHPOINT 5649.78178739548,198.155121803284 5654.88756537437,204.325060844421 5644.67636346817,191.985182762146 PathPoint;PointKind.SMOOTHPOINT 5654.43402528763,213.86604309082 5655.17930388451,221.84778213501 5654.02367949486,209.472734928131 PathPoint;PointKind.SMOOTHPOINT 5655.83005070686,253.096611499786 5653.56659889221,267.759304046631 5656.18658065796,250.786778926849 PathPoint;PointKind.SMOOTHPOINT 5655.63709259033,295.45770406723 5656.24818563461,301.713559627533 5655.02599954605,289.202084541321 PathPoint;PointKind.SMOOTHPOINT 5655.54433107376,315.853908061981 5654.09236550331,325.544536113739 5656.33244991302,310.595297813416 PathPoint;PointKind.SMOOTHPOINT 5656.96159958839,350.377714633942 5657.3460996151,363.007915019989 5656.63905858994,339.775757789612 PathPoint;PointKind.SMOOTHPOINT 5657.79362082481,513.554427623749 5657.76989936829,512.450966835022 5657.69661068916,509.065997600555 PathPoint;PointKind.CORNERPOINT 5659.85738754272,752.046883106232 5659.85738754272,752.046883106232 5659.85738754272,752.046883106232 PathPoint;PointKind.SMOOTHPOINT 5659.55042481422,819.511177539825 5657.20908164978,825.769865512848 5661.89141392708,813.252725601196 PathPoint;PointKind.SMOOTHPOINT 5659.48598742485,833.631699085236 5660.52973151207,838.516430854797 5658.44224333763,828.746731281281 PathPoint;PointKind.SMOOTHPOINT 5659.42898511887,846.183063983917 5659.03492569923,850.726490020752 5659.82269048691,841.639873981476 PathPoint;PointKind.CORNERPOINT 5659.26435112953,882.268710136414 5659.26435112953,882.268710136414 5659.26435112953,882.268710136414 PathPoint;PointKind.CORNERPOINT 5657.61871933937,897.950835227966 5657.61871933937,897.950835227966 5657.61871933937,897.950835227966 PathPoint;PointKind.SMOOTHPOINT 5659.11494135857,915.216279029846 5659.94342207909,918.764111995697 5658.01808953285,910.519902706146 PathPoint;PointKind.SMOOTHPOINT 5659.00766372681,938.750324249268 5660.86962103844,944.400751590729 5655.58398485184,928.361270427704 PathPoint;PointKind.SMOOTHPOINT 5658.94322633743,952.870845794678 5659.58122730255,959.592397212982 5658.3055794239,946.149294376373 PathPoint;PointKind.CORNERPOINT 5658.58634233475,1031.31758451462 5658.58634233475,1031.31758451462 5658.58634233475,1031.31758451462 PathPoint;PointKind.CORNERPOINT 5659.87509012222,1094.08219814301 5659.87509012222,1094.08219814301 5659.87509012222,1094.08219814301 PathPoint;PointKind.CORNERPOINT 5660.828551054,1230.58678865433 5660.828551054,1230.58678865433 5660.828551054,1230.58678865433 PathPoint;PointKind.CORNERPOINT 5661.90309762955,1340.41949272156 5661.90309762955,1340.41949272156 5661.90309762955,1340.41949272156 PathPoint;PointKind.SMOOTHPOINT 5661.60620553547,1662.73720773217 5661.60494877888,1664.10160162702 5661.78187752448,1472.01945780808 PathPoint;PointKind.SMOOTHPOINT 5661.60242692966,1666.83943976068 5661.02714587661,1667.92349619732 5662.21418030689,1665.68665507795 PathPoint;PointKind.SMOOTHPOINT 5661.59902902515,1670.52836516776 5661.53943085657,1735.23095296191 5661.60016386361,1669.29633091165 PathPoint;PointKind.SMOOTHPOINT 5661.40459299088,1881.61826848984 5661.39999032021,1886.32904291153 5661.47377118248,1806.51445887522 PathPoint;PointKind.SMOOTHPOINT 5661.39149308205,1895.79473018646 5661.93248391151,1899.36380624771 5660.71773290634,1891.35185480118 PathPoint;PointKind.SMOOTHPOINT 5661.38157963753,1906.64829969406 5661.30935311317,1984.94562864304 5661.38476610184,1903.02233934402 PathPoint;PointKind.SMOOTHPOINT 5661.15746498108,2149.72973585129 5661.15463256836,2152.99220323563 5661.23358607292,2066.98245048523 PathPoint;PointKind.SMOOTHPOINT 5661.14825963974,2159.52020645142 5660.24613618851,2163.9031291008 5661.80644154549,2156.32241249084 PathPoint;PointKind.SMOOTHPOINT 5661.13940834999,2169.18416261673 5661.03106856346,2287.15651273727 5661.1425948143,2165.96205711365 PathPoint;PointKind.SMOOTHPOINT 5660.81863760948,2517.23481416702 5660.81615924835,2520.01364707947 5660.92131257057,2406.0892868042 PathPoint;PointKind.SMOOTHPOINT 5660.81120252609,2525.55715084076 5662.34282970428,2532.6865696907 5660.22949576378,2522.84912824631 PathPoint;PointKind.SMOOTHPOINT 5660.79385399818,2544.02259349823 5660.6486928463,2701.66264772415 5660.79987287521,2537.89348840714 PathPoint;PointKind.SMOOTHPOINT 5660.43059706688,2938.57815742493 5660.42564034462,2943.5542345047 5660.51981806755,2841.80334806442 PathPoint;PointKind.SMOOTHPOINT 5660.41714310646,2953.15847396851 5659.72709655762,2958.65972757339 5661.00734710693,2948.45218420029 PathPoint;PointKind.SMOOTHPOINT 5660.40404319763,2967.41141080856 5660.34102201462,3035.52409172058 5660.40793776512,2962.787733078 PathPoint;PointKind.CORNERPOINT 5660.30420064926,3075.69171667099 5660.30420064926,3075.69171667099 5660.30420064926,3075.69171667099 PathPoint;PointKind.CORNERPOINT 5659.91155743599,3161.983294487 5659.91155743599,3161.983294487 5659.91155743599,3161.983294487 PathPoint;PointKind.SMOOTHPOINT 5658.30133080482,3169.82058048248 5657.688113451,3175.69524049759 5658.91419410706,3163.94639253616 PathPoint;PointKind.SMOOTHPOINT 5659.82587695122,3180.81034183502 5661.59613490105,3186.4178109169 5658.0552649498,3175.20310878754 PathPoint;PointKind.CORNERPOINT 5659.54015731812,3243.56787443161 5659.54015731812,3243.56787443161 5659.54015731812,3243.56787443161 PathPoint;PointKind.SMOOTHPOINT 5659.31401330551,3293.24033062199 5659.3082752441,3294.50069387692 5659.44022116858,3265.51881601319 PathPoint;PointKind.SMOOTHPOINT 5659.29664312698,3297.05568448325 5660.46439872607,3299.36519550217 5658.71784772031,3295.91098059962 PathPoint;PointKind.SMOOTHPOINT 5659.27060693752,3302.77452472761 5659.06059059632,3348.90454332525 5659.27937338209,3300.84897813096 PathPoint;PointKind.CORNERPOINT 5658.80443811417,3405.16834974289 5658.80443811417,3405.16834974289 5658.80443811417,3405.16834974289 PathPoint;PointKind.CORNERPOINT 5658.51199150085,3469.49456691742 5658.51199150085,3469.49456691742 5658.51199150085,3469.49456691742 PathPoint;PointKind.CORNERPOINT 5659.62229728699,3571.48266792297 5659.62229728699,3571.48266792297 5659.62229728699,3571.48266792297 PathPoint;PointKind.CORNERPOINT 5656.74421191216,3729.50155735016 5656.74421191216,3729.50155735016 5656.74421191216,3729.50155735016 PathPoint;PointKind.SMOOTHPOINT 5656.65145039558,3749.89776134491 5656.64932608604,3754.87596273422 5656.6542828083,3743.49839687347 PathPoint;PointKind.SMOOTHPOINT 5651.84236764908,3768.70332956314 5648.26963305473,3771.30820512772 5655.41049957275,3766.10175848007 PathPoint;PointKind.SMOOTHPOINT 5640.79949855804,3773.36005210876 5635.79887390137,3773.96288394928 5651.65507435799,3772.05124139786 PathPoint;PointKind.SMOOTHPOINT 5529.48780298233,3773.39946985245 5526.60122036934,3773.37940692902 5583.95722389221,3773.77618074417 PathPoint;PointKind.SMOOTHPOINT 5520.81176877022,3773.33810091019 5519.18631792068,3774.12763595581 5523.41440200806,3772.07390069962 PathPoint;PointKind.SMOOTHPOINT 5514.2742061615,3773.28994989395 5455.44039130211,3772.85139799118 5516.45197749138,3773.30623626709 PathPoint;PointKind.CORNERPOINT 5398.32655906677,3772.25659132004 5398.32655906677,3772.25659132004 5398.32655906677,3772.25659132004 PathPoint;PointKind.SMOOTHPOINT 5199.62041497231,3771.87586784363 5195.128916502,3771.86737060547 5309.03333187103,3772.08570241928 PathPoint;PointKind.SMOOTHPOINT 5186.04997158051,3771.84990406036 5178.04097056389,3773.13440322876 5190.54607272148,3771.12905502319 PathPoint;PointKind.SMOOTHPOINT 5163.68948936462,3771.80718183517 5080.5280816555,3771.64809465408 5171.2060046196,3771.82157993317 PathPoint;PointKind.SMOOTHPOINT 4921.20097160339,3771.34290218353 4852.20906257629,3771.90655231476 4990.49170017242,3770.77689170837 PathPoint;PointKind.CORNERPOINT 4803.15910935402,3771.11701726913 4803.15910935402,3771.11701726913 4803.15910935402,3771.11701726913 PathPoint;PointKind.SMOOTHPOINT 4750.37214159966,3771.03487730026 4692.10303902626,3770.94424009323 4783.8098359108,3771.08680486679 PathPoint;PointKind.SMOOTHPOINT 4475.05419015884,3770.60694694519 4461.47418737411,3770.58593988419 4591.05105042458,3770.78727722168 PathPoint;PointKind.SMOOTHPOINT 4433.74380469322,3770.54274559021 4423.53578925133,3771.37759923935 4447.64245390892,3769.40647602081 PathPoint;PointKind.SMOOTHPOINT 4406.2789607048,3770.50002336502 4302.43598341942,3770.33881187439 4415.49350738525,3770.51442146301 PathPoint;PointKind.SMOOTHPOINT 4094.24302697182,3774.00749444962 4091.2654531002,3774.00277376175 4194.51858043671,3774.1632771492 PathPoint;PointKind.SMOOTHPOINT 4085.33898353577,3773.99356842041 4082.44921445847,3773.28168869019 4087.58331656456,3774.54659700394 PathPoint;PointKind.SMOOTHPOINT 4076.4391887188,3773.9798784256 3898.95560503006,3773.70395421982 4079.39551949501,3773.98436307907 PathPoint;PointKind.CORNERPOINT 3755.10408997536,3771.48829936981 3755.10408997536,3771.48829936981 3755.10408997536,3771.48829936981 PathPoint;PointKind.SMOOTHPOINT 3443.17543387413,3772.06115484238 3437.10132479668,3772.07224845886 3636.43095374107,3771.70615911484 PathPoint;PointKind.SMOOTHPOINT 3424.73288655281,3772.09490776062 3420.24315834045,3771.08255624771 3430.38779854774,3773.36996555328 PathPoint;PointKind.SMOOTHPOINT 3410.80485105515,3772.12063550949 3305.83117243399,3772.31331644869 3415.48718333244,3772.11190223694 PathPoint;PointKind.SMOOTHPOINT 3043.24945992456,3772.79556493696 3040.36109294042,3772.80086869648 3181.22797635466,3772.54220209439 PathPoint;PointKind.SMOOTHPOINT 3034.56683276551,3772.81150828635 3032.04460469381,3772.81613965847 3037.46686476366,3772.80618318213 PathPoint;PointKind.SMOOTHPOINT 3026.98701591006,3772.82542642822 3025.37500376349,3772.07450773024 3029.88517399425,3774.17546656268 PathPoint;PointKind.SMOOTHPOINT 3021.64559811475,3772.83523428826 2971.41039095784,3772.92747525933 3023.42821069072,3772.83196108757 PathPoint;PointKind.SMOOTHPOINT 2866.14498496056,3773.12071323395 2861.6729593277,3773.12897443771 2919.47918667838,3773.02281804659 PathPoint;PointKind.SMOOTHPOINT 2852.6998758316,3773.14549684525 2850.04625916481,3773.09545755386 2857.19031214714,3773.23023319244 PathPoint;PointKind.SMOOTHPOINT 2837.85874128342,3773.17287683487 2603.72300863266,3773.60293149948 2842.81723380089,3773.16367149353 PathPoint;PointKind.SMOOTHPOINT 2082.84620404243,3774.55934286118 2075.94290614128,3774.57208871841 2344.01023507118,3774.07972097397 PathPoint;PointKind.SMOOTHPOINT 2062.13347792625,3774.5973443985 2054.28981900215,3775.48884630203 2068.99393558502,3773.81795883179 PathPoint;PointKind.SMOOTHPOINT 2038.37342977524,3774.64101076126 1852.68535003203,3774.98202938763 2046.29356384277,3774.62661266327 PathPoint;PointKind.SMOOTHPOINT 1489.7279471932,3774.81201658066 1486.99553913767,3774.80915623331 1666.90923356782,3774.99749401086 PathPoint;PointKind.SMOOTHPOINT 1482,3775 1480.64667704827,3775.54677244495 1485.83297559892,3773.45139296796 PathPoint;PointKind.SMOOTHPOINT 1477.15986567068,3774.79850863371 1266.42019789886,3774.56612931684 1478.61827539328,3774.80011679918 PathPoint;PointKind.SMOOTHPOINT 897.176357001617,3773.46830974909 895.047754568531,3773.46104015739 1068.18826876613,3774.05234871972 PathPoint;PointKind.SMOOTHPOINT 890.803229691031,3773.44646872571 889.079271355161,3774.08038884399 894.15305684112,3772.21469718054 PathPoint;PointKind.SMOOTHPOINT 885.302397513484,3773.42749562888 873.465313318116,3773.38654689115 887.132809298206,3773.43382768253 PathPoint;PointKind.SMOOTHPOINT 850.198252502241,3773.30376753892 848.751581086222,3773.29857424263 861.762268442751,3773.34528032505 PathPoint;PointKind.SMOOTHPOINT 845.864775553372,3773.28817623 844.748436571427,3774.25506205321 847.958648013595,3771.47462709292 PathPoint;PointKind.SMOOTHPOINT 841.441144463392,3773.27218858807 525.296490458207,3772.12699783662 842.913389656685,3773.27752159484 PathPoint;PointKind.CORNERPOINT 315.300997495651,3770.80922842026 315.300997495651,3770.80922842026 315.300997495651,3770.80922842026 PathPoint;PointKind.SMOOTHPOINT 302.704904079437,3770.75187206268 299.80597838345,3770.57152695844 309.30265545845,3771.16257190704 PathPoint;PointKind.SMOOTHPOINT 287.568080521539,3765.04597415382 287.350052566198,3764.83587395323 290.90401289846,3768.26060807748 PathPoint;PointKind.SMOOTHPOINT 286.988554000854,3764.40443515778 284.910979270935,3761.70278549194 287.155800440071,3764.6219134496 PathPoint;PointKind.SMOOTHPOINT 280.762202739716,3748.68643283844 281.89189805582,3741.1435162661 279.817604875565,3754.99217157364 PathPoint;PointKind.SMOOTHPOINT 282.010942697525,3700.76814651489 282.58096575737,3695.40355682373 281.44127368927,3706.13297224045 PathPoint;PointKind.SMOOTHPOINT 282.082461118698,3685.07894039154 281.047214269638,3680.19751310349 283.078408241272,3689.77295637131 PathPoint;PointKind.SMOOTHPOINT 282.153979539871,3669.3894982338 282.110785245895,3661.27062320709 282.197173833847,3677.47603654861 PathPoint;PointKind.SMOOTHPOINT 280.679354667664,3647.41729259491 281.091824769974,3641.48810863495 280.267238616943,3653.34624052048 PathPoint;PointKind.SMOOTHPOINT 282.446780204773,3605.06304502487 282.809683084488,3598.92284631729 282.071131467819,3611.41543865204 PathPoint;PointKind.CORNERPOINT 280.957993268967,3586.22868061066 280.957993268967,3586.22868061066 280.957993268967,3586.22868061066 PathPoint;PointKind.SMOOTHPOINT 281.015349626541,3573.67731571198 281.664326190948,3565.24663925171 280.29874920845,3582.97707080841 PathPoint;PointKind.SMOOTHPOINT 281.086159944534,3557.98810958862 282.499887943268,3551.25286817551 279.839544296265,3563.92956733704 PathPoint;PointKind.SMOOTHPOINT 281.150597333908,3543.86758804321 280.258387327194,3538.07554006577 282.042807340622,3549.65963602066 PathPoint;PointKind.SMOOTHPOINT 281.250793933868,3521.90246343613 280.728567838669,3516.77792072296 281.772665977478,3527.0267701149 PathPoint;PointKind.SMOOTHPOINT 281.321958303452,3506.21302127838 281.75496339798,3502.59248971939 280.640054941177,3511.9177365303 PathPoint;PointKind.SMOOTHPOINT 281.386395692825,3492.09249973297 280.277860164642,3487.90524959564 282.494931221008,3496.2797498703 PathPoint;PointKind.SMOOTHPOINT 281.4437520504,3479.54113483429 281.836749315262,3473.27678203583 281.050046682358,3485.80548763275 PathPoint;PointKind.SMOOTHPOINT 279.918851852417,3468.55137348175 278.631520271301,3459.54595327377 281.206537485123,3477.55679368973 PathPoint;PointKind.SMOOTHPOINT 278.622668981552,3407.35591650009 277.373929023743,3399.78464126587 279.871762990952,3414.92671966553 PathPoint;PointKind.SMOOTHPOINT 280.268654823303,3391.67355537415 280.089150667191,3387.01659679413 280.448513031006,3396.33074998856 PathPoint;PointKind.SMOOTHPOINT 278.830143213272,3361.85651063919 279.321212768555,3355.751953125 278.3387196064,3367.96106815338 PathPoint;PointKind.SMOOTHPOINT 279.301385879517,3258.30680608749 280.002408027649,3253.82522106171 278.600363731384,3262.78815507889 PathPoint;PointKind.SMOOTHPOINT 279.379631280899,3241.04844331741 278.43891620636,3234.15954351425 280.361770391464,3248.24041128159 PathPoint;PointKind.CORNERPOINT 279.522668123245,3209.66979503632 279.522668123245,3209.66979503632 279.522668123245,3209.66979503632 PathPoint;PointKind.SMOOTHPOINT 278.105045557022,3175.14598846436 278.197233057022,3173.20536346436 278.012858057022,3177.08661346436 PathPoint;PointKind.SMOOTHPOINT 279.722707271576,3165.73954582214 278.473386526108,3159.63552570343 280.987781755206,3171.9240519883 PathPoint;PointKind.SMOOTHPOINT 278.219404220581,3150.0430226326 278.191788196564,3145.27229547501 278.246666193008,3154.81374979019 PathPoint;PointKind.SMOOTHPOINT 278.43360543251,3102.97493219376 278.841826915741,3098.77942085266 277.892614603043,3108.53212594986 PathPoint;PointKind.CORNERPOINT 280.086672306061,3085.72365045547 280.086672306061,3085.72365045547 280.086672306061,3085.72365045547 PathPoint;PointKind.SMOOTHPOINT 278.583369255066,3070.02736330032 279.220308065414,3061.6516828537 277.946784496307,3078.40280771255 PathPoint;PointKind.SMOOTHPOINT 279.111968278885,2953.92605781555 279.305280447006,2946.63944005966 278.95795583725,2959.73793268204 PathPoint;PointKind.SMOOTHPOINT 279.454690217972,2878.61716032028 279.626405239105,2868.9414024353 279.217475652695,2891.97505474091 PathPoint;PointKind.SMOOTHPOINT 278.294109106064,2787.61150360107 278.223298788071,2781.57397985458 278.365273475647,2793.64926338196 PathPoint;PointKind.SMOOTHPOINT 280.19749045372,2715.44752836227 280.800794363022,2708.97994995117 279.593832492828,2721.91534280777 PathPoint;PointKind.SMOOTHPOINT 278.786948919296,2679.35503721237 279.143124818802,2673.16810369492 278.430773019791,2685.54173469543 PathPoint;PointKind.SMOOTHPOINT 279.258191585541,2575.80509662628 278.990882635117,2583.32279205322 278.792613744736,2588.90075683594 PathPoint;PointKind.CORNERPOINT 279.758112430573,2465.97970962524 279.758112430573,2465.97970962524 279.758112430573,2465.97970962524 PathPoint;PointKind.SMOOTHPOINT 278.733133077621,2345.16432523727 278.614171743393,2338.011302948 278.85244846344,2352.31758356094 PathPoint;PointKind.CORNERPOINT 280.464799404144,2310.6551527977 280.464799404144,2310.6551527977 280.464799404144,2310.6551527977 PathPoint;PointKind.CORNERPOINT 279.47593331337,2181.99516534805 279.47593331337,2181.99516534805 279.47593331337,2181.99516534805 PathPoint;PointKind.SMOOTHPOINT 279.089920500223,2025.48899103472 279.087215684758,2024.392342669 279.252809691646,2091.53126558735 PathPoint;PointKind.SMOOTHPOINT 279.081857177311,2022.21977359358 277.947180833569,2021.37898459894 280.926714977989,2023.58680318229 PathPoint;PointKind.SMOOTHPOINT 279.071501896172,2018.02129784417 279.069164936462,2017.07379400175 279.074921269552,2019.40765867982 PathPoint;PointKind.SMOOTHPOINT 279.064538665179,2015.1981049178 279.061226050922,2013.85502881598 279.066843553047,2016.13260545785 PathPoint;PointKind.SMOOTHPOINT 280,2011 281.785489179474,2008.63715987893 279.207604084312,2012.04862291124 PathPoint;PointKind.SMOOTHPOINT 279.044123609692,2006.92096456405 278.97332966733,1978.21805961857 279.047603844411,2008.33200120072 PathPoint;PointKind.CORNERPOINT 278.922550678253,1957.63007640839 278.922550678253,1957.63007640839 278.922550678253,1957.63007640839 PathPoint;PointKind.CORNERPOINT 280.839740037918,1882.32825994492 280.839740037918,1882.32825994492 280.839740037918,1882.32825994492 PathPoint;PointKind.CORNERPOINT 280.007718801498,1719.15154695511 280.007718801498,1719.15154695511 280.007718801498,1719.15154695511 PathPoint;PointKind.SMOOTHPOINT 281.64626955986,1705.03834247589 281.348866224289,1696.50735139847 281.943672895432,1713.56933355331 PathPoint;PointKind.SMOOTHPOINT 280.136239528656,1690.91073989868 280.265114307404,1682.38588571548 280.007364749908,1699.43583011627 PathPoint;PointKind.CORNERPOINT 280.71440577507,1563.82699012756 280.71440577507,1563.82699012756 280.71440577507,1563.82699012756 PathPoint;PointKind.CORNERPOINT 281.093240976334,1480.67325353622 281.093240976334,1480.67325353622 281.093240976334,1480.67325353622 PathPoint;PointKind.CORNERPOINT 281.878527402878,1308.0903339386 281.878527402878,1308.0903339386 281.878527402878,1308.0903339386 PathPoint;PointKind.SMOOTHPOINT 281.950045824051,1292.40089178085 284.685274427159,1284.73483773955 279.098475551605,1300.3920044899 PathPoint;PointKind.SMOOTHPOINT 282.028291225433,1275.14276504517 282.443239688873,1265.98581075668 281.613696813583,1284.29971933365 PathPoint;PointKind.CORNERPOINT 281.103862524033,1132.36225605011 281.103862524033,1132.36225605011 281.103862524033,1132.36225605011 PathPoint;PointKind.SMOOTHPOINT 282.870934009552,1090.00800848007 282.725064754486,1083.34098100662 283.016803264618,1096.67550802231 PathPoint;PointKind.SMOOTHPOINT 282.99237370491,1063.33612203598 282.383050918579,1057.56578922272 283.601696491241,1069.10669088364 PathPoint;PointKind.SMOOTHPOINT 281.610510349274,1020.96794843674 282.219125032425,1013.36032390594 281.001895666122,1028.57533693314 PathPoint;PointKind.SMOOTHPOINT 282.088834047318,915.849087238312 282.385529279709,909.326984882355 281.792846918106,922.371425628662 PathPoint;PointKind.SMOOTHPOINT 283.734819889069,900.166962146759 282.057808828354,895.319434070587 285.321364111922,904.751906595572 PathPoint;PointKind.SMOOTHPOINT 282.353310585022,857.798552513123 282.864561080933,849.974012374878 281.842060089111,865.623092651367 PathPoint;PointKind.SMOOTHPOINT 284.049217700958,831.13374710083 283.317747116089,826.032807826996 284.780334234238,836.234686374664 PathPoint;PointKind.SMOOTHPOINT 282.660273313522,790.334022045135 283.603466749191,782.192959785461 281.717079877853,798.475320339203 PathPoint;PointKind.SMOOTHPOINT 282.845796346664,749.541850090027 283.001579046249,740.547287464142 282.690013647079,758.536648750305 PathPoint;PointKind.SMOOTHPOINT 283.124434947968,688.353238105774 283.156299591064,675.043258666992 283.092570304871,701.663217544556 PathPoint;PointKind.SMOOTHPOINT 285.141466856003,591.086533069611 285.569515228271,586.516199111938 284.512317180634,597.805252075195 PathPoint;PointKind.SMOOTHPOINT 285.612709522247,487.536828517914 285.799294710159,481.667833328247 285.426478385925,493.405587673187 PathPoint;PointKind.SMOOTHPOINT 285.670065879822,474.984991550446 286.147681474686,469.093101024628 285.192096233368,480.87735414505 PathPoint;PointKind.SMOOTHPOINT 285.762827396393,454.589023590088 286.784266233444,448.135607242584 284.741034507751,461.042439937592 PathPoint;PointKind.SMOOTHPOINT 286.20574593544,357.314765453339 286.278680562973,351.159460544586 286.132103204727,363.470542430878 PathPoint;PointKind.SMOOTHPOINT 287.844296693802,343.201797008514 287.625138759613,336.419820785522 288.063454627991,349.983537197113 PathPoint;PointKind.SMOOTHPOINT 287.96538233757,316.529910564423 288.596656322479,307.622916698456 287.334816455841,325.436432361603 PathPoint;PointKind.SMOOTHPOINT 286.569710969925,277.299106121063 287.96821475029,270.896437168121 285.17085313797,283.702011108398 PathPoint;PointKind.SMOOTHPOINT 286.655391454697,258.472058773041 288.605861663818,247.973721027374 285.37478685379,265.364735126495 PathPoint;PointKind.SMOOTHPOINT 288.358379602432,230.238332748413 289.568881988525,224.664144515991 287.147877216339,235.812520980835 PathPoint";

negative35mm[2] = "PointKind.CORNERPOINT 288.436625003815,212.979969978333 288.436625003815,212.979969978333 288.436625003815,212.979969978333 PathPoint;PointKind.SMOOTHPOINT 296.380834579468,197.32640504837 301.475991010666,193.179044723511 290.76026558876,201.901459693909 PathPoint;PointKind.SMOOTHPOINT 316.877589225769,191.143956184387 329.467663764954,190.76630115509 310.720278024673,191.328535079956 PathPoint;PointKind.CORNERPOINT 376.708413362503,191.416103839874 376.708413362503,191.416103839874 376.708413362503,191.416103839874 PathPoint;PointKind.SMOOTHPOINT 438.114058971405,191.695568561554 444.035925865173,191.679990291595 425.039995908737,191.730501651764 PathPoint;PointKind.SMOOTHPOINT 466.455180644989,191.824443340302 471.603090763092,192.266299724579 461.306916475296,191.382586956024 PathPoint;PointKind.SMOOTHPOINT 496.37785077095,190.391714572906 500.463606119156,190.910518169403 492.292095422745,189.873147010803 PathPoint;PointKind.SMOOTHPOINT 521.569683551788,190.506427288055 530.741744041443,191.522083282471 512.397977113724,189.490535259247 PathPoint;PointKind.SMOOTHPOINT 605.018227100372,190.886206626892 612.18989610672,190.789904594421 597.846204042435,190.982744693756 PathPoint;PointKind.SMOOTHPOINT 649.111104011536,189.517915248871 662.829540967941,188.940575122833 635.39266705513,190.095255374908 PathPoint;PointKind.CORNERPOINT 745.162822008133,188.386130332947 745.162822008133,188.386130332947 745.162822008133,188.386130332947 PathPoint;PointKind.SMOOTHPOINT 867.980486154556,187.376139163971 872.60015130043,187.233338356018 831.444486379623,188.505091667175 PathPoint;PointKind.SMOOTHPOINT 1022.2889149189,186.509420871735 1028.87108802795,187.578656673431 1016.13833069801,185.510051250458 PathPoint;PointKind.CORNERPOINT 1036.4520406723,188.142778873444 1036.4520406723,188.142778873444 1036.4520406723,188.142778873444 PathPoint;PointKind.CORNERPOINT 1053.77153635025,188.221614360809 1053.77153635025,188.221614360809 1053.77153635025,188.221614360809 PathPoint;PointKind.SMOOTHPOINT 1088.41760873795,186.810364723206 1097.046200037,186.943016052246 1076.30621194839,186.62389755249 PathPoint;PointKind.SMOOTHPOINT 1115.18426299095,186.932158470154 1121.42371416092,188.067247867584 1109.80834364891,185.954031944275 PathPoint;PointKind.SMOOTHPOINT 1127.77292132378,188.558435440063 1128.31391215324,188.531763553619 1126.08338713646,188.641047477722 PathPoint;PointKind.SMOOTHPOINT 1140.37609577179,187.046635150909 1145.41956067085,185.990381240845 1136.06870412827,187.948758602142 PathPoint;PointKind.CORNERPOINT 1289.95333313942,187.727358341217 1289.95333313942,187.727358341217 1289.95333313942,187.727358341217 PathPoint;PointKind.SMOOTHPOINT 1516.69540643692,185.6214594841 1522.45582580566,185.892899036407 1508.05796384811,185.214536190033 PathPoint;PointKind.SMOOTHPOINT 1524.5610165596,187.226021289825 1533.36238503456,186.954817771912 1520.11342048645,187.363157272339 PathPoint;PointKind.CORNERPOINT 1534.01490211487,185.700294971466 1534.01490211487,185.700294971466 1534.01490211487,185.700294971466 PathPoint;PointKind.CORNERPOINT 1612.73968935013,186.058595180511 1612.73968935013,186.058595180511 1612.73968935013,186.058595180511 PathPoint;PointKind.SMOOTHPOINT 1620.60494542122,187.663156986237 1624.60856080055,188.292424678802 1616.60203814507,187.034361362457 PathPoint;PointKind.CORNERPOINT 1633.20847392082,186.151828765869 1633.20847392082,186.151828765869 1633.20847392082,186.151828765869 PathPoint;PointKind.CORNERPOINT 1771.76408529282,186.782276630402 1771.76408529282,186.782276630402 1771.76408529282,186.782276630402 PathPoint;PointKind.CORNERPOINT 1951.264346838,186.030035018921 1951.264346838,186.030035018921 1951.264346838,186.030035018921 PathPoint;PointKind.CORNERPOINT 1959.1292488575,187.634832859039 1959.1292488575,187.634832859039 1959.1292488575,187.634832859039 PathPoint;PointKind.CORNERPOINT 1968.58348846436,186.10910654068 1968.58348846436,186.10910654068 1968.58348846436,186.10910654068 PathPoint;PointKind.CORNERPOINT 2159.10502195358,185.407140254974 2159.10502195358,185.407140254974 2159.10502195358,185.407140254974 PathPoint;PointKind.CORNERPOINT 2499.20379281044,185.385897159576 2499.20379281044,185.385897159576 2499.20379281044,185.385897159576 PathPoint;PointKind.SMOOTHPOINT 2511.79245114326,187.012174129486 2516.25279307365,187.100450992584 2504.67707633972,186.871497631073 PathPoint;PointKind.SMOOTHPOINT 2524.39597964287,185.500609874725 2534.13133621216,186.100373268127 2514.6599149704,184.90061044693 PathPoint;PointKind.CORNERPOINT 2770.02458095551,185.049548149109 2770.02458095551,185.049548149109 2770.02458095551,185.049548149109 PathPoint;PointKind.SMOOTHPOINT 2784.1880607605,186.682906150818 2786.52409315109,186.615636348724 2781.8520283699,186.750175952911 PathPoint;PointKind.SMOOTHPOINT 2795.21676778793,185.164024829865 2799.61975336075,182.770164012909 2792.06146001816,186.879522800446 PathPoint;PointKind.SMOOTHPOINT 2804.65613722801,186.775903701782 2807.90597677231,187.019727230072 2801.40629768372,186.532080173492 PathPoint;PointKind.CORNERPOINT 2821.98306798935,185.285818576813 2821.98306798935,185.285818576813 2821.98306798935,185.285818576813 PathPoint;PointKind.CORNERPOINT 2996.75213813782,186.081254482269 2996.75213813782,186.081254482269 2996.75213813782,186.081254482269 PathPoint;PointKind.SMOOTHPOINT 3459.76876974106,185.340342521667 3462.0148730278,185.336802005768 3333.43324899673,185.542623996735 PathPoint;PointKind.SMOOTHPOINT 3466.30385398865,185.329957008362 3470.48874378204,186.885895729065 3464.32647585869,184.594709873199 PathPoint;PointKind.SMOOTHPOINT 3472.62721538544,185.319807529449 3494.1308927536,185.285582542419 3470.59637546539,185.323112010956 PathPoint;PointKind.CORNERPOINT 3506.9040119648,185.265047550201 3506.9040119648,185.265047550201 3506.9040119648,185.265047550201 PathPoint;PointKind.CORNERPOINT 3790.32089352608,184.986054897308 3790.32089352608,184.986054897308 3790.32089352608,184.986054897308 PathPoint;PointKind.SMOOTHPOINT 4010.75058102608,185.989201068878 4027.09537267685,185.93585729599 3928.56104493141,186.256864070892 PathPoint;PointKind.SMOOTHPOINT 4210.71183800697,186.89911365509 4216.31470441818,186.509420871735 4205.10897159576,187.288806438446 PathPoint;PointKind.SMOOTHPOINT 4333.52277517319,187.457807064056 4345.41218161583,186.888492107391 4321.63301467896,188.027358055115 PathPoint;PointKind.SMOOTHPOINT 4459.48264718056,188.031134605408 4473.17771673203,187.993133068085 4445.7872235775,188.069372177124 PathPoint;PointKind.SMOOTHPOINT 4517.74608492851,186.727516651154 4523.12873125076,186.990458965302 4512.36379265785,186.464338302612 PathPoint;PointKind.SMOOTHPOINT 4527.18580842018,188.339395523071 4532.29760527611,188.646240234375 4522.07436561584,188.032550811768 PathPoint;PointKind.SMOOTHPOINT 4542.93827176094,186.841993331909 4547.52076148987,186.764574050903 4533.8717186451,186.995179653168 PathPoint;PointKind.SMOOTHPOINT 4641.82240247726,187.127830982208 4643.76862406731,187.136564254761 4594.44959163666,186.917288303375 PathPoint;PointKind.SMOOTHPOINT 4647.66106724739,187.154266834259 4649.96948361397,189.314925670624 4646.24096632004,185.824921131134 PathPoint;PointKind.SMOOTHPOINT 4652.63903260231,187.176926136017 4654.57781910896,187.185895442963 4650.98242521286,187.169373035431 PathPoint;PointKind.SMOOTHPOINT 4658.43910574913,187.204070091248 4660.02030014992,187.211623191833 4656.51200294495,187.195100784302 PathPoint;PointKind.SMOOTHPOINT 4663.16604852676,187.226729393005 4665.91950774193,188.688018321991 4661.77993655205,186.490774154663 PathPoint;PointKind.SMOOTHPOINT 4670.17095923424,187.260954380035 4705.79138159752,187.437508106232 4667.85475373268,187.249388694763 PathPoint;PointKind.SMOOTHPOINT 4742.89952874184,187.752141952515 4729.4469845295,187.4880194664 4736.58360242844,187.627987861633 PathPoint;PointKind.SMOOTHPOINT 5062.5224339962,189.206585884094 5180.10367512703,188.811936378479 5018.35237383842,189.355051517487 PathPoint;PointKind.SMOOTHPOINT 5524.67199325562,192.186284065247 5526.53359651566,192.18652009964 5430.38451433182,192.176606655121 PathPoint;PointKind.SMOOTHPOINT 5530.07198810577,192.18297958374 5530.82930445671,190.996434688568 5528.91707181931,193.991711139679 PathPoint;PointKind.SMOOTHPOINT 5534.16942715645,192.174246311188 5551.5770816803,192.123970985413 5532.84562826157,192.178022861481 PathPoint;PointKind.SMOOTHPOINT 5561.63816571236,191.478180885315 5561.63816571236,191.478180885315 5561.62860631943,191.913900375366 PathPoint;PointKind.SMOOTHPOINT 5612.02253937721,191.707370281219 5620.59129595757,191.874718666077 5603.45342874527,191.540257930756 PathPoint;PointKind.SMOOTHPOINT 5640.35622596741,193.405401706696 5642.49930024147,193.751900196075 5638.21315169334,193.058903217316 PathPoint;PointKind.SMOOTHPOINT 5649.78178739548,198.155121803284 5654.88756537437,204.325060844421 5644.67636346817,191.985182762146 PathPoint;PointKind.SMOOTHPOINT 5654.43402528763,213.86604309082 5655.17930388451,221.84778213501 5654.02367949486,209.472734928131 PathPoint;PointKind.SMOOTHPOINT 5655.83005070686,253.096611499786 5653.56659889221,267.759304046631 5656.18658065796,250.786778926849 PathPoint;PointKind.SMOOTHPOINT 5655.63709259033,295.45770406723 5656.24818563461,301.713559627533 5655.02599954605,289.202084541321 PathPoint;PointKind.SMOOTHPOINT 5655.54433107376,315.853908061981 5654.09236550331,325.544536113739 5656.33244991302,310.595297813416 PathPoint;PointKind.SMOOTHPOINT 5656.96159958839,350.377714633942 5657.3460996151,363.007915019989 5656.63905858994,339.775757789612 PathPoint;PointKind.SMOOTHPOINT 5657.79362082481,513.554427623749 5657.76989936829,512.450966835022 5657.69661068916,509.065997600555 PathPoint;PointKind.CORNERPOINT 5659.85738754272,752.046883106232 5659.85738754272,752.046883106232 5659.85738754272,752.046883106232 PathPoint;PointKind.SMOOTHPOINT 5659.55042481422,819.511177539825 5657.20908164978,825.769865512848 5661.89141392708,813.252725601196 PathPoint;PointKind.SMOOTHPOINT 5659.48598742485,833.631699085236 5660.52973151207,838.516430854797 5658.44224333763,828.746731281281 PathPoint;PointKind.SMOOTHPOINT 5659.42898511887,846.183063983917 5659.03492569923,850.726490020752 5659.82269048691,841.639873981476 PathPoint;PointKind.CORNERPOINT 5659.26435112953,882.268710136414 5659.26435112953,882.268710136414 5659.26435112953,882.268710136414 PathPoint;PointKind.CORNERPOINT 5657.61871933937,897.950835227966 5657.61871933937,897.950835227966 5657.61871933937,897.950835227966 PathPoint;PointKind.SMOOTHPOINT 5659.11494135857,915.216279029846 5659.94342207909,918.764111995697 5658.01808953285,910.519902706146 PathPoint;PointKind.SMOOTHPOINT 5659.00766372681,938.750324249268 5660.86962103844,944.400751590729 5655.58398485184,928.361270427704 PathPoint;PointKind.SMOOTHPOINT 5658.94322633743,952.870845794678 5659.58122730255,959.592397212982 5658.3055794239,946.149294376373 PathPoint;PointKind.CORNERPOINT 5658.58634233475,1031.31758451462 5658.58634233475,1031.31758451462 5658.58634233475,1031.31758451462 PathPoint;PointKind.CORNERPOINT 5659.87509012222,1094.08219814301 5659.87509012222,1094.08219814301 5659.87509012222,1094.08219814301 PathPoint;PointKind.CORNERPOINT 5660.828551054,1230.58678865433 5660.828551054,1230.58678865433 5660.828551054,1230.58678865433 PathPoint;PointKind.CORNERPOINT 5661.90309762955,1340.41949272156 5661.90309762955,1340.41949272156 5661.90309762955,1340.41949272156 PathPoint;PointKind.SMOOTHPOINT 5661.74731492996,1509.48856830597 5661.74554467201,1511.50028944016 5661.84361696243,1405.10117769241 PathPoint;PointKind.SMOOTHPOINT 5661.74165010452,1515.56810617447 5663.52925658226,1517.8215265274 5660.47343730927,1513.9687371254 PathPoint;PointKind.SMOOTHPOINT 5661.73669338226,1521.17439508438 5661.64888858795,1616.52568101883 5661.73846364021,1519.29367303848 PathPoint;PointKind.SMOOTHPOINT 5661.40459299088,1881.61826848984 5661.39999032021,1886.32904291153 5661.53275966644,1742.51965999603 PathPoint;PointKind.SMOOTHPOINT 5661.39149308205,1895.79473018646 5661.93248391151,1899.36380624771 5660.71773290634,1891.35185480118 PathPoint;PointKind.SMOOTHPOINT 5661.38157963753,1906.64829969406 5661.30935311317,1984.94562864304 5661.38476610184,1903.02233934402 PathPoint;PointKind.SMOOTHPOINT 5661.15746498108,2149.72973585129 5661.15463256836,2152.99220323563 5661.23358607292,2066.98245048523 PathPoint;PointKind.SMOOTHPOINT 5661.14825963974,2159.52020645142 5660.24613618851,2163.9031291008 5661.80644154549,2156.32241249084 PathPoint;PointKind.SMOOTHPOINT 5661.13940834999,2169.18416261673 5661.10471129417,2207.04478740692 5661.1425948143,2165.96205711365 PathPoint;PointKind.SMOOTHPOINT 5661.03496313095,2282.77359008789 5661.03283882141,2285.1726436615 5661.06966018677,2245.00431060791 PathPoint;PointKind.SMOOTHPOINT 5661.02823615074,2289.96886253357 5661.87937617302,2291.44690990448 5659.59928393364,2287.48672485352 PathPoint;PointKind.SMOOTHPOINT 5661.02363348007,2295.0841999054 5660.95388531685,2370.80710172653 5661.02504968643,2293.37955951691 PathPoint;PointKind.SMOOTHPOINT 5660.81863760948,2517.23481416702 5660.81615924835,2520.01364707947 5660.88484525681,2445.63661336899 PathPoint;PointKind.SMOOTHPOINT 5660.81120252609,2525.55715084076 5662.34282970428,2532.6865696907 5660.22949576378,2522.84912824631 PathPoint;PointKind.SMOOTHPOINT 5660.79385399818,2544.02259349823 5660.6486928463,2701.66264772415 5660.79987287521,2537.89348840714 PathPoint;PointKind.SMOOTHPOINT 5660.43059706688,2938.57815742493 5660.42564034462,2943.5542345047 5660.51981806755,2841.80334806442 PathPoint;PointKind.SMOOTHPOINT 5660.41714310646,2953.15847396851 5659.72709655762,2958.65972757339 5661.00734710693,2948.45218420029 PathPoint;PointKind.SMOOTHPOINT 5660.40404319763,2967.41141080856 5660.34102201462,3035.52409172058 5660.40793776512,2962.787733078 PathPoint;PointKind.CORNERPOINT 5660.30420064926,3075.69171667099 5660.30420064926,3075.69171667099 5660.30420064926,3075.69171667099 PathPoint;PointKind.CORNERPOINT 5659.91155743599,3161.983294487 5659.91155743599,3161.983294487 5659.91155743599,3161.983294487 PathPoint;PointKind.SMOOTHPOINT 5658.30133080482,3169.82058048248 5657.688113451,3175.69524049759 5658.91419410706,3163.94639253616 PathPoint;PointKind.SMOOTHPOINT 5659.82587695122,3180.81034183502 5661.59613490105,3186.4178109169 5658.0552649498,3175.20310878754 PathPoint;PointKind.CORNERPOINT 5659.54015731812,3243.56787443161 5659.54015731812,3243.56787443161 5659.54015731812,3243.56787443161 PathPoint;PointKind.CORNERPOINT 5658.80443811417,3405.16834974289 5658.80443811417,3405.16834974289 5658.80443811417,3405.16834974289 PathPoint;PointKind.CORNERPOINT 5658.51199150085,3469.49456691742 5658.51199150085,3469.49456691742 5658.51199150085,3469.49456691742 PathPoint;PointKind.CORNERPOINT 5659.62229728699,3571.48266792297 5659.62229728699,3571.48266792297 5659.62229728699,3571.48266792297 PathPoint;PointKind.CORNERPOINT 5656.74421191216,3729.50155735016 5656.74421191216,3729.50155735016 5656.74421191216,3729.50155735016 PathPoint;PointKind.SMOOTHPOINT 5656.65145039558,3749.89776134491 5656.64932608604,3754.87596273422 5656.6542828083,3743.49839687347 PathPoint;PointKind.SMOOTHPOINT 5651.99992060661,3769.00002479553 5647.64862656593,3769.78389501572 5656.55408620834,3768.17956924438 PathPoint;PointKind.SMOOTHPOINT 5640.79949855804,3773.36005210876 5635.79887390137,3773.96288394928 5651.65507435799,3772.05124139786 PathPoint;PointKind.SMOOTHPOINT 5529.48780298233,3773.39946985245 5526.60122036934,3773.37940692902 5583.95722389221,3773.77618074417 PathPoint;PointKind.SMOOTHPOINT 5520.81176877022,3773.33810091019 5519.18631792068,3774.12763595581 5523.41440200806,3772.07390069962 PathPoint;PointKind.SMOOTHPOINT 5514.2742061615,3773.28994989395 5455.44039130211,3772.85139799118 5516.45197749138,3773.30623626709 PathPoint;PointKind.CORNERPOINT 5398.32655906677,3772.25659132004 5398.32655906677,3772.25659132004 5398.32655906677,3772.25659132004 PathPoint;PointKind.SMOOTHPOINT 5199.62041497231,3771.87586784363 5195.128916502,3771.86737060547 5309.03333187103,3772.08570241928 PathPoint;PointKind.SMOOTHPOINT 5186.04997158051,3771.84990406036 5178.04097056389,3773.13440322876 5190.54607272148,3771.12905502319 PathPoint;PointKind.SMOOTHPOINT 5163.68948936462,3771.80718183517 5080.5280816555,3771.64809465408 5171.2060046196,3771.82157993317 PathPoint;PointKind.SMOOTHPOINT 4921.20097160339,3771.34290218353 4913.29429149628,3771.4075756073 4990.49170017242,3770.77689170837 PathPoint;PointKind.SMOOTHPOINT 4898.31082820892,3771.48664712906 4896.57031059265,3771.57397985458 4900.0513458252,3771.39907836914 PathPoint;PointKind.SMOOTHPOINT 4891.29033923149,3771.5135550499 4888.5131585598,3770.68696260452 4893.50174546242,3772.17161893845 PathPoint;PointKind.SMOOTHPOINT 4882.76796340942,3771.53527021408 4834.69802498817,3771.62472724915 4885.55434942245,3771.53007745743 PathPoint;PointKind.CORNERPOINT 4803.15910935402,3771.11701726913 4803.15910935402,3771.11701726913 4803.15910935402,3771.11701726913 PathPoint;PointKind.SMOOTHPOINT 4750.37214159966,3771.03487730026 4692.10303902626,3770.94424009323 4783.8098359108,3771.08680486679 PathPoint;PointKind.SMOOTHPOINT 4475.05419015884,3770.60694694519 4461.47418737411,3770.58593988419 4591.05105042458,3770.78727722168 PathPoint;PointKind.SMOOTHPOINT 4433.74380469322,3770.54274559021 4423.53578925133,3771.37759923935 4447.64245390892,3769.40647602081 PathPoint;PointKind.SMOOTHPOINT 4406.2789607048,3770.50002336502 4302.43598341942,3770.33881187439 4415.49350738525,3770.51442146301 PathPoint;PointKind.SMOOTHPOINT 4094.24302697182,3774.00749444962 4091.2654531002,3774.00277376175 4194.51858043671,3774.1632771492 PathPoint;PointKind.SMOOTHPOINT 4085.33898353577,3773.99356842041 4082.44921445847,3773.28168869019 4087.58331656456,3774.54659700394 PathPoint;PointKind.SMOOTHPOINT 4076.4391887188,3773.9798784256 4038.77553462982,3773.92134189606 4079.39551949501,3773.98436307907 PathPoint;PointKind.SMOOTHPOINT 3969.04471993446,3773.58192443848 3967.5261926651,3773.57319116592 4002.62615919113,3773.77547264099 PathPoint;PointKind.SMOOTHPOINT 3965.00003457069,3770.99994421005 3963.55939865112,3772.79640197754 3965.94358205795,3769.82354879379 PathPoint;PointKind.SMOOTHPOINT 3958.00397515297,3773.51607084274 3839.14283752441,3772.78271198273 3960.15979528427,3773.52928876877 PathPoint;PointKind.CORNERPOINT 3755.10408997536,3771.48829936981 3755.10408997536,3771.48829936981 3755.10408997536,3771.48829936981 PathPoint;PointKind.SMOOTHPOINT 3443.17543387413,3772.06115484238 3437.10132479668,3772.07224845886 3636.43095374107,3771.70615911484 PathPoint;PointKind.SMOOTHPOINT 3424.73288655281,3772.09490776062 3420.24315834045,3771.08255624771 3430.38779854774,3773.36996555328 PathPoint;PointKind.SMOOTHPOINT 3410.80485105515,3772.12063550949 3262.5372505188,3772.39278316498 3415.48718333244,3772.11190223694 PathPoint;PointKind.SMOOTHPOINT 2866.14498496056,3773.12071323395 2861.6729593277,3773.12897443771 3075.10977387428,3772.73715734482 PathPoint;PointKind.SMOOTHPOINT 2852.6998758316,3773.14549684525 2850.04625916481,3773.09545755386 2857.19031214714,3773.23023319244 PathPoint;PointKind.SMOOTHPOINT 2837.85874128342,3773.17287683487 2603.72300863266,3773.60293149948 2842.81723380089,3773.16367149353 PathPoint;PointKind.SMOOTHPOINT 2082.84620404243,3774.55934286118 2075.94290614128,3774.57208871841 2344.01023507118,3774.07972097397 PathPoint;PointKind.SMOOTHPOINT 2062.13347792625,3774.5973443985 2054.28981900215,3775.48884630203 2068.99393558502,3773.81795883179 PathPoint;PointKind.SMOOTHPOINT 2038.37342977524,3774.64101076126 1396.1921775341,3775.82047462463 2046.29356384277,3774.62661266327 PathPoint;PointKind.SMOOTHPOINT 467.827484607697,3771.65234327316 465.817887783051,3771.64195775986 752.95797586441,3773.10607910156 PathPoint;PointKind.SMOOTHPOINT 461.852509975433,3771.62165880203 460.938702821732,3769.64203834534 462.679928541183,3773.41386795044 PathPoint;PointKind.SMOOTHPOINT 455.545080900192,3771.58932209015 366.17679476738,3771.12858295441 457.626904249191,3771.59994363785 PathPoint;PointKind.CORNERPOINT 315.300997495651,3770.80922842026 315.300997495651,3770.80922842026 315.300997495651,3770.80922842026 PathPoint;PointKind.SMOOTHPOINT 302.704904079437,3770.75187206268 299.616512060165,3770.55974006653 309.30265545845,3771.16257190704 PathPoint;PointKind.SMOOTHPOINT 286.988554000854,3764.40443515778 284.910979270935,3761.70278549194 289.714751243591,3767.94943571091 PathPoint;PointKind.SMOOTHPOINT 280.762202739716,3748.68643283844 281.250439882278,3741.07503175735 280.358229875565,3754.98123407364 PathPoint;PointKind.SMOOTHPOINT 282.010942697525,3700.76814651489 282.58096575737,3695.40355682373 281.44127368927,3706.13297224045 PathPoint;PointKind.SMOOTHPOINT 282.082461118698,3685.07894039154 281.047214269638,3680.19751310349 283.078408241272,3689.77295637131 PathPoint;PointKind.SMOOTHPOINT 282.153979539871,3669.3894982338 282.110785245895,3661.27062320709 282.197173833847,3677.47603654861 PathPoint;PointKind.SMOOTHPOINT 280.679354667664,3647.41729259491 281.091824769974,3641.48810863495 280.267238616943,3653.34624052048 PathPoint;PointKind.SMOOTHPOINT 282.446780204773,3605.06304502487 282.809683084488,3598.92284631729 282.071131467819,3611.41543865204 PathPoint;PointKind.CORNERPOINT 280.957993268967,3586.22868061066 280.957993268967,3586.22868061066 280.957993268967,3586.22868061066 PathPoint;PointKind.SMOOTHPOINT 281.015349626541,3573.67731571198 281.664326190948,3565.24663925171 280.29874920845,3582.97707080841 PathPoint;PointKind.SMOOTHPOINT 281.086159944534,3557.98810958862 282.499887943268,3551.25286817551 279.839544296265,3563.92956733704 PathPoint;PointKind.SMOOTHPOINT 281.150597333908,3543.86758804321 280.258387327194,3538.07554006577 282.042807340622,3549.65963602066 PathPoint;PointKind.SMOOTHPOINT 281.250793933868,3521.90246343613 280.728567838669,3516.77792072296 281.772665977478,3527.0267701149 PathPoint;PointKind.SMOOTHPOINT 281.321958303452,3506.21302127838 281.75496339798,3502.59248971939 280.640054941177,3511.9177365303 PathPoint;PointKind.SMOOTHPOINT 281.386395692825,3492.09249973297 280.277860164642,3487.90524959564 282.494931221008,3496.2797498703 PathPoint;PointKind.SMOOTHPOINT 281.4437520504,3479.54113483429 281.836749315262,3473.27678203583 281.050046682358,3485.80548763275 PathPoint;PointKind.SMOOTHPOINT 279.918851852417,3468.55137348175 278.631520271301,3459.54595327377 281.206537485123,3477.55679368973 PathPoint;PointKind.SMOOTHPOINT 278.622668981552,3407.35591650009 277.373929023743,3399.78464126587 279.871762990952,3414.92671966553 PathPoint;PointKind.SMOOTHPOINT 280.268654823303,3391.67355537415 280.089150667191,3387.01659679413 280.448513031006,3396.33074998856 PathPoint;PointKind.SMOOTHPOINT 278.830143213272,3361.85651063919 279.071252346039,3358.85769367218 278.3387196064,3367.96106815338 PathPoint;PointKind.SMOOTHPOINT 278.988758325577,3310.76120138168 278.986279964447,3308.84743452072 279.020268917084,3334.89642620087 PathPoint;PointKind.SMOOTHPOINT 277.000050544739,3305.00007390976 279.441590309143,3302.99071311951 275.528612136841,3306.21069431305 PathPoint;PointKind.SMOOTHPOINT 278.976366519928,3299.32391881943 278.961142301559,3278.5776758194 278.977782726288,3301.20865345001 PathPoint;PointKind.SMOOTHPOINT 279.301385879517,3258.30680608749 280.002408027649,3253.82522106171 278.999379873276,3260.23685932159 PathPoint;PointKind.SMOOTHPOINT 279.379631280899,3241.04844331741 278.43891620636,3234.15954351425 280.361770391464,3248.24041128159 PathPoint;PointKind.CORNERPOINT 279.522668123245,3209.66979503632 279.522668123245,3209.66979503632 279.522668123245,3209.66979503632 PathPoint;PointKind.CORNERPOINT 278.105045557022,3175.14598846436 278.105045557022,3175.14598846436 278.105045557022,3175.14598846436 PathPoint;PointKind.SMOOTHPOINT 279.722707271576,3165.73954582214 280.324949026108,3159.45583820343 279.119757413864,3172.02325344086 PathPoint;PointKind.SMOOTHPOINT 278.219404220581,3150.0430226326 278.191788196564,3145.27229547501 278.246666193008,3154.81374979019 PathPoint;PointKind.SMOOTHPOINT 278.43360543251,3102.97493219376 278.841826915741,3098.77942085266 277.892614603043,3108.53212594986 PathPoint;PointKind.CORNERPOINT 280.086672306061,3085.72365045547 280.086672306061,3085.72365045547 280.086672306061,3085.72365045547 PathPoint;PointKind.SMOOTHPOINT 278.583369255066,3070.02736330032 279.220308065414,3061.6516828537 277.946784496307,3078.40280771255 PathPoint;PointKind.SMOOTHPOINT 279.111968278885,2953.92605781555 279.305280447006,2946.63944005966 278.95795583725,2959.73793268204 PathPoint;PointKind.SMOOTHPOINT 279.454690217972,2878.61716032028 279.626405239105,2868.9414024353 279.217475652695,2891.97505474091 PathPoint;PointKind.SMOOTHPOINT 278.294109106064,2787.61150360107 278.223298788071,2781.57397985458 278.365273475647,2793.64926338196 PathPoint;PointKind.SMOOTHPOINT 280.19749045372,2715.44752836227 280.800794363022,2708.97994995117 279.593832492828,2721.91534280777 PathPoint;PointKind.SMOOTHPOINT 278.786948919296,2679.35503721237 279.143124818802,2673.16810369492 278.430773019791,2685.54173469543 PathPoint;PointKind.SMOOTHPOINT 279.258191585541,2575.80509662628 278.990882635117,2583.32279205322 278.792613744736,2588.90075683594 PathPoint;PointKind.CORNERPOINT 279.758112430573,2465.97970962524 279.758112430573,2465.97970962524 279.758112430573,2465.97970962524 PathPoint;PointKind.SMOOTHPOINT 278.733133077621,2345.16432523727 278.614171743393,2338.011302948 278.85244846344,2352.31758356094 PathPoint;PointKind.CORNERPOINT 280.464799404144,2310.6551527977 280.464799404144,2310.6551527977 280.464799404144,2310.6551527977 PathPoint;PointKind.CORNERPOINT 279.47593331337,2181.99516534805 279.47593331337,2181.99516534805 279.47593331337,2181.99516534805 PathPoint;PointKind.CORNERPOINT 278.922550678253,1957.63007640839 278.922550678253,1957.63007640839 278.922550678253,1957.63007640839 PathPoint;PointKind.CORNERPOINT 280.839740037918,1882.32825994492 280.839740037918,1882.32825994492 280.839740037918,1882.32825994492 PathPoint;PointKind.CORNERPOINT 280.007718801498,1719.15154695511 280.007718801498,1719.15154695511 280.007718801498,1719.15154695511 PathPoint;PointKind.SMOOTHPOINT 281.64626955986,1705.03834247589 281.348866224289,1696.50735139847 281.943672895432,1713.56933355331 PathPoint;PointKind.SMOOTHPOINT 280.136239528656,1690.91073989868 280.265114307404,1682.38588571548 280.007364749908,1699.43583011627 PathPoint;PointKind.CORNERPOINT 280.71440577507,1563.82699012756 280.71440577507,1563.82699012756 280.71440577507,1563.82699012756 PathPoint;PointKind.CORNERPOINT 281.093240976334,1480.67325353622 281.093240976334,1480.67325353622 281.093240976334,1480.67325353622 PathPoint;PointKind.CORNERPOINT 281.878527402878,1308.0903339386 281.878527402878,1308.0903339386 281.878527402878,1308.0903339386 PathPoint;PointKind.SMOOTHPOINT 281.950045824051,1292.40089178085 282.823137044907,1284.3084526062 281.076600551605,1300.4935669899 PathPoint;PointKind.SMOOTHPOINT 282.028291225433,1275.14276504517 282.443239688873,1265.98581075668 281.613696813583,1284.29971933365 PathPoint;PointKind.CORNERPOINT 281.103862524033,1132.36225605011 281.103862524033,1132.36225605011 281.103862524033,1132.36225605011 PathPoint;PointKind.SMOOTHPOINT 282.870934009552,1090.00800848007 282.725064754486,1083.34098100662 283.016803264618,1096.67550802231 PathPoint;PointKind.SMOOTHPOINT 282.99237370491,1063.33612203598 282.383050918579,1057.56578922272 283.601696491241,1069.10669088364 PathPoint;PointKind.SMOOTHPOINT 281.610510349274,1020.96794843674 282.219125032425,1013.36032390594 281.001895666122,1028.57533693314 PathPoint;PointKind.SMOOTHPOINT 282.088834047318,915.849087238312 282.385529279709,909.326984882355 281.792846918106,922.371425628662 PathPoint;PointKind.SMOOTHPOINT 283.734819889069,900.166962146759 283.576558828354,895.317871570587 283.893435001373,905.016052722931 PathPoint;PointKind.SMOOTHPOINT 282.353310585022,857.798552513123 282.864561080933,849.974012374878 281.842060089111,865.623092651367 PathPoint;PointKind.SMOOTHPOINT 284.049217700958,831.13374710083 283.317747116089,826.032807826996 284.780334234238,836.234686374664 PathPoint;PointKind.SMOOTHPOINT 282.660273313522,790.334022045135 283.603466749191,782.192959785461 281.717079877853,798.475320339203 PathPoint;PointKind.SMOOTHPOINT 282.845796346664,749.541850090027 283.001579046249,740.547287464142 282.690013647079,758.536648750305 PathPoint;PointKind.SMOOTHPOINT 283.124434947968,688.353238105774 283.156299591064,675.043258666992 283.092570304871,701.663217544556 PathPoint;PointKind.SMOOTHPOINT 285.141466856003,591.086533069611 285.569515228271,586.516199111938 284.512317180634,597.805252075195 PathPoint;PointKind.SMOOTHPOINT 285.612709522247,487.536828517914 285.799294710159,481.667833328247 285.426478385925,493.405587673187 PathPoint;PointKind.SMOOTHPOINT 285.670065879822,474.984991550446 286.147681474686,469.093101024628 285.192096233368,480.87735414505 PathPoint;PointKind.SMOOTHPOINT 285.762827396393,454.589023590088 286.784266233444,448.135607242584 284.741034507751,461.042439937592 PathPoint;PointKind.SMOOTHPOINT 286.20574593544,357.314765453339 286.278680562973,351.159460544586 286.132103204727,363.470542430878 PathPoint;PointKind.SMOOTHPOINT 287.844296693802,343.201797008514 287.625138759613,336.419820785522 288.063454627991,349.983537197113 PathPoint;PointKind.SMOOTHPOINT 287.96538233757,316.529910564423 288.596656322479,307.622916698456 287.334816455841,325.436432361603 PathPoint;PointKind.SMOOTHPOINT 286.569710969925,277.299106121063 287.96821475029,270.896437168121 285.17085313797,283.702011108398 PathPoint;PointKind.SMOOTHPOINT 286.655391454697,258.472058773041 288.605861663818,247.973721027374 285.37478685379,265.364735126495 PathPoint;PointKind.SMOOTHPOINT 288.358379602432,230.238332748413 289.568881988525,224.664144515991 287.147877216339,235.812520980835 PathPoint";


if (mask_variant_35mm == 8) {
	
	mask35mm[0] = "PointKind.SMOOTHPOINT 5757.14970231056,143.748250007629 5762.3705470562,146.203951835632 5757.14970231056,143.748250007629 PathPoint;PointKind.SMOOTHPOINT 5763.83702874184,155.371291637421 5764.5334482193,159.888517856598 5763.31551074982,151.991279125214 PathPoint;PointKind.SMOOTHPOINT 5761.81716442108,170.369389057159 5761.31157875061,172.210929393768 5763.52404713631,164.149882793427 PathPoint;PointKind.SMOOTHPOINT 5759.70170617104,178.233819007874 5760.00583648682,181.182124614716 5759.70170617104,176.167809963226 PathPoint;PointKind.SMOOTHPOINT 5760.61445116997,187.079916000366 5761.5271961689,187.31972694397 5760.31032085419,184.131610393524 PathPoint;PointKind.SMOOTHPOINT 5763.35233211517,187.799348831177 5762.86515712738,190.928928852081 5762.43994116783,187.559537887573 PathPoint;PointKind.SMOOTHPOINT 5761.8904531002,197.189269065857 5763.28895688057,197.971251010895 5762.377628088,194.059453010559 PathPoint;PointKind.SMOOTHPOINT 5766.0859644413,199.535450935364 5766.63368225098,207.117819786072 5764.68746066093,198.753468990326 PathPoint;PointKind.SMOOTHPOINT 5767.72982597351,222.284445762634 5761.92444205284,228.168075084686 5767.18210816383,214.70231294632 PathPoint;PointKind.SMOOTHPOINT 5762.07633018494,250.09024143219 5763.65646243095,252.136895656586 5762.07633018494,242.172231674194 PathPoint;PointKind.SMOOTHPOINT 5766.81708097458,256.230440139771 5768.82951021194,264.458835124969 5766.37345433235,252.650742530823 PathPoint;PointKind.SMOOTHPOINT 5768.36039185524,278.962204456329 5768.60397934914,281.513736248016 5767.56625413895,270.644352436066 PathPoint;PointKind.SMOOTHPOINT 5769.08336520195,286.679821014404 5768.54626893997,290.395946502686 5769.62718844414,282.9221534729 PathPoint;PointKind.SMOOTHPOINT 5768.67797613144,297.746529579163 5769.9706184864,305.776183605194 5768.10122609138,294.163763523102 PathPoint;PointKind.SMOOTHPOINT 5769.1874563694,319.241001605988 5767.77195811272,326.247446537018 5770.36680221558,313.403162956238 PathPoint;PointKind.SMOOTHPOINT 5762.98482656479,343.612732887268 5764.11920785904,354.606742858887 5762.04198718071,334.476313591003 PathPoint;PointKind.SMOOTHPOINT 5765.72270750999,375.571789741516 5767.54642724991,378.15943479538 5764.27782297134,364.096505641937 PathPoint;PointKind.SMOOTHPOINT 5771.19422078133,383.334724903107 5769.96849417686,384.547941684723 5769.37050104141,380.747315883636 PathPoint;PointKind.SMOOTHPOINT 5768.88651251793,389.34180021286 5764.18541550636,392.413551807404 5771.26361489296,387.788457870483 PathPoint;PointKind.SMOOTHPOINT 5766.45346999168,405.000321865082 5765.90575218201,405.060274600983 5766.45346999168,400.359177589417 PathPoint;PointKind.SMOOTHPOINT 5764.81031656265,405.180180072784 5764.99336123466,415.832412242889 5765.35803437233,405.120227336884 PathPoint;PointKind.SMOOTHPOINT 5765.35945057869,437.139472961426 5764.63010430336,438.763389587402 5765.17640590668,426.487476825714 PathPoint;PointKind.SMOOTHPOINT 5763.17070364952,442.012166976929 5765.41999340057,444.238443374634 5763.90040397644,440.388014316559 PathPoint;PointKind.SMOOTHPOINT 5769.91857290268,448.691704273224 5770.15720367432,454.723327159882 5767.66928315163,446.465427875519 PathPoint;PointKind.SMOOTHPOINT 5770.63446521759,466.787753105164 5770.54878473282,467.300891876221 5771.58367753029,461.113014221191 PathPoint;PointKind.SMOOTHPOINT 5770.69607019424,468.346524238586 5770.92266321182,474.073898792267 5770.67588925362,467.82701253891 PathPoint;PointKind.SMOOTHPOINT 5771.37620329857,485.527703762054 5769.21082377434,487.671368122101 5771.14961028099,479.801273345947 PathPoint;PointKind.SMOOTHPOINT 5767.65582919121,492.858459949493 5768.94280672073,495.008497238159 5765.68482398987,489.566252231598 PathPoint;PointKind.SMOOTHPOINT 5767.18069195747,500.509514808655 5765.60055971146,501.532959938049 5767.18069195747,497.915024757385 PathPoint;PointKind.SMOOTHPOINT 5762.43994116783,503.579850196838 5763.22983026505,512.847504615784 5764.01971936226,502.556405067444 PathPoint;PointKind.SMOOTHPOINT 5764.81031656265,531.385645866394 5766.99870944023,543.059198856354 5764.02007341385,522.117991447449 PathPoint;PointKind.SMOOTHPOINT 5771.37620329857,566.410317420959 5771.67289853096,567.291669845581 5769.1874563694,554.736528396606 PathPoint;PointKind.SMOOTHPOINT 5771.12234830856,587.672295570374 5771.05366230011,589.949555397034 5771.44524335861,576.941699981689 PathPoint;PointKind.SMOOTHPOINT 5770.90779304504,594.576773643494 5771.93737506866,598.775117397308 5770.20606279373,591.71320438385 PathPoint;PointKind.SMOOTHPOINT 5771.61943674088,606.670467853546 5771.93454265594,611.9153881073 5771.39815449715,602.984082698822 PathPoint;PointKind.SMOOTHPOINT 5770.28182983398,616.965107917786 5768.38942408562,618.952281475067 5770.28182983398,615.167233943939 PathPoint;PointKind.SMOOTHPOINT 5764.44670557976,617.868647575378 5763.3618915081,621.198148727417 5766.39151096344,617.567467689514 PathPoint;PointKind.SMOOTHPOINT 5763.83702874184,627.311675548553 5765.10099291801,654.016134738922 5763.71346473694,624.709160327911 PathPoint;PointKind.SMOOTHPOINT 5773.01971077919,710.127882957458 5772.41888523102,710.389409065247 5773.01971077919,681.021301746368 PathPoint;PointKind.SMOOTHPOINT 5770.90637683868,711.300973892212 5770.20146012306,710.590982437134 5772.34701275826,712.752585411072 PathPoint;PointKind.SMOOTHPOINT 5768.45633983612,712.114584445953 5768.45633983612,715.453999042511 5769.37687397003,711.714034080505 PathPoint;PointKind.SMOOTHPOINT 5768.77888083458,722.068154811859 5768.83340477943,722.948563098907 5768.57423901558,718.769338130951 PathPoint;PointKind.SMOOTHPOINT 5769.89626765251,724.299387931824 5769.67533946037,725.110874176025 5770.29103517532,722.85037279129 PathPoint;PointKind.SMOOTHPOINT 5769.16515111923,727.218189239502 5769.49583530426,731.012206077576 5769.0922164917,726.381683349609 PathPoint;PointKind.SMOOTHPOINT 5770.38839936256,738.558461666107 5770.56223869324,739.960033893585 5769.91998910904,734.788756370544 PathPoint;PointKind.SMOOTHPOINT 5770.9269118309,742.760818004608 5771.57907485962,743.763020038605 5770.1543712616,741.573801040649 PathPoint;PointKind.SMOOTHPOINT 5771.43710017204,746.588587760925 5772.02517986298,750.95876455307 5771.26503109932,745.312821865082 PathPoint;PointKind.SMOOTHPOINT 5773.16522598267,759.719889163971 5773.28454136848,760.694239139557 5772.62671351433,755.330121517181 PathPoint;PointKind.SMOOTHPOINT 5773.5132586956,762.645535469055 5773.01440000534,763.635935783386 5773.95617723465,761.76607131958 PathPoint;PointKind.SMOOTHPOINT 5773.8060593605,765.277082920074 5774.52832460403,772.030498981476 5773.71188163757,764.399034976959 PathPoint;PointKind.SMOOTHPOINT 5775.02647519112,785.778086185455 5774.05354142189,786.500351428986 5775.02647519112,778.843631744385 PathPoint;PointKind.SMOOTHPOINT 5772.10696578026,787.944645881653 5772.10696578026,791.495311260223 5773.07989954948,787.222616672516 PathPoint;PointKind.SMOOTHPOINT 5772.10696578026,798.597822189331 5774.10063028336,798.597822189331 5772.10696578026,795.046920776367 PathPoint;PointKind.SMOOTHPOINT 5777.07430958748,801.370046138763 5779.36502337456,802.274057865143 5775.15712022781,800.613555908203 PathPoint;PointKind.SMOOTHPOINT 5779.21809196472,807.443919181824 5777.92261719704,808.72629404068 5779.21809196472,805.420396327972 PathPoint;PointKind.SMOOTHPOINT 5776.06490850449,811.37932062149 5774.24756169319,812.55571603775 5777.38835334778,810.522751808167 PathPoint;PointKind.SMOOTHPOINT 5773.9862716198,816.457364559174 5773.28878998756,819.493002891541 5774.38245534897,814.731245040894 PathPoint;PointKind.SMOOTHPOINT 5774.09992218018,825.792996883392 5774.47627902031,827.609989643097 5773.44315648079,822.622110843658 PathPoint;PointKind.SMOOTHPOINT 5775.95586061478,829.286069869995 5776.36833071709,830.466477870941 5775.31538128853,827.451374530792 PathPoint;PointKind.SMOOTHPOINT 5776.99995875359,834.819660186768 5780.21651744843,842.788653373718 5776.5230512619,833.638308048248 PathPoint;PointKind.SMOOTHPOINT 5784.5079767704,857.814602851868 5782.51714468002,859.808621406555 5784.5079767704,850.717284679413 PathPoint;PointKind.SMOOTHPOINT 5777.34728336334,860.685017108917 5775.26581406593,860.051028728485 5779.97682452202,861.486117839813 PathPoint;PointKind.SMOOTHPOINT 5770.64933538437,860.704843997955 5771.28167152405,862.622623443604 5772.88587927818,860.704843997955 PathPoint;PointKind.SMOOTHPOINT 5772.54705190659,866.458654403687 5773.6934709549,868.071949481964 5771.63749337196,865.179347991943 PathPoint;PointKind.SMOOTHPOINT 5774.94610548019,871.280837059021 5774.64622378349,873.50026845932 5775.15782833099,869.713332653046 PathPoint;PointKind.SMOOTHPOINT 5776.4844596386,878.397037982941 5776.40196561813,880.866901874542 5775.79051852226,876.293263435364 PathPoint;PointKind.SMOOTHPOINT 5776.23626947403,885.807809829712 5776.87816500664,887.930703163147 5775.52037715912,883.439912796021 PathPoint;PointKind.SMOOTHPOINT 5776.01640343666,892.380659580231 5775.92859864235,895.003001689911 5776.08969211578,890.189788341522 PathPoint;PointKind.SMOOTHPOINT 5775.75334310532,900.246977806091 5776.89409732819,902.530138492584 5775.84114789963,897.625107765198 PathPoint;PointKind.SMOOTHPOINT 5779.1766679287,907.09716796875 5780.91116666794,908.605427742004 5777.24319219589,905.415894985199 PathPoint;PointKind.SMOOTHPOINT 5781.33532047272,911.416833400726 5782.15034723282,913.048775196075 5780.61588764191,909.977023601532 PathPoint;PointKind.SMOOTHPOINT 5783.7811088562,916.311950683594 5782.32241630554,920.464975833893 5782.9660820961,914.680480957031 PathPoint;PointKind.SMOOTHPOINT 5779.40396904945,928.772206306458 5779.29704546928,928.349704742432 5780.86266160011,924.619181156158 PathPoint;PointKind.SMOOTHPOINT 5777.82242059708,927.615637779236 5777.52112269402,927.205173969269 5778.57371807098,928.639318943024 PathPoint;PointKind.SMOOTHPOINT 5776.96596980095,927.273859977722 5775.1539337635,928.26827287674 5776.96596980095,927.273859977722 PathPoint;PointKind.SMOOTHPOINT 5773.41766476631,929.589829444885 5771.98304772377,931.010284423828 5775.22970080376,928.595180511475 PathPoint;PointKind.SMOOTHPOINT 5774.94610548019,935.27259349823 5776.43276810646,938.388955593109 5773.82234573364,932.917206287384 PathPoint;PointKind.SMOOTHPOINT 5777.61317610741,941.865742206573 5777.19433307648,943.34851026535 5777.61317610741,941.865742206573 PathPoint;PointKind.SMOOTHPOINT 5776.67529344559,946.56754732132 5775.53029060364,948.692564964294 5777.46412038803,945.103662014008 PathPoint;PointKind.SMOOTHPOINT 5776.27663135529,952.520806789398 5776.17608070374,959.155969619751 5776.3077878952,950.458102226257 PathPoint;PointKind.SMOOTHPOINT 5777.73957252502,973.675625324249 5777.84826636314,974.758079051971 5777.01907753944,966.508440971375 PathPoint;PointKind.SMOOTHPOINT 5778.05361628532,976.907408237457 5777.25204348564,977.620468139648 5779.36077475548,975.745646953583 PathPoint;PointKind.SMOOTHPOINT 5778.32729816437,980.069561004639 5778.5556614399,982.962162494659 5778.2451581955,979.024872779846 PathPoint;PointKind.SMOOTHPOINT 5778.70790362358,988.44712972641 5778.09928894043,988.628404140472 5778.70790362358,985.776164531708 PathPoint;PointKind.SMOOTHPOINT 5776.88241362572,988.990952968597 5777.204246521,990.854680538177 5777.49067425728,988.809678554535 PathPoint;PointKind.SMOOTHPOINT 5776.96596980095,995.264983177185 5777.43402600288,997.974421977997 5776.64378285408,993.401019573212 PathPoint;PointKind.SMOOTHPOINT 5779.25278902054,1002.70974397659 5777.72576451302,1008.79164218903 5778.7847328186,1000.00101327896 PathPoint;PointKind.SMOOTHPOINT 5775.05692362785,1020.22207975388 5776.02950334549,1023.13073158264 5773.62513899803,1013.10115814209 PathPoint;PointKind.SMOOTHPOINT 5777.97466278076,1028.94897937775 5777.88473367691,1028.94897937775 5778.22851777077,1028.94897937775 PathPoint;PointKind.SMOOTHPOINT 5779.99558925629,1031.26046419144 5780.47355890274,1033.59366416931 5779.53815460205,1029.02616262436 PathPoint;PointKind.SMOOTHPOINT 5781.12324357033,1038.55675935745 5782.09830164909,1041.38209104538 5780.37761092186,1036.39775276184 PathPoint;PointKind.SMOOTHPOINT 5783.81155729294,1046.40513896942 5781.72300696373,1049.50615882874 5783.10168385506,1044.28130149841 PathPoint;PointKind.SMOOTHPOINT 5779.06797409058,1055.08506774902 5778.3683681488,1056.81732416153 5780.16765832901,1052.3619389534 PathPoint;PointKind.SMOOTHPOINT 5777.50342011452,1060.15012979507 5775.85212349892,1061.58970355988 5778.7847328186,1059.03345108032 PathPoint;PointKind.SMOOTHPOINT 5776.95251584053,1067.14335680008 5777.07785010338,1069.76664304733 5776.84098958969,1064.80590820312 PathPoint;PointKind.SMOOTHPOINT 5778.29366326332,1075.26128768921 5778.14531564713,1076.59936666489 5778.61585021019,1072.35688447952 PathPoint;PointKind.SMOOTHPOINT 5779.73465323448,1080.05585432053 5780.44558882713,1082.19385385513 5779.18339490891,1078.39676856995 PathPoint;PointKind.SMOOTHPOINT 5782.1722984314,1086.84632778168 5781.50314092636,1092.50336408615 5781.26734256744,1084.44349765778 PathPoint;PointKind.SMOOTHPOINT 5780.16517996788,1103.81932497025 5780.16517996788,1103.81932497025 5780.83433747292,1098.16228866577 PathPoint;PointKind.SMOOTHPOINT 5781.621748209,1116.65983200073 5781.19015932083,1122.42780447006 5782.13016629219,1109.85873699188 PathPoint;PointKind.SMOOTHPOINT 5783.99743437767,1130.53771018982 5784.9632871151,1134.37444925308 5783.09885144234,1126.967689991 PathPoint;PointKind.SMOOTHPOINT 5785.79707860947,1140.89065074921 5786.06863617897,1144.00347232819 5785.52906155586,1137.81583070755 PathPoint;PointKind.SMOOTHPOINT 5785.04542708397,1148.24571847916 5785.45258641243,1150.46396970749 5784.49310660362,1145.23769617081 PathPoint;PointKind.SMOOTHPOINT 5784.71438884735,1154.97623920441 5783.03051948547,1160.81525802612 5785.19377470016,1153.31597328186 PathPoint;PointKind.SMOOTHPOINT 5780.27422785759,1163.19660902023 5781.62705898285,1166.59054756165 5780.27422785759,1163.19660902023 PathPoint;PointKind.SMOOTHPOINT 5782.94377684593,1173.21650505066 5783.3226120472,1175.83011388779 5782.46722340584,1169.92618560791 PathPoint;PointKind.SMOOTHPOINT 5783.02556276321,1181.24167442322 5784.19464111328,1184.85064029694 5782.23496556282,1178.80037069321 PathPoint;PointKind.SMOOTHPOINT 5782.92217969894,1189.9468588829 5782.1191906929,1197.51648187637 5783.23657751083,1186.98037862778 PathPoint;PointKind.SMOOTHPOINT 5780.71006536484,1212.4692606926 5782.35251069069,1214.7554898262 5780.71006536484,1204.96265888214 PathPoint;PointKind.SMOOTHPOINT 5785.6370472908,1219.32865619659 5785.50427794456,1223.17342042923 5783.99460196495,1217.04219102859 PathPoint;PointKind.SMOOTHPOINT 5785.23944735527,1230.86412906647 5785.41753530502,1230.72321653366 5784.66305136681,1231.32061958313 PathPoint;PointKind.SMOOTHPOINT 5785.3230035305,1235.63674449921 5784.14259552956,1242.67198562622 5785.82115411758,1232.66932010651 PathPoint;PointKind.SMOOTHPOINT 5784.17481422424,1261.75654649734 5785.08118629456,1267.28919267654 5784.42017197609,1254.63727712631 PathPoint;PointKind.SMOOTHPOINT 5786.89428448677,1278.35684537888 5788.11505436897,1281.18312120438 5784.66765403748,1273.20232629776 PathPoint;PointKind.SMOOTHPOINT 5788.55230808258,1288.479180336 5787.747194767,1294.09609079361 5787.99963355064,1285.10530471802 PathPoint;PointKind.SMOOTHPOINT 5779.7976744175,1299.67169523239 5781.56262159348,1299.67169523239 5783.28331232071,1296.22134447098 PathPoint;PointKind.SMOOTHPOINT 5783.98858308792,1300.8745265007 5785.27485251427,1300.55233955383 5782.31250286102,1301.2944316864 PathPoint;PointKind.SMOOTHPOINT 5786.05553627014,1304.22621488571 5789.23279523849,1308.87042760849 5785.46887278557,1303.36941003799 PathPoint;PointKind.SMOOTHPOINT 5784.17481422424,1329.28433418274 5785.0195813179,1330.04743337631 5784.17481422424,1325.61045885086 PathPoint;PointKind.SMOOTHPOINT 5787.06529140472,1331.22264862061 5787.61902809143,1331.72280550003 5786.22052431107,1330.45978546143 PathPoint;PointKind.SMOOTHPOINT 5788.37067961693,1333.07363033295 5788.13912987709,1336.76992893219 5787.81694293022,1332.57370948792 PathPoint;PointKind.SMOOTHPOINT 5787.67709255219,1344.16347026825 5787.53865838051,1346.3739323616 5787.90793418884,1340.46669960022 PathPoint;PointKind.SMOOTHPOINT 5787.26179003716,1350.7953286171 5786.15537881851,1352.70248651505 5788.37599039078,1348.87471675873 PathPoint;PointKind.SMOOTHPOINT 5786.91694378853,1356.31216049194 5786.49031162262,1363.13001394272 5787.03201055527,1354.47321653366 PathPoint;PointKind.SMOOTHPOINT 5785.6370472908,1376.76501274109 5787.45935082436,1378.61198186874 5786.06367945671,1369.94810342789 PathPoint;PointKind.SMOOTHPOINT 5790.09030818939,1385.76642036438 5790.71520924568,1391.08191490173 5789.63605999947,1381.90088510513 PathPoint;PointKind.SMOOTHPOINT 5792.38456249237,1399.15429115295 5791.46863102913,1401.70582294464 5792.38456249237,1396.1007142067 PathPoint;PointKind.SMOOTHPOINT 5789.08515572548,1406.2131357193 5789.11383390427,1409.25373077393 5789.0561234951,1403.1364274025 PathPoint;PointKind.SMOOTHPOINT 5786.54943823814,1415.40360689163 5788.11965703964,1420.68204402924 5787.57831215858,1412.53909349442 PathPoint;PointKind.SMOOTHPOINT 5791.26044869423,1431.24080657959 5791.57803297043,1434.30996179581 5790.69432020187,1425.76598882675 PathPoint;PointKind.SMOOTHPOINT 5793.73456120491,1439.55818653107 5794.56197977066,1442.33961582184 5792.90997505188,1436.78572654724 PathPoint;PointKind.SMOOTHPOINT 5796.21681690216,1447.90223836899 5794.88487482071,1450.35888433456 5795.38939833641,1445.12104511261 PathPoint;PointKind.SMOOTHPOINT 5793.12488436699,1456.20687246323 5791.78090453148,1458.68546962738 5794.45682644844,1453.74975442886 PathPoint;PointKind.SMOOTHPOINT 5788.18905115128,1462.70867586136 5794.16473388672,1468.62416982651 5789.5326769352,1460.2303147316 PathPoint;PointKind.SMOOTHPOINT 5796.52200937271,1483.74807357788 5797.27082848549,1486.45255565643 5794.42956447601,1476.19025230408 PathPoint;PointKind.SMOOTHPOINT 5794.13463950157,1494.2020368576 5793.28597784042,1498.71761083603 5794.79317545891,1490.6983423233 PathPoint;PointKind.SMOOTHPOINT 5791.80568814278,1507.67181158066 5790.44506788254,1511.625623703 5793.35253953934,1503.17653656006 PathPoint;PointKind.SMOOTHPOINT 5788.0754005909,1520.19862890244 5786.37949347496,1524.33560371399 5789.60596561432,1516.46385669708 PathPoint;PointKind.SMOOTHPOINT 5782.5355553627,1530.95566034317 5785.02807855606,1533.66297483444 5783.99212360382,1527.33347654343 PathPoint;PointKind.SMOOTHPOINT 5790.01454114914,1539.07831192017 5790.90993762016,1541.72402143478 5787.52166390419,1536.37099742889 PathPoint;PointKind.SMOOTHPOINT 5792.11477518082,1551.19466543198 5792.90820479393,1555.57593584061 5791.24168395996,1546.37271881104 PathPoint;PointKind.SMOOTHPOINT 5794.57330942154,1562.55075216293 5793.5727596283,1567.07718372345 5794.27201151848,1560.14957427979 PathPoint;PointKind.SMOOTHPOINT 5792.11477518082,1577.19172954559 5792.30454683304,1580.4376745224 5791.82480692863,1572.23099470139 PathPoint;PointKind.SMOOTHPOINT 5789.46469902992,1585.65969944 5789.46469902992,1591.17369890213 5790.16713738441,1582.48385667801 PathPoint;PointKind.SMOOTHPOINT 5793.47893595695,1594.51004505157 5792.50600218773,1600.76802492142 5791.98696255684,1590.04451036453 PathPoint;PointKind.SMOOTHPOINT 5790.5594265461,1613.28540086746 5789.06178832054,1619.21458482742 5791.53236031532,1607.02765703201 PathPoint;PointKind.SMOOTHPOINT 5794.39168095589,1630.07429122925 5793.48389267921,1633.27468156815 5795.27999639511,1623.01780700684 PathPoint;PointKind.SMOOTHPOINT 5791.6672539711,1639.67664241791 5789.42964792252,1643.08568716049 5793.49734663963,1636.88884019852 PathPoint;PointKind.SMOOTHPOINT 5788.55230808258,1650.65672636032 5788.55230808258,1657.77930021286 5789.59074139595,1646.99701309204 PathPoint;PointKind.SMOOTHPOINT 5795.30407190323,1662.573158741 5795.40816307068,1665.44380903244 5790.03472208977,1657.39786863327 PathPoint;PointKind.SMOOTHPOINT 5796.15450382233,1672.17952251434 5795.57739973068,1676.35473489761 5796.54785513878,1669.33294773102 PathPoint;PointKind.SMOOTHPOINT 5796.03093981743,1682.61601924896 5793.72110724449,1683.15677404404 5795.89285969734,1678.80666017532 PathPoint;PointKind.SMOOTHPOINT 5789.10144209862,1684.23875570297 5789.44133162498,1686.42561435699 5791.41092061996,1683.6977648735 PathPoint;PointKind.SMOOTHPOINT 5790.12146472931,1690.79980373383 5791.38684511185,1693.2387471199 5789.09967184067,1688.83151292801 PathPoint;PointKind.SMOOTHPOINT 5791.29018902779,1698.32151174545 5790.31725525856,1699.22481536865 5790.90037822723,1695.8145904541 PathPoint;PointKind.SMOOTHPOINT 5788.37067961693,1701.03189468384 5788.37067961693,1705.44975042343 5789.34361338615,1700.12859106064 PathPoint;PointKind.SMOOTHPOINT 5793.12488436699,1710.17468690872 5793.91512751579,1710.35596132278 5789.82370734215,1711.55100345612 PathPoint;PointKind.SMOOTHPOINT 5795.66732883453,1712.76823282242 5794.51276659966,1714.63337659836 5794.87779378891,1712.58695840836 PathPoint;PointKind.SMOOTHPOINT 5792.20293402672,1718.36437225342 5795.82098722458,1718.36437225342 5793.3574962616,1716.49922847748 PathPoint;PointKind.SMOOTHPOINT 5795.84931135178,1744.90714788437 5795.15076756477,1748.52933168411 5795.36673903465,1741.0741853714 PathPoint;PointKind.SMOOTHPOINT 5793.75403404236,1755.77440738678 5791.76745057106,1761.11704587936 5795.04136562347,1752.31367111206 PathPoint;PointKind.SMOOTHPOINT 5790.5594265461,1772.34897851944 5792.68231987953,1774.45039272308 5791.62405967712,1766.8248295784 PathPoint;PointKind.SMOOTHPOINT 5796.01819396019,1796.58994674683 5798.34749937057,1806.35988235474 5793.42936873436,1785.73047637939 PathPoint;PointKind.SMOOTHPOINT 5798.03770422935,1820.01352787018 5796.99573040009,1820.48536062241 5798.03770422935,1816.5936255455 PathPoint;PointKind.SMOOTHPOINT 5795.14474868774,1823.16057443619 5794.01426196098,1823.54176998138 5798.10072541237,1822.16356515884 PathPoint;PointKind.SMOOTHPOINT 5791.65344595909,1822.90376901627 5791.65344595909,1824.70282316208 5792.73932218552,1822.41234540939 PathPoint;PointKind.SMOOTHPOINT 5794.13463950157,1851.15684986115 5794.28688168526,1864.69955921173 5793.9749622345,1836.95678472519 PathPoint;PointKind.SMOOTHPOINT 5794.43381309509,1900.40967464447 5795.36992549896,1914.54128980637 5793.49770069122,1886.27829551697 PathPoint;PointKind.SMOOTHPOINT 5797.20957756042,2010.35378694534 5797.20957756042,2024.54511880875 5794.93267178535,2008.09965848923 PathPoint;PointKind.SMOOTHPOINT 5798.67181062698,2051.33879899979 5798.67181062698,2051.33879899979 5795.69388270378,2036.61544561386 PathPoint;PointKind.SMOOTHPOINT 5799.48754549026,3682.37705469131 5799.51870203018,3745.79949617386 5799.27192807198,3251.30484580994 PathPoint;PointKind.SMOOTHPOINT 5797.18412327766,3804.90800046921 5797.43054318428,3817.90617847443 5796.73235344887,3781.04775571823 PathPoint;PointKind.SMOOTHPOINT 5785.06529140472,3817.90617847443 5761.91987681389,3818.0905213356 5793.6120967865,3817.83820056915 PathPoint;PointKind.SMOOTHPOINT 5648.04661798477,3817.75275611877 4833.43657660484,3814.87384462357 5711.49514126778,3817.97698879242 PathPoint;PointKind.SMOOTHPOINT 248.655546665192,3817.66040611267 204.274471759796,3817.50367927551 944.45330953598,3820.11941242218 PathPoint;PointKind.SMOOTHPOINT 150.652296304703,3817.90871429443 141.489441156387,3817.98589754105 167.397874355316,3817.76732969284 PathPoint;PointKind.SMOOTHPOINT 141.5630838871,3807.90982532501 141.592470169067,3791.1535077095 141.557773113251,3810.87252902985 PathPoint;PointKind.SMOOTHPOINT 141.096993684769,3708.64130973816 141.248881816864,3154.08251523972 141.08495593071,3752.12262153625 PathPoint;PointKind.SMOOTHPOINT 142.062846422195,197.883541107178 142.069927453995,173.476876735687 141.950966119766,606.282522201538 PathPoint;PointKind.SMOOTHPOINT 142.076654434204,148.65762424469 142.184994220734,146.099247455597 141.723310947418,156.976892471313 PathPoint;PointKind.SMOOTHPOINT 147.058160305023,143.015694141388 159.995913505554,142.913019180298 146.086996793747,143.023247241974 PathPoint;PointKind.SMOOTHPOINT 198.335806131363,143.177613735199 784.691265821457,145.031191825867 172.373557090759,143.09570980072 PathPoint";
	
	mask35mm[1] = "PointKind.SMOOTHPOINT 5750.64966917038,143.748250007629 5755.87051391602,146.203951835632 5750.64966917038,143.748250007629 PathPoint;PointKind.SMOOTHPOINT 5757.33699560165,155.371291637421 5761.22873067856,157.767984867096 5752.78389215469,152.567911148071 PathPoint;PointKind.SMOOTHPOINT 5761.31724357605,170.369389057159 5760.81165790558,172.210929393768 5763.02412629128,164.149882793427 PathPoint;PointKind.SMOOTHPOINT 5759.201785326,178.233819007874 5759.50591564178,181.182124614716 5759.201785326,176.167809963226 PathPoint;PointKind.SMOOTHPOINT 5760.11453032494,187.079916000366 5761.02727532387,187.31972694397 5759.81040000916,184.131610393524 PathPoint;PointKind.SMOOTHPOINT 5762.85241127014,187.799348831177 5762.36523628235,190.928928852081 5761.9400203228,187.559537887573 PathPoint;PointKind.SMOOTHPOINT 5761.39053225517,197.189269065857 5762.78903603554,197.971251010895 5761.87770724297,194.059453010559 PathPoint;PointKind.SMOOTHPOINT 5765.58604359627,199.535450935364 5766.13376140594,207.117819786072 5764.1875398159,198.753468990326 PathPoint;PointKind.SMOOTHPOINT 5767.22990512848,222.284445762634 5761.42452120781,228.168075084686 5766.6821873188,214.70231294632 PathPoint;PointKind.SMOOTHPOINT 5761.5764093399,250.09024143219 5763.15654158592,252.136895656586 5761.5764093399,242.172231674194 PathPoint;PointKind.SMOOTHPOINT 5766.31716012955,256.230440139771 5768.32958936691,264.458835124969 5765.87353348732,252.650742530823 PathPoint;PointKind.SMOOTHPOINT 5767.86047101021,278.962204456329 5768.1040585041,281.513736248016 5767.06633329391,270.644352436066 PathPoint;PointKind.SMOOTHPOINT 5768.58344435692,286.679821014404 5768.04634809494,290.395946502686 5769.12726759911,282.9221534729 PathPoint;PointKind.SMOOTHPOINT 5768.17805528641,297.746529579163 5769.47069764137,305.776183605194 5767.60130524635,294.163763523102 PathPoint;PointKind.SMOOTHPOINT 5768.68753552437,319.241001605988 5767.27203726768,326.247446537018 5769.86688137054,313.403162956238 PathPoint;PointKind.SMOOTHPOINT 5762.48490571976,343.612732887268 5763.61928701401,354.606742858887 5761.54206633568,334.476313591003 PathPoint;PointKind.SMOOTHPOINT 5765.22278666496,375.571789741516 5767.04650640488,378.15943479538 5763.77790212631,364.096505641937 PathPoint;PointKind.SMOOTHPOINT 5770.69429993629,383.334724903107 5769.46857333183,384.547941684723 5768.87058019638,380.747315883636 PathPoint;PointKind.SMOOTHPOINT 5768.3865916729,389.34180021286 5763.68549466133,392.413551807404 5770.76369404793,387.788457870483 PathPoint;PointKind.SMOOTHPOINT 5760.95363259315,405.000321865082 5760.40591478348,405.060274600983 5760.95363259315,400.359177589417 PathPoint;PointKind.SMOOTHPOINT 5754.00005936623,415.99999666214 5754.18310403824,426.652228832245 5754.5477771759,415.940043926239 PathPoint;PointKind.SMOOTHPOINT 5759.85961318016,437.139472961426 5759.13026690483,438.763389587402 5759.67656850815,426.487476825714 PathPoint;PointKind.SMOOTHPOINT 5757.67086625099,442.012166976929 5759.92015600204,444.238443374634 5758.40056657791,440.388014316559 PathPoint;PointKind.SMOOTHPOINT 5764.41873550415,448.691704273224 5764.65736627579,454.723327159882 5762.1694457531,446.465427875519 PathPoint;PointKind.SMOOTHPOINT 5765.13462781906,466.787753105164 5765.04894733429,467.300891876221 5766.08384013176,461.113014221191 PathPoint;PointKind.SMOOTHPOINT 5765.19623279572,468.346524238586 5765.42282581329,474.073898792267 5765.17605185509,467.82701253891 PathPoint;PointKind.SMOOTHPOINT 5765.87636590004,485.527703762054 5763.71098637581,487.671368122101 5765.64977288246,479.801273345947 PathPoint;PointKind.SMOOTHPOINT 5762.15599179268,492.858459949493 5763.4429693222,495.008497238159 5760.18498659134,489.566252231598 PathPoint;PointKind.SMOOTHPOINT 5761.68085455894,500.509514808655 5760.10072231293,501.532959938049 5761.68085455894,497.915024757385 PathPoint;PointKind.SMOOTHPOINT 5756.9401037693,503.579850196838 5757.72999286652,512.847504615784 5758.51988196373,502.556405067444 PathPoint;PointKind.SMOOTHPOINT 5764.31039571762,531.385645866394 5766.4987885952,543.059198856354 5763.52015256882,522.117991447449 PathPoint;PointKind.SMOOTHPOINT 5770.87628245354,566.410317420959 5771.17297768593,567.291669845581 5768.68753552437,554.736528396606 PathPoint;PointKind.SMOOTHPOINT 5770.62242746353,587.672295570374 5770.55374145508,589.949555397034 5770.94532251358,576.941699981689 PathPoint;PointKind.SMOOTHPOINT 5770.40787220001,594.576773643494 5771.43745422363,598.775117397308 5769.7061419487,591.71320438385 PathPoint;PointKind.SMOOTHPOINT 5763.11936616898,615.670459270477 5763.43447208405,620.915379524231 5762.89808392525,611.984074115753 PathPoint;PointKind.SMOOTHPOINT 5761.78175926208,625.965099334717 5759.88935351372,627.952272891998 5761.78175926208,624.16722536087 PathPoint;PointKind.SMOOTHPOINT 5755.94663500786,626.86863899231 5754.8618209362,630.198140144348 5757.89144039154,626.567459106445 PathPoint;PointKind.SMOOTHPOINT 5755.33695816994,636.311666965485 5756.60092234612,663.016126155853 5755.21339416504,633.709151744843 PathPoint;PointKind.SMOOTHPOINT 5772.51978993416,710.127882957458 5771.91896438599,710.389409065247 5772.51978993416,681.021301746368 PathPoint;PointKind.SMOOTHPOINT 5770.40645599365,711.300973892212 5769.70153927803,710.590982437134 5771.84709191322,712.752585411072 PathPoint;PointKind.SMOOTHPOINT 5767.95641899109,712.114584445953 5767.95641899109,715.453999042511 5768.876953125,711.714034080505 PathPoint;PointKind.SMOOTHPOINT 5768.27895998955,722.068154811859 5768.3334839344,722.948563098907 5768.07431817055,718.769338130951 PathPoint;PointKind.SMOOTHPOINT 5769.39634680748,724.299387931824 5769.17541861534,725.110874176025 5769.79111433029,722.85037279129 PathPoint;PointKind.SMOOTHPOINT 5768.6652302742,727.218189239502 5768.99591445923,731.012206077576 5768.59229564667,726.381683349609 PathPoint;PointKind.SMOOTHPOINT 5769.88847851753,738.558461666107 5770.06231784821,739.960033893585 5769.42006826401,734.788756370544 PathPoint;PointKind.SMOOTHPOINT 5770.42699098587,742.760818004608 5771.07915401459,743.763020038605 5769.65445041656,741.573801040649 PathPoint;PointKind.SMOOTHPOINT 5770.93717932701,746.588587760925 5771.52525901794,750.95876455307 5770.76511025429,745.312821865082 PathPoint;PointKind.SMOOTHPOINT 5772.66530513763,759.719889163971 5772.78462052345,760.694239139557 5772.1267926693,755.330121517181 PathPoint;PointKind.SMOOTHPOINT 5773.01333785057,762.645535469055 5772.51447916031,763.635935783386 5773.45625638962,761.76607131958 PathPoint;PointKind.SMOOTHPOINT 5773.30613851547,765.277082920074 5774.028403759,772.030498981476 5773.21196079254,764.399034976959 PathPoint;PointKind.SMOOTHPOINT 5774.52655434608,785.778086185455 5773.55362057686,786.500351428986 5774.52655434608,778.843631744385 PathPoint;PointKind.SMOOTHPOINT 5771.60704493523,787.944645881653 5771.60704493523,791.495311260223 5772.57997870445,787.222616672516 PathPoint;PointKind.SMOOTHPOINT 5771.60704493523,798.597822189331 5773.60070943832,798.597822189331 5771.60704493523,795.046920776367 PathPoint;PointKind.SMOOTHPOINT 5776.57438874245,801.370046138763 5778.86510252953,802.274057865143 5774.65719938278,800.613555908203 PathPoint;PointKind.SMOOTHPOINT 5778.71817111969,807.443919181824 5777.42269635201,808.72629404068 5778.71817111969,805.420396327972 PathPoint;PointKind.SMOOTHPOINT 5775.56498765945,811.37932062149 5773.74764084816,812.55571603775 5776.88843250275,810.522751808167 PathPoint;PointKind.SMOOTHPOINT 5773.48635077477,816.457364559174 5772.78886914253,819.493002891541 5773.88253450394,814.731245040894 PathPoint;PointKind.SMOOTHPOINT 5773.60000133514,825.792996883392 5773.97635817528,827.609989643097 5772.94323563576,822.622110843658 PathPoint;PointKind.SMOOTHPOINT 5775.45593976974,829.286069869995 5775.86840987206,830.466477870941 5774.8154604435,827.451374530792 PathPoint;PointKind.SMOOTHPOINT 5776.50003790855,834.819660186768 5779.71659660339,842.788653373718 5776.02313041687,833.638308048248 PathPoint;PointKind.SMOOTHPOINT 5784.00805592537,857.814602851868 5782.01722383499,859.808621406555 5784.00805592537,850.717284679413 PathPoint;PointKind.SMOOTHPOINT 5776.84736251831,860.685017108917 5774.7658932209,860.051028728485 5779.47690367699,861.486117839813 PathPoint;PointKind.SMOOTHPOINT 5770.14941453934,860.704843997955 5770.78175067902,862.622623443604 5772.38595843315,860.704843997955 PathPoint;PointKind.SMOOTHPOINT 5772.04713106155,866.458654403687 5773.19355010986,868.071949481964 5771.13757252693,865.179347991943 PathPoint;PointKind.SMOOTHPOINT 5774.44618463516,871.280837059021 5774.14630293846,873.50026845932 5774.65790748596,869.713332653046 PathPoint;PointKind.SMOOTHPOINT 5775.98453879356,878.397037982941 5775.9020447731,880.866901874542 5775.29059767723,876.293263435364 PathPoint;PointKind.SMOOTHPOINT 5775.736348629,885.807809829712 5776.37824416161,887.930703163147 5775.02045631409,883.439912796021 PathPoint;PointKind.SMOOTHPOINT 5775.51648259163,892.380659580231 5775.42867779732,895.003001689911 5775.58977127075,890.189788341522 PathPoint;PointKind.SMOOTHPOINT 5775.25342226028,900.246977806091 5776.39417648315,902.530138492584 5775.3412270546,897.625107765198 PathPoint;PointKind.SMOOTHPOINT 5778.67674708366,907.09716796875 5780.41124582291,908.605427742004 5776.74327135086,905.415894985199 PathPoint;PointKind.SMOOTHPOINT 5780.83539962769,911.416833400726 5781.65042638779,913.048775196075 5780.11596679688,909.977023601532 PathPoint;PointKind.SMOOTHPOINT 5783.28118801117,916.311950683594 5781.82249546051,920.464975833893 5782.46616125107,914.680480957031 PathPoint;PointKind.SMOOTHPOINT 5778.90404820442,928.772206306458 5778.79712462425,928.349704742432 5780.36274075508,924.619181156158 PathPoint;PointKind.SMOOTHPOINT 5777.32249975204,927.615637779236 5777.02120184898,927.205173969269 5778.07379722595,928.639318943024 PathPoint;PointKind.SMOOTHPOINT 5776.46604895592,927.273859977722 5774.65401291847,928.26827287674 5776.46604895592,927.273859977722 PathPoint;PointKind.SMOOTHPOINT 5772.91774392128,929.589829444885 5771.48312687874,931.010284423828 5774.72977995872,928.595180511475 PathPoint;PointKind.SMOOTHPOINT 5774.44618463516,935.27259349823 5775.93284726143,938.388955593109 5773.32242488861,932.917206287384 PathPoint;PointKind.SMOOTHPOINT 5777.11325526237,941.865742206573 5776.69441223145,943.34851026535 5777.11325526237,941.865742206573 PathPoint;PointKind.SMOOTHPOINT 5776.17537260056,946.56754732132 5775.03036975861,948.692564964294 5776.964199543,945.103662014008 PathPoint;PointKind.SMOOTHPOINT 5775.77671051025,952.520806789398 5775.6761598587,959.155969619751 5775.80786705017,950.458102226257 PathPoint;PointKind.SMOOTHPOINT 5777.23965167999,973.675625324249 5777.34834551811,974.758079051971 5776.51915669441,966.508440971375 PathPoint;PointKind.SMOOTHPOINT 5777.55369544029,976.907408237457 5776.75212264061,977.620468139648 5778.86085391045,975.745646953583 PathPoint;PointKind.SMOOTHPOINT 5777.82737731934,980.069561004639 5778.05574059486,982.962162494659 5777.74523735046,979.024872779846 PathPoint;PointKind.SMOOTHPOINT 5778.20798277855,988.44712972641 5777.5993680954,988.628404140472 5778.20798277855,985.776164531708 PathPoint;PointKind.SMOOTHPOINT 5776.38249278069,988.990952968597 5776.70432567596,990.854680538177 5776.99075341225,988.809678554535 PathPoint;PointKind.SMOOTHPOINT 5776.46604895592,995.264983177185 5776.93410515785,997.974421977997 5776.14386200905,993.401019573212 PathPoint;PointKind.SMOOTHPOINT 5778.75286817551,1002.70974397659 5777.22584366798,1008.79164218903 5778.28481197357,1000.00101327896 PathPoint;PointKind.SMOOTHPOINT 5774.55700278282,1020.22207975388 5775.52958250046,1023.13073158264 5773.125218153,1013.10115814209 PathPoint;PointKind.SMOOTHPOINT 5777.47474193573,1028.94897937775 5777.38481283188,1028.94897937775 5777.72859692574,1028.94897937775 PathPoint;PointKind.SMOOTHPOINT 5779.49566841125,1031.26046419144 5779.97363805771,1033.59366416931 5779.03823375702,1029.02616262436 PathPoint;PointKind.SMOOTHPOINT 5780.6233227253,1038.55675935745 5781.59838080406,1041.38209104538 5779.87769007683,1036.39775276184 PathPoint;PointKind.SMOOTHPOINT 5783.31163644791,1046.40513896942 5782.24523305893,1053.51685523987 5782.60176301003,1044.28130149841 PathPoint;PointKind.SMOOTHPOINT 5778.56805324554,1055.08506774902 5777.86844730377,1056.81732416153 5779.66773748398,1052.3619389534 PathPoint;PointKind.SMOOTHPOINT 5777.00349926949,1060.15012979507 5775.35220265388,1061.58970355988 5778.28481197357,1059.03345108032 PathPoint;PointKind.SMOOTHPOINT 5776.4525949955,1067.14335680008 5776.57792925835,1069.76664304733 5776.34106874466,1064.80590820312 PathPoint;PointKind.SMOOTHPOINT 5777.79374241829,1075.26128768921 5777.64539480209,1076.59936666489 5778.11592936516,1072.35688447952 PathPoint;PointKind.SMOOTHPOINT 5779.23473238945,1080.05585432053 5779.9456679821,1082.19385385513 5778.68347406387,1078.39676856995 PathPoint;PointKind.SMOOTHPOINT 5781.67237758636,1086.84632778168 5781.00322008133,1092.50336408615 5780.76742172241,1084.44349765778 PathPoint;PointKind.SMOOTHPOINT 5779.66525912285,1103.81932497025 5779.66525912285,1103.81932497025 5780.33441662788,1098.16228866577 PathPoint;PointKind.SMOOTHPOINT 5781.12182736397,1116.65983200073 5780.6902384758,1122.42780447006 5781.63024544716,1109.85873699188 PathPoint;PointKind.SMOOTHPOINT 5783.49751353264,1130.53771018982 5784.46336627007,1134.37444925308 5782.59893059731,1126.967689991 PathPoint;PointKind.SMOOTHPOINT 5785.29715776443,1140.89065074921 5785.56871533394,1144.00347232819 5785.02914071083,1137.81583070755 PathPoint;PointKind.SMOOTHPOINT 5784.54550623894,1148.24571847916 5784.9526655674,1150.46396970749 5783.99318575859,1145.23769617081 PathPoint;PointKind.SMOOTHPOINT 5784.21446800232,1154.97623920441 5782.53059864044,1160.81525802612 5784.69385385513,1153.31597328186 PathPoint;PointKind.SMOOTHPOINT 5781.99987530708,1167.00006723404 5783.35270643234,1170.39400577545 5781.99987530708,1167.00006723404 PathPoint;PointKind.SMOOTHPOINT 5782.4438560009,1173.21650505066 5782.82269120216,1175.83011388779 5781.96730256081,1169.92618560791 PathPoint;PointKind.SMOOTHPOINT 5782.52564191818,1181.24167442322 5783.69472026825,1184.85064029694 5781.73504471779,1178.80037069321 PathPoint;PointKind.SMOOTHPOINT 5782.42225885391,1189.9468588829 5781.61926984787,1197.51648187637 5782.7366566658,1186.98037862778 PathPoint;PointKind.SMOOTHPOINT 5780.21014451981,1212.4692606926 5781.85258984566,1214.7554898262 5780.21014451981,1204.96265888214 PathPoint;PointKind.SMOOTHPOINT 5785.13712644577,1219.32865619659 5785.00435709953,1223.17342042923 5783.49468111992,1217.04219102859 PathPoint;PointKind.SMOOTHPOINT 5784.73952651024,1230.86412906647 5784.91761445999,1230.72321653366 5784.16313052177,1231.32061958313 PathPoint;PointKind.SMOOTHPOINT 5784.82308268547,1235.63674449921 5783.64267468452,1242.67198562622 5785.32123327255,1232.66932010651 PathPoint;PointKind.SMOOTHPOINT 5783.67489337921,1261.75654649734 5784.58126544952,1267.28919267654 5783.92025113106,1254.63727712631 PathPoint;PointKind.SMOOTHPOINT 5786.39436364174,1278.35684537888 5787.61513352394,1281.18312120438 5784.16773319244,1273.20232629776 PathPoint;PointKind.SMOOTHPOINT 5785.00010848045,1289.9999499321 5784.19499516487,1295.61686038971 5784.44743394852,1286.62607431412 PathPoint;PointKind.SMOOTHPOINT 5779.29775357246,1299.67169523239 5781.06270074844,1299.67169523239 5782.78339147568,1296.22134447098 PathPoint;PointKind.SMOOTHPOINT 5783.48866224289,1300.8745265007 5784.77493166924,1300.55233955383 5781.81258201599,1301.2944316864 PathPoint;PointKind.SMOOTHPOINT 5785.55561542511,1304.22621488571 5788.73287439346,1308.87042760849 5784.96895194054,1303.36941003799 PathPoint;PointKind.SMOOTHPOINT 5783.67489337921,1329.28433418274 5784.51966047287,1330.04743337631 5783.67489337921,1325.61045885086 PathPoint;PointKind.SMOOTHPOINT 5786.56537055969,1331.22264862061 5787.1191072464,1331.72280550003 5785.72060346603,1330.45978546143 PathPoint;PointKind.SMOOTHPOINT 5787.8707587719,1333.07363033295 5787.63920903206,1336.76992893219 5787.31702208519,1332.57370948792 PathPoint;PointKind.SMOOTHPOINT 5787.17717170715,1344.16347026825 5787.03873753548,1346.3739323616 5787.40801334381,1340.46669960022 PathPoint;PointKind.SMOOTHPOINT 5786.76186919212,1350.7953286171 5785.65545797348,1352.70248651505 5787.87606954575,1348.87471675873 PathPoint;PointKind.SMOOTHPOINT 5786.4170229435,1356.31216049194 5785.99039077759,1363.13001394272 5786.53208971024,1354.47321653366 PathPoint;PointKind.SMOOTHPOINT 5785.13712644577,1376.76501274109 5786.95942997932,1378.61198186874 5785.56375861168,1369.94810342789 PathPoint;PointKind.SMOOTHPOINT 5789.59038734436,1385.76642036438 5790.21528840065,1391.08191490173 5789.13613915443,1381.90088510513 PathPoint;PointKind.SMOOTHPOINT 5791.88464164734,1399.15429115295 5790.9687101841,1401.70582294464 5791.88464164734,1396.1007142067 PathPoint;PointKind.SMOOTHPOINT 5788.58523488045,1406.2131357193 5788.61391305923,1409.25373077393 5788.55620265007,1403.1364274025 PathPoint;PointKind.SMOOTHPOINT 5786.04951739311,1415.40360689163 5787.61973619461,1420.68204402924 5787.07839131355,1412.53909349442 PathPoint;PointKind.SMOOTHPOINT 5790.7605278492,1431.24080657959 5791.0781121254,1434.30996179581 5790.19439935684,1425.76598882675 PathPoint;PointKind.SMOOTHPOINT 5793.23464035988,1439.55818653107 5794.06205892563,1442.33961582184 5792.41005420685,1436.78572654724 PathPoint;PointKind.SMOOTHPOINT 5795.71689605713,1447.90223836899 5794.38495397568,1450.35888433456 5794.88947749138,1445.12104511261 PathPoint;PointKind.SMOOTHPOINT 5792.62496352196,1456.20687246323 5791.28098368645,1458.68546962738 5793.95690560341,1453.74975442886 PathPoint;PointKind.SMOOTHPOINT 5787.68913030624,1462.70867586136 5793.66481304169,1468.62416982651 5789.03275609016,1460.2303147316 PathPoint;PointKind.SMOOTHPOINT 5796.02208852768,1483.74807357788 5796.77090764046,1486.45255565643 5793.92964363098,1476.19025230408 PathPoint;PointKind.SMOOTHPOINT 5793.63471865654,1494.2020368576 5792.78605699539,1498.71761083603 5794.29325461388,1490.6983423233 PathPoint;PointKind.SMOOTHPOINT 5791.30576729774,1507.67181158066 5789.94514703751,1511.625623703 5792.85261869431,1503.17653656006 PathPoint;PointKind.SMOOTHPOINT 5787.57547974586,1520.19862890244 5785.87957262993,1524.33560371399 5789.10604476929,1516.46385669708 PathPoint;PointKind.SMOOTHPOINT 5782.03563451767,1530.95566034317 5784.52815771103,1533.66297483444 5783.49220275879,1527.33347654343 PathPoint;PointKind.SMOOTHPOINT 5789.51462030411,1539.07831192017 5790.41001677513,1541.72402143478 5787.02174305916,1536.37099742889 PathPoint;PointKind.SMOOTHPOINT 5791.61485433578,1551.19466543198 5792.4082839489,1555.57593584061 5790.74176311493,1546.37271881104 PathPoint;PointKind.SMOOTHPOINT 5794.07338857651,1562.55075216293 5793.07283878326,1567.07718372345 5793.77209067345,1560.14957427979 PathPoint;PointKind.SMOOTHPOINT 5791.61485433578,1577.19172954559 5791.80462598801,1580.4376745224 5791.3248860836,1572.23099470139 PathPoint;PointKind.SMOOTHPOINT 5788.96477818489,1585.65969944 5788.96477818489,1591.17369890213 5789.66721653938,1582.48385667801 PathPoint;PointKind.SMOOTHPOINT 5792.97901511192,1594.51004505157 5792.0060813427,1600.76802492142 5791.48704171181,1590.04451036453 PathPoint;PointKind.SMOOTHPOINT 5790.05950570107,1613.28540086746 5788.56186747551,1619.21458482742 5791.03243947029,1607.02765703201 PathPoint;PointKind.SMOOTHPOINT 5793.89176011086,1630.07429122925 5792.98397183418,1633.27468156815 5794.78007555008,1623.01780700684 PathPoint;PointKind.SMOOTHPOINT 5791.16733312607,1639.67664241791 5788.92972707748,1643.08568716049 5792.9974257946,1636.88884019852 PathPoint;PointKind.SMOOTHPOINT 5788.05238723755,1650.65672636032 5788.05238723755,1657.77930021286 5789.09082055092,1646.99701309204 PathPoint;PointKind.SMOOTHPOINT 5794.8041510582,1662.573158741 5794.90824222565,1665.44380903244 5789.53480124474,1657.39786863327 PathPoint;PointKind.SMOOTHPOINT 5795.65458297729,1672.17952251434 5795.07747888565,1676.35473489761 5796.04793429375,1669.33294773102 PathPoint;PointKind.SMOOTHPOINT 5795.5310189724,1682.61601924896 5793.22118639946,1683.15677404404 5795.39293885231,1678.80666017532 PathPoint;PointKind.SMOOTHPOINT 5788.60152125359,1684.23875570297 5788.94141077995,1686.42561435699 5790.91099977493,1683.6977648735 PathPoint;PointKind.SMOOTHPOINT 5789.62154388428,1690.79980373383 5790.88692426682,1693.2387471199 5788.59975099564,1688.83151292801 PathPoint;PointKind.SMOOTHPOINT 5790.79026818275,1698.32151174545 5789.81733441353,1699.22481536865 5790.4004573822,1695.8145904541 PathPoint;PointKind.SMOOTHPOINT 5787.8707587719,1701.03189468384 5787.8707587719,1705.44975042343 5788.84369254112,1700.12859106064 PathPoint;PointKind.SMOOTHPOINT 5792.62496352196,1710.17468690872 5793.41520667076,1710.35596132278 5789.32378649712,1711.55100345612 PathPoint;PointKind.SMOOTHPOINT 5795.1674079895,1712.76823282242 5794.01284575462,1714.63337659836 5794.37787294388,1712.58695840836 PathPoint;PointKind.SMOOTHPOINT 5791.70301318169,1718.36437225342 5795.32106637955,1718.36437225342 5792.85757541656,1716.49922847748 PathPoint;PointKind.SMOOTHPOINT 5795.34939050674,1744.90714788437 5794.65084671974,1748.52933168411 5794.86681818962,1741.0741853714 PathPoint;PointKind.SMOOTHPOINT 5793.25411319733,1755.77440738678 5791.26752972603,1761.11704587936 5794.54144477844,1752.31367111206 PathPoint;PointKind.SMOOTHPOINT 5790.05950570107,1772.34897851944 5792.1823990345,1774.45039272308 5791.12413883209,1766.8248295784 PathPoint;PointKind.SMOOTHPOINT 5795.51827311516,1796.58994674683 5797.84757852554,1806.35988235474 5792.92944788933,1785.73047637939 PathPoint;PointKind.SMOOTHPOINT 5796.0001373291,1814.99992132187 5794.95816349983,1815.4717540741 5796.0001373291,1811.58001899719 PathPoint;PointKind.SMOOTHPOINT 5794.00009989738,1820.99991559982 5792.86961317062,1821.38111114502 5796.95607662201,1820.00290632248 PathPoint;PointKind.SMOOTHPOINT 5791.15352511406,1822.90376901627 5791.15352511406,1824.70282316208 5792.23940134048,1822.41234540939 PathPoint;PointKind.SMOOTHPOINT 5793.63471865654,1851.15684986115 5793.78696084023,1864.69955921173 5793.47504138947,1836.95678472519 PathPoint;PointKind.SMOOTHPOINT 5793.93389225006,1900.40967464447 5794.87000465393,1914.54128980637 5792.99777984619,1886.27829551697 PathPoint;PointKind.SMOOTHPOINT 5796.70965671539,2010.35378694534 5796.70965671539,2024.54511880875 5794.43275094032,2008.09965848923 PathPoint;PointKind.SMOOTHPOINT 5798.17188978195,2051.33879899979 5798.17188978195,2051.33879899979 5795.19396185875,2036.61544561386 PathPoint;PointKind.SMOOTHPOINT 5796.98762464523,3666.37705469131 5797.01878118515,3729.79949617386 5796.77200722694,3235.30484580994 PathPoint;PointKind.SMOOTHPOINT 5796.68420243263,3804.90800046921 5796.93062233925,3817.90617847443 5796.23243260384,3781.04775571823 PathPoint;PointKind.SMOOTHPOINT 5784.56537055969,3817.90617847443 5761.41995596886,3818.0905213356 5793.11217594147,3817.83820056915 PathPoint;PointKind.SMOOTHPOINT 5647.54669713974,3817.75275611877 4832.93665575981,3814.87384462357 5710.99522042274,3817.97698879242 PathPoint;PointKind.SMOOTHPOINT 249.15562582016,3817.66040611267 204.774550914764,3817.50367927551 944.953388690948,3820.11941242218 PathPoint;PointKind.SMOOTHPOINT 151.152375459671,3817.90871429443 141.989520311356,3817.98589754105 167.897953510284,3817.76732969284 PathPoint;PointKind.SMOOTHPOINT 142.063163042068,3807.90982532501 142.092549324036,3791.1535077095 142.057852268219,3810.87252902985 PathPoint;PointKind.SMOOTHPOINT 140.597072839737,3708.64130973816 140.748960971832,3154.08251523972 140.585035085678,3752.12262153625 PathPoint;PointKind.SMOOTHPOINT 141.562925577164,197.883541107178 141.570006608963,173.476876735687 141.451045274734,606.282522201538 PathPoint;PointKind.SMOOTHPOINT 141.576733589172,148.65762424469 141.685073375702,146.099247455597 141.223390102386,156.976892471313 PathPoint;PointKind.SMOOTHPOINT 146.558239459991,143.015694141388 159.495992660522,142.913019180298 145.587075948715,143.023247241974 PathPoint;PointKind.SMOOTHPOINT 197.835885286331,143.177613735199 784.191344976425,145.031191825867 171.873636245728,143.09570980072 PathPoint";
	
	mask35mm[2] = "PointKind.SMOOTHPOINT 5745.64975261688,143.748250007629 5750.87059736252,146.203951835632 5745.64975261688,143.748250007629 PathPoint;PointKind.SMOOTHPOINT 5752.33707904816,155.371291637421 5756.22881412506,157.767984867096 5747.7839756012,152.567911148071 PathPoint;PointKind.SMOOTHPOINT 5756.31732702255,170.369389057159 5755.81174135208,172.210929393768 5758.02420973778,164.149882793427 PathPoint;PointKind.SMOOTHPOINT 5754.20186877251,178.233819007874 5754.50599908829,181.182124614716 5754.20186877251,176.167809963226 PathPoint;PointKind.SMOOTHPOINT 5755.11461377144,187.079916000366 5756.02735877037,187.31972694397 5754.81048345566,184.131610393524 PathPoint;PointKind.SMOOTHPOINT 5757.85249471664,187.799348831177 5757.36531972885,190.928928852081 5756.9401037693,187.559537887573 PathPoint;PointKind.SMOOTHPOINT 5756.39061570168,197.189269065857 5757.78911948204,197.971251010895 5756.87779068947,194.059453010559 PathPoint;PointKind.SMOOTHPOINT 5760.58612704277,199.535450935364 5761.13384485245,207.117819786072 5759.18762326241,198.753468990326 PathPoint;PointKind.SMOOTHPOINT 5762.22998857498,222.284445762634 5756.42460465431,228.168075084686 5761.6822707653,214.70231294632 PathPoint;PointKind.SMOOTHPOINT 5756.57649278641,250.09024143219 5758.15662503242,252.136895656586 5756.57649278641,242.172231674194 PathPoint;PointKind.SMOOTHPOINT 5761.31724357605,256.230440139771 5763.32967281342,264.458835124969 5760.87361693382,252.650742530823 PathPoint;PointKind.SMOOTHPOINT 5762.86055445671,278.962204456329 5763.10414195061,281.513736248016 5762.06641674042,270.644352436066 PathPoint;PointKind.SMOOTHPOINT 5763.58352780342,286.679821014404 5763.04643154144,290.395946502686 5764.12735104561,282.9221534729 PathPoint;PointKind.SMOOTHPOINT 5763.17813873291,297.746529579163 5764.47078108788,305.776183605194 5762.60138869286,294.163763523102 PathPoint;PointKind.SMOOTHPOINT 5763.68761897087,319.241001605988 5762.27212071419,326.247446537018 5764.86696481705,313.403162956238 PathPoint;PointKind.SMOOTHPOINT 5757.48498916626,343.612732887268 5758.61937046051,354.606742858887 5756.54214978218,334.476313591003 PathPoint;PointKind.SMOOTHPOINT 5760.22287011147,375.571789741516 5762.04658985138,378.15943479538 5758.77798557281,364.096505641937 PathPoint;PointKind.SMOOTHPOINT 5765.6943833828,383.334724903107 5764.46865677834,384.547941684723 5763.87066364288,380.747315883636 PathPoint;PointKind.SMOOTHPOINT 5763.3866751194,389.34180021286 5758.68557810783,392.413551807404 5765.76377749443,387.788457870483 PathPoint;PointKind.SMOOTHPOINT 5755.95371603966,405.000321865082 5755.40599822998,405.060274600983 5755.95371603966,400.359177589417 PathPoint;PointKind.SMOOTHPOINT 5752.99986362457,414.999918937683 5753.18290829659,425.652151107788 5753.54758143425,414.939966201782 PathPoint;PointKind.SMOOTHPOINT 5754.85969662666,437.139472961426 5754.13035035133,438.763389587402 5754.67665195465,426.487476825714 PathPoint;PointKind.SMOOTHPOINT 5752.67094969749,442.012166976929 5754.92023944855,444.238443374634 5753.40065002441,440.388014316559 PathPoint;PointKind.SMOOTHPOINT 5759.41881895065,448.691704273224 5759.65744972229,454.723327159882 5757.1695291996,446.465427875519 PathPoint;PointKind.SMOOTHPOINT 5760.13471126556,466.787753105164 5760.04903078079,467.300891876221 5761.08392357826,461.113014221191 PathPoint;PointKind.SMOOTHPOINT 5760.19631624222,468.346524238586 5760.4229092598,474.073898792267 5760.17613530159,467.82701253891 PathPoint;PointKind.SMOOTHPOINT 5760.87644934654,485.527703762054 5758.71106982231,487.671368122101 5760.64985632896,479.801273345947 PathPoint;PointKind.SMOOTHPOINT 5757.15607523918,492.858459949493 5758.44305276871,495.008497238159 5755.18507003784,489.566252231598 PathPoint;PointKind.SMOOTHPOINT 5756.68093800545,500.509514808655 5755.10080575943,501.532959938049 5756.68093800545,497.915024757385 PathPoint;PointKind.SMOOTHPOINT 5754.99990105629,512.999982833862 5755.7897901535,522.267637252808 5756.57967925072,511.976537704468 PathPoint;PointKind.SMOOTHPOINT 5759.31047916412,531.385645866394 5761.4988720417,543.059198856354 5758.52023601532,522.117991447449 PathPoint;PointKind.SMOOTHPOINT 5765.87636590004,566.410317420959 5766.17306113243,567.291669845581 5763.68761897087,554.736528396606 PathPoint;PointKind.SMOOTHPOINT 5765.62251091003,587.672295570374 5765.55382490158,589.949555397034 5765.94540596008,576.941699981689 PathPoint;PointKind.SMOOTHPOINT 5765.40795564651,594.576773643494 5766.43753767014,598.775117397308 5764.7062253952,591.71320438385 PathPoint;PointKind.SMOOTHPOINT 5758.11944961548,615.670459270477 5758.43455553055,620.915379524231 5757.89816737175,611.984074115753 PathPoint;PointKind.SMOOTHPOINT 5756.78184270859,625.965099334717 5754.88943696022,627.952272891998 5756.78184270859,624.16722536087 PathPoint;PointKind.SMOOTHPOINT 5750.94671845436,626.86863899231 5749.86190438271,630.198140144348 5752.89152383804,626.567459106445 PathPoint;PointKind.SMOOTHPOINT 5750.33704161644,636.311666965485 5751.60100579262,663.016126155853 5750.21347761154,633.709151744843 PathPoint;PointKind.SMOOTHPOINT 5767.51987338066,710.127882957458 5766.91904783249,710.389409065247 5767.51987338066,681.021301746368 PathPoint;PointKind.SMOOTHPOINT 5765.40653944016,711.300973892212 5764.70162272453,710.590982437134 5766.84717535973,712.752585411072 PathPoint;PointKind.SMOOTHPOINT 5762.95650243759,712.114584445953 5762.95650243759,715.453999042511 5763.8770365715,711.714034080505 PathPoint;PointKind.SMOOTHPOINT 5763.27904343605,722.068154811859 5763.33356738091,722.948563098907 5763.07440161705,718.769338130951 PathPoint;PointKind.SMOOTHPOINT 5764.39643025398,724.299387931824 5764.17550206184,725.110874176025 5764.79119777679,722.85037279129 PathPoint;PointKind.SMOOTHPOINT 5763.6653137207,727.218189239502 5763.99599790573,731.012206077576 5763.59237909317,726.381683349609 PathPoint;PointKind.SMOOTHPOINT 5764.88856196404,738.558461666107 5765.06240129471,739.960033893585 5764.42015171051,734.788756370544 PathPoint;PointKind.SMOOTHPOINT 5765.42707443237,742.760818004608 5766.07923746109,743.763020038605 5764.65453386307,741.573801040649 PathPoint;PointKind.SMOOTHPOINT 5765.93726277351,746.588587760925 5766.52534246445,750.95876455307 5765.76519370079,745.312821865082 PathPoint;PointKind.SMOOTHPOINT 5767.66538858414,759.719889163971 5767.78470396996,760.694239139557 5767.1268761158,755.330121517181 PathPoint;PointKind.SMOOTHPOINT 5768.01342129707,762.645535469055 5767.51456260681,763.635935783386 5768.45633983612,761.76607131958 PathPoint;PointKind.SMOOTHPOINT 5768.30622196198,765.277082920074 5769.02848720551,772.030498981476 5768.21204423904,764.399034976959 PathPoint;PointKind.SMOOTHPOINT 5769.52663779259,785.778086185455 5768.55370402336,786.500351428986 5769.52663779259,778.843631744385 PathPoint;PointKind.SMOOTHPOINT 5766.60712838173,787.944645881653 5766.60712838173,791.495311260223 5767.58006215096,787.222616672516 PathPoint;PointKind.SMOOTHPOINT 5766.60712838173,798.597822189331 5768.60079288483,798.597822189331 5766.60712838173,795.046920776367 PathPoint;PointKind.SMOOTHPOINT 5771.57447218895,801.370046138763 5773.86518597603,802.274057865143 5769.65728282928,800.613555908203 PathPoint;PointKind.SMOOTHPOINT 5773.71825456619,807.443919181824 5772.42277979851,808.72629404068 5773.71825456619,805.420396327972 PathPoint;PointKind.SMOOTHPOINT 5770.56507110596,811.37932062149 5768.74772429466,812.55571603775 5771.88851594925,810.522751808167 PathPoint;PointKind.SMOOTHPOINT 5768.48643422127,816.457364559174 5767.78895258904,819.493002891541 5768.88261795044,814.731245040894 PathPoint;PointKind.SMOOTHPOINT 5768.60008478165,825.792996883392 5768.97644162178,827.609989643097 5767.94331908226,822.622110843658 PathPoint;PointKind.SMOOTHPOINT 5770.45602321625,829.286069869995 5770.86849331856,830.466477870941 5769.81554389,827.451374530792 PathPoint;PointKind.SMOOTHPOINT 5771.50012135506,834.819660186768 5774.7166800499,842.788653373718 5771.02321386337,833.638308048248 PathPoint;PointKind.SMOOTHPOINT 5779.00813937187,857.814602851868 5777.01730728149,859.808621406555 5779.00813937187,850.717284679413 PathPoint;PointKind.SMOOTHPOINT 5771.84744596481,860.685017108917 5769.7659766674,860.051028728485 5774.47698712349,861.486117839813 PathPoint;PointKind.SMOOTHPOINT 5765.14949798584,860.704843997955 5765.78183412552,862.622623443604 5767.38604187965,860.704843997955 PathPoint;PointKind.SMOOTHPOINT 5767.04721450806,866.458654403687 5768.19363355637,868.071949481964 5766.13765597343,865.179347991943 PathPoint;PointKind.SMOOTHPOINT 5769.44626808167,871.280837059021 5769.14638638496,873.50026845932 5769.65799093246,869.713332653046 PathPoint;PointKind.SMOOTHPOINT 5770.98462224007,878.397037982941 5770.9021282196,880.866901874542 5770.29068112373,876.293263435364 PathPoint;PointKind.SMOOTHPOINT 5770.7364320755,885.807809829712 5771.37832760811,887.930703163147 5770.02053976059,883.439912796021 PathPoint;PointKind.SMOOTHPOINT 5770.51656603813,892.380659580231 5770.42876124382,895.003001689911 5770.58985471725,890.189788341522 PathPoint;PointKind.SMOOTHPOINT 5770.25350570679,900.246977806091 5771.39425992966,902.530138492584 5770.3413105011,897.625107765198 PathPoint;PointKind.SMOOTHPOINT 5773.67683053017,907.09716796875 5775.41132926941,908.605427742004 5771.74335479736,905.415894985199 PathPoint;PointKind.SMOOTHPOINT 5775.83548307419,911.416833400726 5776.65050983429,913.048775196075 5775.11605024338,909.977023601532 PathPoint;PointKind.SMOOTHPOINT 5778.28127145767,916.311950683594 5776.82257890701,920.464975833893 5777.46624469757,914.680480957031 PathPoint;PointKind.SMOOTHPOINT 5773.90413165092,928.772206306458 5773.79720807076,928.349704742432 5775.36282420158,924.619181156158 PathPoint;PointKind.SMOOTHPOINT 5772.32258319855,927.615637779236 5772.02128529549,927.205173969269 5773.07388067245,928.639318943024 PathPoint;PointKind.SMOOTHPOINT 5771.46613240242,927.273859977722 5769.65409636497,928.26827287674 5771.46613240242,927.273859977722 PathPoint;PointKind.SMOOTHPOINT 5767.91782736778,929.589829444885 5766.48321032524,931.010284423828 5769.72986340523,928.595180511475 PathPoint;PointKind.SMOOTHPOINT 5769.44626808167,935.27259349823 5770.93293070793,938.388955593109 5768.32250833511,932.917206287384 PathPoint;PointKind.SMOOTHPOINT 5772.11333870888,941.865742206573 5771.69449567795,943.34851026535 5772.11333870888,941.865742206573 PathPoint;PointKind.SMOOTHPOINT 5771.17545604706,946.56754732132 5770.03045320511,948.692564964294 5771.9642829895,945.103662014008 PathPoint;PointKind.SMOOTHPOINT 5770.77679395676,952.520806789398 5770.67624330521,959.155969619751 5770.80795049667,950.458102226257 PathPoint;PointKind.SMOOTHPOINT 5772.2397351265,973.675625324249 5772.34842896461,974.758079051971 5771.51924014091,966.508440971375 PathPoint;PointKind.SMOOTHPOINT 5772.5537788868,976.907408237457 5771.75220608711,977.620468139648 5773.86093735695,975.745646953583 PathPoint;PointKind.SMOOTHPOINT 5772.82746076584,980.069561004639 5773.05582404137,982.962162494659 5772.74532079697,979.024872779846 PathPoint;PointKind.SMOOTHPOINT 5773.20806622505,988.44712972641 5772.5994515419,988.628404140472 5773.20806622505,985.776164531708 PathPoint;PointKind.SMOOTHPOINT 5771.38257622719,988.990952968597 5771.70440912247,990.854680538177 5771.99083685875,988.809678554535 PathPoint;PointKind.SMOOTHPOINT 5771.46613240242,995.264983177185 5771.93418860435,997.974421977997 5771.14394545555,993.401019573212 PathPoint;PointKind.SMOOTHPOINT 5773.75295162201,1002.70974397659 5772.22592711449,1008.79164218903 5773.28489542007,1000.00101327896 PathPoint;PointKind.SMOOTHPOINT 5769.55708622932,1020.22207975388 5770.52966594696,1023.13073158264 5768.1253015995,1013.10115814209 PathPoint;PointKind.SMOOTHPOINT 5772.47482538223,1028.94897937775 5772.38489627838,1028.94897937775 5772.72868037224,1028.94897937775 PathPoint;PointKind.SMOOTHPOINT 5774.49575185776,1031.26046419144 5774.97372150421,1033.59366416931 5774.03831720352,1029.02616262436 PathPoint;PointKind.SMOOTHPOINT 5775.6234061718,1038.55675935745 5776.59846425056,1041.38209104538 5774.87777352333,1036.39775276184 PathPoint;PointKind.SMOOTHPOINT 5778.31171989441,1046.40513896942 5777.24531650543,1053.51685523987 5777.60184645653,1044.28130149841 PathPoint;PointKind.SMOOTHPOINT 5773.56813669205,1055.08506774902 5772.86853075027,1056.81732416153 5774.66782093048,1052.3619389534 PathPoint;PointKind.SMOOTHPOINT 5772.00358271599,1060.15012979507 5770.35228610039,1061.58970355988 5773.28489542007,1059.03345108032 PathPoint;PointKind.SMOOTHPOINT 5771.452678442,1067.14335680008 5771.57801270485,1069.76664304733 5771.34115219116,1064.80590820312 PathPoint;PointKind.SMOOTHPOINT 5772.79382586479,1075.26128768921 5772.6454782486,1076.59936666489 5773.11601281166,1072.35688447952 PathPoint;PointKind.SMOOTHPOINT 5774.23481583595,1080.05585432053 5774.9457514286,1082.19385385513 5773.68355751038,1078.39676856995 PathPoint;PointKind.SMOOTHPOINT 5776.67246103287,1086.84632778168 5776.00330352783,1092.50336408615 5775.76750516891,1084.44349765778 PathPoint;PointKind.SMOOTHPOINT 5774.66534256935,1103.81932497025 5774.66534256935,1103.81932497025 5775.33450007439,1098.16228866577 PathPoint;PointKind.SMOOTHPOINT 5776.12191081047,1116.65983200073 5775.6903219223,1122.42780447006 5776.63032889366,1109.85873699188 PathPoint;PointKind.SMOOTHPOINT 5778.49759697914,1130.53771018982 5779.46344971657,1134.37444925308 5777.59901404381,1126.967689991 PathPoint;PointKind.SMOOTHPOINT 5780.29724121094,1140.89065074921 5780.56879878044,1144.00347232819 5780.02922415733,1137.81583070755 PathPoint;PointKind.SMOOTHPOINT 5779.54558968544,1148.24571847916 5779.9527490139,1150.46396970749 5778.99326920509,1145.23769617081 PathPoint;PointKind.SMOOTHPOINT 5779.21455144882,1154.97623920441 5777.53068208694,1160.81525802612 5779.69393730164,1153.31597328186 PathPoint;PointKind.SMOOTHPOINT 5776.99995875359,1167.00006723404 5778.35278987885,1170.39400577545 5776.99995875359,1167.00006723404 PathPoint;PointKind.SMOOTHPOINT 5777.4439394474,1173.21650505066 5777.82277464867,1175.83011388779 5776.96738600731,1169.92618560791 PathPoint;PointKind.SMOOTHPOINT 5777.52572536469,1181.24167442322 5778.69480371475,1184.85064029694 5776.73512816429,1178.80037069321 PathPoint;PointKind.SMOOTHPOINT 5777.42234230042,1189.9468588829 5776.61935329437,1197.51648187637 5777.7367401123,1186.98037862778 PathPoint;PointKind.SMOOTHPOINT 5775.21022796631,1212.4692606926 5776.85267329216,1214.7554898262 5775.21022796631,1204.96265888214 PathPoint;PointKind.SMOOTHPOINT 5780.13720989227,1219.32865619659 5780.00444054604,1223.17342042923 5778.49476456642,1217.04219102859 PathPoint;PointKind.SMOOTHPOINT 5779.73960995674,1230.86412906647 5779.91769790649,1230.72321653366 5779.16321396828,1231.32061958313 PathPoint;PointKind.SMOOTHPOINT 5779.82316613197,1235.63674449921 5778.64275813103,1242.67198562622 5780.32131671906,1232.66932010651 PathPoint;PointKind.SMOOTHPOINT 5778.67497682571,1261.75654649734 5779.58134889603,1267.28919267654 5778.92033457756,1254.63727712631 PathPoint;PointKind.SMOOTHPOINT 5781.39444708824,1278.35684537888 5782.61521697044,1281.18312120438 5779.16781663895,1273.20232629776 PathPoint;PointKind.SMOOTHPOINT 5779.99983787537,1289.9999499321 5779.19472455978,1295.61686038971 5779.44716334343,1286.62607431412 PathPoint;PointKind.SMOOTHPOINT 5774.29783701897,1299.67169523239 5776.06278419495,1299.67169523239 5777.78347492218,1296.22134447098 PathPoint;PointKind.SMOOTHPOINT 5778.48874568939,1300.8745265007 5779.77501511574,1300.55233955383 5776.81266546249,1301.2944316864 PathPoint;PointKind.SMOOTHPOINT 5780.55569887161,1304.22621488571 5783.73295783997,1308.87042760849 5779.96903538704,1303.36941003799 PathPoint;PointKind.SMOOTHPOINT 5778.67497682571,1329.28433418274 5779.51974391937,1330.04743337631 5778.67497682571,1325.61045885086 PathPoint;PointKind.SMOOTHPOINT 5781.5654540062,1331.22264862061 5782.1191906929,1331.72280550003 5780.72068691254,1330.45978546143 PathPoint;PointKind.SMOOTHPOINT 5782.8708422184,1333.07363033295 5782.63929247856,1336.76992893219 5782.31710553169,1332.57370948792 PathPoint;PointKind.SMOOTHPOINT 5782.17725515366,1344.16347026825 5782.03882098198,1346.3739323616 5782.40809679031,1340.46669960022 PathPoint;PointKind.SMOOTHPOINT 5781.76195263863,1350.7953286171 5780.65554141998,1352.70248651505 5782.87615299225,1348.87471675873 PathPoint;PointKind.SMOOTHPOINT 5781.41710639,1356.31216049194 5780.99047422409,1363.13001394272 5781.53217315674,1354.47321653366 PathPoint;PointKind.SMOOTHPOINT 5780.13720989227,1376.76501274109 5781.95951342583,1378.61198186874 5780.56384205818,1369.94810342789 PathPoint;PointKind.SMOOTHPOINT 5784.59047079086,1385.76642036438 5785.21537184715,1391.08191490173 5784.13622260094,1381.90088510513 PathPoint;PointKind.SMOOTHPOINT 5786.88472509384,1399.15429115295 5785.9687936306,1401.70582294464 5786.88472509384,1396.1007142067 PathPoint;PointKind.SMOOTHPOINT 5783.58531832695,1406.2131357193 5783.61399650574,1409.25373077393 5783.55628609657,1403.1364274025 PathPoint;PointKind.SMOOTHPOINT 5781.04960083961,1415.40360689163 5782.61981964111,1420.68204402924 5782.07847476006,1412.53909349442 PathPoint;PointKind.SMOOTHPOINT 5785.7606112957,1431.24080657959 5786.0781955719,1434.30996179581 5785.19448280334,1425.76598882675 PathPoint;PointKind.SMOOTHPOINT 5788.23472380638,1439.55818653107 5789.06214237213,1442.33961582184 5787.41013765335,1436.78572654724 PathPoint;PointKind.SMOOTHPOINT 5790.71697950363,1447.90223836899 5789.38503742218,1450.35888433456 5789.88956093788,1445.12104511261 PathPoint;PointKind.SMOOTHPOINT 5787.62504696846,1456.20687246323 5786.28106713295,1458.68546962738 5788.95698904991,1453.74975442886 PathPoint;PointKind.SMOOTHPOINT 5782.68921375275,1462.70867586136 5788.66489648819,1468.62416982651 5784.03283953667,1460.2303147316 PathPoint;PointKind.SMOOTHPOINT 5791.02217197418,1483.74807357788 5791.77099108696,1486.45255565643 5788.92972707748,1476.19025230408 PathPoint;PointKind.SMOOTHPOINT 5788.63480210304,1494.2020368576 5787.78614044189,1498.71761083603 5789.29333806038,1490.6983423233 PathPoint;PointKind.SMOOTHPOINT 5786.30585074425,1507.67181158066 5784.94523048401,1511.625623703 5787.85270214081,1503.17653656006 PathPoint;PointKind.SMOOTHPOINT 5782.57556319237,1520.19862890244 5780.87965607643,1524.33560371399 5784.10612821579,1516.46385669708 PathPoint;PointKind.SMOOTHPOINT 5777.03571796417,1530.95566034317 5779.52824115753,1533.66297483444 5778.49228620529,1527.33347654343 PathPoint;PointKind.SMOOTHPOINT 5784.51470375061,1539.07831192017 5785.41010022163,1541.72402143478 5782.02182650566,1536.37099742889 PathPoint;PointKind.SMOOTHPOINT 5786.61493778229,1551.19466543198 5787.4083673954,1555.57593584061 5785.74184656143,1546.37271881104 PathPoint;PointKind.SMOOTHPOINT 5789.07347202301,1562.55075216293 5788.07292222977,1567.07718372345 5788.77217411995,1560.14957427979 PathPoint;PointKind.SMOOTHPOINT 5786.61493778229,1577.19172954559 5786.80470943451,1580.4376745224 5786.32496953011,1572.23099470139 PathPoint;PointKind.SMOOTHPOINT 5783.96486163139,1585.65969944 5783.96486163139,1591.17369890213 5784.66729998589,1582.48385667801 PathPoint;PointKind.SMOOTHPOINT 5787.97909855843,1594.51004505157 5787.0061647892,1600.76802492142 5786.48712515831,1590.04451036453 PathPoint;PointKind.SMOOTHPOINT 5785.05958914757,1613.28540086746 5783.56195092201,1619.21458482742 5786.03252291679,1607.02765703201 PathPoint;PointKind.SMOOTHPOINT 5788.89184355736,1630.07429122925 5787.98405528069,1633.27468156815 5789.78015899658,1623.01780700684 PathPoint;PointKind.SMOOTHPOINT 5786.16741657257,1639.67664241791 5783.92981052399,1643.08568716049 5787.9975092411,1636.88884019852 PathPoint;PointKind.SMOOTHPOINT 5783.05247068405,1650.65672636032 5783.05247068405,1657.77930021286 5784.09090399742,1646.99701309204 PathPoint;PointKind.SMOOTHPOINT 5789.8042345047,1662.573158741 5789.90832567215,1665.44380903244 5784.53488469124,1657.39786863327 PathPoint;PointKind.SMOOTHPOINT 5790.6546664238,1672.17952251434 5790.07756233215,1676.35473489761 5791.04801774025,1669.33294773102 PathPoint;PointKind.SMOOTHPOINT 5790.5311024189,1682.61601924896 5788.22126984596,1683.15677404404 5790.39302229881,1678.80666017532 PathPoint;PointKind.SMOOTHPOINT 5783.60160470009,1684.23875570297 5783.94149422646,1686.42561435699 5785.91108322144,1683.6977648735 PathPoint;PointKind.SMOOTHPOINT 5784.62162733078,1690.79980373383 5785.88700771332,1693.2387471199 5783.59983444214,1688.83151292801 PathPoint;PointKind.SMOOTHPOINT 5785.79035162926,1698.32151174545 5784.81741786003,1699.22481536865 5785.4005408287,1695.8145904541 PathPoint;PointKind.SMOOTHPOINT 5782.8708422184,1701.03189468384 5782.8708422184,1705.44975042343 5783.84377598763,1700.12859106064 PathPoint;PointKind.SMOOTHPOINT 5787.62504696846,1710.17468690872 5788.41529011726,1710.35596132278 5784.32386994362,1711.55100345612 PathPoint;PointKind.SMOOTHPOINT 5790.167491436,1712.76823282242 5789.01292920113,1714.63337659836 5789.37795639038,1712.58695840836 PathPoint;PointKind.SMOOTHPOINT 5786.70309662819,1718.36437225342 5790.32114982605,1718.36437225342 5787.85765886307,1716.49922847748 PathPoint;PointKind.SMOOTHPOINT 5790.34947395325,1744.90714788437 5789.65093016624,1748.52933168411 5789.86690163612,1741.0741853714 PathPoint;PointKind.SMOOTHPOINT 5788.25419664383,1755.77440738678 5786.26761317253,1761.11704587936 5789.54152822495,1752.31367111206 PathPoint;PointKind.SMOOTHPOINT 5785.05958914757,1772.34897851944 5787.182482481,1774.45039272308 5786.12422227859,1766.8248295784 PathPoint;PointKind.SMOOTHPOINT 5790.51835656166,1796.58994674683 5792.84766197205,1806.35988235474 5787.92953133583,1785.73047637939 PathPoint;PointKind.SMOOTHPOINT 5790.99986672401,1814.99992132187 5789.95789289474,1815.4717540741 5790.99986672401,1811.58001899719 PathPoint;PointKind.SMOOTHPOINT 5788.9998292923,1820.99991559982 5787.86934256554,1821.38111114502 5791.95580601692,1820.00290632248 PathPoint;PointKind.SMOOTHPOINT 5786.15360856056,1822.90376901627 5786.15360856056,1824.70282316208 5787.23948478699,1822.41234540939 PathPoint;PointKind.SMOOTHPOINT 5793.63471865654,1851.15684986115 5793.78696084023,1864.69955921173 5793.47504138947,1836.95678472519 PathPoint;PointKind.SMOOTHPOINT 5793.93389225006,1900.40967464447 5794.87000465393,1914.54128980637 5792.99777984619,1886.27829551697 PathPoint;PointKind.SMOOTHPOINT 5796.70965671539,2010.35378694534 5796.70965671539,2024.54511880875 5794.43275094032,2008.09965848923 PathPoint;PointKind.SMOOTHPOINT 5798.17188978195,2051.33879899979 5798.17188978195,2051.33879899979 5795.19396185875,2036.61544561386 PathPoint;PointKind.SMOOTHPOINT 5798.98762464523,3666.37705469131 5799.01878118515,3729.79949617386 5798.77200722694,3235.30484580994 PathPoint;PointKind.SMOOTHPOINT 5798.68420243263,3804.90800046921 5798.93062233925,3817.90617847443 5798.23243260384,3781.04775571823 PathPoint;PointKind.SMOOTHPOINT 5786.56537055969,3817.90617847443 5763.41995596886,3818.0905213356 5795.11217594147,3817.83820056915 PathPoint;PointKind.SMOOTHPOINT 5649.54669713974,3817.75275611877 4834.93665575981,3814.87384462357 5712.99522042274,3817.97698879242 PathPoint;PointKind.SMOOTHPOINT 249.15562582016,3817.66040611267 204.774550914764,3817.50367927551 944.953388690948,3820.11941242218 PathPoint;PointKind.SMOOTHPOINT 151.152375459671,3817.90871429443 141.989520311356,3817.98589754105 167.897953510284,3817.76732969284 PathPoint;PointKind.SMOOTHPOINT 142.063163042068,3807.90982532501 142.092549324036,3791.1535077095 142.057852268219,3810.87252902985 PathPoint;PointKind.SMOOTHPOINT 142.597072839737,3711.64130973816 142.748960971832,3157.08251523972 142.585035085678,3755.12262153625 PathPoint;PointKind.SMOOTHPOINT 141.562925577164,197.883541107178 141.570006608963,173.476876735687 141.451045274734,606.282522201538 PathPoint;PointKind.SMOOTHPOINT 141.576733589172,148.65762424469 141.685073375702,146.099247455597 141.223390102386,156.976892471313 PathPoint;PointKind.SMOOTHPOINT 146.558239459991,143.015694141388 159.495992660522,142.913019180298 145.587075948715,143.023247241974 PathPoint;PointKind.SMOOTHPOINT 197.835885286331,143.177613735199 784.191344976425,145.031191825867 171.873636245728,143.09570980072 PathPoint";
	
	shadow35mm[0] = "PointKind.SMOOTHPOINT 5757.14970231056,143.748250007629 5762.3705470562,146.203951835632 5757.14970231056,143.748250007629 PathPoint;PointKind.SMOOTHPOINT 5765.00008821487,156.0000872612 5765.69650769234,160.517313480377 5764.47857022285,152.620074748993 PathPoint;PointKind.SMOOTHPOINT 5761.81716442108,170.369389057159 5761.31157875061,172.210929393768 5763.52404713631,164.149882793427 PathPoint;PointKind.SMOOTHPOINT 5759.70170617104,178.233819007874 5760.00583648682,181.182124614716 5759.70170617104,176.167809963226 PathPoint;PointKind.SMOOTHPOINT 5761.9998550415,184.999980926514 5762.91260004044,185.239791870117 5761.69572472572,182.051675319672 PathPoint;PointKind.SMOOTHPOINT 5767.00012564659,186.999900341034 5766.5129506588,190.129480361938 5766.08773469925,186.76008939743 PathPoint;PointKind.SMOOTHPOINT 5761.8904531002,197.189269065857 5763.28895688057,197.971251010895 5762.377628088,194.059453010559 PathPoint;PointKind.SMOOTHPOINT 5772.99988389015,199.999966621399 5773.54760169983,207.582335472107 5771.60138010979,199.217984676361 PathPoint;PointKind.SMOOTHPOINT 5770.99984645844,222.000024318695 5765.19446253777,227.883653640747 5770.45212864876,214.41789150238 PathPoint;PointKind.SMOOTHPOINT 5762.07633018494,250.09024143219 5763.65646243095,252.136895656586 5762.07633018494,242.172231674194 PathPoint;PointKind.SMOOTHPOINT 5766.81708097458,256.230440139771 5768.82951021194,264.458835124969 5766.37345433235,252.650742530823 PathPoint;PointKind.SMOOTHPOINT 5774.00007963181,268.999900817871 5774.2436671257,271.551432609558 5773.20594191551,260.682048797607 PathPoint;PointKind.SMOOTHPOINT 5769.00016307831,283.000044822693 5768.46306681633,286.716170310974 5769.5439863205,279.242377281189 PathPoint;PointKind.SMOOTHPOINT 5770.00000476837,298.000030517578 5771.29264712334,306.02968454361 5769.42325472832,294.417264461517 PathPoint;PointKind.SMOOTHPOINT 5774.99992132187,319.000010490417 5773.58442306519,326.006455421448 5776.17926716805,313.162171840668 PathPoint;PointKind.SMOOTHPOINT 5762.98482656479,343.612732887268 5764.11920785904,354.606742858887 5762.04198718071,334.476313591003 PathPoint;PointKind.SMOOTHPOINT 5765.72270750999,375.571789741516 5767.54642724991,378.15943479538 5764.27782297134,364.096505641937 PathPoint;PointKind.SMOOTHPOINT 5779.19437050819,384.334802627563 5777.96864390373,385.54801940918 5777.37065076828,381.747393608093 PathPoint;PointKind.SMOOTHPOINT 5776.8866622448,390.341877937317 5772.18556523323,393.41362953186 5779.26376461983,388.78853559494 PathPoint;PointKind.SMOOTHPOINT 5766.45346999168,405.000321865082 5765.90575218201,405.060274600983 5766.45346999168,400.359177589417 PathPoint;PointKind.SMOOTHPOINT 5764.81031656265,405.180180072784 5764.99336123466,415.832412242889 5765.35803437233,405.120227336884 PathPoint;PointKind.SMOOTHPOINT 5765.35945057869,437.139472961426 5764.63010430336,438.763389587402 5765.17640590668,426.487476825714 PathPoint;PointKind.SMOOTHPOINT 5763.17070364952,442.012166976929 5765.41999340057,444.238443374634 5763.90040397644,440.388014316559 PathPoint;PointKind.SMOOTHPOINT 5769.91857290268,448.691704273224 5770.15720367432,454.723327159882 5767.66928315163,446.465427875519 PathPoint;PointKind.SMOOTHPOINT 5779.63445663452,467.78783082962 5779.54877614975,468.300969600677 5780.58366894722,462.113091945648 PathPoint;PointKind.SMOOTHPOINT 5779.69606161118,469.346601963043 5779.92265462875,475.073976516724 5779.67588067055,468.827090263367 PathPoint;PointKind.SMOOTHPOINT 5780.3761947155,486.527781486511 5778.21081519127,488.671445846558 5780.14960169792,480.801351070404 PathPoint;PointKind.SMOOTHPOINT 5767.65582919121,492.858459949493 5768.94280672073,495.008497238159 5765.68482398987,489.566252231598 PathPoint;PointKind.SMOOTHPOINT 5767.18069195747,500.509514808655 5765.60055971146,501.532959938049 5767.18069195747,497.915024757385 PathPoint;PointKind.SMOOTHPOINT 5762.43994116783,503.579850196838 5763.22983026505,512.847504615784 5764.01971936226,502.556405067444 PathPoint;PointKind.SMOOTHPOINT 5764.81031656265,531.385645866394 5766.99870944023,543.059198856354 5764.02007341385,522.117991447449 PathPoint;PointKind.SMOOTHPOINT 5772.99988389015,566.000089645386 5773.29657912254,566.881442070007 5770.81113696098,554.326300621033 PathPoint;PointKind.SMOOTHPOINT 5771.12234830856,587.672295570374 5771.05366230011,589.949555397034 5771.44524335861,576.941699981689 PathPoint;PointKind.SMOOTHPOINT 5779.90778446198,602.576687335968 5780.9373664856,606.775031089783 5779.20605421066,599.713118076324 PathPoint;PointKind.SMOOTHPOINT 5783.00007104874,617.000041007996 5783.31517696381,622.244961261749 5782.77878880501,613.313655853271 PathPoint;PointKind.SMOOTHPOINT 5776.00011706352,623.00003528595 5774.10771131516,624.987208843231 5776.00011706352,621.202161312103 PathPoint;PointKind.SMOOTHPOINT 5764.44670557976,617.868647575378 5763.3618915081,621.198148727417 5766.39151096344,617.567467689514 PathPoint;PointKind.SMOOTHPOINT 5763.83702874184,627.311675548553 5765.10099291801,654.016134738922 5763.71346473694,624.709160327911 PathPoint;PointKind.SMOOTHPOINT 5780.0196647644,715.127799510956 5779.41883921623,715.389325618744 5780.0196647644,686.021218299866 PathPoint;PointKind.SMOOTHPOINT 5777.9063308239,716.300890445709 5777.20141410828,715.590898990631 5779.34696674347,717.752501964569 PathPoint;PointKind.SMOOTHPOINT 5775.45629382133,717.114500999451 5775.45629382133,720.453915596008 5776.37682795525,716.713950634003 PathPoint;PointKind.SMOOTHPOINT 5768.77888083458,722.068154811859 5768.83340477943,722.948563098907 5768.57423901558,718.769338130951 PathPoint;PointKind.SMOOTHPOINT 5769.89626765251,724.299387931824 5769.67533946037,725.110874176025 5770.29103517532,722.85037279129 PathPoint;PointKind.SMOOTHPOINT 5769.16515111923,727.218189239502 5769.49583530426,731.012206077576 5769.0922164917,726.381683349609 PathPoint;PointKind.SMOOTHPOINT 5770.38839936256,738.558461666107 5770.56223869324,739.960033893585 5769.91998910904,734.788756370544 PathPoint;PointKind.SMOOTHPOINT 5770.9269118309,742.760818004608 5771.57907485962,743.763020038605 5770.1543712616,741.573801040649 PathPoint;PointKind.SMOOTHPOINT 5771.43710017204,746.588587760925 5772.18591928482,750.933036804199 5771.21865034103,745.319902896881 PathPoint;PointKind.SMOOTHPOINT 5778.33190083504,758.890936374664 5778.18072080612,759.861037731171 5779.04708504677,754.300067424774 PathPoint;PointKind.SMOOTHPOINT 5780.51321268082,764.645454883575 5780.01435399055,765.635855197906 5780.95613121986,763.7659907341 PathPoint;PointKind.SMOOTHPOINT 5780.80601334572,767.277002334595 5781.52827858925,774.030418395996 5780.71183562279,766.398954391479 PathPoint;PointKind.SMOOTHPOINT 5782.02642917633,787.778005599976 5781.0534954071,788.500270843506 5782.02642917633,780.843551158905 PathPoint;PointKind.SMOOTHPOINT 5772.10696578026,787.944645881653 5772.10696578026,791.495311260223 5773.07989954948,787.222616672516 PathPoint;PointKind.SMOOTHPOINT 5772.10696578026,798.597822189331 5774.10063028336,798.597822189331 5772.10696578026,795.046920776367 PathPoint;PointKind.SMOOTHPOINT 5784.07426357269,802.37012386322 5786.36497735977,803.2741355896 5782.15707421303,801.61363363266 PathPoint;PointKind.SMOOTHPOINT 5786.21804594994,808.443996906281 5784.92257118225,809.726371765137 5786.21804594994,806.420474052429 PathPoint;PointKind.SMOOTHPOINT 5776.06490850449,811.37932062149 5774.24756169319,812.55571603775 5777.38835334778,810.522751808167 PathPoint;PointKind.SMOOTHPOINT 5773.9862716198,816.457364559174 5773.28878998756,819.493002891541 5774.38245534897,814.731245040894 PathPoint;PointKind.SMOOTHPOINT 5776.00011706352,824.999921321869 5776.37647390366,826.816914081573 5775.34335136414,821.829035282135 PathPoint;PointKind.SMOOTHPOINT 5775.95586061478,829.286069869995 5776.36833071709,830.466477870941 5775.31538128853,827.451374530792 PathPoint;PointKind.SMOOTHPOINT 5778.00015449524,833.9999127388 5781.21671319008,841.968905925751 5777.52324700356,832.818560600281 PathPoint;PointKind.SMOOTHPOINT 5784.5079767704,857.814602851868 5782.51714468002,859.808621406555 5784.5079767704,850.717284679413 PathPoint;PointKind.SMOOTHPOINT 5777.34728336334,860.685017108917 5775.26581406593,860.051028728485 5779.97682452202,861.486117839813 PathPoint;PointKind.SMOOTHPOINT 5774.99992132187,863.000042438507 5775.63225746155,864.917821884155 5777.23646521568,863.000042438507 PathPoint;PointKind.SMOOTHPOINT 5774.99992132187,869.000036716461 5773.02927017212,868.818998336792 5777.44500160217,869.22379732132 PathPoint;PointKind.SMOOTHPOINT 5774.94610548019,871.280837059021 5774.64622378349,873.50026845932 5775.15782833099,869.713332653046 PathPoint;PointKind.SMOOTHPOINT 5776.4844596386,878.397037982941 5776.40196561813,880.866901874542 5775.79051852226,876.293263435364 PathPoint;PointKind.SMOOTHPOINT 5776.23626947403,885.807809829712 5776.87816500664,887.930703163147 5775.52037715912,883.439912796021 PathPoint;PointKind.SMOOTHPOINT 5776.01640343666,892.380659580231 5775.92859864235,895.003001689911 5776.08969211578,890.189788341522 PathPoint;PointKind.SMOOTHPOINT 5775.75334310532,900.246977806091 5776.89409732819,902.530138492584 5775.84114789963,897.625107765198 PathPoint;PointKind.SMOOTHPOINT 5786.17662191391,909.09708738327 5787.91112065315,910.605347156525 5784.24314618111,907.415814399719 PathPoint;PointKind.SMOOTHPOINT 5788.33527445793,913.416752815247 5789.15030121803,915.048694610596 5787.61584162712,911.976943016052 PathPoint;PointKind.SMOOTHPOINT 5790.78106284142,918.311870098114 5789.32237029076,922.464895248413 5789.96603608131,916.680400371552 PathPoint;PointKind.SMOOTHPOINT 5786.40392303467,930.772125720978 5786.2969994545,930.349624156952 5787.86261558533,926.619100570679 PathPoint;PointKind.SMOOTHPOINT 5784.82237458229,929.615557193756 5784.52107667923,929.205093383789 5785.5736720562,930.639238357544 PathPoint;PointKind.SMOOTHPOINT 5783.96592378616,929.273779392242 5782.15388774872,930.26819229126 5783.96592378616,929.273779392242 PathPoint;PointKind.SMOOTHPOINT 5780.41761875153,931.589748859406 5778.98300170898,933.010203838348 5782.22965478897,930.595099925995 PathPoint;PointKind.SMOOTHPOINT 5774.94610548019,935.27259349823 5776.43276810646,938.388955593109 5773.82234573364,932.917206287384 PathPoint;PointKind.SMOOTHPOINT 5777.61317610741,941.865742206573 5777.19433307648,943.34851026535 5777.61317610741,941.865742206573 PathPoint;PointKind.SMOOTHPOINT 5776.67529344559,946.56754732132 5775.53029060364,948.692564964294 5777.46412038803,945.103662014008 PathPoint;PointKind.SMOOTHPOINT 5776.27663135529,952.520806789398 5776.17608070374,959.155969619751 5776.3077878952,950.458102226257 PathPoint;PointKind.SMOOTHPOINT 5779.99983787537,970.999939441681 5780.10853171349,972.082393169403 5779.27934288979,963.832755088806 PathPoint;PointKind.SMOOTHPOINT 5778.05361628532,976.907408237457 5777.25204348564,977.620468139648 5779.36077475548,975.745646953583 PathPoint;PointKind.SMOOTHPOINT 5779.99983787537,981.000008583069 5780.22820115089,983.89261007309 5779.91769790649,979.955320358276 PathPoint;PointKind.SMOOTHPOINT 5778.70790362358,988.44712972641 5778.09928894043,988.628404140472 5778.70790362358,985.776164531708 PathPoint;PointKind.SMOOTHPOINT 5776.88241362572,988.990952968597 5777.204246521,990.854680538177 5777.49067425728,988.809678554535 PathPoint;PointKind.SMOOTHPOINT 5782.9660820961,996.265060901642 5783.43413829803,998.974499702454 5782.64389514923,994.401097297668 PathPoint;PointKind.SMOOTHPOINT 5785.25290131569,1003.70982170105 5783.72587680817,1009.79171991348 5784.78484511375,1001.00109100342 PathPoint;PointKind.SMOOTHPOINT 5775.05692362785,1020.22207975388 5776.02950334549,1023.13073158264 5773.62513899803,1013.10115814209 PathPoint;PointKind.SMOOTHPOINT 5777.97466278076,1028.94897937775 5777.88473367691,1028.94897937775 5778.22851777077,1028.94897937775 PathPoint;PointKind.SMOOTHPOINT 5779.99558925629,1031.26046419144 5780.47355890274,1033.59366416931 5779.53815460205,1029.02616262436 PathPoint;PointKind.SMOOTHPOINT 5784.1234767437,1039.55683708191 5785.09853482246,1042.38216876984 5783.37784409523,1037.3978304863 PathPoint;PointKind.SMOOTHPOINT 5786.81179046631,1047.40521669388 5784.7232401371,1050.50623655319 5786.10191702843,1045.28137922287 PathPoint;PointKind.SMOOTHPOINT 5782.06820726395,1056.08514547348 5781.36860132217,1057.81740188599 5783.16789150238,1053.36201667786 PathPoint;PointKind.SMOOTHPOINT 5780.50365328789,1061.15020751953 5778.85235667229,1062.58978128433 5781.78496599197,1060.03352880478 PathPoint;PointKind.SMOOTHPOINT 5776.95251584053,1067.14335680008 5777.07785010338,1069.76664304733 5776.84098958969,1064.80590820312 PathPoint;PointKind.SMOOTHPOINT 5778.29366326332,1075.26128768921 5778.14531564713,1076.59936666489 5778.61585021019,1072.35688447952 PathPoint;PointKind.SMOOTHPOINT 5779.73465323448,1080.05585432053 5780.44558882713,1082.19385385513 5779.18339490891,1078.39676856995 PathPoint;PointKind.SMOOTHPOINT 5785.99995017052,1085.0000667572 5785.33079266548,1090.65710306168 5785.09499430656,1082.5972366333 PathPoint;PointKind.SMOOTHPOINT 5781.99987530708,1103.00004959106 5781.99987530708,1103.00004959106 5782.66903281212,1097.34301328659 PathPoint;PointKind.SMOOTHPOINT 5781.621748209,1116.65983200073 5781.19015932083,1122.42780447006 5782.13016629219,1109.85873699188 PathPoint;PointKind.SMOOTHPOINT 5783.99743437767,1130.53771018982 5784.9632871151,1134.37444925308 5783.09885144234,1126.967689991 PathPoint;PointKind.SMOOTHPOINT 5788.79731178284,1140.89065074921 5789.06886935234,1144.00347232819 5788.52929472923,1137.81583070755 PathPoint;PointKind.SMOOTHPOINT 5788.04566025734,1148.24571847916 5788.4528195858,1150.46396970749 5787.49333977699,1145.23769617081 PathPoint;PointKind.SMOOTHPOINT 5787.71462202072,1154.97623920441 5786.03075265884,1160.81525802612 5788.19400787354,1153.31597328186 PathPoint;PointKind.SMOOTHPOINT 5783.27446103096,1163.19660902023 5784.62729215622,1166.59054756165 5783.27446103096,1163.19660902023 PathPoint;PointKind.SMOOTHPOINT 5782.94377684593,1173.21650505066 5783.3226120472,1175.83011388779 5782.46722340584,1169.92618560791 PathPoint;PointKind.SMOOTHPOINT 5787.00014591217,1182.00005292892 5788.16922426224,1185.60901880264 5786.20954871178,1179.55874919891 PathPoint;PointKind.SMOOTHPOINT 5787.00014591217,1191.99988603592 5786.19715690613,1199.56950902939 5787.31454372406,1189.03340578079 PathPoint;PointKind.SMOOTHPOINT 5783.9999127388,1213.00010204315 5785.64235806465,1215.28633117676 5783.9999127388,1205.4935002327 PathPoint;PointKind.SMOOTHPOINT 5785.6370472908,1219.32865619659 5785.50427794456,1223.17342042923 5783.99460196495,1217.04219102859 PathPoint;PointKind.SMOOTHPOINT 5785.23944735527,1230.86412906647 5785.41753530502,1230.72321653366 5784.66305136681,1231.32061958313 PathPoint;PointKind.SMOOTHPOINT 5785.3230035305,1235.63674449921 5784.14259552956,1242.67198562622 5785.82115411758,1232.66932010651 PathPoint;PointKind.SMOOTHPOINT 5787.99998760223,1258.00005912781 5788.90635967255,1263.53270530701 5788.24534535408,1250.88078975677 PathPoint;PointKind.SMOOTHPOINT 5794.89443421364,1279.35692310333 5796.11520409584,1282.18319892883 5792.66780376434,1274.20240402222 PathPoint;PointKind.SMOOTHPOINT 5796.55245780945,1289.47925806046 5795.74734449387,1295.09616851807 5795.99978327751,1286.10538244247 PathPoint;PointKind.SMOOTHPOINT 5779.7976744175,1299.67169523239 5781.56262159348,1299.67169523239 5783.28331232071,1296.22134447098 PathPoint;PointKind.SMOOTHPOINT 5783.98858308792,1300.8745265007 5785.27485251427,1300.55233955383 5782.31250286102,1301.2944316864 PathPoint;PointKind.SMOOTHPOINT 5786.05553627014,1304.22621488571 5789.23279523849,1308.87042760849 5785.46887278557,1303.36941003799 PathPoint;PointKind.SMOOTHPOINT 5788.17488908768,1329.28433418274 5789.01965618134,1330.04743337631 5788.17488908768,1325.61045885086 PathPoint;PointKind.SMOOTHPOINT 5791.06536626816,1331.22264862061 5791.61910295486,1331.72280550003 5790.2205991745,1330.45978546143 PathPoint;PointKind.SMOOTHPOINT 5792.37075448036,1333.07363033295 5792.13920474052,1336.76992893219 5791.81701779366,1332.57370948792 PathPoint;PointKind.SMOOTHPOINT 5791.67716741562,1344.16347026825 5791.53873324394,1346.3739323616 5791.90800905228,1340.46669960022 PathPoint;PointKind.SMOOTHPOINT 5791.26186490059,1350.7953286171 5790.15545368195,1352.70248651505 5792.37606525421,1348.87471675873 PathPoint;PointKind.SMOOTHPOINT 5786.91694378853,1356.31216049194 5786.49031162262,1363.13001394272 5787.03201055527,1354.47321653366 PathPoint;PointKind.SMOOTHPOINT 5785.6370472908,1376.76501274109 5787.45935082436,1378.61198186874 5786.06367945671,1369.94810342789 PathPoint;PointKind.SMOOTHPOINT 5793.09054136276,1385.76642036438 5793.71544241905,1391.08191490173 5792.63629317284,1381.90088510513 PathPoint;PointKind.SMOOTHPOINT 5795.38479566574,1399.15429115295 5794.4688642025,1401.70582294464 5795.38479566574,1396.1007142067 PathPoint;PointKind.SMOOTHPOINT 5792.08538889885,1406.2131357193 5792.11406707764,1409.25373077393 5792.05635666847,1403.1364274025 PathPoint;PointKind.SMOOTHPOINT 5786.54943823814,1415.40360689163 5788.11965703964,1420.68204402924 5787.57831215858,1412.53909349442 PathPoint;PointKind.SMOOTHPOINT 5794.00009989738,1429.99997377396 5794.31768417358,1433.06912899017 5793.43397140503,1424.52515602112 PathPoint;PointKind.SMOOTHPOINT 5796.99997901917,1438.99996519089 5797.82739758492,1441.78139448166 5796.17539286613,1436.22750520706 PathPoint;PointKind.SMOOTHPOINT 5801.99989557266,1449.00003433228 5800.66795349121,1451.45668029785 5801.17247700691,1446.2188410759 PathPoint;PointKind.SMOOTHPOINT 5794.99994158745,1459.00010347366 5793.65596175194,1461.47870063782 5796.3318836689,1456.5429854393 PathPoint;PointKind.SMOOTHPOINT 5788.18905115128,1462.70867586136 5794.21748757362,1468.62416982651 5789.5326769352,1460.2303147316 PathPoint;PointKind.SMOOTHPOINT 5803.32263231277,1483.75822305679 5805.19591927528,1485.84783554077 5796.54148221016,1476.19332075119 PathPoint;PointKind.SMOOTHPOINT 5799.00001645088,1495.99991083145 5798.15135478973,1500.51548480988 5799.65855240822,1492.49621629715 PathPoint;PointKind.SMOOTHPOINT 5796.0001373291,1510.00005483627 5794.63951706886,1513.95386695862 5797.54698872566,1505.50477981567 PathPoint;PointKind.SMOOTHPOINT 5790.00002503395,1519.99988794327 5788.30411791801,1524.13686275482 5791.53059005737,1516.26511573792 PathPoint;PointKind.SMOOTHPOINT 5782.5355553627,1530.95566034317 5785.02807855606,1533.66297483444 5783.99212360382,1527.33347654343 PathPoint;PointKind.SMOOTHPOINT 5790.01454114914,1539.07831192017 5791.08413100243,1541.67846679688 5787.52166390419,1536.37099742889 PathPoint;PointKind.SMOOTHPOINT 5794.84097242355,1550.47995328903 5795.89994072914,1557.19371557236 5793.80820393562,1543.93117904663 PathPoint;PointKind.SMOOTHPOINT 5796.0001373291,1565.00008106232 5792.81225681305,1570.04791259766 5803.9323091507,1560.6360411644 PathPoint;PointKind.SMOOTHPOINT 5794.99994158745,1580.0000667572 5795.18971323967,1583.24601173401 5794.70997333527,1575.03933191299 PathPoint;PointKind.SMOOTHPOINT 5789.46469902992,1585.65969944 5789.46469902992,1591.17369890213 5790.16713738441,1582.48385667801 PathPoint;PointKind.SMOOTHPOINT 5793.47893595695,1594.51004505157 5792.50600218773,1600.76802492142 5791.98696255684,1590.04451036453 PathPoint;PointKind.SMOOTHPOINT 5790.5594265461,1613.28540086746 5789.06178832054,1619.21458482742 5791.53236031532,1607.02765703201 PathPoint;PointKind.SMOOTHPOINT 5803.00009131432,1631.00001811981 5802.09230303764,1634.20040845871 5803.88840675354,1623.9435338974 PathPoint;PointKind.SMOOTHPOINT 5794.00009989738,1641.0000872612 5791.7624938488,1644.40913200378 5795.83019256592,1638.21228504181 PathPoint;PointKind.SMOOTHPOINT 5788.55230808258,1650.65672636032 5788.55230808258,1657.77930021286 5789.59074139595,1646.99701309204 PathPoint;PointKind.SMOOTHPOINT 5801.0000538826,1663.99998664856 5801.10414505005,1666.87063694 5795.73070406914,1658.82469654083 PathPoint;PointKind.SMOOTHPOINT 5801.0000538826,1675.99997520447 5796.7871940136,1675.87110042572 5808.16039323807,1676.21854305267 PathPoint;PointKind.SMOOTHPOINT 5801.0000538826,1686.99988603592 5798.69022130966,1687.54064083099 5800.86197376251,1683.19052696228 PathPoint;PointKind.SMOOTHPOINT 5789.10144209862,1684.23875570297 5789.44133162498,1686.42561435699 5791.41092061996,1683.6977648735 PathPoint;PointKind.SMOOTHPOINT 5790.12146472931,1690.79980373383 5791.38684511185,1693.2387471199 5789.09967184067,1688.83151292801 PathPoint;PointKind.SMOOTHPOINT 5791.29018902779,1698.32151174545 5790.31725525856,1699.22481536865 5790.90037822723,1695.8145904541 PathPoint;PointKind.SMOOTHPOINT 5788.37067961693,1701.03189468384 5788.37067961693,1705.44975042343 5789.34361338615,1700.12859106064 PathPoint;PointKind.SMOOTHPOINT 5793.12488436699,1710.17468690872 5793.91512751579,1710.35596132278 5789.82370734215,1711.55100345612 PathPoint;PointKind.SMOOTHPOINT 5795.66732883453,1712.76823282242 5794.51276659966,1714.63337659836 5794.87779378891,1712.58695840836 PathPoint;PointKind.SMOOTHPOINT 5792.20293402672,1718.36437225342 5795.86205720901,1718.32471847534 5793.3574962616,1716.49922847748 PathPoint;PointKind.SMOOTHPOINT 5797.69250392914,1743.12933683395 5795.15076756477,1748.52933168411 5797.00812220573,1739.49133872986 PathPoint;PointKind.SMOOTHPOINT 5793.75403404236,1755.77440738678 5791.76745057106,1761.11704587936 5795.04136562347,1752.31367111206 PathPoint;PointKind.SMOOTHPOINT 5792.00006246567,1771.00004196167 5794.1229557991,1773.10145616531 5793.06469559669,1765.47589302063 PathPoint;PointKind.SMOOTHPOINT 5796.01819396019,1796.58994674683 5798.34749937057,1806.35988235474 5793.42936873436,1785.73047637939 PathPoint;PointKind.SMOOTHPOINT 5798.03770422935,1820.01352787018 5796.99573040009,1820.48536062241 5798.03770422935,1816.5936255455 PathPoint;PointKind.SMOOTHPOINT 5796.0001373291,1826.00006818771 5794.86965060234,1826.38126373291 5798.95611405373,1825.00305891037 PathPoint;PointKind.SMOOTHPOINT 5794.99994158745,1835.00005960464 5794.99994158745,1836.79911375046 5796.08581781387,1834.50863599777 PathPoint;PointKind.SMOOTHPOINT 5794.99994158745,1853.00004243851 5795.15218377113,1866.54275178909 5794.84026432037,1838.79997730255 PathPoint;PointKind.SMOOTHPOINT 5794.43381309509,1900.40967464447 5795.36992549896,1914.54128980637 5793.49770069122,1886.27829551697 PathPoint;PointKind.SMOOTHPOINT 5797.20957756042,2010.35378694534 5797.20957756042,2024.54511880875 5794.93267178535,2008.09965848923 PathPoint;PointKind.SMOOTHPOINT 5798.67181062698,2051.33879899979 5798.67181062698,2051.33879899979 5795.69388270378,2036.61544561386 PathPoint;PointKind.SMOOTHPOINT 5799.48754549026,3666.37705469131 5799.51870203018,3729.79949617386 5799.27192807198,3235.30484580994 PathPoint;PointKind.SMOOTHPOINT 5799.18412327766,3804.90800046921 5799.43054318428,3817.90617847443 5798.73235344887,3781.04775571823 PathPoint;PointKind.SMOOTHPOINT 5787.06529140472,3817.90617847443 5763.91987681389,3818.0905213356 5795.6120967865,3817.83820056915 PathPoint;PointKind.SMOOTHPOINT 5650.04661798477,3817.75275611877 4835.43657660484,3814.87384462357 5713.49514126778,3817.97698879242 PathPoint;PointKind.SMOOTHPOINT 246.655546665192,3817.66040611267 202.274471759796,3817.50367927551 942.45330953598,3820.11941242218 PathPoint;PointKind.SMOOTHPOINT 148.652296304703,3817.90871429443 139.489441156387,3817.98589754105 165.397874355316,3817.76732969284 PathPoint;PointKind.SMOOTHPOINT 139.5630838871,3807.90982532501 139.592470169067,3791.1535077095 139.557773113251,3810.87252902985 PathPoint;PointKind.SMOOTHPOINT 140.096993684769,3711.64130973816 140.248881816864,3157.08251523972 140.08495593071,3755.12262153625 PathPoint;PointKind.SMOOTHPOINT 142.062846422195,197.883541107178 142.069927453995,173.476876735687 141.950966119766,606.282522201538 PathPoint;PointKind.SMOOTHPOINT 142.076654434204,148.65762424469 142.184994220734,146.099247455597 141.723310947418,156.976892471313 PathPoint;PointKind.SMOOTHPOINT 147.058160305023,143.015694141388 159.995913505554,142.913019180298 146.086996793747,143.023247241974 PathPoint;PointKind.SMOOTHPOINT 198.335806131363,143.177613735199 784.691265821457,145.031191825867 172.373557090759,143.09570980072 PathPoint";
	
	subshadow35mm[0] = "PointKind.SMOOTHPOINT 141.889677762985,142.381206035614 358.867008209229,143.639033317566 136.299557209015,142.34886932373 PathPoint;PointKind.SMOOTHPOINT 5778.00652742386,143.334690093994 5784.62056517601,143.356877326965 5537.60620594025,142.528632640839 PathPoint;PointKind.SMOOTHPOINT 5786.09271168709,153.265365123749 5787.31241941452,357.087436676025 5786.04314446449,144.959078788757 PathPoint;PointKind.SMOOTHPOINT 5807.97966861725,3809.10844087601 5808.02250885963,3815.53919792175 5806.74367451668,3622.8237247467 PathPoint;PointKind.SMOOTHPOINT 5798.70953583717,3817.3264503479 5547.11658143997,3816.64761543274 5805.64682269096,3817.34509706497 PathPoint;PointKind.SMOOTHPOINT 140.341251850128,3817.38862514496 134.815568685532,3817.37092256546 389.925671577454,3818.18783760071 PathPoint;PointKind.SMOOTHPOINT 132.040866374969,3808.64307880402 132.181778907776,3612.31415510178 132.0362637043,3814.9454331398 PathPoint;PointKind.SMOOTHPOINT 135.027449846268,149.391899585724 134.978944778442,144.864287853241 136.883034229279,322.340908527374 PathPoint";
	
} else if (mask_variant_35mm == 7) {
	
	negative35mm[0] = "PointKind.CORNERPOINT 279,191 279,191 279,191 PathPoint;PointKind.SMOOTHPOINT 315.877589225769,191.143956184387 328.473193845966,191.086124747869 309.38840722557,191.173627032906 PathPoint;PointKind.CORNERPOINT 375.708413362503,191.416103839874 375.708413362503,191.416103839874 375.708413362503,191.416103839874 PathPoint;PointKind.SMOOTHPOINT 437.114058971405,191.695568561554 443.035925865173,191.679990291595 424.039995908737,191.730501651764 PathPoint;PointKind.SMOOTHPOINT 465.455180644989,191.824443340302 470.603090763092,192.266299724579 460.306916475296,191.382586956024 PathPoint;PointKind.SMOOTHPOINT 495.37785077095,190.391714572906 499.463606119156,190.910518169403 491.292095422745,189.873147010803 PathPoint;PointKind.SMOOTHPOINT 520.569683551788,190.506427288055 529.741744041443,191.522083282471 511.397977113724,189.490535259247 PathPoint;PointKind.SMOOTHPOINT 604.018227100372,190.886206626892 611.18989610672,190.789904594421 596.846204042435,190.982744693756 PathPoint;PointKind.SMOOTHPOINT 648.111104011536,189.517915248871 661.829540967941,188.940575122833 634.39266705513,190.095255374908 PathPoint;PointKind.CORNERPOINT 744.162822008133,188.386130332947 744.162822008133,188.386130332947 744.162822008133,188.386130332947 PathPoint;PointKind.SMOOTHPOINT 866.980486154556,187.376139163971 871.60015130043,187.233338356018 830.444486379623,188.505091667175 PathPoint;PointKind.SMOOTHPOINT 1021.2889149189,186.509420871735 1027.87108802795,187.578656673431 1015.13833069801,185.510051250458 PathPoint;PointKind.CORNERPOINT 1035.4520406723,188.142778873444 1035.4520406723,188.142778873444 1035.4520406723,188.142778873444 PathPoint;PointKind.CORNERPOINT 1052.77153635025,188.221614360809 1052.77153635025,188.221614360809 1052.77153635025,188.221614360809 PathPoint;PointKind.SMOOTHPOINT 1087.41760873795,186.810364723206 1096.046200037,186.943016052246 1075.30621194839,186.62389755249 PathPoint;PointKind.SMOOTHPOINT 1114.18426299095,186.932158470154 1120.42371416092,188.067247867584 1108.80834364891,185.954031944275 PathPoint;PointKind.SMOOTHPOINT 1126.77292132378,188.558435440063 1127.31391215324,188.531763553619 1125.08338713646,188.641047477722 PathPoint;PointKind.SMOOTHPOINT 1139.37609577179,187.046635150909 1144.41956067085,185.990381240845 1135.06870412827,187.948758602142 PathPoint;PointKind.CORNERPOINT 1288.95333313942,187.727358341217 1288.95333313942,187.727358341217 1288.95333313942,187.727358341217 PathPoint;PointKind.SMOOTHPOINT 1515.69540643692,185.6214594841 1521.45582580566,185.892899036407 1507.05796384811,185.214536190033 PathPoint;PointKind.SMOOTHPOINT 1523.5610165596,187.226021289825 1532.36238503456,186.954817771912 1519.11342048645,187.363157272339 PathPoint;PointKind.CORNERPOINT 1533.01490211487,185.700294971466 1533.01490211487,185.700294971466 1533.01490211487,185.700294971466 PathPoint;PointKind.CORNERPOINT 1611.73968935013,186.058595180511 1611.73968935013,186.058595180511 1611.73968935013,186.058595180511 PathPoint;PointKind.SMOOTHPOINT 1619.60494542122,187.663156986237 1623.60856080055,188.292424678802 1615.60203814507,187.034361362457 PathPoint;PointKind.CORNERPOINT 1632.20847392082,186.151828765869 1632.20847392082,186.151828765869 1632.20847392082,186.151828765869 PathPoint;PointKind.CORNERPOINT 1770.76408529282,186.782276630402 1770.76408529282,186.782276630402 1770.76408529282,186.782276630402 PathPoint;PointKind.CORNERPOINT 1950.264346838,186.030035018921 1950.264346838,186.030035018921 1950.264346838,186.030035018921 PathPoint;PointKind.CORNERPOINT 1958.1292488575,187.634832859039 1958.1292488575,187.634832859039 1958.1292488575,187.634832859039 PathPoint;PointKind.CORNERPOINT 1967.58348846436,186.10910654068 1967.58348846436,186.10910654068 1967.58348846436,186.10910654068 PathPoint;PointKind.CORNERPOINT 2158.10502195358,185.407140254974 2158.10502195358,185.407140254974 2158.10502195358,185.407140254974 PathPoint;PointKind.CORNERPOINT 2498.20379281044,185.385897159576 2498.20379281044,185.385897159576 2498.20379281044,185.385897159576 PathPoint;PointKind.SMOOTHPOINT 2510.79245114326,187.012174129486 2515.25279307365,187.100450992584 2503.67707633972,186.871497631073 PathPoint;PointKind.SMOOTHPOINT 2523.39597964287,185.500609874725 2533.13133621216,186.100373268127 2513.6599149704,184.90061044693 PathPoint;PointKind.CORNERPOINT 2769.02458095551,185.049548149109 2769.02458095551,185.049548149109 2769.02458095551,185.049548149109 PathPoint;PointKind.CORNERPOINT 2783.1880607605,186.682906150818 2783.1880607605,186.682906150818 2783.1880607605,186.682906150818 PathPoint;PointKind.CORNERPOINT 2794.21676778793,185.164024829865 2794.21676778793,185.164024829865 2794.21676778793,185.164024829865 PathPoint;PointKind.CORNERPOINT 2803.65613722801,186.775903701782 2803.65613722801,186.775903701782 2803.65613722801,186.775903701782 PathPoint;PointKind.CORNERPOINT 2820.98306798935,185.285818576813 2820.98306798935,185.285818576813 2820.98306798935,185.285818576813 PathPoint;PointKind.CORNERPOINT 2995.75213813782,186.081254482269 2995.75213813782,186.081254482269 2995.75213813782,186.081254482269 PathPoint;PointKind.CORNERPOINT 3505.9040119648,185.265047550201 3505.9040119648,185.265047550201 3505.9040119648,185.265047550201 PathPoint;PointKind.CORNERPOINT 3789.32089352608,184.986054897308 3789.32089352608,184.986054897308 3789.32089352608,184.986054897308 PathPoint;PointKind.SMOOTHPOINT 4009.75058102608,185.989201068878 4026.09537267685,185.93585729599 3927.56104493141,186.256864070892 PathPoint;PointKind.SMOOTHPOINT 4209.71183800697,186.89911365509 4215.31470441818,186.509420871735 4204.10897159576,187.288806438446 PathPoint;PointKind.SMOOTHPOINT 4332.52277517319,187.457807064056 4344.41218161583,186.888492107391 4320.63301467896,188.027358055115 PathPoint;PointKind.SMOOTHPOINT 4458.48264718056,188.031134605408 4472.17771673203,187.993133068085 4444.7872235775,188.069372177124 PathPoint;PointKind.SMOOTHPOINT 4516.74608492851,186.727516651154 4522.12873125076,186.990458965302 4511.36379265785,186.464338302612 PathPoint;PointKind.SMOOTHPOINT 4526.18580842018,188.339395523071 4531.29760527611,188.646240234375 4521.07436561584,188.032550811768 PathPoint;PointKind.SMOOTHPOINT 4541.93827176094,186.841993331909 4551.0044708252,186.688807010651 4532.8717186451,186.995179653168 PathPoint;PointKind.SMOOTHPOINT 4741.89952874184,187.752141952515 4728.4469845295,187.4880194664 4725.81531906128,187.436091899872 PathPoint;PointKind.SMOOTHPOINT 5061.5224339962,189.206585884094 5208.0346467495,188.714690208435 5017.35237383842,189.355051517487 PathPoint;PointKind.SMOOTHPOINT 5560.63816571236,191.478180885315 5560.63816571236,191.478180885315 5560.58187150955,194.059925079346 PathPoint;PointKind.SMOOTHPOINT 5611.02253937721,191.707370281219 5619.59129595757,191.874718666077 5602.45342874527,191.540257930756 PathPoint;PointKind.SMOOTHPOINT 5641,192 5643.16748604876,192.121789883558 5636.61789317471,191.753771757703 PathPoint;PointKind.CORNERPOINT 5659,192 5659,192 5659,192 PathPoint;PointKind.CORNERPOINT 5662,3774 5662,3774 5662,3774 PathPoint;PointKind.SMOOTHPOINT 5643.79949855804,3774.36005210876 5638.76436701133,3774.49083242907 5655.30637659306,3774.06101346109 PathPoint;PointKind.SMOOTHPOINT 5528.48780298233,3773.39946985245 5525.60122036934,3773.37940692902 5582.95722389221,3773.77618074417 PathPoint;PointKind.SMOOTHPOINT 5519.81176877022,3773.33810091019 5518.18631792068,3774.12763595581 5522.41440200806,3772.07390069962 PathPoint;PointKind.SMOOTHPOINT 5513.2742061615,3773.28994989395 5454.44039130211,3772.85139799118 5515.45197749138,3773.30623626709 PathPoint;PointKind.CORNERPOINT 5397.32655906677,3772.25659132004 5397.32655906677,3772.25659132004 5397.32655906677,3772.25659132004 PathPoint;PointKind.SMOOTHPOINT 5198.62041497231,3771.87586784363 5194.128916502,3771.86737060547 5308.03333187103,3772.08570241928 PathPoint;PointKind.SMOOTHPOINT 5185.04997158051,3771.84990406036 5177.04097056389,3773.13440322876 5189.54607272148,3771.12905502319 PathPoint;PointKind.SMOOTHPOINT 5162.68948936462,3771.80718183517 5079.5280816555,3771.64809465408 5170.2060046196,3771.82157993317 PathPoint;PointKind.SMOOTHPOINT 4920.20097160339,3771.34290218353 4851.20906257629,3771.90655231476 4989.49170017242,3770.77689170837 PathPoint;PointKind.CORNERPOINT 4802.15910935402,3771.11701726913 4802.15910935402,3771.11701726913 4802.15910935402,3771.11701726913 PathPoint;PointKind.SMOOTHPOINT 4749.37214159966,3771.03487730026 4691.10303902626,3770.94424009323 4782.8098359108,3771.08680486679 PathPoint;PointKind.SMOOTHPOINT 4474.05419015884,3770.60694694519 4460.47418737411,3770.58593988419 4590.05105042458,3770.78727722168 PathPoint;PointKind.SMOOTHPOINT 4432.74380469322,3770.54274559021 4422.53578925133,3771.37759923935 4446.64245390892,3769.40647602081 PathPoint;PointKind.SMOOTHPOINT 4405.2789607048,3770.50002336502 4301.43598341942,3770.33881187439 4414.49350738525,3770.51442146301 PathPoint;PointKind.SMOOTHPOINT 4093.24302697182,3774.00749444962 4090.2654531002,3774.00277376175 4193.51858043671,3774.1632771492 PathPoint;PointKind.SMOOTHPOINT 4084.33898353577,3773.99356842041 4081.44921445847,3773.28168869019 4086.58331656456,3774.54659700394 PathPoint;PointKind.SMOOTHPOINT 4075.4391887188,3773.9798784256 3897.95560503006,3773.70395421982 4078.39551949501,3773.98436307907 PathPoint;PointKind.CORNERPOINT 3754.10408997536,3771.48829936981 3754.10408997536,3771.48829936981 3754.10408997536,3771.48829936981 PathPoint;PointKind.SMOOTHPOINT 3442.17543387413,3772.06115484238 3436.10132479668,3772.07224845886 3635.43095374107,3771.70615911484 PathPoint;PointKind.SMOOTHPOINT 3423.73288655281,3772.09490776062 3419.24315834045,3771.08255624771 3429.38779854774,3773.36996555328 PathPoint;PointKind.SMOOTHPOINT 3409.80485105515,3772.12063550949 3261.5372505188,3772.39278316498 3414.48718333244,3772.11190223694 PathPoint;PointKind.SMOOTHPOINT 2865.14498496056,3773.12071323395 2860.6729593277,3773.12897443771 3074.10977387428,3772.73715734482 PathPoint;PointKind.SMOOTHPOINT 2851.6998758316,3773.14549684525 2849.04625916481,3773.09545755386 2856.19031214714,3773.23023319244 PathPoint;PointKind.SMOOTHPOINT 2836.85874128342,3773.17287683487 2602.72300863266,3773.60293149948 2841.81723380089,3773.16367149353 PathPoint;PointKind.SMOOTHPOINT 2081.84620404243,3774.55934286118 2074.94290614128,3774.57208871841 2343.01023507118,3774.07972097397 PathPoint;PointKind.SMOOTHPOINT 2061.13347792625,3774.5973443985 2053.28981900215,3775.48884630203 2067.99393558502,3773.81795883179 PathPoint;PointKind.SMOOTHPOINT 2037.37342977524,3774.64101076126 1176.78270840645,3776.22149705887 2045.29356384277,3774.62661266327 PathPoint;PointKind.CORNERPOINT 314.300997495651,3770.80922842026 314.300997495651,3770.80922842026 314.300997495651,3770.80922842026 PathPoint;PointKind.SMOOTHPOINT 301.704904079437,3770.75187206268 297.554458563268,3771.07688227526 308.29526982603,3770.23604559228 PathPoint;PointKind.CORNERPOINT 278,3771 278,3771 278,3771 PathPoint";
	
	negative35mm[1] = "PointKind.CORNERPOINT 279,191 279,191 279,191 PathPoint;PointKind.SMOOTHPOINT 315.877589225769,191.143956184387 328.473193845966,191.086124747869 309.38840722557,191.173627032906 PathPoint;PointKind.CORNERPOINT 375.708413362503,191.416103839874 375.708413362503,191.416103839874 375.708413362503,191.416103839874 PathPoint;PointKind.SMOOTHPOINT 437.114058971405,191.695568561554 443.035925865173,191.679990291595 424.039995908737,191.730501651764 PathPoint;PointKind.SMOOTHPOINT 465.455180644989,191.824443340302 470.603090763092,192.266299724579 460.306916475296,191.382586956024 PathPoint;PointKind.SMOOTHPOINT 495.37785077095,190.391714572906 499.463606119156,190.910518169403 491.292095422745,189.873147010803 PathPoint;PointKind.SMOOTHPOINT 520.569683551788,190.506427288055 529.741744041443,191.522083282471 511.397977113724,189.490535259247 PathPoint;PointKind.SMOOTHPOINT 604.018227100372,190.886206626892 611.18989610672,190.789904594421 596.846204042435,190.982744693756 PathPoint;PointKind.SMOOTHPOINT 648.111104011536,189.517915248871 661.829540967941,188.940575122833 634.39266705513,190.095255374908 PathPoint;PointKind.CORNERPOINT 744.162822008133,188.386130332947 744.162822008133,188.386130332947 744.162822008133,188.386130332947 PathPoint;PointKind.SMOOTHPOINT 866.980486154556,187.376139163971 871.60015130043,187.233338356018 830.444486379623,188.505091667175 PathPoint;PointKind.SMOOTHPOINT 994.2889149189,186.509420871735 1000.87108802795,187.578656673431 988.138330698013,185.510051250458 PathPoint;PointKind.SMOOTHPOINT 1008.4520406723,188.142778873444 1010.67257112417,186.690114335133 1006.23151022044,189.595443411754 PathPoint;PointKind.CORNERPOINT 1025.77153635025,188.221614360809 1025.77153635025,188.221614360809 1025.77153635025,188.221614360809 PathPoint;PointKind.SMOOTHPOINT 1060.41760873795,186.810364723206 1069.046200037,186.943016052246 1048.30621194839,186.62389755249 PathPoint;PointKind.SMOOTHPOINT 1087.18426299095,186.932158470154 1093.42371416092,188.067247867584 1081.80834364891,185.954031944275 PathPoint;PointKind.SMOOTHPOINT 1099.77292132378,188.558435440063 1100.31391215324,188.531763553619 1098.08338713646,188.641047477722 PathPoint;PointKind.SMOOTHPOINT 1112.37609577179,187.046635150909 1117.41956067085,185.990381240845 1108.06870412827,187.948758602142 PathPoint;PointKind.CORNERPOINT 1288.95333313942,187.727358341217 1288.95333313942,187.727358341217 1288.95333313942,187.727358341217 PathPoint;PointKind.SMOOTHPOINT 1515.69540643692,185.6214594841 1521.45582580566,185.892899036407 1507.05796384811,185.214536190033 PathPoint;PointKind.SMOOTHPOINT 1523.5610165596,187.226021289825 1532.36238503456,186.954817771912 1519.11342048645,187.363157272339 PathPoint;PointKind.CORNERPOINT 1533.01490211487,185.700294971466 1533.01490211487,185.700294971466 1533.01490211487,185.700294971466 PathPoint;PointKind.CORNERPOINT 1611.73968935013,186.058595180511 1611.73968935013,186.058595180511 1611.73968935013,186.058595180511 PathPoint;PointKind.SMOOTHPOINT 1619.60494542122,187.663156986237 1623.60856080055,188.292424678802 1615.60203814507,187.034361362457 PathPoint;PointKind.CORNERPOINT 1632.20847392082,186.151828765869 1632.20847392082,186.151828765869 1632.20847392082,186.151828765869 PathPoint;PointKind.CORNERPOINT 1770.76408529282,186.782276630402 1770.76408529282,186.782276630402 1770.76408529282,186.782276630402 PathPoint;PointKind.CORNERPOINT 1950.264346838,186.030035018921 1950.264346838,186.030035018921 1950.264346838,186.030035018921 PathPoint;PointKind.CORNERPOINT 1958.1292488575,187.634832859039 1958.1292488575,187.634832859039 1958.1292488575,187.634832859039 PathPoint;PointKind.CORNERPOINT 1967.58348846436,186.10910654068 1967.58348846436,186.10910654068 1967.58348846436,186.10910654068 PathPoint;PointKind.CORNERPOINT 2158.10502195358,185.407140254974 2158.10502195358,185.407140254974 2158.10502195358,185.407140254974 PathPoint;PointKind.CORNERPOINT 2498.20379281044,185.385897159576 2498.20379281044,185.385897159576 2498.20379281044,185.385897159576 PathPoint;PointKind.SMOOTHPOINT 2510.79245114326,187.012174129486 2515.25279307365,187.100450992584 2503.67707633972,186.871497631073 PathPoint;PointKind.SMOOTHPOINT 2523.39597964287,185.500609874725 2533.13133621216,186.100373268127 2513.6599149704,184.90061044693 PathPoint;PointKind.CORNERPOINT 2769.02458095551,185.049548149109 2769.02458095551,185.049548149109 2769.02458095551,185.049548149109 PathPoint;PointKind.CORNERPOINT 2779,186 2779,186 2779,186 PathPoint;PointKind.CORNERPOINT 2794.21676778793,185.164024829865 2794.21676778793,185.164024829865 2794.21676778793,185.164024829865 PathPoint;PointKind.CORNERPOINT 2803.65613722801,186.775903701782 2803.65613722801,186.775903701782 2803.65613722801,186.775903701782 PathPoint;PointKind.CORNERPOINT 2820.98306798935,185.285818576813 2820.98306798935,185.285818576813 2820.98306798935,185.285818576813 PathPoint;PointKind.CORNERPOINT 2995.75213813782,186.081254482269 2995.75213813782,186.081254482269 2995.75213813782,186.081254482269 PathPoint;PointKind.CORNERPOINT 3505.9040119648,185.265047550201 3505.9040119648,185.265047550201 3505.9040119648,185.265047550201 PathPoint;PointKind.CORNERPOINT 3789.32089352608,184.986054897308 3789.32089352608,184.986054897308 3789.32089352608,184.986054897308 PathPoint;PointKind.SMOOTHPOINT 4009.75058102608,185.989201068878 4026.09537267685,185.93585729599 3927.56104493141,186.256864070892 PathPoint;PointKind.SMOOTHPOINT 4209.71183800697,186.89911365509 4215.31470441818,186.509420871735 4204.10897159576,187.288806438446 PathPoint;PointKind.SMOOTHPOINT 4332.52277517319,187.457807064056 4344.41218161583,186.888492107391 4320.63301467896,188.027358055115 PathPoint;PointKind.SMOOTHPOINT 4458.48264718056,188.031134605408 4472.17771673203,187.993133068085 4444.7872235775,188.069372177124 PathPoint;PointKind.SMOOTHPOINT 4520.74608492851,186.727516651154 4526.12873125076,186.990458965302 4515.36379265785,186.464338302612 PathPoint;PointKind.SMOOTHPOINT 4530.18580842018,188.339395523071 4535.35586373547,188.075857598071 4525.0718023804,188.600055155512 PathPoint;PointKind.SMOOTHPOINT 4545.93827176094,186.841993331909 4555.0044708252,186.688807010651 4536.8717186451,186.995179653168 PathPoint;PointKind.SMOOTHPOINT 4741.89952874184,187.752141952515 4728.4469845295,187.4880194664 4725.81531906128,187.436091899872 PathPoint;PointKind.SMOOTHPOINT 5061.5224339962,189.206585884094 5208.0346467495,188.714690208435 5017.35237383842,189.355051517487 PathPoint;PointKind.SMOOTHPOINT 5560.63816571236,191.478180885315 5560.63816571236,191.478180885315 5560.58187150955,194.059925079346 PathPoint;PointKind.SMOOTHPOINT 5611.02253937721,191.707370281219 5619.59129595757,191.874718666077 5602.45342874527,191.540257930756 PathPoint;PointKind.SMOOTHPOINT 5641,192 5643.16748604876,192.121789883558 5636.61789317471,191.753771757703 PathPoint;PointKind.CORNERPOINT 5659,192 5659,192 5659,192 PathPoint;PointKind.CORNERPOINT 5662,3774 5662,3774 5662,3774 PathPoint;PointKind.SMOOTHPOINT 5643.79949855804,3774.36005210876 5641.08298497148,3774.43060965302 5655.30637659306,3774.06101346109 PathPoint;PointKind.SMOOTHPOINT 5599.49803107862,3774.01931093788 5596.90029991243,3773.99388649178 5623.58810291308,3774.25508465488 PathPoint;PointKind.SMOOTHPOINT 5591.48502818354,3773.9411688684 5589.88501272275,3774.67675792255 5594.28278222021,3772.65493301879 PathPoint;PointKind.SMOOTHPOINT 5586.12272099851,3773.88939659314 5568.4212916674,3773.71942357432 5587.93576267731,3773.90680581821 PathPoint;PointKind.SMOOTHPOINT 5528.48780298233,3773.39946985245 5525.60122036934,3773.37940692902 5548.36547120305,3773.53694394334 PathPoint;PointKind.SMOOTHPOINT 5519.81176877022,3773.33810091019 5518.18631792068,3774.12763595581 5522.41440200806,3772.07390069962 PathPoint;PointKind.SMOOTHPOINT 5513.2742061615,3773.28994989395 5454.44039130211,3772.85139799118 5515.45197749138,3773.30623626709 PathPoint;PointKind.CORNERPOINT 5397.32655906677,3772.25659132004 5397.32655906677,3772.25659132004 5397.32655906677,3772.25659132004 PathPoint;PointKind.SMOOTHPOINT 5198.62041497231,3771.87586784363 5194.128916502,3771.86737060547 5308.03333187103,3772.08570241928 PathPoint;PointKind.SMOOTHPOINT 5185.04997158051,3771.84990406036 5177.04097056389,3773.13440322876 5189.54607272148,3771.12905502319 PathPoint;PointKind.SMOOTHPOINT 5162.68948936462,3771.80718183517 5079.5280816555,3771.64809465408 5170.2060046196,3771.82157993317 PathPoint;PointKind.SMOOTHPOINT 4920.20097160339,3771.34290218353 4851.20906257629,3771.90655231476 4989.49170017242,3770.77689170837 PathPoint;PointKind.CORNERPOINT 4802.15910935402,3771.11701726913 4802.15910935402,3771.11701726913 4802.15910935402,3771.11701726913 PathPoint;PointKind.SMOOTHPOINT 4749.37214159966,3771.03487730026 4716.68865001281,3770.98403834338 4782.8098359108,3771.08680486679 PathPoint;PointKind.SMOOTHPOINT 4615.85374691919,3770.82734000093 4613.65846788426,3770.82392845313 4670.54499567326,3770.91233229869 PathPoint;PointKind.SMOOTHPOINT 4609.22691240686,3770.8170416282 4607.38819044597,3772.36379705657 4611.73529005033,3768.70696363981 PathPoint;PointKind.SMOOTHPOINT 4601.97180789844,3770.80576684215 4562.75183945092,3770.74481690002 4604.4056335128,3770.80954913817 PathPoint;PointKind.SMOOTHPOINT 4474.05419015884,3770.60694694519 4460.47418737411,3770.58593988419 4519.55265854949,3770.67767947507 PathPoint;PointKind.SMOOTHPOINT 4432.74380469322,3770.54274559021 4422.53578925133,3771.37759923935 4446.64245390892,3769.40647602081 PathPoint;PointKind.SMOOTHPOINT 4405.2789607048,3770.50002336502 4301.43598341942,3770.33881187439 4414.49350738525,3770.51442146301 PathPoint;PointKind.SMOOTHPOINT 4093.24302697182,3774.00749444962 4090.2654531002,3774.00277376175 4193.51858043671,3774.1632771492 PathPoint;PointKind.SMOOTHPOINT 4084.33898353577,3773.99356842041 4081.44921445847,3773.28168869019 4086.58331656456,3774.54659700394 PathPoint;PointKind.SMOOTHPOINT 4075.4391887188,3773.9798784256 3897.95560503006,3773.70395421982 4078.39551949501,3773.98436307907 PathPoint;PointKind.CORNERPOINT 3754.10408997536,3771.48829936981 3754.10408997536,3771.48829936981 3754.10408997536,3771.48829936981 PathPoint;PointKind.SMOOTHPOINT 3442.17543387413,3772.06115484238 3436.10132479668,3772.07224845886 3635.43095374107,3771.70615911484 PathPoint;PointKind.SMOOTHPOINT 3423.73288655281,3772.09490776062 3419.24315834045,3771.08255624771 3429.38779854774,3773.36996555328 PathPoint;PointKind.SMOOTHPOINT 3409.80485105515,3772.12063550949 3261.5372505188,3772.39278316498 3414.48718333244,3772.11190223694 PathPoint;PointKind.SMOOTHPOINT 2865.14498496056,3773.12071323395 2860.6729593277,3773.12897443771 3074.10977387428,3772.73715734482 PathPoint;PointKind.SMOOTHPOINT 2851.6998758316,3773.14549684525 2849.04625916481,3773.09545755386 2856.19031214714,3773.23023319244 PathPoint;PointKind.SMOOTHPOINT 2836.85874128342,3773.17287683487 2602.72300863266,3773.60293149948 2841.81723380089,3773.16367149353 PathPoint;PointKind.SMOOTHPOINT 2081.84620404243,3774.55934286118 2074.94290614128,3774.57208871841 2343.01023507118,3774.07972097397 PathPoint;PointKind.SMOOTHPOINT 2061.13347792625,3774.5973443985 2053.28981900215,3775.48884630203 2067.99393558502,3773.81795883179 PathPoint;PointKind.SMOOTHPOINT 2037.37342977524,3774.64101076126 1303.60993733035,3775.98857716733 2045.29356384277,3774.62661266327 PathPoint;PointKind.SMOOTHPOINT 367.730051422309,3771.12216400761 365.754770182618,3771.11104068697 568.471744645065,3772.25259251284 PathPoint;PointKind.SMOOTHPOINT 361.959945263302,3771.08955821197 361.638128877146,3771.31328799984 364.502001324057,3769.32229685527 PathPoint;PointKind.SMOOTHPOINT 356.64315547278,3771.05930819502 329.06002306366,3770.90184465804 358.36557053307,3771.06914092771 PathPoint;PointKind.CORNERPOINT 314.300997495651,3770.80922842026 314.300997495651,3770.80922842026 314.300997495651,3770.80922842026 PathPoint;PointKind.SMOOTHPOINT 301.704904079437,3770.75187206268 297.554458563268,3771.07688227526 308.29526982603,3770.23604559228 PathPoint;PointKind.CORNERPOINT 278,3771 278,3771 278,3771 PathPoint";
	
	negative35mm[2] = "PointKind.CORNERPOINT 279,191 279,191 279,191 PathPoint;PointKind.SMOOTHPOINT 315.877589225769,191.143956184387 328.473193845966,191.086124747869 309.38840722557,191.173627032906 PathPoint;PointKind.CORNERPOINT 375.708413362503,191.416103839874 375.708413362503,191.416103839874 375.708413362503,191.416103839874 PathPoint;PointKind.SMOOTHPOINT 437.114058971405,191.695568561554 443.035925865173,191.679990291595 424.039995908737,191.730501651764 PathPoint;PointKind.SMOOTHPOINT 465.455180644989,191.824443340302 470.603090763092,192.266299724579 460.306916475296,191.382586956024 PathPoint;PointKind.SMOOTHPOINT 495.37785077095,190.391714572906 499.463606119156,190.910518169403 491.292095422745,189.873147010803 PathPoint;PointKind.SMOOTHPOINT 520.569683551788,190.506427288055 529.741744041443,191.522083282471 511.397977113724,189.490535259247 PathPoint;PointKind.SMOOTHPOINT 604.018227100372,190.886206626892 611.18989610672,190.789904594421 596.846204042435,190.982744693756 PathPoint;PointKind.SMOOTHPOINT 648.111104011536,189.517915248871 661.829540967941,188.940575122833 634.39266705513,190.095255374908 PathPoint;PointKind.CORNERPOINT 744.162822008133,188.386130332947 744.162822008133,188.386130332947 744.162822008133,188.386130332947 PathPoint;PointKind.SMOOTHPOINT 866.980486154556,187.376139163971 871.60015130043,187.233338356018 830.444486379623,188.505091667175 PathPoint;PointKind.SMOOTHPOINT 1021.2889149189,186.509420871735 1027.87108802795,187.578656673431 1015.13833069801,185.510051250458 PathPoint;PointKind.CORNERPOINT 1035.4520406723,188.142778873444 1035.4520406723,188.142778873444 1035.4520406723,188.142778873444 PathPoint;PointKind.CORNERPOINT 1052.77153635025,188.221614360809 1052.77153635025,188.221614360809 1052.77153635025,188.221614360809 PathPoint;PointKind.SMOOTHPOINT 1087.41760873795,186.810364723206 1096.046200037,186.943016052246 1075.30621194839,186.62389755249 PathPoint;PointKind.SMOOTHPOINT 1114.18426299095,186.932158470154 1120.42371416092,188.067247867584 1108.80834364891,185.954031944275 PathPoint;PointKind.SMOOTHPOINT 1126.77292132378,188.558435440063 1127.31391215324,188.531763553619 1125.08338713646,188.641047477722 PathPoint;PointKind.SMOOTHPOINT 1139.37609577179,187.046635150909 1144.41956067085,185.990381240845 1135.06870412827,187.948758602142 PathPoint;PointKind.CORNERPOINT 1288.95333313942,187.727358341217 1288.95333313942,187.727358341217 1288.95333313942,187.727358341217 PathPoint;PointKind.SMOOTHPOINT 1515.69540643692,185.6214594841 1521.45582580566,185.892899036407 1507.05796384811,185.214536190033 PathPoint;PointKind.SMOOTHPOINT 1523.5610165596,187.226021289825 1532.36238503456,186.954817771912 1519.11342048645,187.363157272339 PathPoint;PointKind.CORNERPOINT 1533.01490211487,185.700294971466 1533.01490211487,185.700294971466 1533.01490211487,185.700294971466 PathPoint;PointKind.CORNERPOINT 1611.73968935013,186.058595180511 1611.73968935013,186.058595180511 1611.73968935013,186.058595180511 PathPoint;PointKind.SMOOTHPOINT 1619.60494542122,187.663156986237 1623.60856080055,188.292424678802 1615.60203814507,187.034361362457 PathPoint;PointKind.CORNERPOINT 1632.20847392082,186.151828765869 1632.20847392082,186.151828765869 1632.20847392082,186.151828765869 PathPoint;PointKind.CORNERPOINT 1770.76408529282,186.782276630402 1770.76408529282,186.782276630402 1770.76408529282,186.782276630402 PathPoint;PointKind.CORNERPOINT 1950.264346838,186.030035018921 1950.264346838,186.030035018921 1950.264346838,186.030035018921 PathPoint;PointKind.CORNERPOINT 1958.1292488575,187.634832859039 1958.1292488575,187.634832859039 1958.1292488575,187.634832859039 PathPoint;PointKind.CORNERPOINT 1967.58348846436,186.10910654068 1967.58348846436,186.10910654068 1967.58348846436,186.10910654068 PathPoint;PointKind.CORNERPOINT 2158.10502195358,185.407140254974 2158.10502195358,185.407140254974 2158.10502195358,185.407140254974 PathPoint;PointKind.CORNERPOINT 2498.20379281044,185.385897159576 2498.20379281044,185.385897159576 2498.20379281044,185.385897159576 PathPoint;PointKind.SMOOTHPOINT 2510.79245114326,187.012174129486 2515.25279307365,187.100450992584 2503.67707633972,186.871497631073 PathPoint;PointKind.SMOOTHPOINT 2523.39597964287,185.500609874725 2533.13133621216,186.100373268127 2513.6599149704,184.90061044693 PathPoint;PointKind.CORNERPOINT 2769.02458095551,185.049548149109 2769.02458095551,185.049548149109 2769.02458095551,185.049548149109 PathPoint;PointKind.CORNERPOINT 2783.1880607605,186.682906150818 2783.1880607605,186.682906150818 2783.1880607605,186.682906150818 PathPoint;PointKind.CORNERPOINT 2794.21676778793,185.164024829865 2794.21676778793,185.164024829865 2794.21676778793,185.164024829865 PathPoint;PointKind.CORNERPOINT 2803.65613722801,186.775903701782 2803.65613722801,186.775903701782 2803.65613722801,186.775903701782 PathPoint;PointKind.CORNERPOINT 2820.98306798935,185.285818576813 2820.98306798935,185.285818576813 2820.98306798935,185.285818576813 PathPoint;PointKind.CORNERPOINT 2995.75213813782,186.081254482269 2995.75213813782,186.081254482269 2995.75213813782,186.081254482269 PathPoint;PointKind.CORNERPOINT 3505.9040119648,185.265047550201 3505.9040119648,185.265047550201 3505.9040119648,185.265047550201 PathPoint;PointKind.CORNERPOINT 3789.32089352608,184.986054897308 3789.32089352608,184.986054897308 3789.32089352608,184.986054897308 PathPoint;PointKind.SMOOTHPOINT 4009.75058102608,185.989201068878 4026.09537267685,185.93585729599 3927.56104493141,186.256864070892 PathPoint;PointKind.SMOOTHPOINT 4209.71183800697,186.89911365509 4215.31470441818,186.509420871735 4204.10897159576,187.288806438446 PathPoint;PointKind.SMOOTHPOINT 4332.52277517319,187.457807064056 4344.41218161583,186.888492107391 4320.63301467896,188.027358055115 PathPoint;PointKind.SMOOTHPOINT 4458.48264718056,188.031134605408 4472.17771673203,187.993133068085 4444.7872235775,188.069372177124 PathPoint;PointKind.SMOOTHPOINT 4516.74608492851,186.727516651154 4522.12873125076,186.990458965302 4511.36379265785,186.464338302612 PathPoint;PointKind.SMOOTHPOINT 4526.18580842018,188.339395523071 4531.29760527611,188.646240234375 4521.07436561584,188.032550811768 PathPoint;PointKind.SMOOTHPOINT 4541.93827176094,186.841993331909 4551.0044708252,186.688807010651 4532.8717186451,186.995179653168 PathPoint;PointKind.SMOOTHPOINT 4741.89952874184,187.752141952515 4728.4469845295,187.4880194664 4725.81531906128,187.436091899872 PathPoint;PointKind.SMOOTHPOINT 5061.5224339962,189.206585884094 5111.74685584921,189.037963927892 5017.35237383842,189.355051517487 PathPoint;PointKind.SMOOTHPOINT 5262.33128098689,190.204057156441 5265.1864397623,190.228383025443 5186.18286512197,189.555274887325 PathPoint;PointKind.SMOOTHPOINT 5270.90279349696,190.277560023318 5271.60435831462,188.967625828082 5269.55304006829,192.79776646306 PathPoint;PointKind.SMOOTHPOINT 5277.25547266881,190.332603397643 5418.51040208189,191.561481762029 5275.13756421397,190.314178186652 PathPoint;PointKind.SMOOTHPOINT 5560.63816571236,191.478180885315 5560.63816571236,191.478180885315 5560.60242856089,193.117145089678 PathPoint;PointKind.SMOOTHPOINT 5609,192 5617.56875658035,192.167348384857 5600.43088936806,191.832887649536 PathPoint;PointKind.SMOOTHPOINT 5641,192 5643.16748604876,192.121789883558 5636.61789317471,191.753771757703 PathPoint;PointKind.CORNERPOINT 5659,192 5659,192 5659,192 PathPoint;PointKind.CORNERPOINT 5662,3774 5662,3774 5662,3774 PathPoint;PointKind.SMOOTHPOINT 5643.79949855804,3774.36005210876 5638.76436701133,3774.49083242907 5655.30637659306,3774.06101346109 PathPoint;PointKind.SMOOTHPOINT 5528.48780298233,3773.39946985245 5525.60122036934,3773.37940692902 5582.95722389221,3773.77618074417 PathPoint;PointKind.SMOOTHPOINT 5519.81176877022,3773.33810091019 5518.18631792068,3774.12763595581 5522.41440200806,3772.07390069962 PathPoint;PointKind.SMOOTHPOINT 5513.2742061615,3773.28994989395 5454.44039130211,3772.85139799118 5515.45197749138,3773.30623626709 PathPoint;PointKind.CORNERPOINT 5397.32655906677,3772.25659132004 5397.32655906677,3772.25659132004 5397.32655906677,3772.25659132004 PathPoint;PointKind.SMOOTHPOINT 5198.62041497231,3771.87586784363 5194.128916502,3771.86737060547 5308.03333187103,3772.08570241928 PathPoint;PointKind.SMOOTHPOINT 5185.04997158051,3771.84990406036 5177.04097056389,3773.13440322876 5189.54607272148,3771.12905502319 PathPoint;PointKind.SMOOTHPOINT 5162.68948936462,3771.80718183517 5079.5280816555,3771.64809465408 5170.2060046196,3771.82157993317 PathPoint;PointKind.SMOOTHPOINT 4920.20097160339,3771.34290218353 4851.20906257629,3771.90655231476 4989.49170017242,3770.77689170837 PathPoint;PointKind.CORNERPOINT 4802.15910935402,3771.11701726913 4802.15910935402,3771.11701726913 4802.15910935402,3771.11701726913 PathPoint;PointKind.SMOOTHPOINT 4749.37214159966,3771.03487730026 4691.10303902626,3770.94424009323 4782.8098359108,3771.08680486679 PathPoint;PointKind.SMOOTHPOINT 4474.05419015884,3770.60694694519 4460.47418737411,3770.58593988419 4590.05105042458,3770.78727722168 PathPoint;PointKind.SMOOTHPOINT 4432.74380469322,3770.54274559021 4422.53578925133,3771.37759923935 4446.64245390892,3769.40647602081 PathPoint;PointKind.SMOOTHPOINT 4405.2789607048,3770.50002336502 4301.43598341942,3770.33881187439 4414.49350738525,3770.51442146301 PathPoint;PointKind.SMOOTHPOINT 4093.24302697182,3774.00749444962 4090.2654531002,3774.00277376175 4193.51858043671,3774.1632771492 PathPoint;PointKind.SMOOTHPOINT 4084.33898353577,3773.99356842041 4081.44921445847,3773.28168869019 4086.58331656456,3774.54659700394 PathPoint;PointKind.SMOOTHPOINT 4075.4391887188,3773.9798784256 3897.95560503006,3773.70395421982 4078.39551949501,3773.98436307907 PathPoint;PointKind.CORNERPOINT 3754.10408997536,3771.48829936981 3754.10408997536,3771.48829936981 3754.10408997536,3771.48829936981 PathPoint;PointKind.SMOOTHPOINT 3442.17543387413,3772.06115484238 3436.10132479668,3772.07224845886 3635.43095374107,3771.70615911484 PathPoint;PointKind.SMOOTHPOINT 3423.73288655281,3772.09490776062 3419.24315834045,3771.08255624771 3429.38779854774,3773.36996555328 PathPoint;PointKind.SMOOTHPOINT 3409.80485105515,3772.12063550949 3261.5372505188,3772.39278316498 3414.48718333244,3772.11190223694 PathPoint;PointKind.SMOOTHPOINT 2865.14498496056,3773.12071323395 2860.6729593277,3773.12897443771 3074.10977387428,3772.73715734482 PathPoint;PointKind.SMOOTHPOINT 2851.6998758316,3773.14549684525 2849.04625916481,3773.09545755386 2856.19031214714,3773.23023319244 PathPoint;PointKind.SMOOTHPOINT 2836.85874128342,3773.17287683487 2643.35141307002,3773.52830626118 2841.81723380089,3773.16367149353 PathPoint;PointKind.SMOOTHPOINT 2217.54452095892,3774.31014893816 2215.31686576876,3774.31423958391 2432.37340787545,3773.91565840951 PathPoint;PointKind.SMOOTHPOINT 2211,3774 2209.3793023334,3774.60189749933 2213.47006515902,3773.08266293398 PathPoint;PointKind.SMOOTHPOINT 2205.67305732161,3774.33194858987 2164.49761864955,3774.4075595819 2207.40238301981,3774.32877300666 PathPoint;PointKind.SMOOTHPOINT 2081.84620404243,3774.55934286118 2074.94290614128,3774.57208871841 2123.19009622702,3774.48341573018 PathPoint;PointKind.SMOOTHPOINT 2061.13347792625,3774.5973443985 2053.28981900215,3775.48884630203 2067.99393558502,3773.81795883179 PathPoint;PointKind.SMOOTHPOINT 2037.37342977524,3774.64101076126 1176.78270840645,3776.22149705887 2045.29356384277,3774.62661266327 PathPoint;PointKind.CORNERPOINT 314.300997495651,3770.80922842026 314.300997495651,3770.80922842026 314.300997495651,3770.80922842026 PathPoint;PointKind.SMOOTHPOINT 301.704904079437,3770.75187206268 297.554458563268,3771.07688227526 308.29526982603,3770.23604559228 PathPoint;PointKind.CORNERPOINT 278,3771 278,3771 278,3771 PathPoint";
	
	mask35mm[0] = "PointKind.CORNERPOINT 5612.515625,3843 5612.515625,3843 5612.515625,3843 PathPoint;PointKind.SMOOTHPOINT 5600.28829598427,3843.04031801224 5598.66886401176,3843.19279623032 5608.16665196419,3842.30035018921 PathPoint;PointKind.SMOOTHPOINT 5590.50588798523,3843.0633687973 5566.45268511772,3843.28170061111 5592.30376195908,3843.04755449295 PathPoint;PointKind.SMOOTHPOINT 5465.05160164833,3842.73292064667 5460.70491027832,3842.69515514374 5517.97417116165,3843.19365978241 PathPoint;PointKind.SMOOTHPOINT 5451.44716930389,3840.65156936646 5443.78478479385,3840.16864299774 5455.87281417847,3840.93056201935 PathPoint;PointKind.SMOOTHPOINT 5435.89085054398,3841.63182020187 5423.21757388115,3841.59075021744 5440.17098021507,3841.64574623108 PathPoint;PointKind.SMOOTHPOINT 5397.79171299934,3841.4226937294 5331.92183089256,3840.92631340027 5410.48127603531,3841.51852369308 PathPoint;PointKind.SMOOTHPOINT 5228.8156349659,3846.22575759888 5224.27350711823,3846.15117073059 5277.00064015388,3847.01600074768 PathPoint;PointKind.SMOOTHPOINT 5215.13791394234,3846.02135181427 5208.25692129135,3847.7420425415 5220.84557962418,3844.59334373474 PathPoint;PointKind.SMOOTHPOINT 5193.82223796844,3845.10907888412 5185.45706105232,3846.16674900055 5201.05622005463,3844.19468164444 PathPoint;PointKind.SMOOTHPOINT 5171.46423411369,3845.04889011383 5167.40184617043,3846.25974655151 5180.22134613991,3842.43858575821 PathPoint;PointKind.SMOOTHPOINT 5156.76365804672,3845.56438922882 5153.08895659447,3845.65479040146 5161.82978224754,3845.43976306915 PathPoint;PointKind.SMOOTHPOINT 5137.44306278229,3843.9348077774 5095.02555799484,3844.42670345306 5141.30222511292,3843.88996124268 PathPoint;PointKind.SMOOTHPOINT 4978.02106690407,3842.48178005219 4849.78676748276,3839.50042963028 5049.25978732109,3844.13826942444 PathPoint;PointKind.SMOOTHPOINT 4601.32752370834,3842.26675271988 4502.14244914055,3841.98280334473 4700.51189017296,3842.55070209503 PathPoint;PointKind.SMOOTHPOINT 4425.86769890785,3840.98980665207 4413.01704239845,3840.68012952805 4490.75154733658,3842.55471467972 PathPoint;PointKind.SMOOTHPOINT 4391.50274348259,3840.4417347908 4387.5256819725,3841.17060899734 4402.76760292053,3838.37737798691 PathPoint;PointKind.SMOOTHPOINT 4379.53473758698,3840.39334774017 4375.02270412445,3840.38768291473 4383.50223970413,3840.39830446243 PathPoint;PointKind.SMOOTHPOINT 4365.87401103973,3840.41223049164 4363.47566556931,3841.01057767868 4370.38179588318,3839.28847074509 PathPoint;PointKind.SMOOTHPOINT 4359.2486436367,3840.95298528671 4356.8141849041,3840.822930336 4361.33613181114,3841.06486558914 PathPoint;PointKind.SMOOTHPOINT 4351.83444929123,3840.48209667206 4328.71948313713,3840.61899662018 4354.45159864426,3840.4665184021 PathPoint;PointKind.SMOOTHPOINT 4256.41081881523,3840.71246623993 4239.61567354202,3840.66124677658 4300.68567824364,3840.84794998169 PathPoint;PointKind.SMOOTHPOINT 4198.39521718025,3840.37540912628 4053.63024902344,3839.18603181839 4220.48307967186,3840.55691957474 PathPoint;PointKind.SMOOTHPOINT 3893.15530371666,3839.55094099045 3873.36417388916,3839.20703887939 3964.00987815857,3840.7806801796 PathPoint;PointKind.SMOOTHPOINT 3833.67145013809,3842.19051361084 3827.5739736557,3842.19004154205 3852.85361123085,3842.19216585159 PathPoint;PointKind.SMOOTHPOINT 3811.46568846703,3841.40404701233 3805.88902187347,3841.41820907593 3817.75647711754,3841.3875246048 PathPoint;PointKind.SMOOTHPOINT 3798.04607105255,3842.27076530457 3780.91917943954,3842.3330783844 3803.86561703682,3842.24975824356 PathPoint;PointKind.SMOOTHPOINT 3741.86728906631,3842.43126869202 3735.38106393814,3842.43693351746 3762.55629372597,3842.41214990616 PathPoint;PointKind.SMOOTHPOINT 3720.08815956116,3841.15715503693 3714.42298007011,3841.15031003952 3727.06510019302,3841.1651802063 PathPoint;PointKind.SMOOTHPOINT 3704.15619206429,3842.39137887955 3690.63071322441,3842.34960079193 3710.18498253822,3842.41049766541 PathPoint;PointKind.SMOOTHPOINT 3660.49525809288,3842.15015172958 3653.68897032738,3842.0965719223 3676.14504647255,3842.27383375168 PathPoint;PointKind.SMOOTHPOINT 3641.34779405594,3840.94448804855 3636.75008010864,3840.89822530746 3648.61010026932,3841.01742267609 PathPoint;PointKind.SMOOTHPOINT 3625.46539378166,3841.81710720062 3599.15334177017,3841.53740644455 3630.15657734871,3841.86691045761 PathPoint;PointKind.SMOOTHPOINT 3543.19265556335,3840.87320566177 3535.49982261658,3840.78304052353 3571.44066166878,3841.20554208755 PathPoint;PointKind.SMOOTHPOINT 3520.80986809731,3839.59649562836 3513.17970228195,3839.50869083405 3528.56430602074,3839.68595266342 PathPoint;PointKind.SMOOTHPOINT 3497.07566571236,3840.34378051758 3482.08016467094,3840.17737627029 3504.73167729378,3840.42851686478 PathPoint;PointKind.SMOOTHPOINT 3452.15926480293,3839.87666845322 3449.24860668182,3839.84858036041 3467.06625294685,3840.01923322678 PathPoint;PointKind.SMOOTHPOINT 3442.06419181824,3841.42812252045 3433.69653654099,3841.35164737701 3444.9659986496,3841.4545583725 PathPoint;PointKind.SMOOTHPOINT 3418.48329377174,3839.58186149597 3411.03865098953,3839.524269104 3426.74579572678,3839.64677095413 PathPoint;PointKind.SMOOTHPOINT 3396.32214260101,3839.42489862442 3392.08379101753,3839.39822673798 3403.64605379105,3839.47116136551 PathPoint;PointKind.SMOOTHPOINT 3382.76338291168,3842.29012012482 3375.74785065651,3842.25306272507 3386.95287537575,3842.31230735779 PathPoint;PointKind.SMOOTHPOINT 3357.49153447151,3841.19940519333 3350.7383544445,3841.19161605835 3354.05440163612,3841.19515657425 PathPoint;PointKind.SMOOTHPOINT 3337.98045945168,3841.0521197319 3333.39195084572,3840.99051475525 3344.25000500679,3841.13638401031 PathPoint;PointKind.SMOOTHPOINT 3304.02584981918,3841.05495214462 3281.08932566643,3841.00090026855 3308.98115587234,3841.06675386429 PathPoint;PointKind.SMOOTHPOINT 3246.67444896698,3839.87832069397 3133.76704287529,3841.29783153534 3267.57482242584,3839.61537837982 PathPoint;PointKind.SMOOTHPOINT 2926.87380981445,3840.51207304001 2819.55156755447,3840.98603010178 3032.86835861206,3840.04378080368 PathPoint;PointKind.SMOOTHPOINT 2600.29839348793,3840.18138885498 2595.20854783058,3840.23662090302 2671.96268391609,3839.4010591507 PathPoint;PointKind.SMOOTHPOINT 2583.86331868172,3840.25526762009 2578.27532243729,3840.25007486343 2589.71118879318,3840.25975227356 PathPoint;PointKind.SMOOTHPOINT 2568.22131943703,3839.07226324081 2564.42836475372,3839.03992652893 2574.40235209465,3839.1256070137 PathPoint;PointKind.SMOOTHPOINT 2554.50925540924,3840.04401683807 2539.42276310921,3840.28807640076 2558.49623036385,3839.97934341431 PathPoint;PointKind.SMOOTHPOINT 2505.74077320099,3840.73370933533 2502.31921863556,3840.41246652603 2509.1630358696,3841.05400800705 PathPoint;PointKind.SMOOTHPOINT 2497.53775191307,3840.83213567734 2489.1424806118,3838.73733043671 2500.21509003639,3841.50011301041 PathPoint;PointKind.SMOOTHPOINT 2479.27824926376,3841.03488922119 2412.74062585831,3841.73260688782 2485.42423081398,3840.97021579742 PathPoint;PointKind.SMOOTHPOINT 2294.06288695335,3841.40097856522 2251.20742034912,3840.78964948654 2339.27173447609,3842.04582452774 PathPoint;PointKind.SMOOTHPOINT 2073.13363265991,3840.1558971405 2067.40012121201,3840.14433145523 2163.44440412521,3840.34283638 PathPoint;PointKind.SMOOTHPOINT 2055.91256332397,3840.12403249741 2048.43959641457,3841.16895675659 2061.60571289062,3839.32765245438 PathPoint;PointKind.SMOOTHPOINT 2038.84550642967,3840.09830474854 2013.92629337311,3840.06525993347 2044.52732634544,3840.10538578033 PathPoint;PointKind.SMOOTHPOINT 1965.62055659294,3840.06337165833 1961.18570637703,3840.06549596786 1989.22092747688,3840.05298614502 PathPoint;PointKind.SMOOTHPOINT 1951.88087654114,3841.49893283844 1966.9100124836,3841.48713111877 1956.23110842705,3841.49492025375 PathPoint;PointKind.SMOOTHPOINT 1872.57756900787,3840.51207304001 1850.21602463722,3840.61073541641 1912.10141015053,3840.33905982971 PathPoint;PointKind.SMOOTHPOINT 1806.0934073925,3839.6054649353 1802.29797434807,3839.63048458099 1827.8959043026,3839.4643163681 PathPoint;PointKind.SMOOTHPOINT 1794.71454334259,3839.68028783798 1785.66817116737,3839.86392259598 1798.50501966476,3839.60310459137 PathPoint;PointKind.SMOOTHPOINT 1774.70460963249,3839.81105089188 1768.29769206047,3839.8525929451 1781.37635779381,3839.76809263229 PathPoint;PointKind.SMOOTHPOINT 1755.46332192421,3839.93284463882 1753.0185956955,3839.9477148056 1761.88723397255,3839.89342689514 PathPoint;PointKind.SMOOTHPOINT 1748.12312436104,3839.97721910477 1741.28461790085,3841.48736715317 1750.52005362511,3839.44779396057 PathPoint;PointKind.SMOOTHPOINT 1734.82317638397,3840.05322217941 1723.4641392231,3840.11529922485 1739.26581573486,3840.0289106369 PathPoint;PointKind.SMOOTHPOINT 1700.49362611771,3840.21466970444 1696.43831920624,3840.2302479744 1712.03712415695,3840.17076730728 PathPoint;PointKind.SMOOTHPOINT 1688.28274083138,3840.25715589523 1685.21240544319,3838.94480466843 1692.61456203461,3842.10860967636 PathPoint;PointKind.SMOOTHPOINT 1678.30769133568,3840.28453588486 1667.5802822113,3840.31049966812 1681.64427351952,3840.2760386467 PathPoint;PointKind.SMOOTHPOINT 1645.72113704681,3840.32418966293 1680.03121447563,3840.32418966293 1656.72966313362,3840.32442569733 PathPoint;PointKind.SMOOTHPOINT 1488.47726655006,3839.4820189476 1371.49331045151,3840.39122343063 1574.11845159531,3838.81616592407 PathPoint;PointKind.SMOOTHPOINT 1189.66338944435,3839.83512639999 1181.17606472969,3839.86982345581 1280.23509693146,3839.46974515915 PathPoint;PointKind.SMOOTHPOINT 1164.27328777313,3839.93850946426 1152.90362906456,3841.23740673065 1172.66891312599,3838.97973775864 PathPoint;PointKind.SMOOTHPOINT 1140.31780314445,3840.03835201263 1127.66045880318,3840.09216785431 1148.30060434341,3840.00483512878 PathPoint;PointKind.SMOOTHPOINT 1102.27318954468,3840.20711660385 1079.64681458473,3840.31191587448 1114.99709558487,3840.14787197113 PathPoint;PointKind.SMOOTHPOINT 1029.33077287674,3836.92482233047 1018.17142081261,3836.81506633759 1052.04920125008,3837.14740276337 PathPoint;PointKind.SMOOTHPOINT 999.192485332489,3837.86541938782 996.7010242939,3837.86683559418 1009.94396996498,3837.85928249359 PathPoint;PointKind.SMOOTHPOINT 989.051739692688,3836.78768634796 985.61637711525,3836.79736375809 991.525852203369,3836.78084135056 PathPoint;PointKind.SMOOTHPOINT 978.77610039711,3838.83245229721 966.958212375641,3838.90090227127 982.181014537811,3838.81262540817 PathPoint;PointKind.SMOOTHPOINT 943.745527982712,3837.20074653625 939.961778640747,3837.25715875626 955.322660923004,3837.02867746353 PathPoint;PointKind.SMOOTHPOINT 917.275923013687,3837.66809463501 911.477620124817,3837.78540372849 922.445784330368,3837.56353139877 PathPoint;PointKind.SMOOTHPOINT 899.871454954147,3838.04338932037 896.089121818542,3838.12977790833 905.680025339127,3837.91097402573 PathPoint;PointKind.SMOOTHPOINT 888.375753879547,3836.54409885406 885.118833303452,3836.62222623825 892.170832872391,3836.45228147507 PathPoint;PointKind.SMOOTHPOINT 878.71687245369,3838.55086326599 871.188319444656,3838.73898267746 881.987601041794,3838.4694314003 PathPoint;PointKind.SMOOTHPOINT 849.484248876572,3839.50515031815 806.002819061279,3840.64141988754 857.121495723724,3839.30593729019 PathPoint;PointKind.SMOOTHPOINT 714.354440689087,3842.20656394958 710.458811044693,3842.25731134415 766.83904838562,3841.53008937836 PathPoint;PointKind.SMOOTHPOINT 702.695875883102,3839.10861253738 696.786400794983,3839.17989492416 706.412709474564,3839.06376600266 PathPoint;PointKind.SMOOTHPOINT 685.190503120422,3842.12772846222 675.830795288086,3842.22686290741 690.671929836273,3842.07037210464 PathPoint;PointKind.SMOOTHPOINT 661.863106012344,3841.04267835617 657.569168329239,3841.07430696487 670.09055685997,3840.98225355148 PathPoint;PointKind.SMOOTHPOINT 646.312452077866,3839.97839927673 642.270953178406,3839.99987840652 650.326689004898,3839.95715618134 PathPoint;PointKind.SMOOTHPOINT 629.781429290771,3841.97831869125 548.745747327805,3842.21812963486 633.561992168427,3841.96675300598 PathPoint;PointKind.SMOOTHPOINT 455.77711057663,3840.48587322235 447.28199672699,3840.59397697449 526.739670753479,3839.58398580551 PathPoint;PointKind.SMOOTHPOINT 432.706754922867,3840.80829620361 425.777611255646,3840.91380357742 439.629525661469,3840.70231676102 PathPoint;PointKind.SMOOTHPOINT 414.001501321793,3841.11042022705 405.187741041183,3843.1832742691 419.446460723877,3839.83016967773 PathPoint;PointKind.SMOOTHPOINT 401.17916893959,3841.33016824722 365.44474196434,3841.93866491318 405.060636520386,3841.2640786171 PathPoint;PointKind.SMOOTHPOINT 327.515625,3842 313.156195937752,3841.93727591185 351.753867094597,3842.10671312352 PathPoint;PointKind.SMOOTHPOINT 291.515625,3840 288.883828782735,3837.52970542243 294.460986855435,3842.76407635427 PathPoint;PointKind.SMOOTHPOINT 288.749732494354,3814.49990272522 288.944460868835,3810.08133888245 288.489150524139,3820.43050289154 PathPoint;PointKind.SMOOTHPOINT 288.749732494354,3800.49999475479 289.188756465912,3790.15106678009 288.650952100754,3802.82800197601 PathPoint;PointKind.SMOOTHPOINT 288.332305669785,3720.65144777298 288.17227435112,3713.76797676086 289.30771780014,3762.64432668686 PathPoint;PointKind.SMOOTHPOINT 288.145012378693,3689.89781856537 291.012122154236,3483.84073734283 288.038796901703,3697.50780344009 PathPoint;PointKind.SMOOTHPOINT 291.968769550323,3048.59166383743 290.755434751511,3029.85407352448 292.928603410721,3063.42052459717 PathPoint;PointKind.SMOOTHPOINT 293.750003099442,2967.49992370605 294.926162481308,2940.63425302505 291.702168703079,3014.25880908966 PathPoint;PointKind.SMOOTHPOINT 293.175377368927,2876.08285903931 293.212552785873,2847.96266555786 293.125102043152,2914.05937671661 PathPoint;PointKind.SMOOTHPOINT 294.164951562881,2809.12108182907 294.064046859741,2792.6704287529 294.237886190414,2821.06701850891 PathPoint;PointKind.SMOOTHPOINT 293.175377368927,2738.03814411163 293.138201951981,2720.10118246078 293.233795881271,2766.81852579117 PathPoint;PointKind.SMOOTHPOINT 294.164951562881,2681.37808799744 293.981552839279,2667.16386079788 294.297012805939,2691.55069828033 PathPoint;PointKind.SMOOTHPOINT 294.164951562881,2581.45033121109 296.266955852509,2553.32565307617 293.858696937561,2585.55166482925 PathPoint;PointKind.SMOOTHPOINT 294.968648672104,2507.22577571869 295.147798776627,2487.43381977081 294.781709432602,2527.93118476868 PathPoint;PointKind.SMOOTHPOINT 294.968648672104,2334.45379257202 294.728247642517,2320.40620565414 296.441857337952,2420.5596113205 PathPoint;PointKind.SMOOTHPOINT 296.45637345314,2286.2347984314 294.852165699005,2225.81188201904 296.816089868546,2299.76924657822 PathPoint;PointKind.SMOOTHPOINT 296.848308563232,2131.88766002655 298.543507575989,2060.42565107346 296.210661649704,2158.765604496 PathPoint;PointKind.SMOOTHPOINT 297.654838085175,1813.99488687515 299.164514064789,1775.84299564362 296.14551615715,1852.14677810669 PathPoint;PointKind.SMOOTHPOINT 296.592329263687,1648.95279407501 296.172778129578,1609.02804851532 296.959834814072,1683.88234376907 PathPoint;PointKind.SMOOTHPOINT 299.968565225601,1534.52520847321 298.691147089005,1486.15137577057 300.906093835831,1569.9721455574 PathPoint;PointKind.SMOOTHPOINT 296.675177335739,1395.04304409027 297.573406219482,1377.1174120903 296.430173635483,1399.94831085205 PathPoint;PointKind.SMOOTHPOINT 295.905469179153,1315.31157016754 294.851811647415,1295.38554668427 297.444177389145,1344.40375328064 PathPoint;PointKind.SMOOTHPOINT 295.179663419724,1218.20348024368 294.842960357666,1203.11805009842 295.484501838684,1231.85618162155 PathPoint;PointKind.SMOOTHPOINT 294.583086490631,1171.12854480743 297.580487251282,1103.41759443283 293.987217664719,1184.5803809166 PathPoint;PointKind.SMOOTHPOINT 294.583086490631,1034.11435604095 295.952912092209,1005.04011154175 293.065975427628,1066.3380074501 PathPoint;PointKind.SMOOTHPOINT 293.067037582397,949.510188102722 292.155000686646,939.802565574646 294.927578687668,969.309461116791 PathPoint;PointKind.SMOOTHPOINT 295.750040531158,894.500012397766 296.496027231216,829.557037353516 295.381472826004,926.50155544281 PathPoint;PointKind.SMOOTHPOINT 296.116837978363,510.840504169464 296.810070991516,492.252087593079 296.098427295685,511.330275535583 PathPoint;PointKind.SMOOTHPOINT 296.066916704178,216.998927593231 295.93839597702,182.760722637177 296.138435125351,236.13659620285 PathPoint;PointKind.SMOOTHPOINT 295.750040531158,152.499933242798 296.695358276367,144.454700946808 294.200002670288,165.687882900238 PathPoint;PointKind.SMOOTHPOINT 298.515625,121 304.52317237854,118.961370944977 294.111931324005,122.494097709656 PathPoint;PointKind.SMOOTHPOINT 320.515625,120 330.876559587689,119.498394416235 310.506357947083,120.483856743103 PathPoint;PointKind.SMOOTHPOINT 362.323069095612,120.161805152893 405.320156335831,119.538674354553 342.383591651917,120.450475215912 PathPoint;PointKind.SMOOTHPOINT 867.672587156296,119.872426986694 928.262497901917,120.020184516907 807.083384513855,119.724433422089 PathPoint;PointKind.SMOOTHPOINT 1476.30922150612,118.243789672852 1553.13523006439,118.643159866333 1399.48321294785,117.84441947937 PathPoint;PointKind.SMOOTHPOINT 1918.2102162838,118.243789672852 1927.06008982658,117.94426202774 1868.91738367081,119.915385246277 PathPoint;PointKind.SMOOTHPOINT 1947.70165157318,113.590843677521 1969.68896341324,112.722001075745 1940.45244526863,113.876917362213 PathPoint;PointKind.SMOOTHPOINT 2006.02244567871,117.852916717529 2014.59863734245,117.212319374084 1989.10054993629,119.116644859314 PathPoint;PointKind.SMOOTHPOINT 2032.27714133263,114.857168197632 2038.2340593338,114.721212387085 2021.07105445862,115.113501548767 PathPoint;PointKind.SMOOTHPOINT 2060.69473814964,114.654414653778 2072.18194198608,114.650166034698 2048.0678422451,114.659843444824 PathPoint;PointKind.SMOOTHPOINT 2097.39962053299,118.099336624146 2104.15421676636,119.899334907532 2085.33814501762,114.886436462402 PathPoint;PointKind.SMOOTHPOINT 2123.03472590446,114.891157150269 2204.43260264397,115.399811267853 2115.52316737175,114.843950271606 PathPoint;PointKind.SMOOTHPOINT 2351.12290334702,116.741194725037 2408.65947318077,117.008149623871 2313.20787262917,116.564877033234 PathPoint;PointKind.SMOOTHPOINT 2485.27375888824,117.103271484375 2498.49793982506,117.366921901703 2451.0847671032,116.420187950134 PathPoint;PointKind.SMOOTHPOINT 2557.21173119545,116.275026798248 2556.4724714756,116.28800868988 2557.95063686371,116.26228094101 PathPoint;PointKind.SMOOTHPOINT 2592.20229578018,118.414442539215 2600.80504131317,122.357869148254 2582.9006524086,114.15048122406 PathPoint;PointKind.SMOOTHPOINT 2618.99975252151,118.280611038208 2623.98479890823,118.274238109589 2606.41286444664,118.29571723938 PathPoint;PointKind.SMOOTHPOINT 2641.44662332535,116.279983520508 2652.12729763985,116.262044906616 2636.30614829063,116.288480758667 PathPoint;PointKind.SMOOTHPOINT 2665.10470461845,120.655353069305 2671.83841180801,120.060546398163 2651.37493801117,121.868569850922 PathPoint;PointKind.SMOOTHPOINT 2691.26593065262,118.280611038208 2696.58272337914,118.265976905823 2683.31570219994,118.302798271179 PathPoint;PointKind.SMOOTHPOINT 2711.0648496151,120.340955257416 2717.68349003792,120.321600437164 2705.67830872536,120.357005596161 PathPoint;PointKind.SMOOTHPOINT 2733.96384429932,116.044657230377 2737.80990672112,116.033091545105 2727.26695847511,116.065900325775 PathPoint;PointKind.SMOOTHPOINT 2749.6731133461,119.310901165009 2757.10253190994,119.287061691284 2745.80793213844,119.323174953461 PathPoint;PointKind.SMOOTHPOINT 2774.95735359192,116.848118305206 2778.07300758362,116.818141937256 2767.47836780548,116.918692588806 PathPoint;PointKind.SMOOTHPOINT 2785.31123828888,118.280847072601 2788.58940196037,118.246386051178 2782.20620584488,118.313183784485 PathPoint;PointKind.SMOOTHPOINT 2794.40469932556,114.855988025665 2801.55689549446,114.757797718048 2791.14140582085,114.901070594788 PathPoint;PointKind.SMOOTHPOINT 2815.73135089874,114.576287269592 2819.72115826607,114.52624797821 2808.67050004005,114.664328098297 PathPoint;PointKind.SMOOTHPOINT 2828.8691432476,118.280847072601 2830.76331925392,118.258423805237 2824.91509509087,118.327345848083 PathPoint;PointKind.SMOOTHPOINT 2841.73821043968,118.280847072601 2848.1380469799,118.186905384064 2839.8532397747,118.308699131012 PathPoint;PointKind.SMOOTHPOINT 2856.58748817444,116.220266819 2859.83661961555,116.175420284271 2850.39547991753,116.306891441345 PathPoint;PointKind.SMOOTHPOINT 2870.21776628494,119.149689674377 2872.93475818634,119.113340377808 2867.02740740776,119.192411899567 PathPoint;PointKind.SMOOTHPOINT 2882.86342692375,116.117119789124 2890.8044500351,115.975735187531 2880.18856716156,116.164798736572 PathPoint;PointKind.SMOOTHPOINT 2913.96261048317,119.267706871033 2924.758705616,119.049139022827 2906.51124072075,119.418768882751 PathPoint;PointKind.SMOOTHPOINT 2951.87976551056,117.32608795166 2959.12295293808,117.855041027069 2941.45259213448,116.564168930054 PathPoint;PointKind.SMOOTHPOINT 2968.45221233368,118.280847072601 2977.05070924759,117.766292095184 2962.57141542435,118.632774353027 PathPoint;PointKind.SMOOTHPOINT 2988.82752728462,114.359135627747 2988.92524552345,113.885650634766 2988.55278325081,115.693674087524 PathPoint;PointKind.SMOOTHPOINT 2997.83743214607,113.791708946228 2999.55210399628,113.749694824219 2991.73393678665,113.941354751587 PathPoint;PointKind.SMOOTHPOINT 3003.39887452126,118.486905097961 3007.65917730331,118.413026332855 3001.39423441887,118.522310256958 PathPoint;PointKind.SMOOTHPOINT 3016.95975852013,116.220266819 3024.17072725296,114.77148771286 3012.21900773048,117.172429561615 PathPoint;PointKind.SMOOTHPOINT 3035.76839518547,116.397528648376 3036.4587957859,116.638991832733 3035.07799458504,116.15606546402 PathPoint;PointKind.SMOOTHPOINT 3119.0813369751,117.777621746063 3132.28569102287,117.73962020874 3103.46305918694,117.824592590332 PathPoint;PointKind.SMOOTHPOINT 3187.23060321808,119.487926959991 3187.03906130791,120.894927978516 3187.42285323143,118.081161975861 PathPoint;PointKind.SMOOTHPOINT 3198.11981391907,117.250556945801 3201.92905497551,116.895089149475 3194.254986763,117.610745429993 PathPoint;PointKind.SMOOTHPOINT 3210.98923516273,115.190212726593 3214.19233989716,114.999260902405 3206.92012023926,115.432856082916 PathPoint;PointKind.SMOOTHPOINT 3219.21633195877,114.981558322906 3222.84748506546,114.9076795578 3215.71653199196,115.052840709686 PathPoint;PointKind.SMOOTHPOINT 3234.74822115898,116.220266819 3239.83452630043,116.348905563354 3230.66600632668,116.11688375473 PathPoint;PointKind.SMOOTHPOINT 3245.4600520134,116.074633598328 3250.07830095291,116.261100769043 3240.79931688309,115.886750221252 PathPoint;PointKind.SMOOTHPOINT 3259.74213910103,118.169202804565 3263.98190689087,118.400988578796 3255.49706053734,117.937653064728 PathPoint;PointKind.SMOOTHPOINT 3271.37627434731,115.190212726593 3275.30058217049,115.455515384674 3267.46612858772,114.926326274872 PathPoint;PointKind.SMOOTHPOINT 3284.24534153938,115.190212726593 3289.05159187317,115.56715965271 3280.60852360725,114.90555524826 PathPoint;PointKind.SMOOTHPOINT 3297.95351099968,116.216490268707 3303.07486724854,117.105867862701 3293.60434126854,115.461180210114 PathPoint;PointKind.SMOOTHPOINT 3313.94425106049,117.250556945801 3317.18028259277,117.869203090668 3309.26758360863,116.35575056076 PathPoint;PointKind.SMOOTHPOINT 3333.74352407455,117.250556945801 3346.02911424637,120.755903720856 3330.7004506588,116.382422447205 PathPoint;PointKind.SMOOTHPOINT 3356.20561909676,121.468727588654 3358.63122653961,121.430962085724 3343.30645751953,121.671009063721 PathPoint;PointKind.SMOOTHPOINT 3363.02040410042,117.398550510406 3367.11501073837,117.139620780945 3360.87201905251,117.534034252167 PathPoint;PointKind.SMOOTHPOINT 3389.18056797981,117.250556945801 3404.3605298996,115.345051288605 3385.88470172882,117.664325237274 PathPoint;PointKind.SMOOTHPOINT 3412.66693425179,114.482109546661 3417.17365694046,114.306499958038 3400.89153242111,114.940960407257 PathPoint;PointKind.SMOOTHPOINT 3435.01962733269,116.586828231812 3444.72418141365,116.845993995667 3426.8612165451,116.368496417999 PathPoint;PointKind.SMOOTHPOINT 3461.44639205933,117.250556945801 3470.70767354965,118.284151554108 3453.82861804962,116.400361061096 PathPoint;PointKind.SMOOTHPOINT 3482.23594737053,117.250556945801 3489.45824575424,116.262753009796 3476.56581115723,118.025693893433 PathPoint;PointKind.SMOOTHPOINT 3501.04458403587,117.250556945801 3502.88706851006,117.345914840698 3489.4175298214,116.647253036499 PathPoint;PointKind.SMOOTHPOINT 3516.88379001617,117.250556945801 3523.25388622284,117.438204288483 3512.46062350273,117.1200299263 PathPoint;PointKind.SMOOTHPOINT 3534.70285248756,115.190212726593 3538.48306131363,115.273532867432 3523.77929878235,114.949929714203 PathPoint;PointKind.SMOOTHPOINT 3546.58234548569,119.310901165009 3551.26219940186,119.407203197479 3542.33231019974,119.222860336304 PathPoint;PointKind.SMOOTHPOINT 3566.38161849976,117.250556945801 3572.2762234211,117.365033626556 3561.1827249527,117.149534225464 PathPoint;PointKind.SMOOTHPOINT 3582.22047042847,122.401535511017 3587.70012688637,122.295320034027 3575.69990229607,122.527105808258 PathPoint;PointKind.SMOOTHPOINT 3601.25640821457,120.165581703186 3608.43480420113,120.289499759674 3595.43013525009,120.064558982849 PathPoint;PointKind.SMOOTHPOINT 3620.82838010788,121.371245384216 3630.59701752663,121.045281887054 3613.34479165077,121.621205806732 PathPoint;PointKind.SMOOTHPOINT 3653.75305366516,119.285409450531 3666.83596801758,119.50138092041 3643.08052253723,119.108383655548 PathPoint;PointKind.SMOOTHPOINT 3699.44199514389,119.408855438232 3808.05086088181,114.841825962067 3685.65912079811,119.988083839417 PathPoint;PointKind.SMOOTHPOINT 3993.01944923401,119.179430007935 4114.54871964455,117.135136127472 3936.46501851082,120.130648612976 PathPoint;PointKind.SMOOTHPOINT 4406.17287111282,116.207048892975 4428.9217479229,115.825853347778 4311.843968153,117.788951396942 PathPoint;PointKind.SMOOTHPOINT 4512.47579884529,118.523726463318 4514.30058073997,118.515465259552 4478.36292815208,118.678092956543 PathPoint;PointKind.SMOOTHPOINT 4528.67755365372,118.603978157043 4548.55967473984,122.661881446838 4526.97350335121,118.25582742691 PathPoint;PointKind.SMOOTHPOINT 4549.80522823334,118.311295509338 4550.13591241837,118.058502674103 4549.4748980999,118.563852310181 PathPoint;PointKind.SMOOTHPOINT 4622.12663841248,118.452680110931 4629.85770893097,118.485488891602 4597.43508052826,118.349061012268 PathPoint;PointKind.SMOOTHPOINT 4645.42358708382,118.56739282608 4650.18027019501,116.80846452713 4636.78791475296,121.760702133179 PathPoint;PointKind.SMOOTHPOINT 4660.57416272163,118.659446239471 4711.53528642654,118.992254734039 4655.51724386215,118.626165390015 PathPoint;PointKind.SMOOTHPOINT 4810.58475923538,120.387454032898 4871.4780921936,119.821679592133 4763.04235768318,120.829546451569 PathPoint;PointKind.SMOOTHPOINT 5002.72147607803,119.355747699738 5007.91930747032,119.343473911285 4936.8569047451,119.510586261749 PathPoint;PointKind.SMOOTHPOINT 5021.53082084656,120.95724105835 5028.65787935257,120.943078994751 5016.32874083519,120.967862606049 PathPoint;PointKind.SMOOTHPOINT 5039.70358085632,119.284229278564 5051.9303984642,119.265582561493 5032.57793855667,119.29461479187 PathPoint;PointKind.SMOOTHPOINT 5076.33092594147,119.241743087769 5081.25719976425,119.237966537476 5064.14801073074,119.251420497894 PathPoint;PointKind.SMOOTHPOINT 5091.52186346054,121.146540641785 5094.85101056099,121.144416332245 5086.60868954659,121.149137020111 PathPoint;PointKind.SMOOTHPOINT 5101.0678024292,119.227108955383 5112.84993124008,119.22262430191 5097.74644446373,119.228053092957 PathPoint;PointKind.SMOOTHPOINT 5136.24424409866,119.22333240509 5147.91095209122,119.224984645844 5124.58355498314,119.221208095551 PathPoint;PointKind.SMOOTHPOINT 5174.15360999107,120.347564220428 5181.00627851486,120.333874225616 5162.7382786274,120.369987487793 PathPoint;PointKind.SMOOTHPOINT 5196.82813596725,118.280847072601 5200.44548106194,118.279194831848 5190.10788273811,118.283679485321 PathPoint;PointKind.SMOOTHPOINT 5216.62705492973,119.310901165009 5232.54415225983,119.317038059235 5213.05184197426,119.309484958649 PathPoint;PointKind.SMOOTHPOINT 5254.84586191177,117.49933719635 5374.79854059219,118.114678859711 5239.8949713707,117.422389984131 PathPoint;PointKind.SMOOTHPOINT 5486.18140053749,118.134977817535 5489.56896615028,118.207204341888 5423.342908144,116.792414188385 PathPoint;PointKind.SMOOTHPOINT 5499.78547883034,120.215857028961 5502.57965397835,120.278642177582 5496.34586763382,120.138437747955 PathPoint;PointKind.SMOOTHPOINT 5514.37488269806,117.188715934753 5521.11496281624,117.374475002289 5511.55486178398,117.111060619354 PathPoint;PointKind.SMOOTHPOINT 5531.86998796463,118.258423805237 5537.29335021973,118.721759319305 5524.65229225159,117.641429901123 PathPoint;PointKind.SMOOTHPOINT 5546.28024172783,117.250556945801 5553.98157191277,116.512949466705 5542.70007205009,117.593750953674 PathPoint;PointKind.SMOOTHPOINT 5558.11406207085,119.351263046265 5564.03911542892,119.133403301239 5552.65033793449,119.551656246185 PathPoint;PointKind.SMOOTHPOINT 5572.46731352806,118.151972293854 5584.98799395561,117.229549884796 5568.37483119965,118.453388214111 PathPoint;PointKind.SMOOTHPOINT 5630.96478796005,120.201453208923 5638.53228963722,121.050119949796 5619.58777378047,118.925564024282 PathPoint;PointKind.SMOOTHPOINT 5650.50265434918,123.071197589955 5650.90841946943,124.461943659781 5648.92040090141,117.648078021147 PathPoint;PointKind.SMOOTHPOINT 5651.78611032415,131.056295299283 5651.93095135243,132.426520460363 5651.42546264264,127.644495940151 PathPoint;PointKind.SMOOTHPOINT 5649.17873044582,136.353519449174 5649.70610580691,142.907834634978 5649.0602990391,134.881632772542 PathPoint;PointKind.SMOOTHPOINT 5650.515625,151 5652.15877842903,154.96773815155 5650.01701971961,149.794772586584 PathPoint;PointKind.CORNERPOINT 5651.30079460144,184.637904167175 5651.30079460144,184.637904167175 5651.30079460144,184.637904167175 PathPoint;PointKind.SMOOTHPOINT 5649.55071759224,1995.19849061966 5648.27683997154,2028.35494995117 5651.59996819496,1941.85967445374 PathPoint;PointKind.SMOOTHPOINT 5650.67341518402,2112.58807182312 5650.64615321159,2114.69585895538 5651.20980334282,2071.54169082642 PathPoint;PointKind.SMOOTHPOINT 5648.27683997154,2123.97814750671 5647.84489703178,2140.60629844666 5648.33242607117,2121.82433366776 PathPoint;PointKind.SMOOTHPOINT 5648.18337035179,2160.77614545822 5648.11397624016,2165.10147571564 5648.35366916656,2150.12367725372 PathPoint;PointKind.SMOOTHPOINT 5650.08356523514,2178.15771818161 5650.02550077438,2180.74677944183 5650.15225124359,2175.08337020874 PathPoint;PointKind.SMOOTHPOINT 5649.08797216415,2187.35503435135 5649.01185107231,2190.33709287643 5649.2239279747,2182.07046031952 PathPoint;PointKind.SMOOTHPOINT 5649.4144077301,2204.44675683975 5649.18214988708,2213.26429367065 5649.50787734985,2200.89656352997 PathPoint;PointKind.SMOOTHPOINT 5648.59902691841,2235.27898550034 5648.28108859062,2247.31461524963 5648.90528154373,2223.70456695557 PathPoint;PointKind.SMOOTHPOINT 5647.74611663818,2267.70515441895 5647.65193891525,2271.31199598312 5647.63742280006,2271.84590578079 PathPoint;PointKind.SMOOTHPOINT 5646.81956362724,2315.12045145035 5646.38408017159,2334.61169958115 5647.0362432003,2305.43029546738 PathPoint;PointKind.SMOOTHPOINT 5645.44371914864,2373.1263756752 5646.26228642464,2339.8105931282 5645.90292406082,2354.36943054199 PathPoint;PointKind.SMOOTHPOINT 5648.4407658577,2473.51557970047 5648.84792518616,2488.05435419083 5647.08297801018,2425.0581908226 PathPoint;PointKind.SMOOTHPOINT 5646.30725097656,2548.12841176987 5649.53018260002,2624.13809537888 5645.12224030495,2520.18075942993 PathPoint;PointKind.SMOOTHPOINT 5645.85725140572,2694.3429851532 5645.20721268654,2707.24014043808 5644.53274440765,2720.60487985611 PathPoint;PointKind.SMOOTHPOINT 5646.39470171928,2740.39659976959 5642.5762553215,2813.53586912155 5647.14670729637,2725.99047660828 PathPoint;PointKind.SMOOTHPOINT 5648.51547074318,2943.00002574921 5647.67566037178,3003.6615729332 5649.15488791466,2896.60321712494 PathPoint;PointKind.SMOOTHPOINT 5650.18765640259,3067.78173208237 5649.80669689178,3074.85025405884 5649.76881337166,3075.54608345032 PathPoint;PointKind.SMOOTHPOINT 5651.34717535973,3094.69154119492 5650.96869421005,3116.89033985138 5651.49658513069,3085.94056606293 PathPoint;PointKind.SMOOTHPOINT 5651.51570391655,3129.99992609024 5651.789031744,3218.28623056412 5651.47959065437,3118.41819047928 PathPoint;PointKind.SMOOTHPOINT 5649.51566648483,3366.00009441376 5649.98513889313,3393.31682682037 5648.21877551079,3290.56326627731 PathPoint;PointKind.SMOOTHPOINT 5650.5155081749,3473.99999141693 5652.22770166397,3536.69969558716 5650.36999297142,3468.68756532669 PathPoint;PointKind.SMOOTHPOINT 5651.51570391655,3693.99986028671 5650.99737238884,3737.21374511719 5652.06696224213,3648.14498662949 PathPoint;PointKind.SMOOTHPOINT 5650.515625,3820 5650.44658493996,3823.64649534225 5650.98368120193,3795.11300563812 PathPoint;PointKind.SMOOTHPOINT 5649.515625,3837 5649.44123721258,3837.2149526016 5650.22500714603,3834.95008541479 PathPoint;PointKind.SMOOTHPOINT 5651.515625,3839 5651.52310247229,3839.37363912322 5651.49990530918,3838.2145084233 PathPoint;PointKind.SMOOTHPOINT 5650.515625,3842 5648.14116047799,3842.62652931615 5650.82754277614,3841.91772311544 PathPoint";
	
	mask35mm[1] = "PointKind.CORNERPOINT 5612.515625,3842.859375 5612.515625,3842.859375 5612.515625,3842.859375 PathPoint;PointKind.SMOOTHPOINT 5600.28829598427,3842.89969301224 5598.66886401176,3843.05217123032 5608.16665196419,3842.15972518921 PathPoint;PointKind.SMOOTHPOINT 5590.50588798523,3842.9227437973 5566.45268511772,3843.14107561111 5592.30376195908,3842.90692949295 PathPoint;PointKind.SMOOTHPOINT 5465.05160164833,3842.59229564667 5460.70491027832,3842.55453014374 5517.97417116165,3843.05303478241 PathPoint;PointKind.SMOOTHPOINT 5451.44716930389,3840.51094436646 5443.78478479385,3840.02801799774 5455.87281417847,3840.78993701935 PathPoint;PointKind.SMOOTHPOINT 5435.89085054398,3841.49119520187 5423.21757388115,3841.45012521744 5440.17098021507,3841.50512123108 PathPoint;PointKind.SMOOTHPOINT 5397.79171299934,3841.2820687294 5331.92183089256,3840.78568840027 5410.48127603531,3841.37789869308 PathPoint;PointKind.SMOOTHPOINT 5228.8156349659,3846.08513259888 5224.27350711823,3846.01054573059 5277.00064015388,3846.87537574768 PathPoint;PointKind.SMOOTHPOINT 5215.13791394234,3845.88072681427 5208.25692129135,3847.6014175415 5220.84557962418,3844.45271873474 PathPoint;PointKind.SMOOTHPOINT 5193.82223796844,3844.96845388412 5185.45706105232,3846.02612400055 5201.05622005463,3844.05405664444 PathPoint;PointKind.SMOOTHPOINT 5171.46423411369,3844.90826511383 5167.40184617043,3846.11912155151 5180.22134613991,3842.29796075821 PathPoint;PointKind.SMOOTHPOINT 5156.76365804672,3845.42376422882 5153.08895659447,3845.51416540146 5161.82978224754,3845.29913806915 PathPoint;PointKind.SMOOTHPOINT 5137.44306278229,3843.7941827774 5095.02555799484,3844.28607845306 5141.30222511292,3843.74933624268 PathPoint;PointKind.SMOOTHPOINT 4978.02106690407,3842.34115505219 4849.78676748276,3839.35980463028 5049.25978732109,3843.99764442444 PathPoint;PointKind.SMOOTHPOINT 4601.32752370834,3842.12612771988 4502.14244914055,3841.84217834473 4700.51189017296,3842.41007709503 PathPoint;PointKind.SMOOTHPOINT 4425.86769890785,3840.84918165207 4413.01704239845,3840.53950452805 4490.75154733658,3842.41408967972 PathPoint;PointKind.SMOOTHPOINT 4391.50274348259,3840.3011097908 4387.5256819725,3841.02998399734 4402.76760292053,3838.23675298691 PathPoint;PointKind.SMOOTHPOINT 4379.53473758698,3840.25272274017 4375.02270412445,3840.24705791473 4383.50223970413,3840.25767946243 PathPoint;PointKind.SMOOTHPOINT 4365.87401103973,3840.27160549164 4363.47566556931,3840.86995267868 4370.38179588318,3839.14784574509 PathPoint;PointKind.SMOOTHPOINT 4359.2486436367,3840.81236028671 4356.8141849041,3840.682305336 4361.33613181114,3840.92424058914 PathPoint;PointKind.SMOOTHPOINT 4351.83444929123,3840.34147167206 4328.71948313713,3840.47837162018 4354.45159864426,3840.3258934021 PathPoint;PointKind.SMOOTHPOINT 4256.41081881523,3840.57184123993 4239.61567354202,3840.52062177658 4300.68567824364,3840.70732498169 PathPoint;PointKind.SMOOTHPOINT 4198.39521718025,3840.23478412628 4053.63024902344,3839.04540681839 4220.48307967186,3840.41629457474 PathPoint;PointKind.SMOOTHPOINT 3893.15530371666,3839.41031599045 3873.36417388916,3839.06641387939 3964.00987815857,3840.6400551796 PathPoint;PointKind.SMOOTHPOINT 3833.67145013809,3842.04988861084 3827.5739736557,3842.04941654205 3852.85361123085,3842.05154085159 PathPoint;PointKind.SMOOTHPOINT 3811.46568846703,3841.26342201233 3805.88902187347,3841.27758407593 3817.75647711754,3841.2468996048 PathPoint;PointKind.SMOOTHPOINT 3798.04607105255,3842.13014030457 3780.91917943954,3842.1924533844 3803.86561703682,3842.10913324356 PathPoint;PointKind.SMOOTHPOINT 3741.86728906631,3842.29064369202 3735.38106393814,3842.29630851746 3762.55629372597,3842.27152490616 PathPoint;PointKind.SMOOTHPOINT 3720.08815956116,3841.01653003693 3714.42298007011,3841.00968503952 3727.06510019302,3841.0245552063 PathPoint;PointKind.SMOOTHPOINT 3704.15619206429,3842.25075387955 3690.63071322441,3842.20897579193 3710.18498253822,3842.26987266541 PathPoint;PointKind.SMOOTHPOINT 3660.49525809288,3842.00952672958 3653.68897032738,3841.9559469223 3676.14504647255,3842.13320875168 PathPoint;PointKind.SMOOTHPOINT 3641.34779405594,3840.80386304855 3636.75008010864,3840.75760030746 3648.61010026932,3840.87679767609 PathPoint;PointKind.SMOOTHPOINT 3625.46539378166,3841.67648220062 3599.15334177017,3841.39678144455 3630.15657734871,3841.72628545761 PathPoint;PointKind.SMOOTHPOINT 3543.19265556335,3840.73258066177 3535.49982261658,3840.64241552353 3571.44066166878,3841.06491708755 PathPoint;PointKind.SMOOTHPOINT 3520.80986809731,3839.45587062836 3513.17970228195,3839.36806583405 3528.56430602074,3839.54532766342 PathPoint;PointKind.SMOOTHPOINT 3497.07566571236,3840.20315551758 3482.08016467094,3840.03675127029 3504.73167729378,3840.28789186478 PathPoint;PointKind.SMOOTHPOINT 3452.15926480293,3839.73604345322 3449.24860668182,3839.70795536041 3467.06625294685,3839.87860822678 PathPoint;PointKind.SMOOTHPOINT 3442.06419181824,3841.28749752045 3433.69653654099,3841.21102237701 3444.9659986496,3841.3139333725 PathPoint;PointKind.SMOOTHPOINT 3418.48329377174,3839.44123649597 3411.03865098953,3839.383644104 3426.74579572678,3839.50614595413 PathPoint;PointKind.SMOOTHPOINT 3396.32214260101,3839.28427362442 3392.08379101753,3839.25760173798 3403.64605379105,3839.33053636551 PathPoint;PointKind.SMOOTHPOINT 3382.76338291168,3842.14949512482 3375.74785065651,3842.11243772507 3386.95287537575,3842.17168235779 PathPoint;PointKind.SMOOTHPOINT 3357.49153447151,3841.05878019333 3350.7383544445,3841.05099105835 3354.05440163612,3841.05453157425 PathPoint;PointKind.SMOOTHPOINT 3337.98045945168,3840.9114947319 3333.39195084572,3840.84988975525 3344.25000500679,3840.99575901031 PathPoint;PointKind.SMOOTHPOINT 3304.02584981918,3840.91432714462 3281.08932566643,3840.86027526855 3308.98115587234,3840.92612886429 PathPoint;PointKind.SMOOTHPOINT 3246.67444896698,3839.73769569397 3133.76704287529,3841.15720653534 3267.57482242584,3839.47475337982 PathPoint;PointKind.SMOOTHPOINT 2926.87380981445,3840.37144804001 2819.55156755447,3840.84540510178 3032.86835861206,3839.90315580368 PathPoint;PointKind.SMOOTHPOINT 2600.29839348793,3840.04076385498 2595.20854783058,3840.09599590302 2671.96268391609,3839.2604341507 PathPoint;PointKind.SMOOTHPOINT 2583.86331868172,3840.11464262009 2578.27532243729,3840.10944986343 2589.71118879318,3840.11912727356 PathPoint;PointKind.SMOOTHPOINT 2568.22131943703,3838.93163824081 2564.42836475372,3838.89930152893 2574.40235209465,3838.9849820137 PathPoint;PointKind.SMOOTHPOINT 2554.50925540924,3839.90339183807 2539.42276310921,3840.14745140076 2558.49623036385,3839.83871841431 PathPoint;PointKind.SMOOTHPOINT 2505.74077320099,3840.59308433533 2502.31921863556,3840.27184152603 2509.1630358696,3840.91338300705 PathPoint;PointKind.SMOOTHPOINT 2497.53775191307,3840.69151067734 2489.1424806118,3838.59670543671 2500.21509003639,3841.35948801041 PathPoint;PointKind.SMOOTHPOINT 2479.27824926376,3840.89426422119 2412.74062585831,3841.59198188782 2485.42423081398,3840.82959079742 PathPoint;PointKind.SMOOTHPOINT 2294.06288695335,3841.26035356522 2251.20742034912,3840.64902448654 2339.27173447609,3841.90519952774 PathPoint;PointKind.SMOOTHPOINT 2073.13363265991,3840.0152721405 2067.40012121201,3840.00370645523 2163.44440412521,3840.20221138 PathPoint;PointKind.SMOOTHPOINT 2055.91256332397,3839.98340749741 2048.43959641457,3841.02833175659 2061.60571289062,3839.18702745438 PathPoint;PointKind.SMOOTHPOINT 2038.84550642967,3839.95767974854 2013.92629337311,3839.92463493347 2044.52732634544,3839.96476078033 PathPoint;PointKind.SMOOTHPOINT 1965.62055659294,3839.92274665833 1961.18570637703,3839.92487096786 1989.22092747688,3839.91236114502 PathPoint;PointKind.SMOOTHPOINT 1951.88087654114,3841.35830783844 1966.9100124836,3841.34650611877 1956.23110842705,3841.35429525375 PathPoint;PointKind.SMOOTHPOINT 1872.57756900787,3840.37144804001 1850.21602463722,3840.47011041641 1912.10141015053,3840.19843482971 PathPoint;PointKind.SMOOTHPOINT 1806.0934073925,3839.4648399353 1802.29797434807,3839.48985958099 1827.8959043026,3839.3236913681 PathPoint;PointKind.SMOOTHPOINT 1794.71454334259,3839.53966283798 1785.66817116737,3839.72329759598 1798.50501966476,3839.46247959137 PathPoint;PointKind.SMOOTHPOINT 1774.70460963249,3839.67042589188 1768.29769206047,3839.7119679451 1781.37635779381,3839.62746763229 PathPoint;PointKind.SMOOTHPOINT 1755.46332192421,3839.79221963882 1753.0185956955,3839.8070898056 1761.88723397255,3839.75280189514 PathPoint;PointKind.SMOOTHPOINT 1748.12312436104,3839.83659410477 1741.28461790085,3841.34674215317 1750.52005362511,3839.30716896057 PathPoint;PointKind.SMOOTHPOINT 1734.82317638397,3839.91259717941 1723.4641392231,3839.97467422485 1739.26581573486,3839.8882856369 PathPoint;PointKind.SMOOTHPOINT 1700.49362611771,3840.07404470444 1696.43831920624,3840.0896229744 1712.03712415695,3840.03014230728 PathPoint;PointKind.SMOOTHPOINT 1688.28274083138,3840.11653089523 1685.21240544319,3838.80417966843 1692.61456203461,3841.96798467636 PathPoint;PointKind.SMOOTHPOINT 1678.30769133568,3840.14391088486 1667.5802822113,3840.16987466812 1681.64427351952,3840.1354136467 PathPoint;PointKind.SMOOTHPOINT 1645.72113704681,3840.18356466293 1680.03121447563,3840.18356466293 1656.72966313362,3840.18380069733 PathPoint;PointKind.SMOOTHPOINT 1488.47726655006,3839.3413939476 1371.49331045151,3840.25059843063 1574.11845159531,3838.67554092407 PathPoint;PointKind.SMOOTHPOINT 1189.66338944435,3839.69450139999 1181.17606472969,3839.72919845581 1280.23509693146,3839.32912015915 PathPoint;PointKind.SMOOTHPOINT 1164.27328777313,3839.79788446426 1152.90362906456,3841.09678173065 1172.66891312599,3838.83911275864 PathPoint;PointKind.SMOOTHPOINT 1140.31780314445,3839.89772701263 1127.66045880318,3839.95154285431 1148.30060434341,3839.86421012878 PathPoint;PointKind.SMOOTHPOINT 1102.27318954468,3840.06649160385 1079.64681458473,3840.17129087448 1114.99709558487,3840.00724697113 PathPoint;PointKind.SMOOTHPOINT 1029.33077287674,3836.78419733047 1018.17142081261,3836.67444133759 1052.04920125008,3837.00677776337 PathPoint;PointKind.SMOOTHPOINT 999.192485332489,3837.72479438782 996.7010242939,3837.72621059418 1009.94396996498,3837.71865749359 PathPoint;PointKind.SMOOTHPOINT 989.051739692688,3836.64706134796 985.61637711525,3836.65673875809 991.525852203369,3836.64021635056 PathPoint;PointKind.SMOOTHPOINT 978.77610039711,3838.69182729721 966.958212375641,3838.76027727127 982.181014537811,3838.67200040817 PathPoint;PointKind.SMOOTHPOINT 943.745527982712,3837.06012153625 939.961778640747,3837.11653375626 955.322660923004,3836.88805246353 PathPoint;PointKind.SMOOTHPOINT 917.275923013687,3837.52746963501 911.477620124817,3837.64477872849 922.445784330368,3837.42290639877 PathPoint;PointKind.SMOOTHPOINT 899.871454954147,3837.90276432037 896.089121818542,3837.98915290833 905.680025339127,3837.77034902573 PathPoint;PointKind.SMOOTHPOINT 888.375753879547,3836.40347385406 885.118833303452,3836.48160123825 892.170832872391,3836.31165647507 PathPoint;PointKind.SMOOTHPOINT 878.71687245369,3838.41023826599 871.188319444656,3838.59835767746 881.987601041794,3838.3288064003 PathPoint;PointKind.SMOOTHPOINT 849.484248876572,3839.36452531815 806.002819061279,3840.50079488754 857.121495723724,3839.16531229019 PathPoint;PointKind.SMOOTHPOINT 714.354440689087,3842.06593894958 710.458811044693,3842.11668634415 766.83904838562,3841.38946437836 PathPoint;PointKind.SMOOTHPOINT 706.015625,3839 700.10614991188,3839.07128238678 709.732458591461,3838.95515346527 PathPoint;PointKind.SMOOTHPOINT 685.190503120422,3841.98710346222 675.830795288086,3842.08623790741 690.671929836273,3841.92974710464 PathPoint;PointKind.SMOOTHPOINT 661.863106012344,3840.90205335617 657.569168329239,3840.93368196487 670.09055685997,3840.84162855148 PathPoint;PointKind.SMOOTHPOINT 642.015625,3840 637.97412610054,3840.02147912979 646.029861927032,3839.9787569046 PathPoint;PointKind.SMOOTHPOINT 629.781429290771,3841.83769369125 548.745747327805,3842.07750463486 633.561992168427,3841.82612800598 PathPoint;PointKind.SMOOTHPOINT 455.77711057663,3840.34524822235 447.28199672699,3840.45335197449 526.739670753479,3839.44336080551 PathPoint;PointKind.SMOOTHPOINT 432.706754922867,3840.66767120361 425.777611255646,3840.77317857742 439.629525661469,3840.56169176102 PathPoint;PointKind.SMOOTHPOINT 414.001501321793,3840.96979522705 405.187741041183,3843.0426492691 419.446460723877,3839.68954467773 PathPoint;PointKind.SMOOTHPOINT 401.17916893959,3841.18954324722 365.44474196434,3841.79803991318 405.060636520386,3841.1234536171 PathPoint;PointKind.SMOOTHPOINT 327.515625,3841.859375 313.156195937752,3841.79665091185 351.753867094597,3841.96608812352 PathPoint;PointKind.SMOOTHPOINT 291.015625,3840 289.701606255848,3838.10365918234 293.316493769757,3843.31983093787 PathPoint;PointKind.SMOOTHPOINT 289.015625,3814 289.210353374481,3809.58143615723 288.755043029785,3819.93060016632 PathPoint;PointKind.SMOOTHPOINT 288.749732494354,3800.35936975479 289.188756465912,3790.01044178009 288.650952100754,3802.68737697601 PathPoint;PointKind.SMOOTHPOINT 288.332305669785,3720.51082277298 288.17227435112,3713.62735176086 289.30771780014,3762.50370168686 PathPoint;PointKind.SMOOTHPOINT 288.145012378693,3689.75719356537 291.012122154236,3483.70011234283 288.038796901703,3697.36717844009 PathPoint;PointKind.SMOOTHPOINT 291.968769550323,3048.45103883743 290.755434751511,3029.71344852448 292.928603410721,3063.27989959717 PathPoint;PointKind.SMOOTHPOINT 293.750003099442,2967.35929870605 294.926162481308,2940.49362802505 291.702168703079,3014.11818408966 PathPoint;PointKind.SMOOTHPOINT 293.175377368927,2875.94223403931 293.212552785873,2847.82204055786 293.125102043152,2913.91875171661 PathPoint;PointKind.SMOOTHPOINT 294.164951562881,2808.98045682907 294.064046859741,2792.5298037529 294.237886190414,2820.92639350891 PathPoint;PointKind.SMOOTHPOINT 293.175377368927,2737.89751911163 293.138201951981,2719.96055746078 293.233795881271,2766.67790079117 PathPoint;PointKind.SMOOTHPOINT 294.164951562881,2681.23746299744 293.981552839279,2667.02323579788 294.297012805939,2691.41007328033 PathPoint;PointKind.SMOOTHPOINT 294.164951562881,2581.30970621109 296.266955852509,2553.18502807617 293.858696937561,2585.41103982925 PathPoint;PointKind.SMOOTHPOINT 294.968648672104,2507.08515071869 295.147798776627,2487.29319477081 294.781709432602,2527.79055976868 PathPoint;PointKind.SMOOTHPOINT 294.968648672104,2334.31316757202 294.728247642517,2320.26558065414 296.441857337952,2420.4189863205 PathPoint;PointKind.SMOOTHPOINT 296.45637345314,2286.0941734314 294.852165699005,2225.67125701904 296.816089868546,2299.62862157822 PathPoint;PointKind.SMOOTHPOINT 296.848308563232,2131.74703502655 298.543507575989,2060.28502607346 296.210661649704,2158.624979496 PathPoint;PointKind.SMOOTHPOINT 297.654838085175,1813.85426187515 299.164514064789,1775.70237064362 296.14551615715,1852.00615310669 PathPoint;PointKind.SMOOTHPOINT 296.592329263687,1648.81216907501 296.172778129578,1608.88742351532 296.959834814072,1683.74171876907 PathPoint;PointKind.SMOOTHPOINT 299.968565225601,1534.38458347321 298.691147089005,1486.01075077057 300.906093835831,1569.8315205574 PathPoint;PointKind.SMOOTHPOINT 296.675177335739,1394.90241909027 297.573406219482,1376.9767870903 296.430173635483,1399.80768585205 PathPoint;PointKind.SMOOTHPOINT 295.905469179153,1315.17094516754 294.851811647415,1295.24492168427 297.444177389145,1344.26312828064 PathPoint;PointKind.SMOOTHPOINT 295.179663419724,1218.06285524368 294.842960357666,1202.97742509842 295.484501838684,1231.71555662155 PathPoint;PointKind.SMOOTHPOINT 294.583086490631,1170.98791980743 297.580487251282,1103.27696943283 293.987217664719,1184.4397559166 PathPoint;PointKind.SMOOTHPOINT 294.583086490631,1033.97373104095 295.952912092209,1004.89948654175 293.065975427628,1066.1973824501 PathPoint;PointKind.SMOOTHPOINT 293.067037582397,949.369563102722 292.155000686646,939.661940574646 294.927578687668,969.168836116791 PathPoint;PointKind.SMOOTHPOINT 295.750040531158,894.359387397766 296.496027231216,829.416412353516 295.381472826004,926.36093044281 PathPoint;PointKind.SMOOTHPOINT 296.116837978363,510.699879169464 296.810070991516,492.111462593079 296.098427295685,511.189650535583 PathPoint;PointKind.SMOOTHPOINT 296.066916704178,216.858302593231 295.93839597702,182.620097637177 296.138435125351,235.99597120285 PathPoint;PointKind.SMOOTHPOINT 295.750040531158,152.359308242798 296.695358276367,144.314075946808 294.200002670288,165.547257900238 PathPoint;PointKind.SMOOTHPOINT 298.515625,120.859375 304.52317237854,118.820745944977 294.111931324005,122.353472709656 PathPoint;PointKind.SMOOTHPOINT 320.515625,119.859375 330.876559587689,119.357769416235 310.506357947083,120.343231743103 PathPoint;PointKind.SMOOTHPOINT 362.323069095612,120.021180152893 405.320156335831,119.398049354553 342.383591651917,120.309850215912 PathPoint;PointKind.SMOOTHPOINT 867.672587156296,119.731801986694 928.262497901917,119.879559516907 807.083384513855,119.583808422089 PathPoint;PointKind.SMOOTHPOINT 1476.30922150612,118.103164672852 1553.13523006439,118.502534866333 1399.48321294785,117.70379447937 PathPoint;PointKind.SMOOTHPOINT 1885.2102162838,119.103164672852 1894.06008982658,118.80363702774 1835.91738367081,120.774760246277 PathPoint;PointKind.SMOOTHPOINT 1914.70165157318,114.450218677521 1936.9748157569,113.592538776293 1907.45217565663,114.729376579684 PathPoint;PointKind.SMOOTHPOINT 2007.20714556204,117.758554938142 2010.50462690631,113.521828176175 2003.63484810534,122.34837566991 PathPoint;PointKind.SMOOTHPOINT 2032.27714133263,114.716543197632 2038.2340593338,114.580587387085 2021.07105445862,114.972876548767 PathPoint;PointKind.SMOOTHPOINT 2060.69473814964,114.513789653778 2072.18194198608,114.509541034698 2048.0678422451,114.519218444824 PathPoint;PointKind.SMOOTHPOINT 2097.39962053299,117.958711624146 2104.15421676636,119.758709907532 2085.33814501762,114.745811462402 PathPoint;PointKind.SMOOTHPOINT 2123.03472590446,114.750532150269 2204.43260264397,115.259186267853 2115.52316737175,114.703325271606 PathPoint;PointKind.SMOOTHPOINT 2351.12290334702,116.600569725037 2408.65947318077,116.867524623871 2313.20787262917,116.424252033234 PathPoint;PointKind.SMOOTHPOINT 2485.27375888824,116.962646484375 2498.49793982506,117.226296901703 2451.0847671032,116.279562950134 PathPoint;PointKind.SMOOTHPOINT 2557.21173119545,116.134401798248 2556.4724714756,116.14738368988 2557.95063686371,116.12165594101 PathPoint;PointKind.SMOOTHPOINT 2594.015625,121 2602.61837053299,124.943426609039 2584.71398162842,116.736038684845 PathPoint;PointKind.SMOOTHPOINT 2618.99975252151,118.139986038208 2623.98479890823,118.133613109589 2606.41286444664,118.15509223938 PathPoint;PointKind.SMOOTHPOINT 2641.44662332535,116.139358520508 2652.12729763985,116.121419906616 2636.30614829063,116.147855758667 PathPoint;PointKind.SMOOTHPOINT 2665.10470461845,120.514728069305 2671.83841180801,119.919921398163 2651.37493801117,121.727944850922 PathPoint;PointKind.SMOOTHPOINT 2691.26593065262,118.139986038208 2696.58272337914,118.125351905823 2683.31570219994,118.162173271179 PathPoint;PointKind.SMOOTHPOINT 2706.09332012581,120.64561449806 2711.92609182326,122.095477025888 2700.86583271696,119.346208572041 PathPoint;PointKind.SMOOTHPOINT 2733.96384429932,115.904032230377 2737.80988938728,115.887689071974 2727.18240070442,115.932848899017 PathPoint;PointKind.SMOOTHPOINT 2749.6731133461,119.170276165009 2757.10253190994,119.146436691284 2745.80793213844,119.182549953461 PathPoint;PointKind.SMOOTHPOINT 2769.015625,115 2771.58000923817,115.521293385578 2761.68648768627,113.508706816307 PathPoint;PointKind.SMOOTHPOINT 2785.31123828888,118.140222072601 2788.58940196037,118.105761051178 2782.20620584488,118.172558784485 PathPoint;PointKind.SMOOTHPOINT 2794.40469932556,114.715363025665 2801.55689549446,114.617172718048 2791.14140582085,114.760445594788 PathPoint;PointKind.SMOOTHPOINT 2815.73135089874,114.435662269592 2819.72115826607,114.38562297821 2808.67050004005,114.523703098297 PathPoint;PointKind.SMOOTHPOINT 2828.8691432476,118.140222072601 2830.76331925392,118.117798805237 2824.91509509087,118.186720848083 PathPoint;PointKind.SMOOTHPOINT 2841.73821043968,118.140222072601 2848.1380469799,118.046280384064 2839.8532397747,118.168074131012 PathPoint;PointKind.SMOOTHPOINT 2856.58748817444,116.079641819 2859.83661961555,116.034795284271 2850.39547991753,116.166266441345 PathPoint;PointKind.SMOOTHPOINT 2870.21776628494,119.009064674377 2872.93475818634,118.972715377808 2867.02740740776,119.051786899567 PathPoint;PointKind.SMOOTHPOINT 2882.86342692375,115.976494789124 2890.8044500351,115.835110187531 2880.18856716156,116.024173736572 PathPoint;PointKind.SMOOTHPOINT 2913.96261048317,119.127081871033 2924.758705616,118.908514022827 2906.51124072075,119.278143882751 PathPoint;PointKind.SMOOTHPOINT 2951.87976551056,117.18546295166 2959.12295293808,117.714416027069 2941.45259213448,116.423543930054 PathPoint;PointKind.SMOOTHPOINT 2968.45221233368,118.140222072601 2977.05070924759,117.625667095184 2962.57141542435,118.492149353027 PathPoint;PointKind.SMOOTHPOINT 2988.82752728462,114.218510627747 2988.92524552345,113.745025634766 2988.55278325081,115.553049087524 PathPoint;PointKind.SMOOTHPOINT 2997.83743214607,113.651083946228 2999.55210399628,113.609069824219 2991.73393678665,113.800729751587 PathPoint;PointKind.SMOOTHPOINT 3003.39887452126,118.346280097961 3007.65917730331,118.272401332855 3001.39423441887,118.381685256958 PathPoint;PointKind.SMOOTHPOINT 3016.95975852013,116.079641819 3024.17072725296,114.63086271286 3012.21900773048,117.031804561615 PathPoint;PointKind.SMOOTHPOINT 3035.76839518547,116.256903648376 3036.4587957859,116.498366832733 3035.07799458504,116.01544046402 PathPoint;PointKind.SMOOTHPOINT 3119.0813369751,117.636996746063 3132.28569102287,117.59899520874 3103.46305918694,117.683967590332 PathPoint;PointKind.SMOOTHPOINT 3187.23060321808,119.347301959991 3187.03906130791,120.754302978516 3187.42285323143,117.940536975861 PathPoint;PointKind.SMOOTHPOINT 3198.11981391907,117.109931945801 3201.92905497551,116.754464149475 3194.254986763,117.470120429993 PathPoint;PointKind.SMOOTHPOINT 3210.98923516273,115.049587726593 3214.19233989716,114.858635902405 3206.92012023926,115.292231082916 PathPoint;PointKind.SMOOTHPOINT 3219.21633195877,114.840933322906 3222.84748506546,114.7670545578 3215.71653199196,114.912215709686 PathPoint;PointKind.SMOOTHPOINT 3234.74822115898,116.079641819 3239.83452630043,116.208280563354 3230.66600632668,115.97625875473 PathPoint;PointKind.SMOOTHPOINT 3245.4600520134,115.934008598328 3250.07830095291,116.120475769043 3240.79931688309,115.746125221252 PathPoint;PointKind.SMOOTHPOINT 3259.74213910103,118.028577804565 3263.98190689087,118.260363578796 3255.49706053734,117.797028064728 PathPoint;PointKind.SMOOTHPOINT 3271.37627434731,115.049587726593 3275.30058217049,115.314890384674 3267.46612858772,114.785701274872 PathPoint;PointKind.SMOOTHPOINT 3284.24534153938,115.049587726593 3289.05159187317,115.42653465271 3280.60852360725,114.76493024826 PathPoint;PointKind.SMOOTHPOINT 3297.95351099968,116.075865268707 3303.07486724854,116.965242862701 3293.60434126854,115.320555210114 PathPoint;PointKind.SMOOTHPOINT 3313.94425106049,117.109931945801 3317.18028259277,117.728578090668 3309.26758360863,116.21512556076 PathPoint;PointKind.SMOOTHPOINT 3333.74352407455,117.109931945801 3346.00938941464,120.623591362468 3330.70139641423,116.23848910797 PathPoint;PointKind.SMOOTHPOINT 3350.57112156648,123.70265053308 3352.93610076485,124.242901485256 3342.51746425041,121.862889728208 PathPoint;PointKind.SMOOTHPOINT 3363.02040410042,117.257925510406 3367.11501073837,116.998995780945 3360.87201905251,117.393409252167 PathPoint;PointKind.SMOOTHPOINT 3389.18056797981,117.109931945801 3404.3605298996,115.204426288605 3385.88470172882,117.523700237274 PathPoint;PointKind.SMOOTHPOINT 3412.66693425179,114.341484546661 3417.17365694046,114.165874958038 3400.89153242111,114.800335407257 PathPoint;PointKind.SMOOTHPOINT 3435.01962733269,116.446203231812 3444.72418141365,116.705368995667 3426.8612165451,116.227871417999 PathPoint;PointKind.SMOOTHPOINT 3461.44639205933,117.109931945801 3470.70767354965,118.143526554108 3453.82861804962,116.259736061096 PathPoint;PointKind.SMOOTHPOINT 3482.23594737053,117.109931945801 3489.45824575424,116.122128009796 3476.56581115723,117.885068893433 PathPoint;PointKind.SMOOTHPOINT 3501.04458403587,117.109931945801 3502.88706851006,117.205289840698 3489.4175298214,116.506628036499 PathPoint;PointKind.SMOOTHPOINT 3516.88379001617,117.109931945801 3523.25388622284,117.297579288483 3512.46062350273,116.9794049263 PathPoint;PointKind.SMOOTHPOINT 3534.70285248756,115.049587726593 3538.48306131363,115.132907867432 3523.77929878235,114.809304714203 PathPoint;PointKind.SMOOTHPOINT 3546.58234548569,119.170276165009 3551.26219940186,119.266578197479 3542.33231019974,119.082235336304 PathPoint;PointKind.SMOOTHPOINT 3566.38161849976,117.109931945801 3570.22631413845,115.584216545597 3561.54838026479,119.027875601842 PathPoint;PointKind.SMOOTHPOINT 3582.22047042847,122.260910511017 3587.70012688637,122.154695034027 3575.69990229607,122.386480808258 PathPoint;PointKind.SMOOTHPOINT 3601.25640821457,120.024956703186 3608.43480420113,120.148874759674 3595.43013525009,119.923933982849 PathPoint;PointKind.SMOOTHPOINT 3620.82838010788,121.230620384216 3630.59701752663,120.904656887054 3613.34479165077,121.480580806732 PathPoint;PointKind.SMOOTHPOINT 3653.75305366516,119.144784450531 3666.83596801758,119.36075592041 3643.08052253723,118.967758655548 PathPoint;PointKind.SMOOTHPOINT 3699.44199514389,119.268230438232 3808.05086088181,114.701200962067 3685.65912079811,119.847458839417 PathPoint;PointKind.SMOOTHPOINT 3993.01944923401,119.038805007935 4114.54871964455,116.994511127472 3936.46501851082,119.990023612976 PathPoint;PointKind.SMOOTHPOINT 4406.17287111282,116.066423892975 4428.9217479229,115.685228347778 4311.843968153,117.648326396942 PathPoint;PointKind.SMOOTHPOINT 4512.47579884529,118.383101463318 4514.30058073997,118.374840259552 4478.36292815208,118.537467956543 PathPoint;PointKind.SMOOTHPOINT 4528.67755365372,118.463353157043 4548.55967473984,122.521256446838 4526.97350335121,118.11520242691 PathPoint;PointKind.SMOOTHPOINT 4549.80522823334,118.170670509338 4550.13591241837,117.917877674103 4549.4748980999,118.423227310181 PathPoint;PointKind.SMOOTHPOINT 4622.12663841248,118.312055110931 4629.85770893097,118.344863891602 4597.43508052826,118.208436012268 PathPoint;PointKind.SMOOTHPOINT 4645.42358708382,118.42676782608 4655.7172137734,115.898201582544 4636.48222794303,120.623164341334 PathPoint;PointKind.SMOOTHPOINT 4660.57416272163,118.518821239471 4711.53528642654,118.851629734039 4655.51724386215,118.485540390015 PathPoint;PointKind.SMOOTHPOINT 4810.58475923538,120.246829032898 4871.4780921936,119.681054592133 4763.04235768318,120.688921451569 PathPoint;PointKind.SMOOTHPOINT 5002.72147607803,119.215122699738 5007.91930747032,119.202848911285 4936.8569047451,119.369961261749 PathPoint;PointKind.SMOOTHPOINT 5021.53082084656,120.81661605835 5028.65787935257,120.802453994751 5016.32874083519,120.827237606049 PathPoint;PointKind.SMOOTHPOINT 5039.70358085632,119.143604278564 5051.9303984642,119.124957561493 5032.57793855667,119.15398979187 PathPoint;PointKind.SMOOTHPOINT 5076.33092594147,119.101118087769 5081.25719976425,119.097341537476 5064.14801073074,119.110795497894 PathPoint;PointKind.SMOOTHPOINT 5091.52186346054,121.005915641785 5094.85101056099,121.003791332245 5086.60868954659,121.008512020111 PathPoint;PointKind.SMOOTHPOINT 5101.0678024292,119.086483955383 5112.84993124008,119.08199930191 5097.74644446373,119.087428092957 PathPoint;PointKind.SMOOTHPOINT 5136.24424409866,119.08270740509 5147.91095209122,119.084359645844 5124.58355498314,119.080583095551 PathPoint;PointKind.SMOOTHPOINT 5174.15360999107,120.206939220428 5181.00627851486,120.193249225616 5162.7382786274,120.229362487793 PathPoint;PointKind.SMOOTHPOINT 5196.82813596725,118.140222072601 5200.44548106194,118.138569831848 5190.10788273811,118.143054485321 PathPoint;PointKind.SMOOTHPOINT 5216.62705492973,119.170276165009 5232.54415225983,119.176413059235 5213.05184197426,119.168859958649 PathPoint;PointKind.SMOOTHPOINT 5254.84586191177,117.35871219635 5374.79854059219,117.974053859711 5239.8949713707,117.281764984131 PathPoint;PointKind.SMOOTHPOINT 5486.18140053749,117.994352817535 5489.56896615028,118.066579341888 5423.342908144,116.651789188385 PathPoint;PointKind.SMOOTHPOINT 5499.78547883034,120.075232028961 5502.57965397835,120.138017177582 5496.34586763382,119.997812747955 PathPoint;PointKind.SMOOTHPOINT 5514.37488269806,117.048090934753 5521.11496281624,117.233850002289 5511.55486178398,116.970435619354 PathPoint;PointKind.SMOOTHPOINT 5531.86998796463,118.117798805237 5537.29335021973,118.581134319305 5524.65229225159,117.500804901123 PathPoint;PointKind.SMOOTHPOINT 5546.28024172783,117.109931945801 5553.98157191277,116.372324466705 5542.70007205009,117.453125953674 PathPoint;PointKind.SMOOTHPOINT 5558.11406207085,119.210638046265 5564.03911542892,118.992778301239 5552.65033793449,119.411031246185 PathPoint;PointKind.SMOOTHPOINT 5572.46731352806,118.011347293854 5584.97815493692,117.080267083635 5568.37506345078,118.315900196229 PathPoint;PointKind.SMOOTHPOINT 5629.03776607365,118.365153788332 5632.99878443602,118.295918277457 5619.17710748409,118.537510407906 PathPoint;PointKind.SMOOTHPOINT 5646.015625,119 5648.05649557547,119.166822218328 5641.44435337426,118.626340992735 PathPoint;PointKind.SMOOTHPOINT 5650.015625,124 5650.42139012025,125.390746069826 5649.30739921397,121.572580344336 PathPoint;PointKind.SMOOTHPOINT 5651.78611032415,130.915670299283 5651.93095135243,132.285895460363 5651.42546264264,127.503870940151 PathPoint;PointKind.SMOOTHPOINT 5650.015625,137 5650.54300036109,143.554315185804 5649.89719359328,135.528113323367 PathPoint;PointKind.SMOOTHPOINT 5650.515625,150.859375 5652.15877842903,154.82711315155 5650.01701971961,149.654147586584 PathPoint;PointKind.CORNERPOINT 5651.30079460144,184.497279167175 5651.30079460144,184.497279167175 5651.30079460144,184.497279167175 PathPoint;PointKind.SMOOTHPOINT 5651.22172390748,996.772832944999 5651.22124902467,998.13874016467 5651.36763478376,577.088824826262 PathPoint;PointKind.SMOOTHPOINT 5650.015625,1001 5649.45521062973,1001.62310023722 5650.92940570728,999.984007181674 PathPoint;PointKind.SMOOTHPOINT 5651.21819331156,1006.81578329746 5651.05279452661,1472.14097735041 5651.21889781292,1004.8337721721 PathPoint;PointKind.SMOOTHPOINT 5649.55071759224,1995.05786561966 5648.27683997154,2028.21432495117 5650.62362838106,1967.13166115663 PathPoint;PointKind.SMOOTHPOINT 5650.67341518402,2112.44744682312 5650.64615321159,2114.55523395538 5651.20980334282,2071.40106582642 PathPoint;PointKind.SMOOTHPOINT 5648.27683997154,2123.83752250671 5647.84489703178,2140.46567344666 5648.33242607117,2121.68370866776 PathPoint;PointKind.SMOOTHPOINT 5648.18337035179,2160.63552045822 5648.11397624016,2164.96085071564 5648.35366916656,2149.98305225372 PathPoint;PointKind.SMOOTHPOINT 5650.08356523514,2178.01709318161 5650.02550077438,2180.60615444183 5650.15225124359,2174.94274520874 PathPoint;PointKind.SMOOTHPOINT 5649.08797216415,2187.21440935135 5649.01185107231,2190.19646787643 5649.2239279747,2181.92983531952 PathPoint;PointKind.SMOOTHPOINT 5649.4144077301,2204.30613183975 5649.18214988708,2213.12366867065 5649.50787734985,2200.75593852997 PathPoint;PointKind.SMOOTHPOINT 5648.59902691841,2235.13836050034 5648.28108859062,2247.17399024963 5648.90528154373,2223.56394195557 PathPoint;PointKind.SMOOTHPOINT 5647.74611663818,2267.56452941895 5647.65193891525,2271.17137098312 5647.63742280006,2271.70528078079 PathPoint;PointKind.SMOOTHPOINT 5646.81956362724,2314.97982645035 5646.38408017159,2334.47107458115 5647.0362432003,2305.28967046738 PathPoint;PointKind.SMOOTHPOINT 5645.44371914864,2372.9857506752 5646.26228642464,2339.6699681282 5645.90292406082,2354.22880554199 PathPoint;PointKind.SMOOTHPOINT 5648.4407658577,2473.37495470047 5648.84792518616,2487.91372919083 5647.08297801018,2424.9175658226 PathPoint;PointKind.SMOOTHPOINT 5646.30725097656,2547.98778676987 5649.53018260002,2623.99747037888 5645.12224030495,2520.04013442993 PathPoint;PointKind.SMOOTHPOINT 5645.85725140572,2694.2023601532 5645.20721268654,2707.09951543808 5644.53274440765,2720.46425485611 PathPoint;PointKind.SMOOTHPOINT 5646.39470171928,2740.25597476959 5642.5762553215,2813.39524412155 5647.14670729637,2725.84985160828 PathPoint;PointKind.SMOOTHPOINT 5648.51547074318,2942.85940074921 5647.67566037178,3003.5209479332 5649.15488791466,2896.46259212494 PathPoint;PointKind.SMOOTHPOINT 5650.18765640259,3067.64110708237 5649.80669689178,3074.70962905884 5649.76881337166,3075.40545845032 PathPoint;PointKind.SMOOTHPOINT 5651.34717535973,3094.55091619492 5650.96869421005,3116.74971485138 5651.49658513069,3085.79994106293 PathPoint;PointKind.SMOOTHPOINT 5651.51570391655,3129.85930109024 5651.789031744,3218.14560556412 5651.47959065437,3118.27756547928 PathPoint;PointKind.SMOOTHPOINT 5649.51566648483,3365.85946941376 5649.98513889313,3393.17620182037 5648.21877551079,3290.42264127731 PathPoint;PointKind.SMOOTHPOINT 5650.5155081749,3473.85936641693 5652.22770166397,3536.55907058716 5650.36999297142,3468.54694032669 PathPoint;PointKind.SMOOTHPOINT 5651.51570391655,3693.85923528671 5650.99737238884,3737.07312011719 5652.06696224213,3648.00436162949 PathPoint;PointKind.SMOOTHPOINT 5650.515625,3819.859375 5650.44658493996,3823.50587034225 5650.98368120193,3794.97238063812 PathPoint;PointKind.SMOOTHPOINT 5649.515625,3835.859375 5649.44123721258,3836.0743276016 5650.22500714603,3833.80946041479 PathPoint;PointKind.SMOOTHPOINT 5651.515625,3837.859375 5651.52310247229,3838.23301412322 5651.49990530918,3837.0738834233 PathPoint;PointKind.SMOOTHPOINT 5650.515625,3840.859375 5648.14116047799,3841.48590431615 5650.82754277614,3840.77709811544 PathPoint";
	
	mask35mm[2] = "PointKind.CORNERPOINT 5612.515625,3843 5612.515625,3843 5612.515625,3843 PathPoint;PointKind.SMOOTHPOINT 5600.28829598427,3843.04031801224 5598.66886401176,3843.19279623032 5608.16665196419,3842.30035018921 PathPoint;PointKind.SMOOTHPOINT 5590.50588798523,3843.0633687973 5566.45268511772,3843.28170061111 5592.30376195908,3843.04755449295 PathPoint;PointKind.SMOOTHPOINT 5465.05160164833,3842.73292064667 5460.70491027832,3842.69515514374 5517.97417116165,3843.19365978241 PathPoint;PointKind.SMOOTHPOINT 5451.44716930389,3840.65156936646 5443.78478479385,3840.16864299774 5455.87281417847,3840.93056201935 PathPoint;PointKind.SMOOTHPOINT 5435.89085054398,3841.63182020187 5423.21757388115,3841.59075021744 5440.17098021507,3841.64574623108 PathPoint;PointKind.SMOOTHPOINT 5397.79171299934,3841.4226937294 5331.92183089256,3840.92631340027 5410.48127603531,3841.51852369308 PathPoint;PointKind.SMOOTHPOINT 5228.8156349659,3846.22575759888 5224.27350711823,3846.15117073059 5277.00064015388,3847.01600074768 PathPoint;PointKind.SMOOTHPOINT 5215.13791394234,3846.02135181427 5208.25692129135,3847.7420425415 5220.84557962418,3844.59334373474 PathPoint;PointKind.SMOOTHPOINT 5193.82223796844,3845.10907888412 5185.45706105232,3846.16674900055 5201.05622005463,3844.19468164444 PathPoint;PointKind.SMOOTHPOINT 5171.46423411369,3845.04889011383 5167.40184617043,3846.25974655151 5180.22134613991,3842.43858575821 PathPoint;PointKind.SMOOTHPOINT 5156.76365804672,3845.56438922882 5153.08895659447,3845.65479040146 5161.82978224754,3845.43976306915 PathPoint;PointKind.SMOOTHPOINT 5137.44306278229,3843.9348077774 5095.02555799484,3844.42670345306 5141.30222511292,3843.88996124268 PathPoint;PointKind.SMOOTHPOINT 4978.02106690407,3842.48178005219 4849.78676748276,3839.50042963028 5049.25978732109,3844.13826942444 PathPoint;PointKind.SMOOTHPOINT 4601.32752370834,3842.26675271988 4502.14244914055,3841.98280334473 4700.51189017296,3842.55070209503 PathPoint;PointKind.SMOOTHPOINT 4425.86769890785,3840.98980665207 4413.01704239845,3840.68012952805 4490.75154733658,3842.55471467972 PathPoint;PointKind.SMOOTHPOINT 4391.50274348259,3840.4417347908 4387.5256819725,3841.17060899734 4402.76760292053,3838.37737798691 PathPoint;PointKind.SMOOTHPOINT 4379.53473758698,3840.39334774017 4375.02270412445,3840.38768291473 4383.50223970413,3840.39830446243 PathPoint;PointKind.SMOOTHPOINT 4365.87401103973,3840.41223049164 4363.47566556931,3841.01057767868 4370.38179588318,3839.28847074509 PathPoint;PointKind.SMOOTHPOINT 4359.2486436367,3840.95298528671 4356.8141849041,3840.822930336 4361.33613181114,3841.06486558914 PathPoint;PointKind.SMOOTHPOINT 4351.83444929123,3840.48209667206 4328.71948313713,3840.61899662018 4354.45159864426,3840.4665184021 PathPoint;PointKind.SMOOTHPOINT 4256.41081881523,3840.71246623993 4239.61567354202,3840.66124677658 4300.68567824364,3840.84794998169 PathPoint;PointKind.SMOOTHPOINT 4198.39521718025,3840.37540912628 4053.63024902344,3839.18603181839 4220.48307967186,3840.55691957474 PathPoint;PointKind.SMOOTHPOINT 3893.15530371666,3839.55094099045 3873.36417388916,3839.20703887939 3964.00987815857,3840.7806801796 PathPoint;PointKind.SMOOTHPOINT 3833.67145013809,3842.19051361084 3827.5739736557,3842.19004154205 3852.85361123085,3842.19216585159 PathPoint;PointKind.SMOOTHPOINT 3811.46568846703,3841.40404701233 3805.88902187347,3841.41820907593 3817.75647711754,3841.3875246048 PathPoint;PointKind.SMOOTHPOINT 3798.04607105255,3842.27076530457 3780.91917943954,3842.3330783844 3803.86561703682,3842.24975824356 PathPoint;PointKind.SMOOTHPOINT 3741.86728906631,3842.43126869202 3735.38106393814,3842.43693351746 3762.55629372597,3842.41214990616 PathPoint;PointKind.SMOOTHPOINT 3720.08815956116,3841.15715503693 3714.42298007011,3841.15031003952 3727.06510019302,3841.1651802063 PathPoint;PointKind.SMOOTHPOINT 3704.15619206429,3842.39137887955 3690.63071322441,3842.34960079193 3710.18498253822,3842.41049766541 PathPoint;PointKind.SMOOTHPOINT 3660.49525809288,3842.15015172958 3653.68897032738,3842.0965719223 3676.14504647255,3842.27383375168 PathPoint;PointKind.SMOOTHPOINT 3641.34779405594,3840.94448804855 3636.75008010864,3840.89822530746 3648.61010026932,3841.01742267609 PathPoint;PointKind.SMOOTHPOINT 3625.46539378166,3841.81710720062 3599.15334177017,3841.53740644455 3630.15657734871,3841.86691045761 PathPoint;PointKind.SMOOTHPOINT 3543.19265556335,3840.87320566177 3535.49982261658,3840.78304052353 3571.44066166878,3841.20554208755 PathPoint;PointKind.SMOOTHPOINT 3520.80986809731,3839.59649562836 3513.17970228195,3839.50869083405 3528.56430602074,3839.68595266342 PathPoint;PointKind.SMOOTHPOINT 3497.07566571236,3840.34378051758 3482.08016467094,3840.17737627029 3504.73167729378,3840.42851686478 PathPoint;PointKind.SMOOTHPOINT 3452.15926480293,3839.87666845322 3449.24860668182,3839.84858036041 3467.06625294685,3840.01923322678 PathPoint;PointKind.SMOOTHPOINT 3442.06419181824,3841.42812252045 3433.69653654099,3841.35164737701 3444.9659986496,3841.4545583725 PathPoint;PointKind.SMOOTHPOINT 3418.48329377174,3839.58186149597 3411.03865098953,3839.524269104 3426.74579572678,3839.64677095413 PathPoint;PointKind.SMOOTHPOINT 3396.32214260101,3839.42489862442 3392.08379101753,3839.39822673798 3403.64605379105,3839.47116136551 PathPoint;PointKind.SMOOTHPOINT 3382.76338291168,3842.29012012482 3375.74785065651,3842.25306272507 3386.95287537575,3842.31230735779 PathPoint;PointKind.SMOOTHPOINT 3357.49153447151,3841.19940519333 3350.7383544445,3841.19161605835 3354.05440163612,3841.19515657425 PathPoint;PointKind.SMOOTHPOINT 3337.98045945168,3841.0521197319 3333.39195084572,3840.99051475525 3344.25000500679,3841.13638401031 PathPoint;PointKind.SMOOTHPOINT 3304.02584981918,3841.05495214462 3281.08932566643,3841.00090026855 3308.98115587234,3841.06675386429 PathPoint;PointKind.SMOOTHPOINT 3246.67444896698,3839.87832069397 3133.76704287529,3841.29783153534 3267.57482242584,3839.61537837982 PathPoint;PointKind.SMOOTHPOINT 2926.87380981445,3840.51207304001 2819.55156755447,3840.98603010178 3032.86835861206,3840.04378080368 PathPoint;PointKind.SMOOTHPOINT 2600.29839348793,3840.18138885498 2595.20854783058,3840.23662090302 2671.96268391609,3839.4010591507 PathPoint;PointKind.SMOOTHPOINT 2583.86331868172,3840.25526762009 2578.27532243729,3840.25007486343 2589.71118879318,3840.25975227356 PathPoint;PointKind.SMOOTHPOINT 2568.22131943703,3839.07226324081 2564.42836475372,3839.03992652893 2574.40235209465,3839.1256070137 PathPoint;PointKind.SMOOTHPOINT 2554.50925540924,3840.04401683807 2539.42276310921,3840.28807640076 2558.49623036385,3839.97934341431 PathPoint;PointKind.SMOOTHPOINT 2505.74077320099,3840.73370933533 2502.31921863556,3840.41246652603 2509.1630358696,3841.05400800705 PathPoint;PointKind.SMOOTHPOINT 2497.53775191307,3840.83213567734 2489.1424806118,3838.73733043671 2500.21509003639,3841.50011301041 PathPoint;PointKind.SMOOTHPOINT 2479.27824926376,3841.03488922119 2412.74062585831,3841.73260688782 2485.42423081398,3840.97021579742 PathPoint;PointKind.SMOOTHPOINT 2294.06288695335,3841.40097856522 2251.20742034912,3840.78964948654 2339.27173447609,3842.04582452774 PathPoint;PointKind.SMOOTHPOINT 2073.13363265991,3840.1558971405 2067.40012121201,3840.14433145523 2163.44440412521,3840.34283638 PathPoint;PointKind.SMOOTHPOINT 2055.91256332397,3840.12403249741 2048.43959641457,3841.16895675659 2061.60571289062,3839.32765245438 PathPoint;PointKind.SMOOTHPOINT 2038.84550642967,3840.09830474854 2013.92629337311,3840.06525993347 2044.52732634544,3840.10538578033 PathPoint;PointKind.SMOOTHPOINT 1965.62055659294,3840.06337165833 1961.18570637703,3840.06549596786 1989.22092747688,3840.05298614502 PathPoint;PointKind.SMOOTHPOINT 1951.88087654114,3841.49893283844 1966.9100124836,3841.48713111877 1956.23110842705,3841.49492025375 PathPoint;PointKind.SMOOTHPOINT 1872.57756900787,3840.51207304001 1850.21602463722,3840.61073541641 1912.10141015053,3840.33905982971 PathPoint;PointKind.SMOOTHPOINT 1806.0934073925,3839.6054649353 1802.29797434807,3839.63048458099 1827.8959043026,3839.4643163681 PathPoint;PointKind.SMOOTHPOINT 1794.71454334259,3839.68028783798 1785.66817116737,3839.86392259598 1798.50501966476,3839.60310459137 PathPoint;PointKind.SMOOTHPOINT 1774.70460963249,3839.81105089188 1768.29769206047,3839.8525929451 1781.37635779381,3839.76809263229 PathPoint;PointKind.SMOOTHPOINT 1755.46332192421,3839.93284463882 1753.0185956955,3839.9477148056 1761.88723397255,3839.89342689514 PathPoint;PointKind.SMOOTHPOINT 1748.12312436104,3839.97721910477 1741.28461790085,3841.48736715317 1750.52005362511,3839.44779396057 PathPoint;PointKind.SMOOTHPOINT 1734.82317638397,3840.05322217941 1723.4641392231,3840.11529922485 1739.26581573486,3840.0289106369 PathPoint;PointKind.SMOOTHPOINT 1700.49362611771,3840.21466970444 1696.43831920624,3840.2302479744 1712.03712415695,3840.17076730728 PathPoint;PointKind.SMOOTHPOINT 1688.28274083138,3840.25715589523 1685.21240544319,3838.94480466843 1692.61456203461,3842.10860967636 PathPoint;PointKind.SMOOTHPOINT 1678.30769133568,3840.28453588486 1667.5802822113,3840.31049966812 1681.64427351952,3840.2760386467 PathPoint;PointKind.SMOOTHPOINT 1645.72113704681,3840.32418966293 1680.03121447563,3840.32418966293 1656.72966313362,3840.32442569733 PathPoint;PointKind.SMOOTHPOINT 1488.47726655006,3839.4820189476 1371.49331045151,3840.39122343063 1574.11845159531,3838.81616592407 PathPoint;PointKind.SMOOTHPOINT 1189.66338944435,3839.83512639999 1181.17606472969,3839.86982345581 1280.23509693146,3839.46974515915 PathPoint;PointKind.SMOOTHPOINT 1164.27328777313,3839.93850946426 1152.90362906456,3841.23740673065 1172.66891312599,3838.97973775864 PathPoint;PointKind.SMOOTHPOINT 1140.31780314445,3840.03835201263 1127.66045880318,3840.09216785431 1148.30060434341,3840.00483512878 PathPoint;PointKind.SMOOTHPOINT 1102.27318954468,3840.20711660385 1079.64681458473,3840.31191587448 1114.99709558487,3840.14787197113 PathPoint;PointKind.SMOOTHPOINT 1029.33077287674,3836.92482233047 1018.17142081261,3836.81506633759 1052.04920125008,3837.14740276337 PathPoint;PointKind.SMOOTHPOINT 999.192485332489,3837.86541938782 996.7010242939,3837.86683559418 1009.94396996498,3837.85928249359 PathPoint;PointKind.SMOOTHPOINT 989.051739692688,3836.78768634796 985.61637711525,3836.79736375809 991.525852203369,3836.78084135056 PathPoint;PointKind.SMOOTHPOINT 978.77610039711,3838.83245229721 966.958212375641,3838.90090227127 982.181014537811,3838.81262540817 PathPoint;PointKind.SMOOTHPOINT 943.745527982712,3837.20074653625 939.961778640747,3837.25715875626 955.322660923004,3837.02867746353 PathPoint;PointKind.SMOOTHPOINT 917.275923013687,3837.66809463501 911.477620124817,3837.78540372849 922.445784330368,3837.56353139877 PathPoint;PointKind.SMOOTHPOINT 899.871454954147,3838.04338932037 896.089121818542,3838.12977790833 905.680025339127,3837.91097402573 PathPoint;PointKind.SMOOTHPOINT 888.375753879547,3836.54409885406 885.118833303452,3836.62222623825 892.170832872391,3836.45228147507 PathPoint;PointKind.SMOOTHPOINT 878.71687245369,3838.55086326599 871.188319444656,3838.73898267746 881.987601041794,3838.4694314003 PathPoint;PointKind.SMOOTHPOINT 849.484248876572,3839.50515031815 806.002819061279,3840.64141988754 857.121495723724,3839.30593729019 PathPoint;PointKind.SMOOTHPOINT 714.354440689087,3842.20656394958 710.458811044693,3842.25731134415 766.83904838562,3841.53008937836 PathPoint;PointKind.SMOOTHPOINT 702.695875883102,3839.10861253738 696.786400794983,3839.17989492416 706.412709474564,3839.06376600266 PathPoint;PointKind.SMOOTHPOINT 685.190503120422,3842.12772846222 675.830795288086,3842.22686290741 690.671929836273,3842.07037210464 PathPoint;PointKind.SMOOTHPOINT 661.863106012344,3841.04267835617 657.569168329239,3841.07430696487 670.09055685997,3840.98225355148 PathPoint;PointKind.SMOOTHPOINT 646.312452077866,3839.97839927673 642.270953178406,3839.99987840652 650.326689004898,3839.95715618134 PathPoint;PointKind.SMOOTHPOINT 629.781429290771,3841.97831869125 548.745747327805,3842.21812963486 633.561992168427,3841.96675300598 PathPoint;PointKind.SMOOTHPOINT 455.77711057663,3840.48587322235 447.28199672699,3840.59397697449 526.739670753479,3839.58398580551 PathPoint;PointKind.SMOOTHPOINT 432.706754922867,3840.80829620361 425.777611255646,3840.91380357742 439.629525661469,3840.70231676102 PathPoint;PointKind.SMOOTHPOINT 414.001501321793,3841.11042022705 405.187741041183,3843.1832742691 419.446460723877,3839.83016967773 PathPoint;PointKind.SMOOTHPOINT 401.17916893959,3841.33016824722 365.44474196434,3841.93866491318 405.060636520386,3841.2640786171 PathPoint;PointKind.SMOOTHPOINT 327.515625,3842 316.317516498855,3841.95108502283 351.753867094597,3842.10671312352 PathPoint;PointKind.SMOOTHPOINT 295,3842 293.016521281859,3841.9236844904 300.314928165261,3842.20449498536 PathPoint;PointKind.SMOOTHPOINT 291.515625,3840 290.797191768429,3839.32565382355 292.164065335135,3840.60852916737 PathPoint;PointKind.SMOOTHPOINT 289.82827136777,3835.23134058264 289.519994355664,3833.50976450425 290.245466825327,3837.56117281643 PathPoint;PointKind.SMOOTHPOINT 289,3830 289.025990445584,3827.71656132175 288.974009554416,3832.28343867825 PathPoint;PointKind.SMOOTHPOINT 288.749732494354,3814.49990272522 288.401819924835,3810.09075514134 288.821699522959,3815.41042227264 PathPoint;PointKind.SMOOTHPOINT 288.749732494354,3800.49999475479 289.188756465912,3790.15106678009 288.650952100754,3802.82800197601 PathPoint;PointKind.SMOOTHPOINT 288.332305669785,3720.65144777298 288.17227435112,3713.76797676086 289.30771780014,3762.64432668686 PathPoint;PointKind.SMOOTHPOINT 288.145012378693,3689.89781856537 291.012122154236,3483.84073734283 288.038796901703,3697.50780344009 PathPoint;PointKind.SMOOTHPOINT 291.968769550323,3048.59166383743 290.755434751511,3029.85407352448 292.928603410721,3063.42052459717 PathPoint;PointKind.SMOOTHPOINT 293.750003099442,2967.49992370605 294.926162481308,2940.63425302505 291.702168703079,3014.25880908966 PathPoint;PointKind.SMOOTHPOINT 293.175377368927,2876.08285903931 293.212552785873,2847.96266555786 293.125102043152,2914.05937671661 PathPoint;PointKind.SMOOTHPOINT 294.164951562881,2809.12108182907 294.064046859741,2792.6704287529 294.237886190414,2821.06701850891 PathPoint;PointKind.SMOOTHPOINT 293.175377368927,2738.03814411163 293.138201951981,2720.10118246078 293.233795881271,2766.81852579117 PathPoint;PointKind.SMOOTHPOINT 294.164951562881,2681.37808799744 293.981552839279,2667.16386079788 294.297012805939,2691.55069828033 PathPoint;PointKind.SMOOTHPOINT 294.164951562881,2581.45033121109 296.266955852509,2553.32565307617 293.858696937561,2585.55166482925 PathPoint;PointKind.SMOOTHPOINT 294.968648672104,2507.22577571869 295.147798776627,2487.43381977081 294.781709432602,2527.93118476868 PathPoint;PointKind.SMOOTHPOINT 294.968648672104,2334.45379257202 294.728247642517,2320.40620565414 296.441857337952,2420.5596113205 PathPoint;PointKind.SMOOTHPOINT 296.45637345314,2286.2347984314 294.852165699005,2225.81188201904 296.816089868546,2299.76924657822 PathPoint;PointKind.SMOOTHPOINT 296.848308563232,2131.88766002655 298.543507575989,2060.42565107346 296.210661649704,2158.765604496 PathPoint;PointKind.SMOOTHPOINT 297.654838085175,1813.99488687515 299.164514064789,1775.84299564362 296.14551615715,1852.14677810669 PathPoint;PointKind.SMOOTHPOINT 296.592329263687,1648.95279407501 296.172778129578,1609.02804851532 296.959834814072,1683.88234376907 PathPoint;PointKind.SMOOTHPOINT 299.968565225601,1534.52520847321 298.691147089005,1486.15137577057 300.906093835831,1569.9721455574 PathPoint;PointKind.SMOOTHPOINT 296.675177335739,1395.04304409027 297.573406219482,1377.1174120903 296.430173635483,1399.94831085205 PathPoint;PointKind.SMOOTHPOINT 295.905469179153,1315.31157016754 294.851811647415,1295.38554668427 297.444177389145,1344.40375328064 PathPoint;PointKind.SMOOTHPOINT 295.179663419724,1218.20348024368 294.842960357666,1203.11805009842 295.484501838684,1231.85618162155 PathPoint;PointKind.SMOOTHPOINT 294.583086490631,1171.12854480743 297.580487251282,1103.41759443283 293.987217664719,1184.5803809166 PathPoint;PointKind.SMOOTHPOINT 294.583086490631,1034.11435604095 295.952912092209,1005.04011154175 293.065975427628,1066.3380074501 PathPoint;PointKind.SMOOTHPOINT 293.067037582397,949.510188102722 292.155000686646,939.802565574646 294.927578687668,969.309461116791 PathPoint;PointKind.SMOOTHPOINT 295.750040531158,894.500012397766 296.496027231216,829.557037353516 295.381472826004,926.50155544281 PathPoint;PointKind.SMOOTHPOINT 296.116837978363,510.840504169464 296.810070991516,492.252087593079 296.098427295685,511.330275535583 PathPoint;PointKind.SMOOTHPOINT 296.066916704178,216.998927593231 295.93839597702,182.760722637177 296.138435125351,236.13659620285 PathPoint;PointKind.SMOOTHPOINT 295.750040531158,152.499933242798 296.510655397652,146.026635433951 294.200002670288,165.687882900238 PathPoint;PointKind.SMOOTHPOINT 296.656134611951,123.963318550029 297.06151636486,122.365186420743 294.986754091122,130.544499442342 PathPoint;PointKind.SMOOTHPOINT 298.515625,121 299.119002785952,120.033530115015 298.03440757579,121.770702506759 PathPoint;PointKind.SMOOTHPOINT 301.576579348442,120.245048783813 306.658781375747,119.418366638617 300.543951605053,120.413018280796 PathPoint;PointKind.SMOOTHPOINT 320.515625,120 330.876559587689,119.498394416235 312.196649784701,120.402146554023 PathPoint;PointKind.SMOOTHPOINT 362.323069095612,120.161805152893 371.26252982339,120.032250951491 342.383591651917,120.450475215912 PathPoint;PointKind.SMOOTHPOINT 429.375082643992,119.870428724046 429.724181977592,119.869731532359 395.709998630708,119.937661784812 PathPoint;PointKind.SMOOTHPOINT 431,120 431.373415959089,120.354188308813 430.74528095185,119.758396751154 PathPoint;PointKind.SMOOTHPOINT 432.062455279828,119.865157184557 450.451546911067,119.829726654834 431.514412489552,119.866213106555 PathPoint;PointKind.SMOOTHPOINT 494.122087084673,119.781302175362 494.343288505366,119.781098427095 471.465545915933,119.802171078378 PathPoint;PointKind.SMOOTHPOINT 495,120 495.506134359731,120.586396595429 494.855263211677,119.832311009371 PathPoint;PointKind.SMOOTHPOINT 496.469598187308,119.779168998818 632.879054695265,119.656892514593 495.907466671512,119.779672889583 PathPoint;PointKind.SMOOTHPOINT 867.672587156296,119.872426986694 928.262497901917,120.020184516907 827.030597494651,119.773155950596 PathPoint;PointKind.SMOOTHPOINT 1476.30922150612,118.243789672852 1553.13523006439,118.643159866333 1399.48321294785,117.84441947937 PathPoint;PointKind.SMOOTHPOINT 1918.2102162838,118.243789672852 1927.06008982658,117.94426202774 1868.91738367081,119.915385246277 PathPoint;PointKind.SMOOTHPOINT 1947.70165157318,113.590843677521 1969.68896341324,112.722001075745 1940.45244526863,113.876917362213 PathPoint;PointKind.SMOOTHPOINT 2006.02244567871,117.852916717529 2014.59863734245,117.212319374084 1989.10054993629,119.116644859314 PathPoint;PointKind.SMOOTHPOINT 2032.27714133263,114.857168197632 2038.2340593338,114.721212387085 2021.07105445862,115.113501548767 PathPoint;PointKind.SMOOTHPOINT 2060.69473814964,114.654414653778 2072.18194198608,114.650166034698 2048.0678422451,114.659843444824 PathPoint;PointKind.SMOOTHPOINT 2097.39962053299,118.099336624146 2100.55715787455,118.940772825241 2085.33814501762,114.886436462402 PathPoint;PointKind.SMOOTHPOINT 2111,118 2112.1677394076,118.309161009091 2106.73812614521,116.871661594203 PathPoint;PointKind.SMOOTHPOINT 2123.03472590446,114.891157150269 2204.43260264397,115.399811267853 2119.03455809607,114.866017835233 PathPoint;PointKind.SMOOTHPOINT 2351.12290334702,116.741194725037 2408.65947318077,117.008149623871 2313.20787262917,116.564877033234 PathPoint;PointKind.SMOOTHPOINT 2485.27375888824,117.103271484375 2498.49793982506,117.366921901703 2451.0847671032,116.420187950134 PathPoint;PointKind.SMOOTHPOINT 2557.21173119545,116.275026798248 2556.4724714756,116.28800868988 2557.95063686371,116.26228094101 PathPoint;PointKind.SMOOTHPOINT 2592.20229578018,118.414442539215 2600.80504131317,122.357869148254 2582.9006524086,114.15048122406 PathPoint;PointKind.SMOOTHPOINT 2618.99975252151,118.280611038208 2623.98479890823,118.274238109589 2606.41286444664,118.29571723938 PathPoint;PointKind.SMOOTHPOINT 2641.44662332535,116.279983520508 2645.85020407689,115.98178530338 2636.3178778248,116.627151168999 PathPoint;PointKind.SMOOTHPOINT 2665.10470461845,120.655353069305 2671.83841180801,120.060546398163 2651.37493801117,121.868569850922 PathPoint;PointKind.SMOOTHPOINT 2691.26593065262,118.280611038208 2692.97098287252,117.70462606848 2683.73392824461,120.825324076826 PathPoint;PointKind.SMOOTHPOINT 2711.0648496151,120.340955257416 2717.68349003792,120.321600437164 2705.67830872536,120.357005596161 PathPoint;PointKind.SMOOTHPOINT 2733.96384429932,116.044657230377 2735.42481075681,115.506669204308 2727.67985114967,118.359859404436 PathPoint;PointKind.SMOOTHPOINT 2749.6731133461,119.310901165009 2757.10253190994,119.287061691284 2745.80793213844,119.323174953461 PathPoint;PointKind.SMOOTHPOINT 2774.95735359192,116.848118305206 2778.07300758362,116.818141937256 2767.47836780548,116.918692588806 PathPoint;PointKind.SMOOTHPOINT 2785.31123828888,118.280847072601 2788.58940196037,118.246386051178 2782.20620584488,118.313183784485 PathPoint;PointKind.SMOOTHPOINT 2794.40469932556,114.855988025665 2801.55689549446,114.757797718048 2791.14140582085,114.901070594788 PathPoint;PointKind.SMOOTHPOINT 2815.73135089874,114.576287269592 2819.72115826607,114.52624797821 2808.67050004005,114.664328098297 PathPoint;PointKind.SMOOTHPOINT 2828.8691432476,118.280847072601 2830.76331925392,118.258423805237 2824.91509509087,118.327345848083 PathPoint;PointKind.SMOOTHPOINT 2841.73821043968,118.280847072601 2848.1380469799,118.186905384064 2839.8532397747,118.308699131012 PathPoint;PointKind.SMOOTHPOINT 2856.58748817444,116.220266819 2859.83661961555,116.175420284271 2850.39547991753,116.306891441345 PathPoint;PointKind.SMOOTHPOINT 2870.21776628494,119.149689674377 2872.93475818634,119.113340377808 2867.02740740776,119.192411899567 PathPoint;PointKind.SMOOTHPOINT 2882.86342692375,116.117119789124 2890.8044500351,115.975735187531 2880.18856716156,116.164798736572 PathPoint;PointKind.SMOOTHPOINT 2913.96261048317,119.267706871033 2924.758705616,119.049139022827 2906.51124072075,119.418768882751 PathPoint;PointKind.SMOOTHPOINT 2951.87976551056,117.32608795166 2959.12295293808,117.855041027069 2941.45259213448,116.564168930054 PathPoint;PointKind.SMOOTHPOINT 2968.45221233368,118.280847072601 2977.05070924759,117.766292095184 2962.57141542435,118.632774353027 PathPoint;PointKind.SMOOTHPOINT 2988.82752728462,114.359135627747 2988.92524552345,113.885650634766 2988.55278325081,115.693674087524 PathPoint;PointKind.SMOOTHPOINT 2997.83743214607,113.791708946228 2999.55210399628,113.749694824219 2991.73393678665,113.941354751587 PathPoint;PointKind.SMOOTHPOINT 3003.39887452126,118.486905097961 3007.65917730331,118.413026332855 3001.39423441887,118.522310256958 PathPoint;PointKind.SMOOTHPOINT 3016.95975852013,116.220266819 3024.17072725296,114.77148771286 3012.21900773048,117.172429561615 PathPoint;PointKind.SMOOTHPOINT 3035.76839518547,116.397528648376 3036.4587957859,116.638991832733 3035.07799458504,116.15606546402 PathPoint;PointKind.SMOOTHPOINT 3119.0813369751,117.777621746063 3132.28569102287,117.73962020874 3103.46305918694,117.824592590332 PathPoint;PointKind.SMOOTHPOINT 3187.23060321808,119.487926959991 3187.03906130791,120.894927978516 3187.42285323143,118.081161975861 PathPoint;PointKind.SMOOTHPOINT 3198.11981391907,117.250556945801 3201.92905497551,116.895089149475 3194.254986763,117.610745429993 PathPoint;PointKind.SMOOTHPOINT 3210.98923516273,115.190212726593 3214.19233989716,114.999260902405 3206.92012023926,115.432856082916 PathPoint;PointKind.SMOOTHPOINT 3219.21633195877,114.981558322906 3222.84748506546,114.9076795578 3215.71653199196,115.052840709686 PathPoint;PointKind.SMOOTHPOINT 3234.74822115898,116.220266819 3239.83452630043,116.348905563354 3230.66600632668,116.11688375473 PathPoint;PointKind.SMOOTHPOINT 3245.4600520134,116.074633598328 3250.07830095291,116.261100769043 3240.79931688309,115.886750221252 PathPoint;PointKind.SMOOTHPOINT 3259.74213910103,118.169202804565 3263.98190689087,118.400988578796 3255.49706053734,117.937653064728 PathPoint;PointKind.SMOOTHPOINT 3271.37627434731,115.190212726593 3275.30058217049,115.455515384674 3267.46612858772,114.926326274872 PathPoint;PointKind.SMOOTHPOINT 3284.24534153938,115.190212726593 3289.05159187317,115.56715965271 3280.60852360725,114.90555524826 PathPoint;PointKind.SMOOTHPOINT 3297.95351099968,116.216490268707 3303.07486724854,117.105867862701 3293.60434126854,115.461180210114 PathPoint;PointKind.SMOOTHPOINT 3313.94425106049,117.250556945801 3317.18028259277,117.869203090668 3309.26758360863,116.35575056076 PathPoint;PointKind.SMOOTHPOINT 3333.74352407455,117.250556945801 3346.02911424637,120.755903720856 3330.7004506588,116.382422447205 PathPoint;PointKind.SMOOTHPOINT 3356.20561909676,121.468727588654 3358.63122653961,121.430962085724 3343.30645751953,121.671009063721 PathPoint;PointKind.SMOOTHPOINT 3363.02040410042,117.398550510406 3367.11501073837,117.139620780945 3360.87201905251,117.534034252167 PathPoint;PointKind.SMOOTHPOINT 3389.18056797981,117.250556945801 3404.3605298996,115.345051288605 3385.88470172882,117.664325237274 PathPoint;PointKind.SMOOTHPOINT 3412.66693425179,114.482109546661 3417.17365694046,114.306499958038 3400.89153242111,114.940960407257 PathPoint;PointKind.SMOOTHPOINT 3435.01962733269,116.586828231812 3444.72418141365,116.845993995667 3426.8612165451,116.368496417999 PathPoint;PointKind.SMOOTHPOINT 3461.44639205933,117.250556945801 3470.70767354965,118.284151554108 3453.82861804962,116.400361061096 PathPoint;PointKind.SMOOTHPOINT 3482.23594737053,117.250556945801 3489.45824575424,116.262753009796 3476.56581115723,118.025693893433 PathPoint;PointKind.SMOOTHPOINT 3501.04458403587,117.250556945801 3502.88706851006,117.345914840698 3489.4175298214,116.647253036499 PathPoint;PointKind.SMOOTHPOINT 3516.88379001617,117.250556945801 3523.25388622284,117.438204288483 3512.46062350273,117.1200299263 PathPoint;PointKind.SMOOTHPOINT 3534.70285248756,115.190212726593 3538.48306131363,115.273532867432 3523.77929878235,114.949929714203 PathPoint;PointKind.SMOOTHPOINT 3546.58234548569,119.310901165009 3551.26219940186,119.407203197479 3542.33231019974,119.222860336304 PathPoint;PointKind.SMOOTHPOINT 3566.38161849976,117.250556945801 3572.2762234211,117.365033626556 3561.1827249527,117.149534225464 PathPoint;PointKind.SMOOTHPOINT 3582.22047042847,122.401535511017 3587.70012688637,122.295320034027 3575.69990229607,122.527105808258 PathPoint;PointKind.SMOOTHPOINT 3601.25640821457,120.165581703186 3608.43480420113,120.289499759674 3595.43013525009,120.064558982849 PathPoint;PointKind.SMOOTHPOINT 3620.82838010788,121.371245384216 3630.59701752663,121.045281887054 3613.34479165077,121.621205806732 PathPoint;PointKind.SMOOTHPOINT 3653.75305366516,119.285409450531 3666.83596801758,119.50138092041 3643.08052253723,119.108383655548 PathPoint;PointKind.SMOOTHPOINT 3699.44199514389,119.408855438232 3808.05086088181,114.841825962067 3685.65912079811,119.988083839417 PathPoint;PointKind.SMOOTHPOINT 3993.01944923401,119.179430007935 4114.54871964455,117.135136127472 3936.46501851082,120.130648612976 PathPoint;PointKind.SMOOTHPOINT 4406.17287111282,116.207048892975 4428.9217479229,115.825853347778 4311.843968153,117.788951396942 PathPoint;PointKind.SMOOTHPOINT 4512.47579884529,118.523726463318 4514.30058073997,118.515465259552 4478.36292815208,118.678092956543 PathPoint;PointKind.SMOOTHPOINT 4528.67755365372,118.603978157043 4548.55967473984,122.661881446838 4526.97350335121,118.25582742691 PathPoint;PointKind.SMOOTHPOINT 4546,118 4546.33068418503,117.747207164764 4545.66966986656,118.252556800842 PathPoint;PointKind.SMOOTHPOINT 4622.12663841248,118.452680110931 4629.85770893097,118.485488891602 4597.43508052826,118.349061012268 PathPoint;PointKind.SMOOTHPOINT 4645.42358708382,118.56739282608 4650.18027019501,116.80846452713 4636.78791475296,121.760702133179 PathPoint;PointKind.SMOOTHPOINT 4660.57416272163,118.659446239471 4711.53528642654,118.992254734039 4655.51724386215,118.626165390015 PathPoint;PointKind.SMOOTHPOINT 4810.58475923538,120.387454032898 4871.4780921936,119.821679592133 4763.04235768318,120.829546451569 PathPoint;PointKind.SMOOTHPOINT 5002.72147607803,119.355747699738 5007.91930747032,119.343473911285 4936.8569047451,119.510586261749 PathPoint;PointKind.SMOOTHPOINT 5021.53082084656,120.95724105835 5028.65787935257,120.943078994751 5016.32874083519,120.967862606049 PathPoint;PointKind.SMOOTHPOINT 5039.70358085632,119.284229278564 5051.9303984642,119.265582561493 5032.57793855667,119.29461479187 PathPoint;PointKind.SMOOTHPOINT 5076.33092594147,119.241743087769 5081.25719976425,119.237966537476 5064.14801073074,119.251420497894 PathPoint;PointKind.SMOOTHPOINT 5091.52186346054,121.146540641785 5094.85101056099,121.144416332245 5086.60868954659,121.149137020111 PathPoint;PointKind.SMOOTHPOINT 5101.0678024292,119.227108955383 5112.84993124008,119.22262430191 5097.74644446373,119.228053092957 PathPoint;PointKind.SMOOTHPOINT 5136.24424409866,119.22333240509 5147.91095209122,119.224984645844 5124.58355498314,119.221208095551 PathPoint;PointKind.SMOOTHPOINT 5174.15360999107,120.347564220428 5181.00627851486,120.333874225616 5162.7382786274,120.369987487793 PathPoint;PointKind.SMOOTHPOINT 5196.82813596725,118.280847072601 5200.44548106194,118.279194831848 5190.10788273811,118.283679485321 PathPoint;PointKind.SMOOTHPOINT 5216.62705492973,119.310901165009 5232.54415225983,119.317038059235 5213.05184197426,119.309484958649 PathPoint;PointKind.SMOOTHPOINT 5254.84586191177,117.49933719635 5374.79854059219,118.114678859711 5239.8949713707,117.422389984131 PathPoint;PointKind.SMOOTHPOINT 5486.18140053749,118.134977817535 5489.56896615028,118.207204341888 5423.342908144,116.792414188385 PathPoint;PointKind.SMOOTHPOINT 5499.78547883034,120.215857028961 5502.57965397835,120.278642177582 5496.34586763382,120.138437747955 PathPoint;PointKind.SMOOTHPOINT 5514.37488269806,117.188715934753 5521.11496281624,117.374475002289 5511.55486178398,117.111060619354 PathPoint;PointKind.SMOOTHPOINT 5531.86998796463,118.258423805237 5537.29335021973,118.721759319305 5524.65229225159,117.641429901123 PathPoint;PointKind.SMOOTHPOINT 5546.28024172783,117.250556945801 5553.98157191277,116.512949466705 5542.70007205009,117.593750953674 PathPoint;PointKind.SMOOTHPOINT 5558.11406207085,119.351263046265 5564.03911542892,119.133403301239 5552.65033793449,119.551656246185 PathPoint;PointKind.SMOOTHPOINT 5572.46731352806,118.151972293854 5584.98799395561,117.229549884796 5568.37483119965,118.453388214111 PathPoint;PointKind.SMOOTHPOINT 5630.96478796005,120.201453208923 5638.53228963722,121.050119949796 5619.58777378047,118.925564024282 PathPoint;PointKind.SMOOTHPOINT 5650.50265434918,123.071197589955 5650.90841946943,124.461943659781 5648.92040090141,117.648078021147 PathPoint;PointKind.SMOOTHPOINT 5651.78611032415,131.056295299283 5651.93095135243,132.426520460363 5651.42546264264,127.644495940151 PathPoint;PointKind.SMOOTHPOINT 5649.17873044582,136.353519449174 5649.70610580691,142.907834634978 5649.0602990391,134.881632772542 PathPoint;PointKind.SMOOTHPOINT 5650.515625,151 5652.15877842903,154.96773815155 5650.01701971961,149.794772586584 PathPoint;PointKind.CORNERPOINT 5651.30079460144,184.637904167175 5651.30079460144,184.637904167175 5651.30079460144,184.637904167175 PathPoint;PointKind.SMOOTHPOINT 5649.55071759224,1995.19849061966 5648.27683997154,2028.35494995117 5651.59996819496,1941.85967445374 PathPoint;PointKind.SMOOTHPOINT 5650.67341518402,2112.58807182312 5650.64615321159,2114.69585895538 5651.20980334282,2071.54169082642 PathPoint;PointKind.SMOOTHPOINT 5648.27683997154,2123.97814750671 5647.84489703178,2140.60629844666 5648.33242607117,2121.82433366776 PathPoint;PointKind.SMOOTHPOINT 5648.18337035179,2160.77614545822 5648.11397624016,2165.10147571564 5648.35366916656,2150.12367725372 PathPoint;PointKind.SMOOTHPOINT 5650.08356523514,2178.15771818161 5650.02550077438,2180.74677944183 5650.15225124359,2175.08337020874 PathPoint;PointKind.SMOOTHPOINT 5649.08797216415,2187.35503435135 5649.01185107231,2190.33709287643 5649.2239279747,2182.07046031952 PathPoint;PointKind.SMOOTHPOINT 5649.4144077301,2204.44675683975 5649.18214988708,2213.26429367065 5649.50787734985,2200.89656352997 PathPoint;PointKind.SMOOTHPOINT 5648.59902691841,2235.27898550034 5648.28108859062,2247.31461524963 5648.90528154373,2223.70456695557 PathPoint;PointKind.SMOOTHPOINT 5647.74611663818,2267.70515441895 5647.65193891525,2271.31199598312 5647.63742280006,2271.84590578079 PathPoint;PointKind.SMOOTHPOINT 5646.81956362724,2315.12045145035 5646.38408017159,2334.61169958115 5647.0362432003,2305.43029546738 PathPoint;PointKind.SMOOTHPOINT 5645.44371914864,2373.1263756752 5646.26228642464,2339.8105931282 5645.90292406082,2354.36943054199 PathPoint;PointKind.SMOOTHPOINT 5648.4407658577,2473.51557970047 5648.84792518616,2488.05435419083 5647.08297801018,2425.0581908226 PathPoint;PointKind.SMOOTHPOINT 5646.30725097656,2548.12841176987 5649.53018260002,2624.13809537888 5645.12224030495,2520.18075942993 PathPoint;PointKind.SMOOTHPOINT 5645.85725140572,2694.3429851532 5645.20721268654,2707.24014043808 5644.53274440765,2720.60487985611 PathPoint;PointKind.SMOOTHPOINT 5646.39470171928,2740.39659976959 5642.5762553215,2813.53586912155 5647.14670729637,2725.99047660828 PathPoint;PointKind.SMOOTHPOINT 5648.51547074318,2943.00002574921 5647.67566037178,3003.6615729332 5649.15488791466,2896.60321712494 PathPoint;PointKind.SMOOTHPOINT 5650.18765640259,3067.78173208237 5649.80669689178,3074.85025405884 5649.76881337166,3075.54608345032 PathPoint;PointKind.SMOOTHPOINT 5651.34717535973,3094.69154119492 5650.96869421005,3116.89033985138 5651.49658513069,3085.94056606293 PathPoint;PointKind.SMOOTHPOINT 5651.51570391655,3129.99992609024 5651.789031744,3218.28623056412 5651.47959065437,3118.41819047928 PathPoint;PointKind.SMOOTHPOINT 5649.51566648483,3366.00009441376 5649.98513889313,3393.31682682037 5648.21877551079,3290.56326627731 PathPoint;PointKind.SMOOTHPOINT 5650.5155081749,3473.99999141693 5652.22770166397,3536.69969558716 5650.36999297142,3468.68756532669 PathPoint;PointKind.SMOOTHPOINT 5651.51570391655,3693.99986028671 5650.99737238884,3737.21374511719 5652.06696224213,3648.14498662949 PathPoint;PointKind.SMOOTHPOINT 5650.515625,3820 5650.44658493996,3823.64649534225 5650.98368120193,3795.11300563812 PathPoint;PointKind.SMOOTHPOINT 5649.515625,3837 5649.44123721258,3837.2149526016 5650.22500714603,3834.95008541479 PathPoint;PointKind.SMOOTHPOINT 5651.515625,3839 5651.52310247229,3839.37363912322 5651.49990530918,3838.2145084233 PathPoint;PointKind.SMOOTHPOINT 5650.515625,3842 5648.14116047799,3842.62652931615 5650.82754277614,3841.91772311544 PathPoint";
	
	shadow35mm[0] = "PointKind.CORNERPOINT 5650.75,3844.6875 5650.75,3844.6875 5650.75,3844.6875 PathPoint;PointKind.SMOOTHPOINT 5612.65382838249,3845.63332653046 5600.46241593361,3845.74379062653 5612.03530025482,3845.6389913559 PathPoint;PointKind.SMOOTHPOINT 5191.11782646179,3843.67879772186 5193.24178195,3843.67620134354 5389.6214530468,3843.44795608521 PathPoint;PointKind.SMOOTHPOINT 5134.75954031944,3842.50429058075 5092.35761380196,3842.9964222908 5147.64312362671,3842.35511684418 PathPoint;PointKind.SMOOTHPOINT 4975.39737915993,3841.05173492432 4847.21052265167,3838.0706205368 5046.6095457077,3842.70775222778 PathPoint;PointKind.SMOOTHPOINT 4598.84404039383,3840.83670759201 4480.64250087738,3840.4984703064 4697.99158549309,3841.12065696716 PathPoint;PointKind.SMOOTHPOINT 4349.44478964806,3839.05228757858 4326.33832073212,3839.1894235611 4345.14978981018,3839.07801532745 PathPoint;PointKind.SMOOTHPOINT 4254.05621027946,3839.28289318085 4237.26708388329,3839.23120164871 4298.31478333473,3839.41837692261 PathPoint;PointKind.SMOOTHPOINT 4196.06255984306,3838.94560003281 4051.35140752792,3837.75622272491 4218.14192509651,3839.12734651566 PathPoint;PointKind.SMOOTHPOINT 3890.93665099144,3838.12113189697 3871.15260219574,3837.77746582031 3961.7646715641,3839.35063505173 PathPoint;PointKind.SMOOTHPOINT 3831.47474861145,3840.76023244858 3854.32240581512,3840.76117658615 3850.64947462082,3840.76188468933 PathPoint;PointKind.SMOOTHPOINT 3702.00764155388,3840.96133375168 3687.75387859344,3840.91719532013 3734.64234685898,3841.06400871277 PathPoint;PointKind.SMOOTHPOINT 3623.34658360481,3840.38706207275 3597.04409098625,3840.10736131668 3626.58650970459,3840.42128705978 PathPoint;PointKind.SMOOTHPOINT 3541.10464787483,3839.4433965683 3549.84441137314,3839.54630756378 3569.34167838097,3839.77549695969 PathPoint;PointKind.SMOOTHPOINT 3416.44131278992,3838.15228843689 3348.2757601738,3840.59028768539 3440.42264318466,3837.29477548599 PathPoint;PointKind.SMOOTHPOINT 3244.69690537453,3838.4482755661 3131.83127737045,3839.86802244186 3249.25000882149,3838.39115524292 PathPoint;PointKind.SMOOTHPOINT 2925.01593565941,3839.08226394653 2724.1164419651,3839.96951723099 3030.97083067894,3838.61397171021 PathPoint;PointKind.SMOOTHPOINT 2477.586779356,3839.60508012772 2411.07429361343,3840.30232572556 2466.84945678711,3839.71790456772 PathPoint;PointKind.SMOOTHPOINT 2292.44045710564,3839.97069740295 2199.77524256706,3838.6493768692 2337.63231015205,3840.61554336548 PathPoint;PointKind.SMOOTHPOINT 1871.11304616928,3839.08226394653 1862.32761001587,3839.12120962143 1969.85236978531,3838.65032100677 PathPoint;PointKind.SMOOTHPOINT 1733.40928292274,3838.62364912033 1722.05520248413,3838.68525409698 1739.5290646553,3838.58989620209 PathPoint;PointKind.SMOOTHPOINT 1699.09283256531,3838.78509664536 1719.72625112534,3838.7057890892 1710.63208198547,3838.74095821381 PathPoint;PointKind.SMOOTHPOINT 1487.15578055382,3838.05244588852 1370.21537280083,3838.96141433716 1590.97043371201,3837.2452082634 PathPoint;PointKind.SMOOTHPOINT 1188.45342969894,3838.40555334091 1194.22588682175,3838.38194990158 1278.991502285,3838.03993606567 PathPoint;PointKind.SMOOTHPOINT 1101.09615659714,3838.77730751038 1061.4834485054,3838.96070623398 1134.61386656761,3838.6212887764 PathPoint;PointKind.SMOOTHPOINT 998.054044008255,3836.43631839752 907.232730150223,3836.48942613602 991.499132871628,3836.44009494781 PathPoint;PointKind.SMOOTHPOINT 848.401039600372,3838.07557725906 804.935896158218,3839.21161079407 832.982446908951,3838.47825193405 PathPoint;PointKind.SMOOTHPOINT 713.321506738663,3840.77651882172 706.622850656509,3840.86361551285 765.786995649338,3840.10028028488 PathPoint;PointKind.SMOOTHPOINT 628.780359983444,3840.54827356339 547.775126457214,3840.78808450699 618.26254940033,3840.58013820648 PathPoint;PointKind.SMOOTHPOINT 454.841186761856,3839.05582809448 446.349259376526,3839.16416788101 525.777193069458,3838.15441274643 PathPoint;PointKind.SMOOTHPOINT 431.778974294662,3839.37848711014 424.852663040161,3839.48375844955 438.699266672134,3839.27274370193 PathPoint;PointKind.SMOOTHPOINT 413.081155776978,3839.68037509918 404.270581960678,3841.75299310684 418.523990869522,3838.40012454987 PathPoint;PointKind.SMOOTHPOINT 400.75,3840.6875 365.029026985168,3841.29599666595 404.629697322845,3840.62164640427 PathPoint;PointKind.SMOOTHPOINT 328.75,3841.6875 314.321428056909,3841.50610387063 346.397487917555,3841.90936436842 PathPoint;PointKind.SMOOTHPOINT 289.065804965151,3837.90944913942 285.997869502294,3836.00964468048 294.120993688722,3841.03985073818 PathPoint;PointKind.SMOOTHPOINT 288.552081108093,3822.39976453781 288.747163534164,3817.98167276382 288.291853189468,3828.32918453217 PathPoint;PointKind.CORNERPOINT 300.75,3787.6875 300.75,3787.6875 300.75,3787.6875 PathPoint;PointKind.SMOOTHPOINT 298.902902858122,156.984558158147 297.824890426233,157.161026982622 298.902902858122,156.984558158147 PathPoint;PointKind.SMOOTHPOINT 291.518727052024,130.00409339367 291.897403769,123.673808727525 291.253869259324,134.431683336973 PathPoint;PointKind.SMOOTHPOINT 293.75,118.6875 322.735920499912,115.954150174136 291.141534054821,118.933476315882 PathPoint;PointKind.SMOOTHPOINT 369.418805599213,118.33357000351 412.401249768779,117.807101353145 349.284068207675,118.580189483271 PathPoint;PointKind.SMOOTHPOINT 866.582650899887,119.043797492981 927.14990234375,119.191555023193 806.016461610794,118.896039962769 PathPoint;PointKind.CORNERPOINT 1474.99233818054,117.415868282318 1474.99233818054,117.415868282318 1474.99233818054,117.415868282318 PathPoint;PointKind.CORNERPOINT 1916.7283449173,117.415868282318 1916.7283449173,117.415868282318 1916.7283449173,117.415868282318 PathPoint;PointKind.CORNERPOINT 3990.76326704025,118.351272583008 3990.76326704025,118.351272583008 3990.76326704025,118.351272583008 PathPoint;PointKind.CORNERPOINT 5088.85533547401,120.317675113678 5088.85533547401,120.317675113678 5088.85533547401,120.317675113678 PathPoint;PointKind.CORNERPOINT 5098.39808797836,118.398951530457 5098.39808797836,118.398951530457 5098.39808797836,118.398951530457 PathPoint;PointKind.SMOOTHPOINT 5133.56178379059,118.39493894577 5145.22388911247,118.396591186523 5121.90463519096,118.393050670624 PathPoint;PointKind.SMOOTHPOINT 5166.95238924026,119.707290172577 5173.80222535133,119.693364143372 5155.54166054726,119.729713439941 PathPoint;PointKind.SMOOTHPOINT 5194.12266230583,117.452689647675 5197.73894524574,117.450801372528 5187.40488743782,117.455522060394 PathPoint;PointKind.SMOOTHPOINT 5213.91414618492,118.482271671295 5229.82557868958,118.488880634308 5210.34034943581,118.480855464935 PathPoint;PointKind.SMOOTHPOINT 5260.74242568016,117.697457313538 5380.65013980865,118.312562942505 5245.79684591293,117.620274066925 PathPoint;PointKind.SMOOTHPOINT 5475.26192998886,119.707290172577 5478.64807939529,119.77951669693 5412.4471590519,118.365198612213 PathPoint;PointKind.SMOOTHPOINT 5496.96670866013,119.387463569641 5499.75982165337,119.450012683868 5493.52851366997,119.309808254242 PathPoint;PointKind.SMOOTHPOINT 5511.550801754,116.360558509827 5518.28840351105,116.546317577362 5508.73184299469,116.283139228821 PathPoint;PointKind.SMOOTHPOINT 5529.03953409195,117.430030345917 5534.46077203751,117.893837928772 5521.82467079163,116.813272476196 PathPoint;PointKind.SMOOTHPOINT 5543.4444770813,116.422635555267 5551.14297485352,115.685028076172 5539.86536955833,116.765593528748 PathPoint;PointKind.SMOOTHPOINT 5556.08057832718,115.687388420105 5562.00386142731,115.470000743866 5550.61897850037,115.887781620026 PathPoint;PointKind.SMOOTHPOINT 5569.6219894886,117.323814868927 5582.13771319389,116.401392459869 5565.53092336655,117.624994754791 PathPoint;PointKind.SMOOTHPOINT 5605.75,114.6875 5613.29908800125,115.573337078094 5594.38388180733,113.353669643402 PathPoint;PointKind.SMOOTHPOINT 5650.75,114.6875 5655.16928225581,116.034437987288 5647.93049642193,113.828229904175 PathPoint;PointKind.SMOOTHPOINT 5650.75,147.6875 5652.39244532585,151.65453004837 5649.86062240601,145.537934780121 PathPoint;PointKind.CORNERPOINT 5646.42781710625,177.800547122955 5646.42781710625,177.800547122955 5646.42781710625,177.800547122955 PathPoint;PointKind.SMOOTHPOINT 5640.75,3807.6875 5634.5117481203,3794.75634398496 5646.9882518797,3820.61865601504 PathPoint;PointKind.SMOOTHPOINT 5649.75,3828.6875 5652.30816156228,3830.74044579118 5638.11599828903,3819.36358647305 PathPoint";
	
	subshadow35mm[0] = "PointKind.CORNERPOINT 5605.77034235001,3844.41466569901 5605.77034235001,3844.41466569901 5605.77034235001,3844.41466569901 PathPoint;PointKind.SMOOTHPOINT 5587.29451417923,3847.43968248367 5575.09956121445,3847.55061864853 5586.67598605156,3847.44511127472 PathPoint;PointKind.SMOOTHPOINT 5190.64733147621,3849.49129343033 5192.77164101601,3849.488697052 5389.20654416084,3849.25974369049 PathPoint;PointKind.SMOOTHPOINT 5134.27311301231,3848.31324577332 5091.85950279236,3848.80679368973 5147.16059088707,3848.16336393356 PathPoint;PointKind.SMOOTHPOINT 4974.86634135246,3846.8564414978 4846.64337158203,3843.86635780334 5046.09833478928,3848.51717948914 PathPoint;PointKind.SMOOTHPOINT 4598.20714116096,3846.64047002792 4479.97267484665,3846.30128860474 4697.38265633583,3846.92536354065 PathPoint;PointKind.SMOOTHPOINT 4348.73778820038,3844.85109329224 4325.62494635582,3844.98846530914 4344.44208025932,3844.87682104111 PathPoint;PointKind.SMOOTHPOINT 4253.32265496254,3845.08217096329 4236.52927994728,3845.03047943115 4297.59397387505,3845.21836280823 PathPoint;PointKind.SMOOTHPOINT 4195.312718153,3844.74416971207 4050.56084990501,3843.55125188828 4217.39845633507,3844.92615222931 PathPoint;PointKind.SMOOTHPOINT 3890.1011288166,3843.91710519791 3870.31176924706,3843.57273101807 3960.9493303299,3845.15038490295 PathPoint;PointKind.SMOOTHPOINT 3830.62258601189,3846.56399488449 3853.47697019577,3846.56493902206 3849.80297684669,3846.56564712524 PathPoint;PointKind.SMOOTHPOINT 3701.11936569214,3846.76556825638 3686.86135411263,3846.72166585922 3733.76327633858,3846.86871528625 PathPoint;PointKind.SMOOTHPOINT 3622.4360024929,3846.1896443367 3596.12642884254,3845.90947151184 3625.67699074745,3846.22434139252 PathPoint;PointKind.SMOOTHPOINT 3540.17105340958,3845.24338245392 3548.91329526901,3845.3465294838 3568.41622710228,3845.57666301727 PathPoint;PointKind.SMOOTHPOINT 3415.47302126884,3843.94849777222 3347.28799581528,3846.39357805252 3439.4610786438,3843.0881524086 PathPoint;PointKind.SMOOTHPOINT 3243.68046283722,3844.245429039 3130.78297019005,3845.66918849945 3248.23498249054,3844.18807268143 PathPoint;PointKind.SMOOTHPOINT 2923.90920996666,3844.88106966019 2722.95377612114,3845.77115535736 3029.89419937134,3844.41159725189 PathPoint;PointKind.SMOOTHPOINT 2476.355073452,3845.40530204773 2409.82346892357,3846.1049079895 2465.61456441879,3845.51859855652 PathPoint;PointKind.SMOOTHPOINT 2291.1567056179,3845.77233552933 2198.46564531326,3844.4467663765 2336.36130452156,3846.4188337326 PathPoint;PointKind.SMOOTHPOINT 1869.71068739891,3844.88106966019 1860.92312693596,3844.92001533508 1968.47798109055,3844.44771051407 PathPoint;PointKind.SMOOTHPOINT 1731.96868658066,3844.42103862762 1720.61141967773,3844.48311567307 1738.09023857117,3844.38752174377 PathPoint;PointKind.SMOOTHPOINT 1697.64267683029,3844.58295822144 1718.28176021576,3844.50365066528 1709.18511271477,3844.53881978989 PathPoint;PointKind.SMOOTHPOINT 1485.6457901001,3843.84818315506 1368.67280960083,3844.75998401642 1589.48982954025,3843.038585186 PathPoint;PointKind.SMOOTHPOINT 1186.85988306999,3844.20223474503 1192.63411045074,3844.17863130569 1277.42344737053,3843.83590936661 PathPoint;PointKind.SMOOTHPOINT 1099.47782635689,3844.57540512085 1059.85414266586,3844.75927591324 1133.00509572029,3844.41867828369 PathPoint;PointKind.SMOOTHPOINT 996.406681537628,3842.2273349762 905.560230016708,3842.28044271469 989.850354194641,3842.2308754921 PathPoint;PointKind.SMOOTHPOINT 846.712253093719,3843.8713145256 803.235071897507,3845.01065254211 831.289411783218,3844.27516937256 PathPoint;PointKind.SMOOTHPOINT 711.594482660294,3846.58051729202 704.89405632019,3846.66761398315 764.074841737747,3845.90215444565 PathPoint;PointKind.SMOOTHPOINT 627.029968500137,3846.35132789612 546.00172162056,3846.5918469429 616.508617401123,3846.38342857361 PathPoint;PointKind.SMOOTHPOINT 453.041582107544,3844.85463380814 444.547530412674,3844.96320962906 523.997415304184,3843.95062208176 PathPoint;PointKind.SMOOTHPOINT 429.972996711731,3845.17800092697 423.04491519928,3845.28374433517 436.895413398743,3845.07202148438 PathPoint;PointKind.SMOOTHPOINT 411.269867420197,3845.48106908798 402.457169294357,3847.55982398987 416.714472770691,3844.19727802277 PathPoint;PointKind.SMOOTHPOINT 398.448597192764,3845.70152521133 362.717710733414,3846.31143808365 402.32971072197,3845.63519954681 PathPoint;PointKind.SMOOTHPOINT 325.04697561264,3845.49995183945 312.556035518646,3845.70010900497 348.6714220047,3845.12158870697 PathPoint;PointKind.SMOOTHPOINT 291.047047376633,3844.50011014938 289.177654981613,3844.10310029984 294.032764434814,3845.13409852982 PathPoint;PointKind.SMOOTHPOINT 289.047009944916,3819.50005531311 289.242092370987,3815.06921768188 288.786427974701,3825.44741392136 PathPoint;PointKind.CORNERPOINT 391,3781 391,3781 391,3781 PathPoint;PointKind.CORNERPOINT 380,165 380,165 380,165 PathPoint;PointKind.SMOOTHPOINT 295.046768188477,123.500039577484 295.768325328827,122.271244525909 292.691617012024,127.511208057404 PathPoint;PointKind.SMOOTHPOINT 301.046880483627,113.499970436096 309.726809263229,112.643401622772 295.343817472458,114.062204360962 PathPoint;PointKind.SMOOTHPOINT 367.595479488373,113.153944015503 410.588672161102,112.528924942017 347.657772302628,113.443322181702 PathPoint;PointKind.SMOOTHPOINT 864.898821115494,113.866059780121 925.483067035675,114.014525413513 804.315637350082,113.718066215515 PathPoint;PointKind.CORNERPOINT 1473.47916126251,112.233173847198 1473.47916126251,112.233173847198 1473.47916126251,112.233173847198 PathPoint;PointKind.CORNERPOINT 1915.33908605576,112.233173847198 1915.33908605576,112.233173847198 1915.33908605576,112.233173847198 PathPoint;PointKind.CORNERPOINT 3989.95571494102,113.171410560608 3989.95571494102,113.171410560608 3989.95571494102,113.171410560608 PathPoint;PointKind.CORNERPOINT 5088.35651636124,115.143713951111 5088.35651636124,115.143713951111 5088.35651636124,115.143713951111 PathPoint;PointKind.CORNERPOINT 5097.90139317513,113.21932554245 5097.90139317513,113.21932554245 5097.90139317513,113.21932554245 PathPoint;PointKind.SMOOTHPOINT 5133.07500243187,113.215312957764 5144.74029421806,113.216965198517 5121.41466736794,113.213424682617 PathPoint;PointKind.SMOOTHPOINT 5166.47516727448,114.531440734863 5173.32677364349,114.517750740051 5155.06089806557,114.553864002228 PathPoint;PointKind.SMOOTHPOINT 5193.65287542343,112.270231246948 5197.27022051811,112.268342971802 5186.93333029747,112.273299694061 PathPoint;PointKind.SMOOTHPOINT 5213.45002412796,113.303117752075 5229.36570525169,113.309490680695 5209.87516522408,113.301701545715 PathPoint;PointKind.SMOOTHPOINT 5260.29140353203,112.515943050385 5380.23275256157,113.132936954498 5245.34192919731,112.438759803772 PathPoint;PointKind.SMOOTHPOINT 5474.87109661102,114.531440734863 5478.25830817223,114.60390329361 5412.03862309456,113.185336589813 PathPoint;PointKind.SMOOTHPOINT 5496.58189415932,114.210669994354 5499.37571525574,114.273455142975 5493.14263701439,114.133014678955 PathPoint;PointKind.SMOOTHPOINT 5511.17023587227,111.175031661987 5517.90996193886,111.361262798309 5508.35021495819,111.097140312195 PathPoint;PointKind.SMOOTHPOINT 5528.66392493248,112.247807979584 5534.0865790844,112.712559700012 5521.44693732262,111.629161834717 PathPoint;PointKind.SMOOTHPOINT 5543.07311654091,111.237108707428 5550.77338457108,110.497376918793 5539.49294686317,111.581246852875 PathPoint;PointKind.SMOOTHPOINT 5555.71275830269,110.499737262726 5561.63710355759,110.281641483307 5550.24903416634,110.70107460022 PathPoint;PointKind.SMOOTHPOINT 5569.04704928398,115.499889850616 5581.56666755676,114.574871063232 5564.95492100716,115.802485942841 PathPoint;PointKind.SMOOTHPOINT 5624.04683947563,115.499889850616 5631.59805178642,116.388559341431 5612.67753481865,114.162282943726 PathPoint;PointKind.SMOOTHPOINT 5650.04697203636,117.50004529953 5651.23339891434,119.996817111969 5647.99878358841,113.190529346466 PathPoint;PointKind.SMOOTHPOINT 5650.82128286362,135.094285011292 5650.62513828278,139.493730068207 5651.11195921898,128.579971790314 PathPoint;PointKind.SMOOTHPOINT 5591,196 5596.8995616436,189.368377685547 5591,196 PathPoint;PointKind.CORNERPOINT 5604,3801 5604,3801 5604,3801 PathPoint;PointKind.SMOOTHPOINT 5650.04697203636,3838.50011587143 5649.50775146484,3838.81144523621 5652.49028205872,3837.08910226822 PathPoint;PointKind.SMOOTHPOINT 5648.04693460464,3844.50011014938 5645.45563101768,3845.8898806572 5650.14221191406,3843.37587833405 PathPoint";
	
} else if (mask_variant_35mm == 6) {
	
	mask35mm[0] = "PointKind.CORNERPOINT 305.659818649292,174.451603889465 305.659818649292,174.451603889465 305.659818649292,174.451603889465 PathPoint;PointKind.SMOOTHPOINT 316.464056968689,173.487167358398 318.100129365921,173.339409828186 308.505685329437,174.205420017242 PathPoint;PointKind.SMOOTHPOINT 324.32541847229,171.523361206055 348.622916936874,171.311638355255 322.509133815765,171.538939476013 PathPoint;PointKind.SMOOTHPOINT 451.053228378296,171.844367980957 455.444176197052,171.88095331192 397.593562602997,171.397082805634 PathPoint;PointKind.SMOOTHPOINT 464.795740842819,173.864586353302 472.536370754242,174.333350658417 460.325485467911,173.593854904175 PathPoint;PointKind.SMOOTHPOINT 480.509966611862,172.913131713867 493.312118053436,172.953021526337 476.18664264679,172.899677753448 PathPoint;PointKind.SMOOTHPOINT 518.996436595917,173.116121292114 585.534768104553,173.598103523254 506.177644729614,173.02312374115 PathPoint;PointKind.SMOOTHPOINT 689.687894582748,168.453733921051 694.276049137115,168.526196479797 641.013590097427,167.686622142792 PathPoint;PointKind.SMOOTHPOINT 703.504403829575,168.652238845825 710.455144643784,166.98205947876 697.738673686981,170.038468837738 PathPoint;PointKind.SMOOTHPOINT 725.036405324936,169.537603855133 733.48655462265,168.511090278625 717.729134559631,170.425329208374 PathPoint;PointKind.SMOOTHPOINT 747.621356248856,169.596140384674 751.725168228149,168.420925140381 738.77537727356,172.129969596863 PathPoint;PointKind.SMOOTHPOINT 762.471342086792,169.095747470856 766.183573007584,169.007942676544 757.353880405426,169.216597080231 PathPoint;PointKind.SMOOTHPOINT 781.988081932068,170.677649974823 824.836467504501,170.200152397156 778.089973926544,170.721080303192 PathPoint;PointKind.SMOOTHPOINT 943.028447628021,172.087955474854 1072.56494879723,174.982209205627 871.066399812698,170.480325222015 PathPoint;PointKind.SMOOTHPOINT 1323.54681015015,172.296845912933 1423.73845338821,172.572298049927 1223.35516691208,172.021157741547 PathPoint;PointKind.SMOOTHPOINT 1500.78786849976,173.536262512207 1513.76881599426,173.836734294891 1435.2451300621,172.01714515686 PathPoint;PointKind.SMOOTHPOINT 1535.50156474113,174.068284034729 1539.51898813248,173.360888957977 1524.12234663963,176.072216033936 PathPoint;PointKind.SMOOTHPOINT 1547.59101033211,174.115254878998 1552.14907050133,174.120683670044 1543.58350038528,174.110534191132 PathPoint;PointKind.SMOOTHPOINT 1561.39052510262,174.09684419632 1563.81294608116,173.516199588776 1556.83671355247,175.187795162201 PathPoint;PointKind.SMOOTHPOINT 1568.08316230774,173.57213973999 1570.54240465164,173.698182106018 1565.9744310379,173.463563919067 PathPoint;PointKind.SMOOTHPOINT 1575.57241559029,174.029102325439 1598.92211794853,173.896214962006 1572.92871236801,174.044208526611 PathPoint;PointKind.SMOOTHPOINT 1671.96508526802,173.805577754974 1688.93088340759,173.855381011963 1627.24058032036,173.673870563507 PathPoint;PointKind.SMOOTHPOINT 1730.56947469711,174.132721424103 1876.80446505547,175.287401676178 1708.25749754906,173.9564037323 PathPoint;PointKind.SMOOTHPOINT 2038.90840172768,174.933114051819 2058.90063285828,175.266630649567 1967.33439445496,173.739488124847 PathPoint;PointKind.SMOOTHPOINT 2098.99626731873,172.370960712433 2105.15570282936,172.371196746826 2079.61937785149,172.36930847168 PathPoint;PointKind.SMOOTHPOINT 2121.4275598526,173.134295940399 2127.06087470055,173.120369911194 2115.0726878643,173.150346279144 PathPoint;PointKind.SMOOTHPOINT 2134.98313307762,172.292833328247 2152.28421807289,172.23240852356 2129.10481452942,172.313132286072 PathPoint;PointKind.SMOOTHPOINT 2191.73229217529,172.137050628662 2198.28472495079,172.131621837616 2170.83333492279,172.155697345734 PathPoint;PointKind.SMOOTHPOINT 2213.73270392418,173.373870849609 2219.45559382439,173.380479812622 2206.68459892273,173.36608171463 PathPoint;PointKind.SMOOTHPOINT 2229.82647299767,172.175760269165 2243.48896980286,172.216358184814 2223.73643159866,172.157349586487 PathPoint;PointKind.SMOOTHPOINT 2273.93067955971,172.409906387329 2280.80600738525,172.462069988251 2258.12192201614,172.289764881134 PathPoint;PointKind.SMOOTHPOINT 2293.27251791954,173.580164909363 2297.91661262512,173.625247478485 2285.93621492386,173.509590625763 PathPoint;PointKind.SMOOTHPOINT 2309.31601166725,172.733273506165 2335.89537262917,173.004713058472 2304.57738518715,172.684886455536 PathPoint;PointKind.SMOOTHPOINT 2392.42395758629,173.649322986603 2400.19503593445,173.737127780914 2363.88952374458,173.326900005341 PathPoint;PointKind.SMOOTHPOINT 2415.0340461731,174.888739585876 2422.74174928665,174.973948001862 2407.20100879669,174.802114963531 PathPoint;PointKind.SMOOTHPOINT 2439.00935769081,174.163405895233 2454.15710091591,174.324853420258 2431.2754547596,174.081265926361 PathPoint;PointKind.SMOOTHPOINT 2484.38177704811,174.616827964783 2487.32217550278,174.643971920013 2469.32360887527,174.478511810303 PathPoint;PointKind.SMOOTHPOINT 2494.5795249939,173.110928535461 2503.03215265274,173.185279369354 2491.64797782898,173.085200786591 PathPoint;PointKind.SMOOTHPOINT 2518.39976191521,174.902901649475 2525.91981768608,174.959077835083 2510.05334973335,174.840116500854 PathPoint;PointKind.SMOOTHPOINT 2540.78573584557,175.055379867554 2545.06692767143,175.081343650818 2533.38747382164,175.010533332825 PathPoint;PointKind.SMOOTHPOINT 2554.48222160339,172.274186611176 2561.56891822815,172.310063838959 2550.25024294853,172.252707481384 PathPoint;PointKind.SMOOTHPOINT 2580.0104033947,173.332800865173 2586.83226943016,173.340353965759 2583.48258733749,173.337049484253 PathPoint;PointKind.SMOOTHPOINT 2599.71974730492,173.47583770752 2604.35499072075,173.535554409027 2593.38647246361,173.394169807434 PathPoint;PointKind.SMOOTHPOINT 2634.01884913445,173.4730052948 2657.18869328499,173.525640964508 2629.01326775551,173.461675643921 PathPoint;PointKind.SMOOTHPOINT 2691.95266485214,174.615411758423 2806.00648999214,173.237206935883 2670.84021449089,174.870564937592 PathPoint;PointKind.SMOOTHPOINT 3014.99995708466,174.000070095062 3123.41197013855,173.5400390625 2907.92944550514,174.454672336578 PathPoint;PointKind.SMOOTHPOINT 3344.8914206028,174.321076869965 3350.03260374069,174.267497062683 3272.49920010567,175.078511238098 PathPoint;PointKind.SMOOTHPOINT 3361.49325370789,174.249558448792 3367.13789820671,174.254279136658 3355.58590292931,174.245073795319 PathPoint;PointKind.SMOOTHPOINT 3377.29386806488,175.397629737854 3381.12541437149,175.429022312164 3371.05016827583,175.345938205719 PathPoint;PointKind.SMOOTHPOINT 3391.14507436752,174.454436302185 3406.38487100601,174.217457771301 3387.11773753166,174.517221450806 PathPoint;PointKind.SMOOTHPOINT 3440.40887475014,173.785042762756 3443.86512637138,174.096608161926 3436.95191502571,173.473949432373 PathPoint;PointKind.SMOOTHPOINT 3448.6950981617,173.689448833466 3457.17569589615,175.722885131836 3445.99085211754,173.041062355042 PathPoint;PointKind.SMOOTHPOINT 3467.14012384415,173.492596149445 3534.35327768326,172.815413475037 3460.93147516251,173.555381298065 PathPoint;PointKind.SMOOTHPOINT 3654.23585414886,173.137364387512 3697.52645015717,173.730518817902 3608.56815576553,172.511401176453 PathPoint;PointKind.SMOOTHPOINT 3877.40802526474,174.345624446869 3883.1996011734,174.356954097748 3786.18026018143,174.164350032806 PathPoint;PointKind.SMOOTHPOINT 3894.80364203453,174.376780986786 3902.35273003578,173.36254119873 3889.05278205872,175.149793624878 PathPoint;PointKind.SMOOTHPOINT 3912.04418420792,174.401800632477 3937.21654415131,174.433901309967 3906.30465388298,174.394719600677 PathPoint;PointKind.SMOOTHPOINT 3986.01264238358,174.43555355072 3990.49245715141,174.433665275574 3962.17257857323,174.445703029633 PathPoint;PointKind.SMOOTHPOINT 3999.89181876183,173.042242527008 3984.71008658409,173.053572177887 3995.49733042717,173.046019077301 PathPoint;PointKind.SMOOTHPOINT 4079.99988555908,174.000070095062 4102.58873105049,173.904240131378 4040.074903965,174.167890548706 PathPoint;PointKind.SMOOTHPOINT 4147.15957760811,174.880006313324 4150.99360227585,174.855694770813 4125.13544440269,175.017142295837 PathPoint;PointKind.SMOOTHPOINT 4158.65386247635,174.807307720184 4167.79228806496,174.629101753235 4154.82479453087,174.882366657257 PathPoint;PointKind.SMOOTHPOINT 4178.8666677475,174.680557250977 4185.33873081207,174.64019536972 4172.1272957325,174.722335338593 PathPoint;PointKind.SMOOTHPOINT 4198.30339193344,174.562304019928 4200.77325582504,174.547905921936 4191.81433439255,174.600541591644 PathPoint;PointKind.SMOOTHPOINT 4205.71794033051,174.519345760345 4212.62584090233,173.053336143494 4203.29693555832,175.033192634583 PathPoint;PointKind.SMOOTHPOINT 4219.15349006653,174.445466995239 4230.62723994255,174.385278224945 4214.66553211212,174.46907043457 PathPoint;PointKind.SMOOTHPOINT 4253.83142709732,174.288740158081 4257.92780399323,174.273633956909 4242.1707379818,174.33146238327 PathPoint;PointKind.SMOOTHPOINT 4266.16623044014,174.247670173645 4269.26736831665,175.521311759949 4261.79050683975,172.450268268585 PathPoint;PointKind.SMOOTHPOINT 4276.24218463898,174.220998287201 4287.07899570465,174.195742607117 4272.87196755409,174.229023456573 PathPoint;PointKind.SMOOTHPOINT 4309.15977716446,174.182288646698 4274.50131297112,174.182288646698 4298.03937077522,174.182052612305 PathPoint;PointKind.SMOOTHPOINT 4468.00006628036,174.999911785126 4586.17186546326,174.117379188538 4381.48933053017,175.64617395401 PathPoint;PointKind.SMOOTHPOINT 4769.84781146049,174.657189846039 4778.42117071152,174.623436927795 4678.35627794266,175.011949539185 PathPoint;PointKind.SMOOTHPOINT 4795.49566268921,174.556875228882 4806.98074221611,173.295979499817 4787.01471090317,175.487558841705 PathPoint;PointKind.SMOOTHPOINT 4819.69438076019,174.459865093231 4832.48024582863,174.40770149231 4811.63050174713,174.492437839508 PathPoint;PointKind.SMOOTHPOINT 4858.12491059303,174.296057224274 4880.98106503487,174.194326400757 4845.27212977409,174.353649616241 PathPoint;PointKind.SMOOTHPOINT 4931.80835723877,177.482285499573 4943.0806517601,177.588737010956 4908.85908722878,177.2660779953 PathPoint;PointKind.SMOOTHPOINT 4962.25219130516,176.569068431854 4964.76914405823,176.567652225494 4951.39201283455,176.57520532608 PathPoint;PointKind.SMOOTHPOINT 4972.49632000923,177.6154088974 4975.96637964249,177.605967521667 4969.99671578407,177.622017860413 PathPoint;PointKind.SMOOTHPOINT 4982.87605047226,175.630595684052 4994.81396198273,175.564033985138 4979.43643927574,175.64971446991 PathPoint;PointKind.SMOOTHPOINT 5018.26209068298,177.214386463165 5022.08443164825,177.159626483917 5006.56776666641,177.381498813629 PathPoint;PointKind.SMOOTHPOINT 5045.00077486038,176.760728359222 5050.85785031319,176.646959781647 5039.7781598568,176.861987113953 PathPoint;PointKind.SMOOTHPOINT 5062.58191466331,176.396527290344 5066.40248537064,176.312499046326 5056.71421766281,176.524930000305 PathPoint;PointKind.SMOOTHPOINT 5074.19409871101,177.851915359497 5077.48430013657,177.775912284851 5070.36042809486,177.940900325775 PathPoint;PointKind.SMOOTHPOINT 5083.95140647888,175.903923511505 5091.55608057976,175.721232891083 5080.64739704132,175.982995033264 PathPoint;PointKind.SMOOTHPOINT 5113.48072528839,174.977488517761 5157.40330338478,173.874499797821 5105.76558709145,175.171036720276 PathPoint;PointKind.SMOOTHPOINT 5249.98248338699,172.355146408081 5253.91741275787,172.306051254272 5196.96467399597,173.011794090271 PathPoint;PointKind.SMOOTHPOINT 5261.75894737244,175.362224578857 5267.72861123085,175.293066501617 5258.00493836403,175.40589094162 PathPoint;PointKind.SMOOTHPOINT 5279.44240808487,172.431621551514 5288.89700174332,172.335555553436 5273.9050412178,172.487561702728 PathPoint;PointKind.SMOOTHPOINT 5303.00666570663,173.485043048859 5307.34379768372,173.454358577728 5294.69530463219,173.5435795784 PathPoint;PointKind.SMOOTHPOINT 5318.71522665024,174.518165588379 5322.79779553413,174.497394561768 5314.65991973877,174.538700580597 PathPoint;PointKind.SMOOTHPOINT 5335.41406989098,172.5767827034 5417.27221369743,172.344052791595 5331.5952694416,172.587876319885 PathPoint;PointKind.SMOOTHPOINT 5511.18475198746,174.02556180954 5519.76590037346,173.920526504517 5439.50169682503,174.900777339935 PathPoint;PointKind.SMOOTHPOINT 5534.48948979378,173.71258020401 5541.48873567581,173.610141277313 5527.49661684036,173.8152551651 PathPoint;PointKind.SMOOTHPOINT 5553.38451504707,173.419189453125 5562.28749632835,171.406996250153 5547.88432359695,174.662146568298 PathPoint;PointKind.SMOOTHPOINT 5566.33713841438,173.206050395966 5602.43411421776,172.615256309509 5562.4163711071,173.270015716553 PathPoint;PointKind.SMOOTHPOINT 5631.96414113045,175.331540107727 5646.3832461834,176.848297119141 5606.76876783371,172.68016576767 PathPoint;PointKind.SMOOTHPOINT 5671.29112958908,186.304070949554 5673.97731900215,188.673620223999 5663.50978374481,179.440190792084 PathPoint;PointKind.SMOOTHPOINT 5672.14899659157,201.846699714661 5671.95214390755,206.135680675507 5672.41205692291,196.089820861816 PathPoint;PointKind.SMOOTHPOINT 5672.98030972481,211.133944988251 5675.59427261353,216.561319828033 5671.99179768562,209.081389904022 PathPoint;PointKind.SMOOTHPOINT 5672.24813103676,291.319313049316 5672.40993261337,298.001210689545 5671.26315951347,250.556645393372 PathPoint;PointKind.SMOOTHPOINT 5672.43754863739,321.171998977661 5669.54105257988,521.191792488098 5672.54482626915,313.784830570221 PathPoint;PointKind.SMOOTHPOINT 5669.93015527725,960.324339866638 5671.15588188171,978.512914180756 5668.96040797234,945.930018424988 PathPoint;PointKind.SMOOTHPOINT 5671.97763562202,1012.87078857422 5670.78908443451,1038.94928455353 5674.0460050106,967.482082843781 PathPoint;PointKind.SMOOTHPOINT 5675.43742775917,1110.17195463181 5675.39954423904,1137.4683880806 5675.48841118813,1073.30833911896 PathPoint;PointKind.SMOOTHPOINT 5674.43758606911,1175.17181396484 5674.53955292702,1191.14048480988 5674.36429738998,1163.57591629028 PathPoint;PointKind.SMOOTHPOINT 5675.43742775917,1244.17198419571 5675.47495722771,1261.58353328705 5675.37830114365,1216.23495340347 PathPoint;PointKind.SMOOTHPOINT 5674.43758606911,1299.17201042175 5674.62275505066,1312.96987295151 5674.30446267128,1289.29751157761 PathPoint;PointKind.SMOOTHPOINT 5674.43758606911,1396.17199659348 5672.31433868408,1423.47267866135 5674.74702715874,1392.19080448151 PathPoint;PointKind.SMOOTHPOINT 5670.83050847054,1466.29285812378 5670.64958810806,1485.50487756729 5671.01921796799,1446.1940574646 PathPoint;PointKind.SMOOTHPOINT 5671.30954027176,1656.80093765259 5671.55206561089,1670.43711662292 5669.82146143913,1573.21785449982 PathPoint;PointKind.SMOOTHPOINT 5675.15347838402,1688.56196165085 5676.77397251129,1747.21462011337 5674.79022145271,1675.42405128479 PathPoint;PointKind.SMOOTHPOINT 5674.75764870644,1838.38668107986 5673.04510116577,1907.75506496429 5675.40131449699,1812.29638338089 PathPoint;PointKind.SMOOTHPOINT 5673.94297599792,2146.96530103683 5672.41772174835,2183.99956941605 5675.46752214432,2109.93150472641 PathPoint;PointKind.SMOOTHPOINT 5675.01575231552,2307.17199325562 5675.4399061203,2345.92671632767 5674.64506030083,2273.26588869095 PathPoint;PointKind.SMOOTHPOINT 5672.1373128891,2431.39288187027 5667.86497235298,2458.79222631454 5677.44242191315,2397.35955476761 PathPoint;PointKind.SMOOTHPOINT 5671.90186858177,2547.81826257706 5670.99478840828,2565.21848201752 5672.14970469475,2543.05650472641 PathPoint;PointKind.SMOOTHPOINT 5672.67936587334,2625.2134680748 5673.66752386093,2643.16789627075 5671.12507939339,2596.97360515594 PathPoint;PointKind.SMOOTHPOINT 5676.47656917572,2674.83427047729 5676.81681275368,2689.88429546356 5676.04816675186,2655.91894626617 PathPoint;PointKind.SMOOTHPOINT 5673.41260671616,2719.47639942169 5673.75285029411,2734.11973714828 5673.08864951134,2705.52558660507 PathPoint;PointKind.SMOOTHPOINT 5674.01555657387,2765.17194986343 5670.98770737648,2830.89903116226 5674.61709022522,2752.1142911911 PathPoint;PointKind.SMOOTHPOINT 5674.01555657387,2898.17190170288 5672.63156890869,2926.39429807663 5675.54789185524,2866.89238786697 PathPoint;PointKind.SMOOTHPOINT 5675.54682970047,2980.29700040817 5676.46807193756,2989.72020149231 5673.66752386093,2961.07789993286 PathPoint;PointKind.SMOOTHPOINT 5676.49745821953,3021.15124940872 5675.74368238449,3084.1915512085 5676.86956644058,2990.0874710083 PathPoint;PointKind.SMOOTHPOINT 5676.50666356087,3407.0943903923 5675.80634951591,3425.13827562332 5676.52507424355,3406.61901712418 PathPoint;PointKind.SMOOTHPOINT 5675.54682970047,3693.29694986343 5675.67712068558,3726.53200864792 5675.47460317612,3674.72009897232 PathPoint;PointKind.SMOOTHPOINT 5672.54695057869,3755.29704809189 5671.59171938896,3763.10648202896 5674.11256670952,3742.4954867363 PathPoint;PointKind.SMOOTHPOINT 5667.54703402519,3776.29702806473 5661.47858977318,3778.27594041824 5671.99569225311,3774.84659671783 PathPoint;PointKind.SMOOTHPOINT 5650.54689288139,3787.29693889618 5641.78517818451,3788.19268941879 5660.61257958412,3786.26830101013 PathPoint;PointKind.SMOOTHPOINT 5601.5468609333,3787.29693889618 5558.11322808266,3787.90189504623 5621.68885588646,3787.01676607132 PathPoint;PointKind.SMOOTHPOINT 5095.1075720787,3785.62699556351 5033.90267372131,3785.48348665237 5156.31176233292,3785.77050447464 PathPoint;PointKind.SMOOTHPOINT 4480.29167532921,3787.20771789551 4402.68569111824,3786.82014942169 4557.89765954018,3787.59528636932 PathPoint;PointKind.SMOOTHPOINT 4033.90413880348,3787.20771789551 4024.96469020844,3787.49874830246 4083.69760036469,3785.5849814415 PathPoint;PointKind.SMOOTHPOINT 4004.11352992058,3791.7244720459 3981.90316557884,3792.5678229332 4011.43637895584,3791.44665956497 PathPoint;PointKind.SMOOTHPOINT 3945.20076155663,3787.58726119995 3936.53711915016,3788.20897579193 3962.29401826859,3786.36059045792 PathPoint;PointKind.SMOOTHPOINT 3918.67946505547,3790.49520492554 3912.66200423241,3790.6271481514 3929.99920248985,3790.24642467499 PathPoint;PointKind.SMOOTHPOINT 3889.97331619263,3790.69182157516 3878.3692753315,3790.69607019424 3902.72837877274,3790.68686485291 PathPoint;PointKind.SMOOTHPOINT 3852.89561748505,3787.34792232513 3846.07233524323,3785.60079574585 3865.07959485054,3790.46664476395 PathPoint;PointKind.SMOOTHPOINT 3827.00028419495,3790.46216011047 3744.77605104446,3789.96861219406 3834.5879638195,3790.50795078278 PathPoint;PointKind.SMOOTHPOINT 3596.59625530243,3788.66641044617 3538.47585439682,3788.40724468231 3634.89614009857,3788.83753538132 PathPoint;PointKind.SMOOTHPOINT 3461.08371734619,3788.31471920013 3447.72499680519,3788.05885791779 3495.61967968941,3788.97797584534 PathPoint;PointKind.SMOOTHPOINT 3388.41533660889,3789.11865234375 3389.16203141212,3789.1061425209 3387.66864180565,3789.1311621666 PathPoint;PointKind.SMOOTHPOINT 3353.06930422783,3787.0420217514 3344.37910795212,3783.21425199509 3362.46583342552,3791.1811208725 PathPoint;PointKind.SMOOTHPOINT 3325.9999358654,3787.17207670212 3320.96426010132,3787.17821359634 3338.71463656425,3787.15720653534 PathPoint;PointKind.SMOOTHPOINT 3303.32505583763,3789.11416769028 3292.5360417366,3789.13139820099 3308.51793050766,3789.10590648651 PathPoint;PointKind.SMOOTHPOINT 3279.42692756653,3784.86672878265 3272.6248884201,3785.44406890869 3293.29619050026,3783.68915319443 PathPoint;PointKind.SMOOTHPOINT 3253.00016283989,3787.17207670212 3247.62920022011,3787.18623876572 3261.03111505508,3787.15059757233 PathPoint;PointKind.SMOOTHPOINT 3233.00014257431,3785.1719212532 3226.3142323494,3785.19080400467 3238.44120740891,3785.15657901764 PathPoint;PointKind.SMOOTHPOINT 3209.86889004707,3789.34241294861 3205.98352789879,3789.35374259949 3216.63339972496,3789.32187795639 PathPoint;PointKind.SMOOTHPOINT 3193.99994373322,3786.17199897766 3186.49511218071,3786.19513034821 3197.90407061577,3786.1599612236 PathPoint;PointKind.SMOOTHPOINT 3168.45901608467,3788.56255531311 3165.31149744987,3788.59158754349 3176.01376891136,3788.49386930466 PathPoint;PointKind.SMOOTHPOINT 3157.99997806549,3787.17184066772 3154.68853354454,3787.20512151718 3161.136521101,3787.14044809341 PathPoint;PointKind.SMOOTHPOINT 3148.81410956383,3790.4963850975 3141.58933281898,3790.5917429924 3152.110683918,3790.45271873474 PathPoint;PointKind.SMOOTHPOINT 3127.27113246918,3790.76782464981 3123.2409632206,3790.81644773483 3134.40385580063,3790.68238019943 PathPoint;PointKind.SMOOTHPOINT 3113.9998626709,3787.17184066772 3112.08621382713,3787.19355583191 3117.9939186573,3787.1267580986 PathPoint;PointKind.SMOOTHPOINT 3101.00015044212,3787.17184066772 3094.53552246094,3787.26294994354 3102.90423989296,3787.14469671249 PathPoint;PointKind.SMOOTHPOINT 3086.00004673004,3789.17199611664 3082.71798849106,3789.21542644501 3092.25507616997,3789.08796787262 PathPoint;PointKind.SMOOTHPOINT 3072.23133444786,3786.32848978043 3069.48672652245,3786.36389493942 3075.45426607132,3786.2869477272 PathPoint;PointKind.SMOOTHPOINT 3059.45750713348,3789.2720746994 3051.43576025963,3789.40944671631 3062.15927481651,3789.22581195831 PathPoint;PointKind.SMOOTHPOINT 3028.04250955582,3786.21377706528 3017.13701248169,3786.42597198486 3035.56964635849,3786.06719970703 PathPoint;PointKind.SMOOTHPOINT 2989.74014639854,3788.09874773026 2982.4236702919,3787.58513689041 3000.27353525162,3788.8382434845 PathPoint;PointKind.SMOOTHPOINT 2972.99987912178,3787.17184066772 2964.31393146515,3787.67128944397 2978.94015669823,3786.83006286621 PathPoint;PointKind.SMOOTHPOINT 2952.41744399071,3790.97860336304 2952.3190176487,3791.43816232681 2952.69502043724,3789.68324661255 PathPoint;PointKind.SMOOTHPOINT 2943.31619381905,3791.52927160263 2941.58417344093,3791.57010555267 2949.48164820671,3791.38411045074 PathPoint;PointKind.SMOOTHPOINT 2937.69845724106,3786.9716835022 2933.39460611343,3787.04343795776 2939.72327828407,3786.93745851517 PathPoint;PointKind.SMOOTHPOINT 2923.99984717369,3789.17199611664 2916.71558976173,3790.57828903198 2928.78839492798,3788.24768543243 PathPoint;PointKind.SMOOTHPOINT 2905.00002264977,3788.99992704391 2904.30254101753,3788.76554489136 2905.697504282,3789.23430919647 PathPoint;PointKind.SMOOTHPOINT 2820.84125161171,3787.66043186188 2807.50306606293,3787.69725322723 2836.61814451218,3787.61487722397 PathPoint;PointKind.SMOOTHPOINT 2752.00016856194,3785.99992990494 2752.19383478165,3784.63423490524 2751.80614829063,3787.36562490463 PathPoint;PointKind.SMOOTHPOINT 2741.00013971329,3788.17191839218 2737.15230703354,3788.51676464081 2744.90462064743,3787.82235145569 PathPoint;PointKind.SMOOTHPOINT 2728.00007343292,3790.1718378067 2724.76475000381,3790.35736083984 2732.11061239243,3789.93627548218 PathPoint;PointKind.SMOOTHPOINT 2719.68977451324,3790.37435531616 2716.02144598961,3790.44610977173 2723.22497963905,3790.30519723892 PathPoint;PointKind.SMOOTHPOINT 2703.99997830391,3789.17199611664 2698.86198163033,3789.04713392258 2708.12397122383,3789.2723107338 PathPoint;PointKind.SMOOTHPOINT 2693.17945361137,3789.31338071823 2688.51411581039,3789.13234233856 2697.88763165474,3789.49583530426 PathPoint;PointKind.SMOOTHPOINT 2678.75255942345,3787.28018045425 2674.46959733963,3787.05523967743 2683.04047822952,3787.50488519669 PathPoint;PointKind.SMOOTHPOINT 2667.00017094612,3790.1718378067 2663.03585529327,3789.9143242836 2670.94997048378,3790.42817115784 PathPoint;PointKind.SMOOTHPOINT 2654.00010466576,3790.1718378067 2649.14534926414,3789.80598449707 2657.67409801483,3790.44823408127 PathPoint;PointKind.SMOOTHPOINT 2640.15314698219,3789.17577266693 2634.97974514961,3788.3123588562 2644.54657316208,3789.90889549255 PathPoint;PointKind.SMOOTHPOINT 2623.99989724159,3788.17191839218 2620.73129296303,3787.57121086121 2628.72400760651,3789.04052495956 PathPoint;PointKind.SMOOTHPOINT 2603.99987697601,3788.17191839218 2591.58966064453,3784.76924657822 2607.0737528801,3789.0145611763 PathPoint;PointKind.SMOOTHPOINT 2581.30977272987,3784.07742977142 2578.85902762413,3784.11401510239 2594.33993339539,3783.88104915619 PathPoint;PointKind.SMOOTHPOINT 2574.42559361458,3788.02840948105 2570.2895629406,3788.27955007553 2576.59557580948,3787.89670228958 PathPoint;PointKind.SMOOTHPOINT 2547.99989104271,3788.17191839218 2532.66591668129,3790.02148389816 2551.32939219475,3787.77042388916 PathPoint;PointKind.SMOOTHPOINT 2524.2748939991,3790.85916996002 2519.72249865532,3791.02982282639 2536.16996526718,3790.41377305984 PathPoint;PointKind.SMOOTHPOINT 2501.69525384903,3788.81629228592 2491.89262747765,3788.56444358826 2509.93686676025,3789.02801513672 PathPoint;PointKind.SMOOTHPOINT 2475.0001180172,3788.17191839218 2465.64501285553,3787.16853618622 2482.69578337669,3788.99733066559 PathPoint;PointKind.SMOOTHPOINT 2453.99990200996,3788.17191839218 2446.70431494713,3789.13069009781 2459.72739458084,3787.41944074631 PathPoint;PointKind.SMOOTHPOINT 2435.00007748604,3788.17191839218 2433.13882827759,3788.07915687561 2446.74538493156,3788.75751972198 PathPoint;PointKind.SMOOTHPOINT 2419.00013208389,3788.17191839218 2412.56559848785,3787.98969984055 2423.46826314926,3788.29866886139 PathPoint;PointKind.SMOOTHPOINT 2401.00014925003,3790.1718378067 2397.18134880066,3790.0908780098 2412.03452110291,3790.40527582169 PathPoint;PointKind.SMOOTHPOINT 2388.99992465973,3786.17199897766 2384.27262783051,3786.07852935791 2393.29315423965,3786.25744342804 PathPoint;PointKind.SMOOTHPOINT 2368.99990439415,3788.17191839218 2363.04511070251,3788.06074619293 2374.25155162811,3788.26987266541 PathPoint;PointKind.SMOOTHPOINT 2352.999958992,3783.17200183868 2347.46507048607,3783.27491283417 2359.58673477173,3783.04997205734 PathPoint;PointKind.SMOOTHPOINT 2333.77070903778,3785.34233808517 2326.51973247528,3785.22196054459 2339.65610861778,3785.44052839279 PathPoint;PointKind.SMOOTHPOINT 2314.0001142025,3784.17184352875 2304.13234233856,3784.48836565018 2321.55982375145,3783.92943620682 PathPoint;PointKind.SMOOTHPOINT 2280.74121594429,3786.19678258896 2267.52553224564,3785.98694801331 2291.52208685875,3786.3683795929 PathPoint;PointKind.SMOOTHPOINT 2234.58846688271,3786.07687711716 2124.87708449364,3790.51007509232 2248.51154565811,3785.5144071579 PathPoint;PointKind.SMOOTHPOINT 1938.03060650826,3786.29945755005 1815.2671122551,3788.284034729 1995.15930891037,3785.37609100342 PathPoint;PointKind.SMOOTHPOINT 1520.68238139153,3789.18497800827 1497.70266294479,3789.55507993698 1615.96899390221,3787.64933824539 PathPoint;PointKind.SMOOTHPOINT 1413.30030441284,3786.93604230881 1411.45711183548,3786.94406747818 1447.75979161263,3786.78616046906 PathPoint;PointKind.SMOOTHPOINT 1396.93391561508,3786.85815095901 1376.85033917427,3782.91920900345 1398.65566849709,3787.19615221024 PathPoint;PointKind.SMOOTHPOINT 1375.59168577194,3787.14233636856 1375.2578151226,3787.38757610321 1375.92555642128,3786.89709663391 PathPoint;PointKind.SMOOTHPOINT 1302.5363266468,3787.00496435165 1294.72665667534,3786.97309970856 1327.47855305672,3787.1057510376 PathPoint;PointKind.SMOOTHPOINT 1279.00251746178,3786.8937921524 1274.19768333435,3788.60102891922 1287.72599458694,3783.79395246506 PathPoint;PointKind.SMOOTHPOINT 1263.69828343391,3786.80433511734 1212.21989035606,3786.48144006729 1268.80653977394,3786.83667182922 PathPoint;PointKind.SMOOTHPOINT 1112.16455698013,3785.12683868408 1050.65340399742,3785.67609071732 1160.18953084946,3784.69796419144 PathPoint;PointKind.SMOOTHPOINT 918.07736992836,3786.1283326149 912.826784849167,3786.14013433456 984.610390663147,3785.97797870636 PathPoint;PointKind.SMOOTHPOINT 899.076837301254,3784.57381010056 891.877552270889,3784.58750009537 904.332025051117,3784.56366062164 PathPoint;PointKind.SMOOTHPOINT 880.719616413116,3786.19796276093 868.368880748749,3786.21590137482 887.917839288712,3786.18757724762 PathPoint;PointKind.SMOOTHPOINT 843.720517158508,3786.23903274536 838.744322061539,3786.24280929565 856.02735042572,3786.22959136963 PathPoint;PointKind.SMOOTHPOINT 828.3755671978,3784.39017534256 825.012431144714,3784.39206361771 833.338662385941,3784.38757896423 PathPoint;PointKind.SMOOTHPOINT 818.732618093491,3786.25319480896 806.8308198452,3786.25767946243 822.087610960007,3786.25225067139 PathPoint;PointKind.SMOOTHPOINT 783.198938369751,3786.25697135925 771.413623094559,3786.2553191185 794.978234767914,3786.2588596344 PathPoint;PointKind.SMOOTHPOINT 744.904718399048,3785.16554832458 737.982655763626,3785.179002285 756.435824632645,3785.1438331604 PathPoint;PointKind.SMOOTHPOINT 722.000058889389,3787.17184066772 718.345892429352,3787.17349290848 728.788644075394,3787.169008255 PathPoint;PointKind.SMOOTHPOINT 702.00003862381,3786.17199897766 685.921493768692,3786.16586208344 705.611718893051,3786.17341518402 PathPoint;PointKind.SMOOTHPOINT 663.393191099167,3787.93045520782 542.222574949265,3787.33328819275 678.495969772339,3788.0052781105 PathPoint;PointKind.SMOOTHPOINT 429.709228277206,3787.31346130371 426.287319660187,3787.2433590889 493.185367584229,3788.61660718918 PathPoint;PointKind.SMOOTHPOINT 415.967069864273,3785.29347896576 413.144570589066,3785.23258209229 419.441378116608,3785.36877393723 PathPoint;PointKind.SMOOTHPOINT 401.229318380356,3788.23187112808 394.420906305313,3788.05177688599 404.078017473221,3788.30740213394 PathPoint;PointKind.SMOOTHPOINT 383.556479215622,3787.19355583191 378.078238964081,3786.74367427826 390.847463607788,3787.79261112213 PathPoint;PointKind.SMOOTHPOINT 369.000002145767,3788.17191839218 361.220426559448,3788.88781070709 372.616639137268,3787.83887386322 PathPoint;PointKind.SMOOTHPOINT 357.046158313751,3786.13281726837 351.060916185379,3786.34406805038 362.565468549728,3785.93832492828 PathPoint;PointKind.SMOOTHPOINT 342.547037601471,3787.29693889618 329.899252653122,3788.1924533844 346.681298017502,3787.00425624847 PathPoint;PointKind.SMOOTHPOINT 292.547163963318,3788.29701662064 284.918414354324,3787.43690729141 304.032951593399,3789.59190130234 PathPoint;PointKind.SMOOTHPOINT 276.000208854675,3784.17184352875 273.991674184799,3780.12243747711 278.069286346436,3788.34327936172 PathPoint;PointKind.SMOOTHPOINT 266.547031402588,3770.29679775238 264.887237548828,3766.44542455673 267.445614337921,3772.38381385803 PathPoint;PointKind.CORNERPOINT 263.923509120941,3739.33852672577 263.923509120941,3739.33852672577 263.923509120941,3739.33852672577 PathPoint;PointKind.SMOOTHPOINT 264.681179523468,1965.24690628052 265.968157052994,1933.06196451187 262.611039876938,2017.02293872833 PathPoint;PointKind.SMOOTHPOINT 263.546798229218,1851.29681825638 263.574414253235,1849.25087213516 263.00509929657,1891.14036798477 PathPoint;PointKind.SMOOTHPOINT 265.968157052994,1840.24025917053 266.404348611832,1824.09951925278 265.911508798599,1842.33105182648 PathPoint;PointKind.SMOOTHPOINT 266.062334775925,1804.52070236206 266.132436990738,1800.32188653946 265.890265703201,1814.86089706421 PathPoint;PointKind.SMOOTHPOINT 264.14302110672,1787.64825582504 264.201439619064,1785.13496160507 264.073626995087,1790.63243865967 PathPoint;PointKind.SMOOTHPOINT 265.148527622223,1778.72049093246 265.225710868835,1775.8257651329 265.011155605316,1783.85022640228 PathPoint;PointKind.SMOOTHPOINT 264.818905591965,1762.12939739227 265.053287744522,1753.57031822205 264.724373817444,1765.57549953461 PathPoint;PointKind.SMOOTHPOINT 265.642429590225,1732.20070838928 265.856276750565,1724.4233751297 265.333342552185,1743.43594551086 PathPoint;PointKind.SMOOTHPOINT 270.236603021622,1711.26256942749 270.096044540405,1709.04951095581 271.411346197128,1729.79056119919 PathPoint;PointKind.SMOOTHPOINT 266.504191160202,1700.72457790375 266.599076986313,1697.22324371338 266.442586183548,1702.98673152924 PathPoint;PointKind.SMOOTHPOINT 267.439949512482,1654.69857931137 267.880035638809,1635.77829837799 267.221145629883,1664.10478591919 PathPoint;PointKind.SMOOTHPOINT 268.829956054688,1598.39210271835 268.937587738037,1594.18266534805 268.366148471832,1616.59955978394 PathPoint;PointKind.SMOOTHPOINT 272.525546550751,1588.23318243027 273.617087602615,1545.34620523453 272.421455383301,1592.32342243195 PathPoint;PointKind.SMOOTHPOINT 265.80246090889,1500.94412326813 265.391052961349,1486.83162689209 266.11154794693,1511.54277563095 PathPoint;PointKind.SMOOTHPOINT 267.957572937012,1428.51744174957 263.499001264572,1400.66255092621 272.252218723297,1455.34935951233 PathPoint;PointKind.SMOOTHPOINT 264.546993970871,1359.29681539536 264.598331451416,1354.24638748169 264.368197917938,1376.92952871323 PathPoint;PointKind.SMOOTHPOINT 264.358638525009,1334.20305490494 264.56221818924,1329.80974674225 263.715680837631,1348.06535482407 PathPoint;PointKind.SMOOTHPOINT 264.106907844543,1313.65295648575 264.578858613968,1304.06972408295 263.857301473618,1318.72793197632 PathPoint;PointKind.SMOOTHPOINT 268.412175178528,1286.58689260483 269.068940877914,1274.06786441803 267.808163166046,1298.09616565704 PathPoint;PointKind.SMOOTHPOINT 267.86941409111,1241.88268661499 271.726452112198,1170.8863735199 267.109619379044,1255.86678028107 PathPoint;PointKind.SMOOTHPOINT 267.97138094902,1043.53000402451 268.316581249237,1029.66794013977 266.852577924728,1088.55852127075 PathPoint;PointKind.SMOOTHPOINT 270.019569396973,1011.78408622742 270.246516466141,1000.73106765747 269.949467182159,1015.20280838013 PathPoint;PointKind.SMOOTHPOINT 269.103283882141,986.976399421692 265.650218725204,977.94501543045 272.259653806686,995.231938362122 PathPoint;PointKind.SMOOTHPOINT 263.395264148712,955.171709060669 263.52130651474,952.531428337097 263.00509929657,963.334722518921 PathPoint;PointKind.SMOOTHPOINT 265.192075967789,922.619969844818 265.576930046082,915.758450031281 264.179134368896,940.669519901276 PathPoint;PointKind.SMOOTHPOINT 270.410796403885,901.609604358673 271.554737091064,878.912537097931 269.983102083206,910.095276832581 PathPoint;PointKind.SMOOTHPOINT 268.244000673294,868.462586402893 272.919251918793,785.699486732483 267.616267204285,879.5734333992 PathPoint;PointKind.SMOOTHPOINT 276.091200113297,609.9112200737 276.296550035477,591.85152053833 275.394780635834,671.187872886658 PathPoint;PointKind.SMOOTHPOINT 275.22164940834,567.243282794952 276.080224514008,549.116077423096 274.977707862854,572.396621704102 PathPoint;PointKind.SMOOTHPOINT 274.785103797913,426.646564006805 275.110477209091,418.79842042923 272.298953533173,486.545011997223 PathPoint;PointKind.SMOOTHPOINT 271.60218000412,410.485997200012 270.689435005188,404.091353416443 272.566616535187,417.242953777313 PathPoint;PointKind.SMOOTHPOINT 271.667679548264,385.68067073822 271.836208105087,382.064151763916 271.351511478424,392.479877471924 PathPoint;PointKind.SMOOTHPOINT 274,366 275.212980747223,340.990267753601 273.831471443176,369.461680412292 PathPoint;PointKind.SMOOTHPOINT 269,314 269.267004556882,273.019236564636 268.928498649332,324.916081528495 PathPoint;PointKind.SMOOTHPOINT 272.972005605698,193.203356266022 273.421651124954,189.689748287201 269.949467182159,216.845977306366 PathPoint;PointKind.SMOOTHPOINT 275.999854803085,183.171894550323 276.544740200043,182.870478630066 273.531407117844,184.537825584412 PathPoint;PointKind.SMOOTHPOINT 278.546901941299,177.296998500824 282.098747491837,173.344838619232 276.979515552521,179.041056632996 PathPoint";
	
	mask35mm[1] = "PointKind.CORNERPOINT 305.189992285809,174.264178502004 305.189992285809,174.264178502004 305.189992285809,174.264178502004 PathPoint;PointKind.SMOOTHPOINT 314.391651547254,171.999604246398 315.928979051705,171.420892826414 310.064687145618,173.628587207544 PathPoint;PointKind.SMOOTHPOINT 323.854960975853,171.335927038815 348.151604305649,171.124220618045 322.038634375706,171.351504099875 PathPoint;PointKind.SMOOTHPOINT 450.5789702828,171.65690890308 454.970019502101,171.693491394963 397.12090243685,171.209658437799 PathPoint;PointKind.SMOOTHPOINT 464.321091984843,173.677206519336 472.06154659155,174.145934447594 459.851087437699,173.406496079401 PathPoint;PointKind.SMOOTHPOINT 480.034972524356,172.725825714298 492.836711487611,172.765712431254 475.711902780148,172.712372797928 PathPoint;PointKind.SMOOTHPOINT 518.520206921262,172.92879954023 585.056888467564,173.410744368781 505.701827149,172.835809206024 PathPoint;PointKind.SMOOTHPOINT 689.206755206841,168.266301945703 693.795015715867,168.338758881239 640.533805099874,167.499013680463 PathPoint;PointKind.SMOOTHPOINT 703.022875400003,168.464791466179 709.973422668516,166.794505691616 697.25736616866,169.850913884435 PathPoint;PointKind.SMOOTHPOINT 724.554311956476,169.350087769751 733.004302334468,168.323653852332 717.247226503489,170.237980250166 PathPoint;PointKind.SMOOTHPOINT 747.138722257362,169.408619756764 751.242274946581,168.233495711046 738.292893060859,171.942488355845 PathPoint;PointKind.SMOOTHPOINT 761.988342907799,168.908265674233 765.700305495701,168.820467693713 756.87076304844,169.029105905486 PathPoint;PointKind.SMOOTHPOINT 781.504471275573,170.490281436122 824.351367931192,170.012820913028 777.606273250696,170.533708394229 PathPoint;PointKind.SMOOTHPOINT 942.540058456514,171.900477494199 1072.07282388801,174.794978658424 870.580243472698,170.29297199603 PathPoint;PointKind.SMOOTHPOINT 1323.04738097586,172.109351722047 1423.23638111166,172.385018499593 1222.85873489983,171.833684944502 PathPoint;PointKind.SMOOTHPOINT 1500.28332681495,173.348908156695 1513.26386596009,173.64935662229 1434.74261539072,171.829672671199 PathPoint;PointKind.SMOOTHPOINT 1534.99605440395,173.880888393499 1539.01357057,173.173548211732 1523.61728164069,175.884900900466 PathPoint;PointKind.SMOOTHPOINT 1547.08507105802,173.927855592755 1551.64323648693,173.933283962519 1543.07782262519,173.923135271222 PathPoint;PointKind.SMOOTHPOINT 1560.88419638241,173.909446338776 1563.30667330214,173.328846790178 1556.33063373046,175.0005486612 PathPoint;PointKind.SMOOTHPOINT 1567.57663408143,173.384782600348 1570.03593321683,173.510815185287 1565.46820817424,173.276215205082 PathPoint;PointKind.SMOOTHPOINT 1575.0657062542,173.841709724772 1598.41488564988,173.70883267361 1572.42229604042,173.856814753679 PathPoint;PointKind.SMOOTHPOINT 1671.45564509963,173.61820250017 1688.42112691235,173.668001892347 1626.73258574339,173.486505529391 PathPoint;PointKind.SMOOTHPOINT 1730.05820134717,173.945320782429 1876.28913346797,175.100147445553 1707.74712518572,173.769016773159 PathPoint;PointKind.SMOOTHPOINT 2038.3883161863,174.745887314478 2058.37994681996,175.079378030806 1966.81655070615,173.552117998704 PathPoint;PointKind.SMOOTHPOINT 2098.47438285384,172.18346077012 2104.63396060486,172.183696786197 2079.09810809368,172.181808657584 PathPoint;PointKind.SMOOTHPOINT 2120.90513121623,172.946972778133 2126.53822209505,172.93304782961 2114.55046653408,172.963021871347 PathPoint;PointKind.SMOOTHPOINT 2134.46030936177,172.105339448744 2151.76108577299,172.044919333118 2128.58220912481,172.125636831337 PathPoint;PointKind.SMOOTHPOINT 2191.20794649465,171.949568838145 2197.76017652629,171.944140468382 2170.30956879999,171.968214108202 PathPoint;PointKind.SMOOTHPOINT 2213.20780412169,173.186529095949 2218.93047212133,173.193137546095 2206.1598904175,173.178740565419 PathPoint;PointKind.SMOOTHPOINT 2229.30088267071,171.988275474718 2242.96298686561,172.028870239904 2223.21105469361,171.969866220738 PathPoint;PointKind.SMOOTHPOINT 2273.40398337649,172.22240342277 2280.27911591482,172.274562975713 2257.59556887942,172.102271239748 PathPoint;PointKind.SMOOTHPOINT 2292.7452062198,173.392807146955 2297.38905411211,173.437886217598 2285.40908786599,173.322238340032 PathPoint;PointKind.SMOOTHPOINT 2308.7883623418,172.545981463879 2335.36692086418,172.817399952044 2304.04962643218,172.497598168162 PathPoint;PointKind.SMOOTHPOINT 2391.893624703,173.461959857418 2399.6645284496,173.549757837937 2363.36030221193,173.139561896693 PathPoint;PointKind.SMOOTHPOINT 2414.50317324728,174.701516292065 2422.21070029574,174.786718095741 2406.67030904162,174.614898391929 PathPoint;PointKind.SMOOTHPOINT 2438.47797624969,173.976002872395 2453.62500710366,174.137437868834 2430.74424877853,173.893869277716 PathPoint;PointKind.SMOOTHPOINT 2483.84896497791,174.429389755669 2486.78907727569,174.456531604486 2468.791157185,174.291084334744 PathPoint;PointKind.SMOOTHPOINT 2494.04624030165,172.923607186543 2502.49870909801,172.997952250693 2491.11497949802,172.897881434187 PathPoint;PointKind.SMOOTHPOINT 2517.8659651265,174.715677256665 2525.38584049892,174.771849082911 2509.51971425998,174.652896980272 PathPoint;PointKind.SMOOTHPOINT 2540.25139383883,174.868143642191 2544.53233047087,174.894105410624 2532.85331502595,174.823300587625 PathPoint;PointKind.SMOOTHPOINT 2553.94748777128,172.086694178688 2561.03399398998,172.122568622341 2549.71541138696,172.065216715711 PathPoint;PointKind.SMOOTHPOINT 2579.47484284807,173.145462298609 2586.29651236172,173.153014813062 2582.94675291455,173.149710587989 PathPoint;PointKind.SMOOTHPOINT 2599.18357972861,173.288488041068 2603.81857612676,173.348200108465 2592.85051269219,173.206826478542 PathPoint;PointKind.SMOOTHPOINT 2633.4817033315,173.285655848149 2656.651020366,173.338287433245 2628.47636041799,173.274327076469 PathPoint;PointKind.SMOOTHPOINT 2691.41367038202,174.42797365921 2805.46446442081,173.049875787559 2670.30214870815,174.683343054161 PathPoint;PointKind.SMOOTHPOINT 3014.45178196515,173.812679747342 3122.86063363097,173.352684413921 2907.38446275312,174.267246711001 PathPoint;PointKind.SMOOTHPOINT 3344.33386882719,174.133661611607 3349.47481663112,174.080085962204 3271.94351716779,174.891273217704 PathPoint;PointKind.SMOOTHPOINT 3360.93502314058,174.062148740378 3366.57944393191,174.066869061911 3355.02789000279,174.057664434921 PathPoint;PointKind.SMOOTHPOINT 3376.73529426302,175.210366953355 3380.5665749921,175.241757091552 3370.49180434743,175.158679432566 PathPoint;PointKind.SMOOTHPOINT 3390.58611231326,174.267010694923 3405.82555276619,174.030050553951 3386.55868247376,174.329790971316 PathPoint;PointKind.SMOOTHPOINT 3439.8485719308,173.5976691015 3443.30454930781,173.909210322699 3436.3915323745,173.286599912455 PathPoint;PointKind.SMOOTHPOINT 3448.13427857732,173.50208259045 3456.6147180952,175.535597107 3445.43032414353,172.85374642785 PathPoint;PointKind.SMOOTHPOINT 3466.57902209284,173.305245182511 3533.79018749358,172.628115058558 3460.3705840941,173.368025458904 PathPoint;PointKind.SMOOTHPOINT 3653.66915934232,172.95004098713 3696.95863070558,173.54314938779 3608.00288476916,172.324126351813 PathPoint;PointKind.SMOOTHPOINT 3876.83480022055,174.15820728358 3882.62650987459,174.16953605526 3785.60988524313,173.976946936701 PathPoint;PointKind.SMOOTHPOINT 3894.23011058932,174.1893614057 3901.77901886256,173.175200324269 3888.47947186816,174.962550072857 PathPoint;PointKind.SMOOTHPOINT 3911.46998872077,174.214379109827 3936.64186779239,174.246477296253 3905.73067991212,174.207298627527 PathPoint;PointKind.SMOOTHPOINT 3985.4366144589,174.24812940879 3989.91617861973,174.246241280176 3961.59706228715,174.258278100086 PathPoint;PointKind.SMOOTHPOINT 3999.3150491709,172.854926508233 3984.13402857938,172.866255279913 3994.9208134137,172.85870276546 PathPoint;PointKind.SMOOTHPOINT 4079.42107125338,173.812679747342 4102.00902215193,173.716857220216 4039.49729202677,173.980487177852 PathPoint;PointKind.SMOOTHPOINT 4146.57877362944,174.692783697228 4150.41253277689,174.668474041331 4124.55519399808,174.82990903777 PathPoint;PointKind.SMOOTHPOINT 4158.07261581668,174.620090745615 4167.21089838,174.441662591656 4154.24381350597,174.695143857994 PathPoint;PointKind.SMOOTHPOINT 4178.28482568463,174.493114096369 4184.75668414936,174.452755347259 4171.54565209649,174.534888941939 PathPoint;PointKind.SMOOTHPOINT 4197.72093654526,174.374870041959 4200.19085747365,174.360473061283 4191.23208321176,174.413104646379 PathPoint;PointKind.SMOOTHPOINT 4205.48157255864,177.999132915235 4212.38927859545,176.533237063066 4203.06086593774,178.513175930213 PathPoint;PointKind.SMOOTHPOINT 4218.57045399221,174.25804208401 4230.04411477278,174.19785798446 4214.08274645676,174.281643691676 PathPoint;PointKind.SMOOTHPOINT 4253.24742154483,174.101327409104 4257.34389303873,174.086222380197 4241.58717126751,174.144046318981 PathPoint;PointKind.SMOOTHPOINT 4265.48301894207,176.99936881448 4268.58422843343,178.272911564167 4261.10754835248,175.201870374595 PathPoint;PointKind.SMOOTHPOINT 4275.65763444079,174.033590795101 4286.49398764236,174.008337074898 4272.28733952718,174.041615341708 PathPoint;PointKind.SMOOTHPOINT 4308.57421683631,173.994884158528 4273.91672257082,173.994884158528 4297.45426176208,173.994648142451 PathPoint;PointKind.SMOOTHPOINT 4467.41003069041,174.812679864174 4585.57818574929,173.929979737445 4380.90154585735,175.458891882084 PathPoint;PointKind.SMOOTHPOINT 4769.24881377768,174.469748504779 4777.82201695427,174.435998205816 4677.76012427451,174.824716684084 PathPoint;PointKind.SMOOTHPOINT 4794.89619511518,174.369441672196 4806.38083174851,173.108643790649 4786.41540153754,175.300289078565 PathPoint;PointKind.SMOOTHPOINT 4819.09405577023,174.272439064687 4831.87950798425,174.220279511744 4811.03034459707,174.305009283266 PathPoint;PointKind.SMOOTHPOINT 4857.52370278386,174.108643907481 4880.37896880582,174.006920978438 4844.67097921428,174.166231830187 PathPoint;PointKind.SMOOTHPOINT 4931.2049563505,177.295096958542 4942.4768030644,177.401540209118 4908.25621855029,177.078906232317 PathPoint;PointKind.SMOOTHPOINT 4961.64772316021,176.381714741846 4964.16473403749,176.380298645386 4950.78800201407,176.38785115984 PathPoint;PointKind.SMOOTHPOINT 4971.89173437308,177.428210025781 4975.36152008097,177.418769382715 4969.39207242434,177.434818475928 PathPoint;PointKind.SMOOTHPOINT 4982.27099641661,175.443314821024 4994.20847549079,175.376758287405 4978.83165984861,175.462432123234 PathPoint;PointKind.SMOOTHPOINT 5017.65608350145,177.027218711527 5021.47815867662,176.97246298174 5005.96219754636,177.194318093806 PathPoint;PointKind.SMOOTHPOINT 5044.39396891858,176.573359796099 5050.25082556958,176.459600047146 5039.17158736845,176.674610692988 PathPoint;PointKind.SMOOTHPOINT 5061.97480660479,176.209186989804 5065.79511148113,176.125165266511 5056.10697410105,176.33757973551 PathPoint;PointKind.SMOOTHPOINT 5073.58655069415,177.6646981346 5076.87647404085,177.588700957914 5069.75279154671,177.753676195503 PathPoint;PointKind.SMOOTHPOINT 5083.34337566886,175.716621437803 5090.94787132538,175.533944994464 5080.03964399128,175.795686823486 PathPoint;PointKind.SMOOTHPOINT 5112.87196016247,174.790258336891 5156.79342820823,173.687119194556 5105.15699785892,174.983791519756 PathPoint;PointKind.SMOOTHPOINT 5249.36978931289,172.167647692983 5253.30445549368,172.118556349037 5196.35358805505,172.824480434344 PathPoint;PointKind.SMOOTHPOINT 5261.14581713372,175.174964541855 5267.11526479035,175.105811831393 5257.39207549342,175.218627516039 PathPoint;PointKind.SMOOTHPOINT 5278.82897809234,172.244116901823 5288.28308196702,172.14805835862 5273.29183741014,172.30028872807 PathPoint;PointKind.SMOOTHPOINT 5302.39236364653,173.297692668058 5306.72959578138,173.267010578091 5294.08116469685,173.356224655071 PathPoint;PointKind.SMOOTHPOINT 5318.10057922978,174.330735035623 5322.18288833303,174.309965620876 5314.04553272852,174.351268434293 PathPoint;PointKind.SMOOTHPOINT 5334.79874591908,172.389502805049 5416.65453136568,172.15655493738 5330.98021134158,172.400595560652 PathPoint;PointKind.SMOOTHPOINT 5510.56463560928,173.838169483622 5519.14527404097,173.733142329506 5438.88346566139,174.713553111974 PathPoint;PointKind.SMOOTHPOINT 5533.8684953549,173.525212165964 5540.86754881137,173.422781188691 5526.87581497422,173.627879159313 PathPoint;PointKind.SMOOTHPOINT 5552.76324883315,173.231844182668 5561.66572759223,171.219571113018 5547.26293036663,174.474704842389 PathPoint;PointKind.SMOOTHPOINT 5565.715463197,173.018721665439 5601.81114823243,172.427973425546 5561.7946053471,173.082682022216 PathPoint;PointKind.SMOOTHPOINT 5631.34044084557,175.144282451889 5645.75917076065,176.660921760541 5606.14590194892,172.492877846628 PathPoint;PointKind.SMOOTHPOINT 5670.66621312722,186.117141888223 5673.3524645727,188.486743297944 5662.88504164741,179.253086330559 PathPoint;PointKind.SMOOTHPOINT 5671.52409994051,201.659980617031 5671.32724271055,205.949100778273 5671.78716634673,195.903076475005 PathPoint;PointKind.SMOOTHPOINT 5672.35543227134,210.947449249896 5674.96945552453,216.375110964973 5671.36689740435,208.895053447212 PathPoint;PointKind.SMOOTHPOINT 5675.03106192383,290.990413522395 5675.19286723694,297.672500684949 5674.04642171428,250.226660825032 PathPoint;PointKind.SMOOTHPOINT 5672.03111352558,334.987114437922 5669.13490463879,535.011919492337 5672.13839363471,327.599575222214 PathPoint;PointKind.SMOOTHPOINT 5669.30520738629,960.157355049089 5670.53096229657,978.346406029471 5668.33579174668,945.762734533259 PathPoint;PointKind.SMOOTHPOINT 5675.03106192383,1012.93432604873 5673.84283734876,1039.01363048811 5677.09947907745,967.54465824872 PathPoint;PointKind.SMOOTHPOINT 5674.81260704814,1110.00891846164 5677.01415067382,1137.21708779572 5671.9086088465,1074.12409010111 PathPoint;PointKind.SMOOTHPOINT 5673.81274226865,1175.01034215217 5673.91471148129,1190.97942591544 5673.73945189706,1163.41416425736 PathPoint;PointKind.SMOOTHPOINT 5674.81260704814,1244.01223834218 5674.85013738335,1261.42432439818 5674.7534790672,1216.07454331513 PathPoint;PointKind.SMOOTHPOINT 5673.81274226865,1299.01366086439 5673.99791552632,1312.81210477056 5673.67961579659,1289.13898423278 PathPoint;PointKind.SMOOTHPOINT 5673.81274226865,1396.01626837392 5671.68944585128,1423.31766405828 5674.12219050423,1392.03491317665 PathPoint;PointKind.SMOOTHPOINT 5670.20558137151,1466.13900491201 5670.02465683103,1485.35142160082 5670.39429522685,1446.0396398071 PathPoint;PointKind.SMOOTHPOINT 5670.68462423506,1656.65189004465 5670.92715517485,1670.28842692224 5669.1965110381,1573.06679649356 PathPoint;PointKind.SMOOTHPOINT 5674.52865111572,1688.41375356192 5676.14882860544,1747.06799690268 5674.16538579569,1675.27544662218 PathPoint;PointKind.SMOOTHPOINT 5674.13281229721,1838.24242341503 5672.42022520853,1907.61250468464 5674.776492952,1812.15131817181 PathPoint;PointKind.SMOOTHPOINT 5673.31812077539,2146.82895934975 5671.79283130299,2183.86413006795 5674.84270212826,2109.7942606637 PathPoint;PointKind.SMOOTHPOINT 5674.3909218667,2307.0397403993 5674.8150854665,2345.7954683164 5674.02022129159,2273.1329627773 PathPoint;PointKind.SMOOTHPOINT 5671.51241596823,2431.26397015928 5667.24033083034,2458.66402056369 5676.81729344386,2397.22974385588 PathPoint;PointKind.SMOOTHPOINT 5671.27696622376,2547.69235289092 5670.36986510299,2565.09311017524 5671.52480806004,2542.93049252812 PathPoint;PointKind.SMOOTHPOINT 5672.05448147014,2625.089576944 5673.04266227736,2643.04449997633 5670.50015909692,2596.84907329059 PathPoint;PointKind.SMOOTHPOINT 5675.85141840191,2674.71172104685 5676.19166983714,2689.76199422366 5675.42336014468,2655.79574055034 PathPoint;PointKind.SMOOTHPOINT 5672.78773924576,2719.35486999636 5673.12799068099,2733.99872348915 5672.46377455976,2705.40372368859 PathPoint;PointKind.SMOOTHPOINT 5673.39070302744,2765.05159471211 5670.36278390767,2830.78041995092 5673.99225057006,2751.99376925452 PathPoint;PointKind.SMOOTHPOINT 5673.39070302744,2898.0551504919 5672.00668340172,2926.27818895564 5674.92307369517,2866.77475977103 PathPoint;PointKind.SMOOTHPOINT 5674.92201151587,2980.18237273743 5675.84292096752,2989.60578663045 5673.04266227736,2960.96263955025 PathPoint;PointKind.SMOOTHPOINT 5675.87230792811,3021.03746365646 5675.11886874583,3084.07948187851 5676.24442474229,2989.97302764574 PathPoint;PointKind.SMOOTHPOINT 5675.88151348203,3406.99077757037 5675.18153732443,3425.03515069575 5675.89992458987,3406.51520517588 PathPoint;PointKind.SMOOTHPOINT 5674.92201151587,3693.20062927642 5675.0523055098,3726.43664920854 5674.84978332358,3674.62333184993 PathPoint;PointKind.SMOOTHPOINT 5671.92206311762,3755.20228863253 5670.96680986865,3763.0120606094 5673.48771540336,3742.40054061812 PathPoint;PointKind.SMOOTHPOINT 5666.92238516037,3776.20299913423 5660.854154829,3778.181757921 5671.37079206178,3774.75244432705 PathPoint;PointKind.SMOOTHPOINT 5649.92255955034,3787.20300041938 5641.16135063794,3788.0989174464 5659.9881246411,3786.17444235727 PathPoint;PointKind.SMOOTHPOINT 5600.92387445856,3787.20300041938 5557.49171700956,3787.80814563995 5621.06527237328,3786.92284933638 PathPoint;PointKind.SMOOTHPOINT 5094.49944483923,3785.53318667697 5033.29631960962,3785.38968890236 5155.70186194931,3785.67668445159 PathPoint;PointKind.SMOOTHPOINT 4479.70121547093,3787.1137863424 4402.09733375555,3786.72624794452 4557.30509718631,3787.50156075636 PathPoint;PointKind.SMOOTHPOINT 4033.32638436323,3787.1137863424 4024.38743744824,3787.40479416493 4083.11851739087,3785.49117581533 PathPoint;PointKind.SMOOTHPOINT 4003.536857822,3791.63066201763 3979.50540525702,3793.71067170128 4010.8375701992,3790.99908299647 PathPoint;PointKind.SMOOTHPOINT 3944.62556145842,3787.49353620976 3935.96242710123,3788.11520255569 3961.71850478693,3786.26672464325 PathPoint;PointKind.SMOOTHPOINT 3918.10506873768,3790.40149029035 3912.08782301263,3790.53342327721 3929.42471352,3790.15272934555 PathPoint;PointKind.SMOOTHPOINT 3889.40002726004,3790.59809168222 3877.79607248554,3790.6023399716 3902.15467627441,3790.59313534461 PathPoint;PointKind.SMOOTHPOINT 3852.32324261273,3787.25397989194 3845.50015686001,3785.50698889246 3864.50679322435,3790.37293234508 PathPoint;PointKind.SMOOTHPOINT 3826.42872755847,3790.36844803962 3744.20684431371,3789.87493842331 3834.01622834622,3790.41423515849 PathPoint;PointKind.SMOOTHPOINT 3596.03141595743,3788.57260171227 3537.91250535041,3788.31345606009 3634.3300608576,3788.74371336785 PathPoint;PointKind.SMOOTHPOINT 3460.52282979352,3788.22093775804 3447.16450887794,3787.96509633094 3495.05746532017,3788.88414293347 PathPoint;PointKind.SMOOTHPOINT 3387.85631151655,3789.02480851516 3377.57512402824,3788.99766666635 3378.21101536817,3789.00002682711 PathPoint;PointKind.SMOOTHPOINT 3352.51123318528,3786.94810305658 3343.82154434563,3783.12039432522 3361.90762531808,3791.08735300914 PathPoint;PointKind.SMOOTHPOINT 3325.4426559466,3787.07814791483 3320.40721795298,3787.08428433282 3338.15694214763,3787.063278902 PathPoint;PointKind.SMOOTHPOINT 3302.76866852489,3789.02032420971 3291.97975933198,3789.0375533833 3307.96130905467,3789.01206364702 PathPoint;PointKind.SMOOTHPOINT 3278.8710505515,3784.77274287796 3272.06920838476,3785.35027421756 3292.73992564981,3783.59525867147 PathPoint;PointKind.SMOOTHPOINT 3252.44509178832,3787.07814791483 3247.07435919619,3787.09230887943 3260.47587540324,3787.05667045185 PathPoint;PointKind.SMOOTHPOINT 3232.44567183981,3785.07791166509 3225.75996127634,3785.09679295122 3237.88650826562,3785.0625706201 PathPoint;PointKind.SMOOTHPOINT 3209.31494731981,3789.24855175584 3205.44188753833,3788.94503508125 3218.16396305421,3789.94125894086 PathPoint;PointKind.SMOOTHPOINT 3193.44669672227,3786.07814779799 3185.9420459198,3786.10127737351 3197.35055970341,3786.06611097808 PathPoint;PointKind.SMOOTHPOINT 3167.90624143413,3788.46875463854 3164.77564498218,3788.79327674395 3176.21673226428,3787.60847603909 PathPoint;PointKind.SMOOTHPOINT 3157.447670003,3787.07791189875 3154.13650307033,3787.11119016556 3160.58428547097,3787.04652176055 PathPoint;PointKind.SMOOTHPOINT 3148.26194343103,3790.40267037074 3141.03735390354,3790.49802086571 3151.55859391328,3790.35900739655 PathPoint;PointKind.SMOOTHPOINT 3126.71988508157,3790.6740888589 3122.68962276393,3790.7227081707 3133.8520650101,3790.58865103915 PathPoint;PointKind.SMOOTHPOINT 3113.44866286845,3787.07791189875 3111.53532389239,3787.0996253778 3117.44281108994,3787.03283282811 PathPoint;PointKind.SMOOTHPOINT 3100.44935855571,3787.07791189875 3093.98493534606,3787.16901410434 3102.35349197785,3787.05077004993 PathPoint;PointKind.SMOOTHPOINT 3085.44997062421,3789.07814814849 3082.25812183272,3789.77463159073 3091.56104218727,3787.74324121887 PathPoint;PointKind.SMOOTHPOINT 3071.68164849947,3786.23462645682 3068.93697719258,3786.27002886832 3074.90430049061,3786.19308762733 PathPoint;PointKind.SMOOTHPOINT 3058.90788025774,3789.178218965 3050.88665625651,3789.31558032162 3061.60971033293,3789.13195981397 PathPoint;PointKind.SMOOTHPOINT 3027.49392750959,3786.11992264356 3016.58888671339,3786.33210109649 3035.02088407733,3785.97335665995 PathPoint;PointKind.SMOOTHPOINT 2989.19280419106,3788.00498304789 2981.86624545094,3787.66889615472 3002.85915710316,3788.63160573144 PathPoint;PointKind.SMOOTHPOINT 2972.45285844936,3787.07791189875 2963.76706426714,3787.57755793305 2978.3929191454,3786.73616061974 PathPoint;PointKind.SMOOTHPOINT 2951.8710101856,3790.88485121536 2951.7382377733,3791.38898155512 2952.00378259789,3790.38072087561 PathPoint;PointKind.SMOOTHPOINT 2942.77025795749,3791.43547672223 2941.03819758168,3791.47630750349 2948.93550066477,3791.29032683508 PathPoint;PointKind.SMOOTHPOINT 2937.15239164862,3786.87777026574 2932.84879519155,3786.94951915304 2939.17725945101,3786.84354793462 PathPoint;PointKind.SMOOTHPOINT 2923.45417335757,3789.07814814849 2916.17010178938,3790.48456794934 2928.24283169422,3788.15390919227 PathPoint;PointKind.SMOOTHPOINT 2904.45497224832,3789.07814814849 2903.00828404399,3788.82065460885 2905.90166045265,3789.33564168813 PathPoint;PointKind.SMOOTHPOINT 2820.29850644153,3787.56670119352 2806.96178317169,3787.60658791048 2836.07505555965,3787.51926196211 PathPoint;PointKind.SMOOTHPOINT 2751.84777779964,3786.49306406077 2749.07407359193,3787.23203039681 2754.5697892815,3785.76778665718 PathPoint;PointKind.SMOOTHPOINT 2740.45979948246,3788.07814803166 2736.61223200414,3788.42296751967 2744.36437058313,3787.72860822212 PathPoint;PointKind.SMOOTHPOINT 2727.46014110995,3790.07814826532 2724.225097027,3790.26365690158 2731.57077499449,3789.84260422081 PathPoint;PointKind.SMOOTHPOINT 2719.15000433957,3790.2806500591 2715.48194516267,3790.35239894641 2722.68529110419,3790.21149734864 PathPoint;PointKind.SMOOTHPOINT 2703.46090798369,3789.07814814849 2698.32279265789,3788.95329564393 2707.58464207958,3789.17845498107 PathPoint;PointKind.SMOOTHPOINT 2692.64048747159,3789.21952177841 2687.97539599332,3789.03849744761 2697.34877424132,3789.40196220567 PathPoint;PointKind.SMOOTHPOINT 2678.21396824165,3787.18624327794 2673.93126131078,3786.96131995688 2682.50198606902,3787.41093058292 PathPoint;PointKind.SMOOTHPOINT 2666.46201648492,3790.07814826532 2662.14815229463,3787.46120200725 2669.8461197294,3792.13054406801 PathPoint;PointKind.SMOOTHPOINT 2653.4623581124,3790.07814826532 2648.60784465926,3789.71208733041 2657.13608224557,3790.3545230911 PathPoint;PointKind.SMOOTHPOINT 2639.61578877936,3789.08192440572 2634.44262153672,3788.21857759727 2644.00896235726,3789.81522635592 PathPoint;PointKind.SMOOTHPOINT 2623.46287412987,3788.07814803166 2620.1945484289,3787.47748711654 2628.18709358908,3788.94668719379 PathPoint;PointKind.SMOOTHPOINT 2603.46345418135,3788.07814803166 2591.05365937918,3784.67526823829 2606.53740107073,3788.92072542535 PathPoint;PointKind.SMOOTHPOINT 2580.7742421897,3783.98350511759 2578.32344048868,3784.02008760947 2593.80399564233,3783.7871397418 PathPoint;PointKind.SMOOTHPOINT 2573.89025815722,3787.93465025705 2569.75413196951,3788.18577136262 2576.05993640394,3787.80295328627 PathPoint;PointKind.SMOOTHPOINT 2547.46536157333,3788.07814803166 2532.13174122262,3789.92780602449 2550.79458555407,3787.67668468525 PathPoint;PointKind.SMOOTHPOINT 2523.74087882557,3790.76542708057 2519.18873241269,3790.936066704 2535.63551666805,3790.3200647439 PathPoint;PointKind.SMOOTHPOINT 2501.16177942117,3788.72247192096 2491.35963479641,3788.47064276715 2509.40322859693,3788.93417834172 PathPoint;PointKind.SMOOTHPOINT 2474.46744335528,3788.07814803166 2465.11283027487,3787.07460767368 2482.16293237169,3788.90349625176 PathPoint;PointKind.SMOOTHPOINT 2453.4678045675,3788.07814803166 2446.1724030868,3789.03684533507 2459.1950753441,3787.32549276317 PathPoint;PointKind.SMOOTHPOINT 2434.46860345825,3788.07814803166 2432.60731126781,3787.98539371353 2446.21347401967,3788.66370391787 PathPoint;PointKind.SMOOTHPOINT 2418.46899668749,3788.07814803166 2412.03466855796,3787.89594362047 2422.9372309358,3788.20488866483 PathPoint;PointKind.SMOOTHPOINT 2400.46966035773,3790.07814826532 2396.65112578023,3789.99719475103 2411.5035789088,3790.31156816514 PathPoint;PointKind.SMOOTHPOINT 2388.46986676472,3786.07814779799 2383.74281482738,3785.98468543164 2392.7628414288,3786.16358561775 PathPoint;PointKind.SMOOTHPOINT 2368.4704468162,3788.07814803166 2362.51586966976,3787.96698445955 2373.72186126715,3788.17609470347 PathPoint;PointKind.SMOOTHPOINT 2352.47084004544,3783.0781474475 2346.9361777816,3783.18105045693 2359.05741387439,3782.95612713586 PathPoint;PointKind.SMOOTHPOINT 2333.24220820775,3785.24855128852 2325.99141825757,3785.12794707334 2339.12738964003,3785.34673397641 PathPoint;PointKind.SMOOTHPOINT 2313.47221898767,3784.07791154825 2303.60457330618,3784.39440910706 2321.0317490539,3783.83552303752 PathPoint;PointKind.SMOOTHPOINT 2280.21432297762,3786.10292948604 2266.99904220755,3785.89311119389 2290.99473473615,3786.27451317378 PathPoint;PointKind.SMOOTHPOINT 2234.06298652489,3785.9830333191 2124.35473551745,3790.41635930318 2247.98532464789,3785.4206070084 PathPoint;PointKind.SMOOTHPOINT 1937.51350228355,3786.20559647939 1814.75354611797,3788.19025566807 1994.6406914857,3785.28230158748 PathPoint;PointKind.SMOOTHPOINT 1527.46661941784,3786.71916746222 1504.48459999962,3786.74040890912 1625.9207266997,3786.6273572084 PathPoint;PointKind.SMOOTHPOINT 1412.79834514696,3786.84213183816 1410.95511000459,3786.85015638477 1447.25685782389,3786.69226162948 PathPoint;PointKind.SMOOTHPOINT 1396.43228651827,3786.76424653286 1376.34930846495,3782.82513821331 1398.15407916086,3787.10222155465 PathPoint;PointKind.SMOOTHPOINT 1375.0909800562,3787.04840988917 1378.10332054626,3787.16216963812 1373.99728943868,3787.00687105967 PathPoint;PointKind.SMOOTHPOINT 1302.03747445487,3786.91104853255 1294.22797819377,3786.8791863622 1326.97921467852,3787.01182739728 PathPoint;PointKind.SMOOTHPOINT 1278.50453804057,3786.79988496044 1273.69959295469,3788.50722525904 1287.22750849823,3783.70004980951 PathPoint;PointKind.SMOOTHPOINT 1263.20065871021,3786.71043486738 1211.72390931542,3786.3875648745 1268.30867895589,3786.74276906988 PathPoint;PointKind.SMOOTHPOINT 1111.67122218957,3785.03283259444 1050.16183526227,3785.58227802092 1159.69482668549,3784.60399138314 PathPoint;PointKind.SMOOTHPOINT 917.589820798478,3786.03448482381 912.33911446706,3786.04628562764 984.120837388523,3785.88414258298 PathPoint;PointKind.SMOOTHPOINT 898.589911569694,3784.47984692682 891.390814345371,3784.49353585926 903.844866618305,3784.46969823552 PathPoint;PointKind.SMOOTHPOINT 880.232974876167,3786.10410956643 867.882662114703,3786.12204678825 887.431009921192,3786.09372485905 PathPoint;PointKind.SMOOTHPOINT 843.235145556691,3786.14517636377 838.258835544009,3786.14895262099 855.541554907158,3786.1357357207 PathPoint;PointKind.SMOOTHPOINT 827.890549353232,3784.29622641917 824.527335634949,3784.29811454778 832.853405094802,3784.29363024233 PathPoint;PointKind.SMOOTHPOINT 818.247731623214,3786.15933732837 806.346366645178,3786.16382163382 821.602801966877,3786.15839326406 PathPoint;PointKind.SMOOTHPOINT 782.71535567567,3786.16311358559 770.930122300918,3786.16146147306 794.494215974632,3786.16500171421 PathPoint;PointKind.SMOOTHPOINT 744.422021671997,3785.07153923102 737.500153244538,3785.08499214739 755.952686074915,3785.04982575196 PathPoint;PointKind.SMOOTHPOINT 721.517895402313,3787.07791189875 717.863998616053,3787.07956401129 728.306283297949,3787.07507970583 PathPoint;PointKind.SMOOTHPOINT 701.5184754538,3786.07814779799 685.440621474725,3786.07201138 705.130239127891,3786.07956389445 PathPoint;PointKind.SMOOTHPOINT 662.912860736416,3787.83670358523 541.745819458573,3787.23934689519 678.015280059857,3787.91152068153 PathPoint;PointKind.SMOOTHPOINT 429.235539462131,3787.21952154475 425.813905882439,3787.14942476998 492.709958091344,3788.5228023201 PathPoint;PointKind.SMOOTHPOINT 415.493771819853,3785.19969596065 412.671561424187,3785.13856779679 418.968160304694,3785.2749850891 PathPoint;PointKind.SMOOTHPOINT 400.756742175038,3788.13809611513 393.9485269325,3787.95801584864 403.605152993397,3788.21362125966 PathPoint;PointKind.SMOOTHPOINT 383.084203009402,3787.0996253778 377.606190308142,3786.64977873568 390.375001713148,3787.69887019646 PathPoint;PointKind.SMOOTHPOINT 368.52809790507,3788.07814803166 360.748696724092,3788.79398479218 372.144818415888,3787.74512934748 PathPoint;PointKind.SMOOTHPOINT 356.574686141416,3786.03896912927 350.589659855085,3786.25020351788 362.093769775545,3785.8444918821 PathPoint;PointKind.SMOOTHPOINT 342.075938719194,3787.20300041938 329.428569813964,3788.09868143033 346.210294608066,3786.91034048432 PathPoint;PointKind.SMOOTHPOINT 292.077742907676,3788.20323655229 284.449171187061,3787.34295795285 303.563087660532,3789.49802074888 PathPoint;PointKind.SMOOTHPOINT 275.531113798272,3784.07791154825 273.522532745127,3780.02834770483 277.60023907142,3788.24949570332 PathPoint;PointKind.SMOOTHPOINT 266.078072102889,3770.20252640109 264.41859397913,3766.35098004598 266.976675789278,3772.28961656704 PathPoint;PointKind.CORNERPOINT 263.454843295777,3739.24335356056 263.454843295777,3739.24335356056 263.454843295777,3739.24335356056 PathPoint;PointKind.SMOOTHPOINT 264.212531195253,1965.10602096036 265.499184385299,1932.92003655333 262.142343742806,2016.88322785924 PathPoint;PointKind.SMOOTHPOINT 263.078123704635,1851.15297484079 263.105740366392,1849.10695147218 262.536412262486,1890.99744491954 PathPoint;PointKind.SMOOTHPOINT 265.499184385299,1840.09609368116 265.935386017147,1823.95495419801 265.442534822721,1842.18696010434 PathPoint;PointKind.SMOOTHPOINT 265.593364283084,1804.37553250999 265.663468116773,1800.17657049003 265.421291236754,1814.71610487694 PathPoint;PointKind.SMOOTHPOINT 263.674360350765,1787.50274318917 263.732780212174,1784.98940798876 263.604964636607,1790.48693046253 PathPoint;PointKind.SMOOTHPOINT 264.679890086519,1778.57472704107 264.757075115531,1775.67975384469 264.542514897268,1783.70453646739 PathPoint;PointKind.SMOOTHPOINT 264.35026044427,1761.98303286756 264.584648009435,1753.42390984728 264.255726486718,1765.42933961903 PathPoint;PointKind.SMOOTHPOINT 265.173449400477,1732.05359816953 265.387301499208,1724.27616039517 264.864709284428,1743.28914349919 PathPoint;PointKind.SMOOTHPOINT 269.767728925525,1711.11495989599 269.62716719838,1708.9018371451 270.94249922948,1729.64340199462 PathPoint;PointKind.SMOOTHPOINT 266.03523087119,1700.57684207288 266.130118888507,1697.07530755947 265.973624471886,1702.83905616771 PathPoint;PointKind.SMOOTHPOINT 266.971010833019,1654.54945883372 266.793272830432,1634.95351602033 267.056339236652,1663.95823972999 PathPoint;PointKind.SMOOTHPOINT 266.284134886765,1600.18976402396 266.261475061734,1596.57682992237 266.404515207243,1619.31839500555 PathPoint;PointKind.SMOOTHPOINT 272.056371253663,1588.0823753071 273.84260277369,1545.21760749526 271.883236028036,1592.23767435287 PathPoint;PointKind.SMOOTHPOINT 265.333484414758,1500.79112130412 264.922066966538,1486.67830398383 265.642578590573,1511.39013127502 PathPoint;PointKind.SMOOTHPOINT 267.488646211073,1428.36250769701 263.03032563621,1400.50694626463 271.783037114226,1455.19517545311 PathPoint;PointKind.SMOOTHPOINT 264.078342543898,1359.14017249139 264.129681209984,1354.08966446683 263.899542362012,1376.77340561123 PathPoint;PointKind.SMOOTHPOINT 263.889982748326,1334.04576313993 264.09356711384,1329.6523238728 263.24701021307,1347.90840341896 PathPoint;PointKind.SMOOTHPOINT 263.638246254622,1313.49513529643 264.110207922847,1303.91170250343 263.388634119514,1318.57018899297 PathPoint;PointKind.SMOOTHPOINT 267.943258950759,1286.42833959228 268.600039816894,1273.90886680555 267.339232989774,1297.93789958695 PathPoint;PointKind.SMOOTHPOINT 267.400485329312,1241.72288239852 271.257612421318,1170.72476223208 266.640673071239,1255.70754298919 PathPoint;PointKind.SMOOTHPOINT 267.502454541951,1043.3650588936 267.847662813909,1029.50265463065 266.383625681042,1088.39480217669 PathPoint;PointKind.SMOOTHPOINT 269.5506902889,1011.61830040524 269.777642598977,1000.56519550284 269.48058645521,1015.03722929182 PathPoint;PointKind.SMOOTHPOINT 268.634383614206,986.810178554774 265.181238715331,977.778551349014 271.790472369315,995.065784900457 PathPoint;PointKind.SMOOTHPOINT 264.390623257606,954.939039594015 264.516668534342,952.298491728281 264.000449395353,963.102127637645 PathPoint;PointKind.SMOOTHPOINT 264.72343943775,922.451898673159 265.107948343746,915.590203276262 263.710474446909,940.501936184385 PathPoint;PointKind.SMOOTHPOINT 269.941926330452,901.441039480164 274.26322577583,878.957203952699 268.338035589972,909.785151854597 PathPoint;PointKind.SMOOTHPOINT 267.775080561856,868.293289560721 272.450085713578,785.527879843885 267.147332596543,879.404454417981 PathPoint;PointKind.SMOOTHPOINT 275.622107158161,609.735081396796 275.827461822506,591.674895194273 274.925671598223,671.013351477926 PathPoint;PointKind.SMOOTHPOINT 274.752536372594,567.066206928589 275.611131305413,548.93852012814 274.508589193744,572.219617962581 PathPoint;PointKind.SMOOTHPOINT 274.31598068098,426.465765673096 274.641361606035,418.617523075738 271.829773003353,486.3657018665 PathPoint;PointKind.SMOOTHPOINT 271.133337443413,410.304800839501 270.220571366381,403.909945242249 272.097442186532,417.061941114435 PathPoint;PointKind.SMOOTHPOINT 269.390655274618,385.983108123042 267.953526683976,382.430358120996 271.944134307806,392.292997932695 PathPoint;PointKind.SMOOTHPOINT 271.437828842269,366.984521999697 270.588439463369,341.69587141714 271.553960445553,370.448293940841 PathPoint;PointKind.SMOOTHPOINT 266.292632321152,314.05461258238 265.095202192167,272.89647702091 266.656605760713,326.565352774267 PathPoint;PointKind.SMOOTHPOINT 272.502840618728,193.016599857386 272.952496521689,189.50279250799 269.48058645521,216.659746353432 PathPoint;PointKind.SMOOTHPOINT 275.530759738505,182.984736518718 276.075657718549,182.683343988816 273.062255049183,184.350797570458 PathPoint;PointKind.SMOOTHPOINT 278.077865695904,177.10982433836 281.629439209757,173.157499118519 276.510443111332,178.853747128841 PathPoint";
	
	mask35mm[2] = "PointKind.CORNERPOINT 305.67539691925,174.57670211792 305.67539691925,174.57670211792 305.67539691925,174.57670211792 PathPoint;PointKind.SMOOTHPOINT 316.479635238647,173.612265586853 318.11570763588,173.464508056641 308.521263599396,174.330518245697 PathPoint;PointKind.SMOOTHPOINT 324.340996742249,171.648459434509 348.638495206833,171.43673658371 322.524712085724,171.664037704468 PathPoint;PointKind.SMOOTHPOINT 451.068806648254,171.969466209412 455.45975446701,172.006051540375 397.609140872955,171.522181034088 PathPoint;PointKind.SMOOTHPOINT 464.811319112778,173.989684581757 472.5519490242,174.458448886871 460.341063737869,173.718953132629 PathPoint;PointKind.SMOOTHPOINT 480.525544881821,173.038229942322 493.327696323395,173.078119754791 476.202220916748,173.024775981903 PathPoint;PointKind.SMOOTHPOINT 519.012014865875,173.241219520569 585.550346374512,173.723201751709 506.193222999573,173.148221969604 PathPoint;PointKind.SMOOTHPOINT 682.015596628189,168.124938011169 686.603751182556,168.197400569916 633.341292142868,167.35782623291 PathPoint;PointKind.SMOOTHPOINT 703.519982099533,168.77733707428 710.470722913742,167.107157707214 697.75425195694,170.163567066193 PathPoint;PointKind.SMOOTHPOINT 725.051983594894,169.662702083588 733.502132892609,168.63618850708 717.74471282959,170.550427436829 PathPoint;PointKind.SMOOTHPOINT 742.015657424927,171.124935150146 746.119469404221,169.949719905853 733.169678449631,173.658764362335 PathPoint;PointKind.SMOOTHPOINT 762.48692035675,169.22084569931 766.199151277542,169.133040904999 757.369458675385,169.341695308685 PathPoint;PointKind.SMOOTHPOINT 782.003660202026,170.802748203278 824.85204577446,170.32525062561 778.105552196503,170.846178531647 PathPoint;PointKind.SMOOTHPOINT 943.04402589798,172.213053703308 1072.58052706718,175.107307434082 871.081978082657,170.60542345047 PathPoint;PointKind.SMOOTHPOINT 1323.5623884201,172.421944141388 1423.75403165817,172.697396278381 1223.37074518204,172.146255970001 PathPoint;PointKind.SMOOTHPOINT 1500.80344676971,173.661360740662 1513.78439426422,173.961832523346 1435.26070833206,172.142243385315 PathPoint;PointKind.SMOOTHPOINT 1535.51714301109,174.193382263184 1539.53456640244,173.485987186432 1524.13792490959,176.19731426239 PathPoint;PointKind.SMOOTHPOINT 1547.60658860207,174.240353107452 1552.16464877129,174.245781898499 1543.59907865524,174.235632419586 PathPoint;PointKind.SMOOTHPOINT 1561.40610337257,174.221942424774 1563.82852435112,173.64129781723 1556.85229182243,175.312893390656 PathPoint;PointKind.SMOOTHPOINT 1570.01557588577,172.125012874603 1572.47481822968,172.251055240631 1567.90684461594,172.01643705368 PathPoint;PointKind.SMOOTHPOINT 1575.58799386024,174.154200553894 1598.93769621849,174.02131319046 1572.94429063797,174.169306755066 PathPoint;PointKind.SMOOTHPOINT 1671.98066353798,173.930675983429 1688.94646167755,173.980479240417 1627.25615859032,173.798968791962 PathPoint;PointKind.SMOOTHPOINT 1730.58505296707,174.257819652557 1876.82004332542,175.412499904633 1708.27307581902,174.081501960754 PathPoint;PointKind.SMOOTHPOINT 2038.92397999763,175.058212280273 2058.91621112823,175.391728878021 1967.34997272491,173.864586353302 PathPoint;PointKind.SMOOTHPOINT 2099.01184558868,172.496058940887 2105.17128109932,172.496294975281 2079.63495612144,172.494406700134 PathPoint;PointKind.SMOOTHPOINT 2121.44313812256,173.259394168854 2127.0764529705,173.245468139648 2115.08826613426,173.275444507599 PathPoint;PointKind.SMOOTHPOINT 2134.99871134758,172.417931556702 2152.29979634285,172.357506752014 2129.12039279938,172.438230514526 PathPoint;PointKind.SMOOTHPOINT 2191.74787044525,172.262148857117 2198.30030322075,172.256720066071 2170.84891319275,172.280795574188 PathPoint;PointKind.SMOOTHPOINT 2213.74828219414,173.498969078064 2219.47117209435,173.505578041077 2206.70017719269,173.491179943085 PathPoint;PointKind.SMOOTHPOINT 2229.84205126762,172.30085849762 2243.50454807281,172.341456413269 2223.75200986862,172.282447814941 PathPoint;PointKind.SMOOTHPOINT 2273.94625782967,172.535004615784 2280.82158565521,172.587168216705 2258.1375002861,172.414863109589 PathPoint;PointKind.SMOOTHPOINT 2293.2880961895,173.705263137817 2297.93219089508,173.75034570694 2285.95179319382,173.634688854218 PathPoint;PointKind.SMOOTHPOINT 2309.33158993721,172.858371734619 2335.91095089912,173.129811286926 2304.59296345711,172.80998468399 PathPoint;PointKind.SMOOTHPOINT 2392.43953585625,173.774421215057 2400.21061420441,173.862226009369 2363.90510201454,173.451998233795 PathPoint;PointKind.SMOOTHPOINT 2415.04962444305,175.013837814331 2422.75732755661,175.099046230316 2407.21658706665,174.927213191986 PathPoint;PointKind.SMOOTHPOINT 2439.02493596077,174.288504123688 2454.17267918587,174.449951648712 2431.29103302956,174.206364154816 PathPoint;PointKind.SMOOTHPOINT 2484.39735531807,174.741926193237 2487.33775377274,174.769070148468 2469.33918714523,174.603610038757 PathPoint;PointKind.SMOOTHPOINT 2494.59510326385,173.236026763916 2503.0477309227,173.310377597809 2491.66355609894,173.210299015045 PathPoint;PointKind.SMOOTHPOINT 2518.41534018517,175.02799987793 2525.93539595604,175.084176063538 2510.06892800331,174.965214729309 PathPoint;PointKind.SMOOTHPOINT 2537.01579451561,176.125087738037 2541.29698634148,176.151051521301 2529.61753249168,176.080241203308 PathPoint;PointKind.SMOOTHPOINT 2554.49779987335,172.39928483963 2561.58449649811,172.435162067413 2550.26582121849,172.377805709839 PathPoint;PointKind.SMOOTHPOINT 2580.02598166466,173.457899093628 2586.84784770012,173.465452194214 2583.49816560745,173.462147712708 PathPoint;PointKind.SMOOTHPOINT 2599.73532557487,173.600935935974 2604.37056899071,173.660652637482 2593.40205073357,173.519268035889 PathPoint;PointKind.SMOOTHPOINT 2634.0344274044,173.598103523254 2657.20427155495,173.650739192963 2629.02884602547,173.586773872375 PathPoint;PointKind.SMOOTHPOINT 2691.9682431221,174.740509986877 2806.0220682621,173.362305164337 2670.85579276085,174.995663166046 PathPoint;PointKind.SMOOTHPOINT 3015.01553535461,174.125168323517 3123.42754840851,173.665137290955 2907.9450237751,174.579770565033 PathPoint;PointKind.SMOOTHPOINT 3343.01565527916,172.125012874603 3348.15683841705,172.071433067322 3270.62343478203,172.882447242737 PathPoint;PointKind.SMOOTHPOINT 3361.50883197784,174.374656677246 3367.15347647667,174.379377365112 3355.60148119926,174.370172023773 PathPoint;PointKind.SMOOTHPOINT 3377.30944633484,175.522727966309 3381.14099264145,175.554120540619 3371.06574654579,175.471036434174 PathPoint;PointKind.SMOOTHPOINT 3391.16065263748,174.57953453064 3406.40044927597,174.342555999756 3387.13331580162,174.64231967926 PathPoint;PointKind.SMOOTHPOINT 3440.4244530201,173.910140991211 3443.88070464134,174.221706390381 3436.96749329567,173.599047660828 PathPoint;PointKind.SMOOTHPOINT 3448.71067643166,173.81454706192 3457.19127416611,175.847983360291 3446.0064303875,173.166160583496 PathPoint;PointKind.SMOOTHPOINT 3467.15570211411,173.617694377899 3534.36885595322,172.940511703491 3460.94705343246,173.68047952652 PathPoint;PointKind.SMOOTHPOINT 3654.25143241882,173.262462615967 3697.54202842712,173.855617046356 3608.58373403549,172.636499404907 PathPoint;PointKind.SMOOTHPOINT 3877.4236035347,174.470722675323 3883.21517944336,174.482052326202 3786.19583845139,174.289448261261 PathPoint;PointKind.SMOOTHPOINT 3894.81922030449,174.50187921524 3902.36830830574,173.487639427185 3889.06836032867,175.274891853333 PathPoint;PointKind.SMOOTHPOINT 3912.05976247787,174.526898860931 3937.23212242126,174.558999538422 3906.32023215294,174.519817829132 PathPoint;PointKind.SMOOTHPOINT 3986.02822065353,174.560651779175 3990.50803542137,174.558763504028 3962.18815684319,174.570801258087 PathPoint;PointKind.SMOOTHPOINT 3999.90739703178,173.167340755463 3984.72566485405,173.178670406342 3995.51290869713,173.171117305756 PathPoint;PointKind.SMOOTHPOINT 4080.01546382904,174.125168323517 4102.60430932045,174.029338359833 4040.09048223495,174.292988777161 PathPoint;PointKind.SMOOTHPOINT 4147.17515587807,175.005104541779 4151.00918054581,174.980792999268 4125.15102267265,175.142240524292 PathPoint;PointKind.SMOOTHPOINT 4158.66944074631,174.932405948639 4167.80786633492,174.754199981689 4154.84037280083,175.007464885712 PathPoint;PointKind.SMOOTHPOINT 4178.88224601746,174.805655479431 4185.35430908203,174.765293598175 4172.14287400246,174.847433567047 PathPoint;PointKind.SMOOTHPOINT 4198.3189702034,174.687402248383 4200.788834095,174.673004150391 4191.82991266251,174.725639820099 PathPoint;PointKind.SMOOTHPOINT 4205.73351860046,174.6444439888 4212.64141917229,173.178434371948 4203.31251382828,175.158290863037 PathPoint;PointKind.SMOOTHPOINT 4219.16906833649,174.570565223694 4230.64281821251,174.5103764534 4214.68111038208,174.594168663025 PathPoint;PointKind.SMOOTHPOINT 4253.84700536728,174.413838386536 4257.94338226318,174.398732185364 4242.18631625175,174.456560611725 PathPoint;PointKind.SMOOTHPOINT 4266.1818087101,174.3727684021 4269.28294658661,175.646409988403 4261.80608510971,172.57536649704 PathPoint;PointKind.SMOOTHPOINT 4276.25776290894,174.346096515656 4287.09457397461,174.320840835571 4272.88754582405,174.354121685028 PathPoint;PointKind.SMOOTHPOINT 4309.17535543442,174.307386875153 4274.51689124107,174.307386875153 4298.05494904518,174.307150840759 PathPoint;PointKind.SMOOTHPOINT 4468.01564455032,175.12501001358 4586.18744373322,174.242477416992 4381.50490880013,175.771272182465 PathPoint;PointKind.SMOOTHPOINT 4769.86338973045,174.782288074493 4778.43674898148,174.74853515625 4678.37185621262,175.137047767639 PathPoint;PointKind.SMOOTHPOINT 4795.51124095917,174.681973457336 4806.99632048607,173.421077728271 4787.03028917313,175.61265707016 PathPoint;PointKind.SMOOTHPOINT 4819.70995903015,174.584963321686 4832.49582409859,174.532799720764 4811.64608001709,174.617536067963 PathPoint;PointKind.SMOOTHPOINT 4858.14048886299,174.421155452728 4880.99664330482,174.319424629211 4845.28770804405,174.478747844696 PathPoint;PointKind.SMOOTHPOINT 4931.82393550873,177.607383728027 4943.09623003006,177.71383523941 4908.87466549873,177.391176223755 PathPoint;PointKind.SMOOTHPOINT 4962.26776957512,176.694166660309 4964.78472232819,176.692750453949 4951.40759110451,176.700303554535 PathPoint;PointKind.SMOOTHPOINT 4970.01548051834,179.125084877014 4973.4855401516,179.115643501282 4967.51587629318,179.131693840027 PathPoint;PointKind.SMOOTHPOINT 4982.89162874222,175.755693912506 4994.82954025269,175.689132213593 4979.4520175457,175.774812698364 PathPoint;PointKind.SMOOTHPOINT 5018.27766895294,177.33948469162 5022.10000991821,177.284724712372 5006.58334493637,177.506597042084 PathPoint;PointKind.SMOOTHPOINT 5045.01635313034,176.885826587677 5050.87342858315,176.772058010101 5039.79373812675,176.987085342407 PathPoint;PointKind.SMOOTHPOINT 5062.59749293327,176.521625518799 5066.41806364059,176.43759727478 5056.72979593277,176.65002822876 PathPoint;PointKind.SMOOTHPOINT 5070.01558184624,178.125007152557 5073.30578327179,178.049004077911 5066.18191123009,178.213992118835 PathPoint;PointKind.SMOOTHPOINT 5083.96698474884,176.02902173996 5091.57165884972,175.846331119537 5080.66297531128,176.108093261719 PathPoint;PointKind.SMOOTHPOINT 5113.49630355835,175.102586746216 5157.41888165474,173.999598026276 5105.7811653614,175.29613494873 PathPoint;PointKind.SMOOTHPOINT 5249.99806165695,172.480244636536 5253.93299102783,172.431149482727 5196.98025226593,173.136892318726 PathPoint;PointKind.SMOOTHPOINT 5261.7745256424,175.487322807312 5268.71853947639,172.414627075195 5258.3412873745,177.006440162659 PathPoint;PointKind.SMOOTHPOINT 5279.45798635483,172.556719779968 5288.91258001328,172.460653781891 5273.92061948776,172.612659931183 PathPoint;PointKind.SMOOTHPOINT 5303.02224397659,173.610141277313 5307.35937595367,173.579456806183 5294.71088290215,173.668677806854 PathPoint;PointKind.SMOOTHPOINT 5318.7308049202,174.643263816833 5322.81337380409,174.622492790222 5314.67549800873,174.663798809052 PathPoint;PointKind.SMOOTHPOINT 5335.42964816093,172.701880931854 5417.28779196739,172.46915102005 5331.61084771156,172.71297454834 PathPoint;PointKind.SMOOTHPOINT 5511.20033025742,174.150660037994 5519.78147864342,174.045624732971 5439.51727509499,175.02587556839 PathPoint;PointKind.SMOOTHPOINT 5534.50506806374,173.837678432465 5541.50431394577,173.735239505768 5527.51219511032,173.940353393555 PathPoint;PointKind.SMOOTHPOINT 5553.40009331703,173.54428768158 5562.30307459831,171.532094478607 5547.89990186691,174.787244796753 PathPoint;PointKind.SMOOTHPOINT 5566.35271668434,173.33114862442 5602.44969248772,172.740354537964 5562.43194937706,173.395113945007 PathPoint;PointKind.SMOOTHPOINT 5631.97971940041,175.456638336182 5646.39882445335,176.973395347595 5606.78434610367,172.805263996124 PathPoint;PointKind.SMOOTHPOINT 5671.30670785904,186.429169178009 5673.99289727211,188.798718452454 5663.52536201477,179.565289020538 PathPoint;PointKind.SMOOTHPOINT 5672.16457486153,201.971797943115 5671.96772217751,206.260778903961 5672.42763519287,196.214919090271 PathPoint;PointKind.SMOOTHPOINT 5672.99588799477,211.259043216705 5675.60985088348,216.686418056488 5672.00737595558,209.206488132477 PathPoint;PointKind.SMOOTHPOINT 5672.26370930672,291.444411277771 5672.42551088333,298.126308917999 5671.27873778343,250.681743621826 PathPoint;PointKind.SMOOTHPOINT 5672.45312690735,321.297097206116 5669.55663084984,521.316890716553 5672.56040453911,313.909928798676 PathPoint;PointKind.SMOOTHPOINT 5669.94573354721,960.449438095093 5671.17146015167,978.63801240921 5668.97598624229,946.055116653442 PathPoint;PointKind.SMOOTHPOINT 5671.99321389198,1012.99588680267 5670.80466270447,1039.07438278198 5674.06158328056,967.607181072235 PathPoint;PointKind.SMOOTHPOINT 5675.45300602913,1110.29705286026 5675.415122509,1137.59348630905 5675.50398945808,1073.43343734741 PathPoint;PointKind.SMOOTHPOINT 5674.45316433907,1175.2969121933 5674.55513119698,1191.26558303833 5674.37987565994,1163.70101451874 PathPoint;PointKind.SMOOTHPOINT 5674.01555657387,1244.12501335144 5674.0530860424,1261.53656244278 5673.95642995834,1216.1879825592 PathPoint;PointKind.SMOOTHPOINT 5674.45316433907,1299.29710865021 5674.63833332062,1313.09497117996 5674.32004094124,1289.42260980606 PathPoint;PointKind.SMOOTHPOINT 5674.45316433907,1396.29709482193 5672.32991695404,1423.5977768898 5674.7626054287,1392.31590270996 PathPoint;PointKind.SMOOTHPOINT 5670.84608674049,1466.41795635223 5670.66516637802,1485.62997579575 5671.03479623795,1446.31915569305 PathPoint;PointKind.SMOOTHPOINT 5671.32511854172,1656.92603588104 5671.56764388084,1670.56221485138 5669.83703970909,1573.34295272827 PathPoint;PointKind.SMOOTHPOINT 5675.16905665398,1688.6870598793 5676.78955078125,1747.33971834183 5674.80579972267,1675.54914951324 PathPoint;PointKind.SMOOTHPOINT 5674.77322697639,1838.51177930832 5673.06067943573,1907.88016319275 5675.41689276695,1812.42148160934 PathPoint;PointKind.SMOOTHPOINT 5673.95855426788,2147.09039926529 5672.43330001831,2184.1246676445 5675.48310041428,2110.05660295486 PathPoint;PointKind.SMOOTHPOINT 5675.03133058548,2307.29709148407 5675.45548439026,2346.05181455612 5674.66063857079,2273.3909869194 PathPoint;PointKind.SMOOTHPOINT 5672.15289115906,2431.51798009872 5667.88055062294,2458.917324543 5677.45800018311,2397.48465299606 PathPoint;PointKind.SMOOTHPOINT 5671.91744685173,2547.94336080551 5671.01036667824,2565.34358024597 5672.16528296471,2543.18160295486 PathPoint;PointKind.SMOOTHPOINT 5672.6949441433,2625.33856630325 5673.68310213089,2643.29299449921 5671.14065766335,2597.0987033844 PathPoint;PointKind.SMOOTHPOINT 5675.01575231552,2675.12506484985 5677.85737037659,2689.90813493729 5671.23660564423,2655.47024488449 PathPoint;PointKind.SMOOTHPOINT 5673.42818498611,2719.60149765015 5673.76842856407,2734.24483537674 5673.1042277813,2705.65068483353 PathPoint;PointKind.SMOOTHPOINT 5674.03113484383,2765.29704809189 5671.00328564644,2831.02412939072 5674.63266849518,2752.23938941956 PathPoint;PointKind.SMOOTHPOINT 5674.03113484383,2898.29699993134 5672.64714717865,2926.51939630508 5675.5634701252,2867.01748609543 PathPoint;PointKind.SMOOTHPOINT 5675.56240797043,2980.42209863663 5676.48365020752,2989.84529972076 5673.68310213089,2961.20299816132 PathPoint;PointKind.SMOOTHPOINT 5676.51303648949,3021.27634763718 5675.75926065445,3084.31664943695 5676.88514471054,2990.21256923676 PathPoint;PointKind.SMOOTHPOINT 5676.52224183083,3407.21948862076 5675.82192778587,3425.26337385178 5676.5406525135,3406.74411535263 PathPoint;PointKind.SMOOTHPOINT 5675.56240797043,3693.42204809189 5675.69269895554,3726.65710687637 5675.49018144608,3674.84519720078 PathPoint;PointKind.SMOOTHPOINT 5672.56252884865,3755.42214632034 5671.60729765892,3763.23158025742 5674.12814497948,3742.62058496475 PathPoint;PointKind.SMOOTHPOINT 5667.56261229515,3776.42212629318 5661.49416804314,3778.4010386467 5672.01127052307,3774.97169494629 PathPoint;PointKind.SMOOTHPOINT 5647.01558232307,3789.12502527237 5638.25386762619,3790.02077579498 5657.0812690258,3788.09638738632 PathPoint;PointKind.SMOOTHPOINT 5598.01555037498,3789.12502527237 5554.58191752434,3789.72998142242 5618.15754532814,3788.84485244751 PathPoint;PointKind.SMOOTHPOINT 5095.12315034866,3785.75209379196 5033.91825199127,3785.60858488083 5156.32734060287,3785.89560270309 PathPoint;PointKind.SMOOTHPOINT 4480.30725359917,3787.33281612396 4402.7012693882,3786.94524765015 4557.91323781013,3787.72038459778 PathPoint;PointKind.SMOOTHPOINT 4033.91971707344,3787.33281612396 4024.98026847839,3787.62384653091 4083.71317863464,3785.71007966995 PathPoint;PointKind.SMOOTHPOINT 4004.12910819054,3791.84957027435 3981.9187438488,3792.69292116165 4011.4519572258,3791.57175779343 PathPoint;PointKind.SMOOTHPOINT 3945.21633982658,3787.71235942841 3936.55269742012,3788.33407402039 3962.30959653854,3786.48568868637 PathPoint;PointKind.SMOOTHPOINT 3918.69504332542,3790.62030315399 3912.67758250237,3790.75224637985 3930.01478075981,3790.37152290344 PathPoint;PointKind.SMOOTHPOINT 3889.98889446259,3790.81691980362 3878.38485360146,3790.8211684227 3902.74395704269,3790.81196308136 PathPoint;PointKind.SMOOTHPOINT 3852.911195755,3787.47302055359 3846.08791351318,3785.7258939743 3865.0951731205,3790.5917429924 PathPoint;PointKind.SMOOTHPOINT 3827.0158624649,3790.58725833893 3744.79162931442,3790.09371042252 3834.60354208946,3790.63304901123 PathPoint;PointKind.SMOOTHPOINT 3596.61183357239,3788.79150867462 3538.49143266678,3788.53234291077 3634.91171836853,3788.96263360977 PathPoint;PointKind.SMOOTHPOINT 3461.09929561615,3788.43981742859 3447.74057507515,3788.18395614624 3495.63525795937,3789.10307407379 PathPoint;PointKind.SMOOTHPOINT 3388.43091487885,3789.2437505722 3389.17796373367,3789.23124074936 3387.68422007561,3789.25602436066 PathPoint;PointKind.SMOOTHPOINT 3353.08488249779,3787.16711997986 3344.39468622208,3783.33935022354 3362.48141169548,3791.30621910095 PathPoint;PointKind.SMOOTHPOINT 3326.01551413536,3787.29717493057 3320.97983837128,3787.3033118248 3338.73021483421,3787.28230476379 PathPoint;PointKind.SMOOTHPOINT 3303.34063410759,3789.23926591873 3292.55162000656,3789.25649642944 3308.53350877762,3789.23100471497 PathPoint;PointKind.SMOOTHPOINT 3279.44250583649,3784.99182701111 3272.64046669006,3785.56916713715 3293.31176877022,3783.81425142288 PathPoint;PointKind.SMOOTHPOINT 3253.01574110985,3787.29717493057 3247.64477849007,3787.31133699417 3261.04669332504,3787.27569580078 PathPoint;PointKind.SMOOTHPOINT 3233.01572084427,3785.29701948166 3226.32981061935,3785.31590223312 3238.45678567886,3785.28167724609 PathPoint;PointKind.SMOOTHPOINT 3209.88446831703,3789.46751117706 3205.99910616875,3789.47884082794 3216.64897799492,3789.44697618484 PathPoint;PointKind.SMOOTHPOINT 3194.01552200317,3786.29709720612 3186.51069045067,3786.32022857666 3197.91964888573,3786.28505945206 PathPoint;PointKind.SMOOTHPOINT 3168.47459435463,3788.68765354156 3165.32707571983,3788.71668577194 3176.02934718132,3788.61896753311 PathPoint;PointKind.SMOOTHPOINT 3158.01555633545,3787.29693889618 3154.7041118145,3787.33021974564 3161.15209937096,3787.26554632187 PathPoint;PointKind.SMOOTHPOINT 3148.82968783379,3790.62148332596 3141.60491108894,3790.71684122086 3152.12626218796,3790.5778169632 PathPoint;PointKind.SMOOTHPOINT 3127.28671073914,3790.89292287827 3123.25654149055,3790.94154596329 3134.41943407059,3790.80747842789 PathPoint;PointKind.SMOOTHPOINT 3114.01544094086,3787.29693889618 3112.10179209709,3787.31865406036 3118.00949692726,3787.25185632706 PathPoint;PointKind.SMOOTHPOINT 3101.01572871208,3787.29693889618 3094.5511007309,3787.388048172 3102.91981816292,3787.26979494095 PathPoint;PointKind.SMOOTHPOINT 3086.015625,3789.29709434509 3082.73356676102,3789.34052467346 3092.27065443993,3789.21306610107 PathPoint;PointKind.SMOOTHPOINT 3072.24691271782,3786.45358800888 3069.5023047924,3786.48899316788 3075.46984434128,3786.41204595566 PathPoint;PointKind.SMOOTHPOINT 3059.47308540344,3789.39717292786 3051.45133852959,3789.53454494476 3062.17485308647,3789.35091018677 PathPoint;PointKind.SMOOTHPOINT 3028.05808782578,3786.33887529373 3017.46521830559,3788.93926620483 3036.94301247597,3784.15744543076 PathPoint;PointKind.SMOOTHPOINT 2989.7557246685,3788.22384595871 2982.43924856186,3787.71023511887 3000.28911352158,3788.96334171295 PathPoint;PointKind.SMOOTHPOINT 2973.01545739174,3787.29693889618 2964.32950973511,3787.79638767242 2978.95573496819,3786.95516109467 PathPoint;PointKind.SMOOTHPOINT 2952.43302226067,3791.10370159149 2952.33459591866,3791.56326055527 2952.7105987072,3789.80810880661 PathPoint;PointKind.SMOOTHPOINT 2943.331772089,3791.65436983109 2941.59975171089,3791.69520378113 2949.49722647667,3791.5092086792 PathPoint;PointKind.SMOOTHPOINT 2937.71403551102,3787.09678173065 2933.41018438339,3787.16853618622 2939.73885655403,3787.06255674362 PathPoint;PointKind.SMOOTHPOINT 2914.01559233665,3790.29693603516 2906.7313349247,3791.7032289505 2918.80414009094,3789.37262535095 PathPoint;PointKind.SMOOTHPOINT 2895.01576781273,3790.12510299683 2894.3182861805,3789.89072084427 2895.71324944496,3790.35948514938 PathPoint;PointKind.SMOOTHPOINT 2820.85682988167,3787.78553009033 2807.51864433289,3787.82235145569 2836.63372278214,3787.73997545242 PathPoint;PointKind.SMOOTHPOINT 2752.01574683189,3786.12502813339 2752.20941305161,3784.7593331337 2751.82172656059,3787.49072313309 PathPoint;PointKind.SMOOTHPOINT 2741.01571798325,3788.29701662064 2737.1678853035,3788.64186286926 2744.92019891739,3787.94744968414 PathPoint;PointKind.SMOOTHPOINT 2728.01565170288,3790.29693603516 2724.78032827377,3790.4824590683 2732.12619066238,3790.06137371063 PathPoint;PointKind.SMOOTHPOINT 2719.7053527832,3790.49945354462 2716.03702425957,3790.57120800018 2723.24055790901,3790.43029546738 PathPoint;PointKind.SMOOTHPOINT 2704.01555657387,3789.29709434509 2698.87755990028,3789.17223215103 2708.13954949379,3789.39740896225 PathPoint;PointKind.SMOOTHPOINT 2693.19503188133,3789.43847894669 2688.52969408035,3789.25744056702 2697.9032099247,3789.62093353271 PathPoint;PointKind.SMOOTHPOINT 2678.76813769341,3787.40527868271 2674.48517560959,3787.18033790588 2683.05605649948,3787.62998342514 PathPoint;PointKind.SMOOTHPOINT 2667.01574921608,3790.29693603516 2663.05143356323,3790.03942251205 2670.96554875374,3790.55326938629 PathPoint;PointKind.SMOOTHPOINT 2654.01568293571,3790.29693603516 2649.1609275341,3789.93108272552 2657.68967628479,3790.57333230972 PathPoint;PointKind.SMOOTHPOINT 2640.16872525215,3789.30087089539 2634.99532341957,3788.43745708466 2644.56215143204,3790.03399372101 PathPoint;PointKind.SMOOTHPOINT 2624.01547551155,3788.29701662064 2620.74687123299,3787.69630908966 2628.73958587646,3789.16562318802 PathPoint;PointKind.SMOOTHPOINT 2604.01545524597,3788.29701662064 2591.60523891449,3784.89434480667 2607.08933115005,3789.13965940475 PathPoint;PointKind.SMOOTHPOINT 2581.32535099983,3784.20252799988 2578.87460589409,3784.23911333084 2594.35551166534,3784.00614738464 PathPoint;PointKind.SMOOTHPOINT 2574.44117188454,3788.1535077095 2570.30514121056,3788.40464830399 2576.61115407944,3788.02180051804 PathPoint;PointKind.SMOOTHPOINT 2548.01546931267,3788.29701662064 2532.68149495125,3790.14658212662 2551.34497046471,3787.89552211761 PathPoint;PointKind.SMOOTHPOINT 2524.29047226906,3790.98426818848 2519.73807692528,3791.15492105484 2536.18554353714,3790.5388712883 PathPoint;PointKind.SMOOTHPOINT 2501.71083211899,3788.94139051437 2491.9082057476,3788.68954181671 2509.95244503021,3789.15311336517 PathPoint;PointKind.SMOOTHPOINT 2475.01569628716,3788.29701662064 2465.66059112549,3787.29363441467 2482.71136164665,3789.12242889404 PathPoint;PointKind.SMOOTHPOINT 2454.01548027992,3788.29701662064 2446.71989321709,3789.25578832626 2459.7429728508,3787.54453897476 PathPoint;PointKind.SMOOTHPOINT 2435.015655756,3788.29701662064 2433.15440654755,3788.20425510406 2446.76096320152,3788.88261795044 PathPoint;PointKind.SMOOTHPOINT 2419.01571035385,3788.29701662064 2412.58117675781,3788.114798069 2423.48384141922,3788.42376708984 PathPoint;PointKind.SMOOTHPOINT 2401.01572751999,3790.29693603516 2397.19692707062,3790.21597623825 2412.05009937286,3790.53037405014 PathPoint;PointKind.SMOOTHPOINT 2389.01550292969,3786.29709720612 2384.28820610046,3786.20362758636 2393.30873250961,3786.38254165649 PathPoint;PointKind.SMOOTHPOINT 2369.01548266411,3788.29701662064 2363.06068897247,3788.18584442139 2374.26712989807,3788.39497089386 PathPoint;PointKind.SMOOTHPOINT 2353.01553726196,3783.29710006714 2347.48064875603,3783.40001106262 2359.60231304169,3783.1750702858 PathPoint;PointKind.SMOOTHPOINT 2333.78628730774,3785.46743631363 2326.53531074524,3785.34705877304 2339.67168688774,3785.56562662125 PathPoint;PointKind.SMOOTHPOINT 2314.01569247246,3784.2969417572 2304.14792060852,3784.61346387863 2321.57540202141,3784.05453443527 PathPoint;PointKind.SMOOTHPOINT 2280.75679421425,3786.32188081741 2267.54111051559,3786.11204624176 2291.53766512871,3786.49347782135 PathPoint;PointKind.SMOOTHPOINT 2231.0001540184,3787.00000762939 2121.28877162933,3791.43320560455 2244.92323279381,3786.43753767014 PathPoint;PointKind.SMOOTHPOINT 1938.04618477821,3786.4245557785 1815.28269052505,3788.40913295746 1995.17488718033,3785.50118923187 PathPoint;PointKind.SMOOTHPOINT 1520.69795966148,3789.31007623672 1497.71824121475,3789.68017816544 1615.98457217216,3787.77443647385 PathPoint;PointKind.SMOOTHPOINT 1413.3158826828,3787.06114053726 1411.47269010544,3787.06916570663 1447.77536988258,3786.91125869751 PathPoint;PointKind.SMOOTHPOINT 1396.94949388504,3786.98324918747 1376.86591744423,3783.0443072319 1398.67124676704,3787.32125043869 PathPoint;PointKind.SMOOTHPOINT 1375.6072640419,3787.26743459702 1375.27374744415,3787.51267433167 1375.94113469124,3787.02195882797 PathPoint;PointKind.SMOOTHPOINT 1302.55190491676,3787.13006258011 1294.7422349453,3787.09819793701 1327.49413132668,3787.23084926605 PathPoint;PointKind.SMOOTHPOINT 1279.01809573174,3787.01889038086 1274.21326160431,3788.72612714767 1287.7415728569,3783.91905069351 PathPoint;PointKind.SMOOTHPOINT 1263.71386170387,3786.92943334579 1212.23546862602,3786.60653829575 1268.8221180439,3786.96177005768 PathPoint;PointKind.SMOOTHPOINT 1112.18013525009,3785.25193691254 1050.66898226738,3785.80118894577 1160.20510911942,3784.82306241989 PathPoint;PointKind.SMOOTHPOINT 918.092948198318,3786.25343084335 912.842363119125,3786.26523256302 984.625968933105,3786.10307693481 PathPoint;PointKind.SMOOTHPOINT 899.092415571213,3784.69890832901 891.893130540848,3784.71259832382 904.347603321075,3784.6887588501 PathPoint;PointKind.SMOOTHPOINT 880.735194683075,3786.32306098938 868.384459018707,3786.34099960327 887.93341755867,3786.31267547607 PathPoint;PointKind.SMOOTHPOINT 843.736095428467,3786.36413097382 838.759900331497,3786.36790752411 856.042928695679,3786.35468959808 PathPoint;PointKind.SMOOTHPOINT 828.391145467758,3784.51527357101 825.028009414673,3784.51716184616 833.354240655899,3784.51267719269 PathPoint;PointKind.SMOOTHPOINT 818.748196363449,3786.37829303741 806.846398115158,3786.38277769089 822.103189229965,3786.37734889984 PathPoint;PointKind.SMOOTHPOINT 783.214516639709,3786.38206958771 771.429201364517,3786.38041734695 794.993813037872,3786.38395786285 PathPoint;PointKind.SMOOTHPOINT 744.920296669006,3785.29064655304 737.998234033585,3785.30410051346 756.451402902603,3785.26893138885 PathPoint;PointKind.SMOOTHPOINT 722.015637159348,3787.29693889618 718.36147069931,3787.29859113693 728.804222345352,3787.29410648346 PathPoint;PointKind.SMOOTHPOINT 702.015616893768,3786.29709720612 685.937072038651,3786.29096031189 705.62729716301,3786.29851341248 PathPoint;PointKind.SMOOTHPOINT 663.408769369125,3788.05555343628 542.238153219223,3787.4583864212 678.511548042297,3788.13037633896 PathPoint;PointKind.SMOOTHPOINT 429.724806547165,3787.43855953217 426.302897930145,3787.36845731735 493.200945854187,3788.74170541763 PathPoint;PointKind.SMOOTHPOINT 415.982648134232,3785.41857719421 413.160148859024,3785.35768032074 419.456956386566,3785.49387216568 PathPoint;PointKind.SMOOTHPOINT 401.244896650314,3788.35696935654 394.436484575272,3788.17687511444 404.093595743179,3788.4325003624 PathPoint;PointKind.SMOOTHPOINT 383.57205748558,3787.31865406036 378.093817234039,3786.86877250671 390.863041877747,3787.91770935059 PathPoint;PointKind.SMOOTHPOINT 369.015580415726,3788.29701662064 361.236004829407,3789.01290893555 372.632217407227,3787.96397209167 PathPoint;PointKind.SMOOTHPOINT 357.06173658371,3786.25791549683 351.076494455338,3786.46916627884 362.581046819687,3786.06342315674 PathPoint;PointKind.SMOOTHPOINT 342.562615871429,3787.42203712463 329.91483092308,3788.31755161285 346.69687628746,3787.12935447693 PathPoint;PointKind.SMOOTHPOINT 292.562742233276,3788.42211484909 284.933992624283,3787.56200551987 304.048529863358,3789.71699953079 PathPoint;PointKind.SMOOTHPOINT 276.015787124634,3784.2969417572 274.007252454758,3780.24753570557 278.084864616394,3788.46837759018 PathPoint;PointKind.SMOOTHPOINT 266.562609672546,3770.42189598083 264.902815818787,3766.57052278519 267.46119260788,3772.50891208649 PathPoint;PointKind.CORNERPOINT 263.9390873909,3739.46362495422 263.9390873909,3739.46362495422 263.9390873909,3739.46362495422 PathPoint;PointKind.SMOOTHPOINT 264.696757793427,1965.37200450897 265.983735322952,1933.18706274033 262.626618146896,2017.14803695679 PathPoint;PointKind.SMOOTHPOINT 263.562376499176,1851.42191648483 263.589992523193,1849.37597036362 263.020677566528,1891.26546621323 PathPoint;PointKind.SMOOTHPOINT 265.983735322952,1840.36535739899 266.41992688179,1824.22461748123 265.927087068558,1842.45615005493 PathPoint;PointKind.SMOOTHPOINT 266.077913045883,1804.64580059052 266.148015260696,1800.44698476791 265.90584397316,1814.98599529266 PathPoint;PointKind.SMOOTHPOINT 264.158599376678,1787.7733540535 264.217017889023,1785.26005983353 264.089205265045,1790.75753688812 PathPoint;PointKind.SMOOTHPOINT 266.015599966049,1778.12497615814 268.631333112717,1773.91105413437 263.30887556076,1782.48453140259 PathPoint;PointKind.SMOOTHPOINT 264.834483861923,1762.25449562073 265.068866014481,1753.6954164505 264.739952087402,1765.70059776306 PathPoint;PointKind.SMOOTHPOINT 265.658007860184,1732.32580661774 265.871855020523,1724.54847335815 265.348920822144,1743.56104373932 PathPoint;PointKind.SMOOTHPOINT 270.25218129158,1711.38766765594 270.111622810364,1709.17460918427 271.426924467087,1729.91565942764 PathPoint;PointKind.SMOOTHPOINT 266.519769430161,1700.8496761322 266.614655256271,1697.34834194183 266.458164453506,1703.11182975769 PathPoint;PointKind.SMOOTHPOINT 265.015758275986,1655.12509346008 265.455844402313,1636.2048125267 264.796954393387,1664.5313000679 PathPoint;PointKind.SMOOTHPOINT 265.015758275986,1598.12491178513 265.123389959335,1593.91547441483 264.55195069313,1616.33236885071 PathPoint;PointKind.SMOOTHPOINT 272.541124820709,1588.35828065872 273.632665872574,1545.47130346298 272.437033653259,1592.4485206604 PathPoint;PointKind.SMOOTHPOINT 265.818039178848,1501.06922149658 265.406631231308,1486.95672512054 266.127126216888,1511.66787385941 PathPoint;PointKind.SMOOTHPOINT 267.97315120697,1428.64253997803 263.514579534531,1400.78764915466 272.267796993256,1455.47445774078 PathPoint;PointKind.SMOOTHPOINT 264.562572240829,1359.42191362381 264.613909721375,1354.37148571014 264.383776187897,1377.05462694168 PathPoint;PointKind.SMOOTHPOINT 264.374216794968,1334.32815313339 264.577796459198,1329.9348449707 263.73125910759,1348.19045305252 PathPoint;PointKind.SMOOTHPOINT 264.122486114502,1313.7780547142 264.594436883926,1304.1948223114 263.872879743576,1318.85303020477 PathPoint;PointKind.SMOOTHPOINT 268.427753448486,1286.71199083328 269.084519147873,1274.19296264648 267.823741436005,1298.2212638855 PathPoint;PointKind.SMOOTHPOINT 267.884992361069,1242.00778484344 271.742030382156,1171.01147174835 267.125197649002,1255.99187850952 PathPoint;PointKind.SMOOTHPOINT 267.986959218979,1043.65510225296 268.332159519196,1029.79303836823 266.868156194687,1088.68361949921 PathPoint;PointKind.SMOOTHPOINT 270.035147666931,1011.90918445587 270.262094736099,1000.85616588593 269.965045452118,1015.32790660858 PathPoint;PointKind.SMOOTHPOINT 267.015795707703,991.124939918518 263.562730550766,982.093555927277 270.172165632248,999.380478858948 PathPoint;PointKind.SMOOTHPOINT 263.410842418671,955.296807289124 263.536884784698,952.656526565552 263.020677566528,963.459820747375 PathPoint;PointKind.SMOOTHPOINT 265.207654237747,922.745068073273 265.59250831604,915.883548259735 264.194712638855,940.79461812973 PathPoint;PointKind.SMOOTHPOINT 270.426374673843,901.734702587128 271.570315361023,879.037635326385 269.998680353165,910.220375061035 PathPoint;PointKind.SMOOTHPOINT 268.259578943253,868.587684631348 272.934830188751,785.824584960938 267.631845474243,879.698531627655 PathPoint;PointKind.SMOOTHPOINT 276.106778383255,610.036318302155 276.312128305435,591.976618766785 275.410358905792,671.312971115112 PathPoint;PointKind.SMOOTHPOINT 275.237227678299,567.368381023407 276.095802783966,549.24117565155 274.993286132812,572.521719932556 PathPoint;PointKind.SMOOTHPOINT 272.800644636154,432.771656513214 273.126018047333,424.923512935638 270.314494371414,492.670104503632 PathPoint;PointKind.SMOOTHPOINT 269.617720842361,416.611089706421 268.70497584343,410.216445922852 270.582157373428,423.368046283722 PathPoint;PointKind.SMOOTHPOINT 269.683220386505,391.805763244629 269.851748943329,388.189244270325 269.367052316666,398.604969978333 PathPoint;PointKind.SMOOTHPOINT 275,367 276.212980747223,341.990267753601 274.831471443176,370.461680412292 PathPoint;PointKind.SMOOTHPOINT 269,314 267.463221145194,286.927959281606 269.618229461711,324.898583012505 PathPoint;PointKind.SMOOTHPOINT 268,228 268.0431228798,224.546483315226 267.85739709631,239.42042251051 PathPoint;PointKind.SMOOTHPOINT 272.987583875656,193.328454494476 273.437229394913,189.814846515656 271.934185350667,201.568251195428 PathPoint;PointKind.SMOOTHPOINT 276.015433073044,183.296992778778 276.560318470001,182.995576858521 273.546985387802,184.662923812866 PathPoint;PointKind.SMOOTHPOINT 278.562480211258,177.422096729279 282.114325761795,173.469936847687 276.995093822479,179.16615486145 PathPoint";
	
	subshadow35mm[0] = "PointKind.SMOOTHPOINT 271,185 271.81211339948,181.723989853914 266.984742201254,201.197276508748 PathPoint;PointKind.SMOOTHPOINT 290.45436501503,170.280640125275 291.921908855438,169.510223865509 287.086980342865,172.048065662384 PathPoint;PointKind.SMOOTHPOINT 2455.72307109833,171.917538642883 2462.78852462769,171.926271915436 1308.55449557304,170.520451068878 PathPoint;PointKind.SMOOTHPOINT 2476.93465590477,171.943502426147 2484.32017207146,176.92666053772 2471.0694372654,167.986149787903 PathPoint;PointKind.SMOOTHPOINT 2494.26937580109,171.964509487152 3970.00632405281,173.768520355225 2488.48806738853,171.957428455353 PathPoint;PointKind.SMOOTHPOINT 5648.0132997036,176.26859664917 5654.45172786713,176.419186592102 5644.41224098206,176.184568405151 PathPoint;PointKind.SMOOTHPOINT 5675,196 5676.51013496667,208.367526136897 5673.78280752296,186.053705066703 PathPoint;PointKind.SMOOTHPOINT 5677,452 5677.02195119858,461.724380970001 5676.62293505669,285.506059646606 PathPoint;PointKind.SMOOTHPOINT 5680.67385077477,500.168681144714 5678.46067428589,507.259862422943 5683.84792327881,489.998667240143 PathPoint;PointKind.SMOOTHPOINT 5680.72483420372,522.802727222443 5681.08702898026,684.060008525848 5680.7078397274,515.142703056335 PathPoint;PointKind.SMOOTHPOINT 5682.0627951622,1134.56587314606 5682.1017408371,1152.77049779892 5681.5511906147,896.064212322235 PathPoint;PointKind.SMOOTHPOINT 5682.18069434166,1189.63198900223 5680.22668361664,1200.92316627502 5684.9667263031,1173.53066682816 PathPoint;PointKind.SMOOTHPOINT 5682.25433707237,1224.17137384415 5682.65937209129,1413.82618904114 5682.22955346107,1212.60474443436 PathPoint;PointKind.SMOOTHPOINT 5683.51688504219,1824.19888973236 5683.53033900261,1830.64003229141 5683.08848261833,1617.599401474 PathPoint;PointKind.SMOOTHPOINT 5683.55724692345,1843.5298705101 5679.12947773933,1856.08076334 5685.70173740387,1837.45080471039 PathPoint;PointKind.SMOOTHPOINT 5683.59725475311,1862.86085128784 5684.35067653656,2226.98544502258 5683.58380079269,1856.41498804092 PathPoint;PointKind.SMOOTHPOINT 5685.69784283638,2913.40320110321 5685.72722911835,2928.71262788773 5685.09701728821,2597.68241643906 PathPoint;PointKind.SMOOTHPOINT 5685.78423142433,2958.93683195114 5682.59174823761,2969.86357212067 5691.13253474236,2940.63330888748 PathPoint;PointKind.SMOOTHPOINT 5685.84831476212,2992.85048961639 5685.86318492889,3000.67927837372 5685.82707166672,2981.6261100769 PathPoint;PointKind.SMOOTHPOINT 5685.89221715927,3016.21765851974 5684.12266731262,3027.47980356216 5687.09493041039,3008.5625910759 PathPoint;PointKind.SMOOTHPOINT 5685.94957351685,3046.88017845154 5686.35035991669,3262.08241224289 5685.93045473099,3036.73235177994 PathPoint;PointKind.SMOOTHPOINT 5686.84249162674,3569.81838941574 5686.85665369034,3579.85362768173 5686.66511178017,3444.08215999603 PathPoint;PointKind.SMOOTHPOINT 5686.88249945641,3598.83692979813 5682.47774362564,3611.02126121521 5690.04630446434,3590.08453845978 PathPoint;PointKind.SMOOTHPOINT 5686.91613435745,3625.12596845627 5686.92888021469,3635.38449525833 5686.90586686134,3616.72597646713 PathPoint;PointKind.SMOOTHPOINT 5686.95012331009,3654.24081087112 5683.90244722366,3663.1017780304 5689.92451071739,3645.59321880341 PathPoint;PointKind.SMOOTHPOINT 5686.9745528698,3678.43244791031 5686.98198795319,3686.67854547501 5686.967471838,3670.87698698044 PathPoint;PointKind.SMOOTHPOINT 5684,3695 5680.70165538788,3702.44216442108 5686.83630728722,3688.60039949417 PathPoint;PointKind.SMOOTHPOINT 5679,3716 5679.00460267067,3738.41382598877 5678.99858379364,3710.01676416397 PathPoint;PointKind.SMOOTHPOINT 5678,3757 5677.16089773178,3760.86128664017 5678.04850506783,3756.77741956711 PathPoint;PointKind.SMOOTHPOINT 5658.99208545685,3786.03722333908 5656.68296098709,3787.35689163208 5661.64959669113,3784.51857805252 PathPoint;PointKind.SMOOTHPOINT 529.208700656891,3788.89418363571 521.738212108612,3788.88993501663 1596.14493727684,3789.49512720108 PathPoint;PointKind.SMOOTHPOINT 509.999985694885,3788.00008535385 501.132409572601,3782.03360795975 518.076256513596,3793.43406915665 PathPoint;PointKind.SMOOTHPOINT 476.17708325386,3788.86019468307 348.033421039581,3788.76719713211 486.194972991943,3788.86751174927 PathPoint;PointKind.SMOOTHPOINT 274.938054084778,3788.42305898666 271.207766532898,3786.68702602386 275.370351076126,3788.62439632416 PathPoint;PointKind.SMOOTHPOINT 259,3762 261.884907184757,3743.06904193977 258.689744505541,3764.03629194624 PathPoint;PointKind.SMOOTHPOINT 257,3506 257.027970075607,3498.03855991364 256.412982463837,3673.47159481049 PathPoint;PointKind.SMOOTHPOINT 251.943111419678,3470.56687116623 249.174427986145,3463.659324646 255.771825313568,3480.11847496033 PathPoint;PointKind.SMOOTHPOINT 252.02277302742,3447.88585424423 252.048618793488,3440.55462598801 251.995865106583,3455.56381702423 PathPoint;PointKind.SMOOTHPOINT 252.101372480392,3425.57517528534 248.331431150436,3419.68588113785 257.528629302979,3434.05235052109 PathPoint;PointKind.SMOOTHPOINT 252.176431417465,3404.33019161224 252.196612358093,3398.59951257706 252.151293754578,3411.50020837784 PathPoint;PointKind.SMOOTHPOINT 252.238036394119,3386.97127819061 248.038984537125,3379.60983753204 256.340078115463,3394.16324615479 PathPoint;PointKind.SMOOTHPOINT 252.32902765274,3361.20198726654 254.028475284576,2881.16538763046 252.298225164413,3369.90575551987 PathPoint;PointKind.SMOOTHPOINT 259.327919483185,1369.62804079056 259.366865158081,1358.02459001541 257.007111310959,2057.09591388702 PathPoint;PointKind.SMOOTHPOINT 259.444756507874,1334.93688583374 255.95486998558,1325.71927070618 264.150810241699,1347.36669301987 PathPoint;PointKind.SMOOTHPOINT 259.543890953064,1305.46067476273 260.315369367599,1075.68190097809 259.510964155197,1315.25492191315 PathPoint;PointKind.SMOOTHPOINT 261.535785198212,686.984710693359 261.558798551559,679.304859638214 261.004353761673,863.298861980438 PathPoint;PointKind.SMOOTHPOINT 261.604117155075,664.152159690857 257.461359500885,656.925730705261 269.855997562408,678.545536994934 PathPoint;PointKind.SMOOTHPOINT 261.677759885788,639.421420097351 261.702897548676,630.882639884949 261.65368437767,647.578296661377 PathPoint;PointKind.SMOOTHPOINT 261.752110719681,614.094929695129 261.799199581146,598.054976463318 261.727681159973,622.43968963623 PathPoint;PointKind.SMOOTHPOINT 261.888420581818,567.080655097961 258.530595302582,559.694430828094 269.982748031616,584.885437488556 PathPoint;PointKind.SMOOTHPOINT 269,523 267.860061687305,312.552415098198 269.04277804741,530.897389414856 PathPoint";
	
} else if (mask_variant_35mm == 5) {
	
	mask35mm[0] = "PointKind.CORNERPOINT 246.629859209061,173.235790729523 246.629859209061,173.235790729523 246.629859209061,173.235790729523 PathPoint;PointKind.SMOOTHPOINT 249.569903612137,155.682857036591 250.197991132736,155.570032596588 244.761528968811,156.544382572174 PathPoint;PointKind.SMOOTHPOINT 260.350420475006,155.682857036591 275.499933958054,155.846428871155 259.622136354446,155.674831867218 PathPoint;PointKind.CORNERPOINT 337.775484323502,154.707562923431 337.775484323502,154.707562923431 337.775484323502,154.707562923431 PathPoint;PointKind.SMOOTHPOINT 356.396473646164,155.682857036591 366.033049821854,154.210002422333 346.759897470474,157.155475616455 PathPoint;PointKind.SMOOTHPOINT 469.103486537933,153.732504844666 475.238138437271,152.605204582214 462.968834638596,154.859805107117 PathPoint;PointKind.CORNERPOINT 481.844741106033,158.608267307281 481.844741106033,158.608267307281 481.844741106033,158.608267307281 PathPoint;PointKind.CORNERPOINT 946.393353939056,159.583561420441 946.393353939056,159.583561420441 946.393353939056,159.583561420441 PathPoint;PointKind.CORNERPOINT 995.396572351456,157.632973194122 995.396572351456,157.632973194122 995.396572351456,157.632973194122 PathPoint;PointKind.SMOOTHPOINT 1014.01756167412,153.732504844666 1020.87589502335,150.795056819916 1007.15958237648,156.669716835022 PathPoint;PointKind.CORNERPOINT 1035.57894945145,159.583561420441 1035.57894945145,159.583561420441 1035.57894945145,159.583561420441 PathPoint;PointKind.SMOOTHPOINT 1264.91303443909,156.657915115356 1281.28190159798,157.625420093536 1248.54487538338,155.69064617157 PathPoint;PointKind.SMOOTHPOINT 1302.15572118759,156.657915115356 1311.43505930901,154.595918655396 1292.87602901459,158.719675540924 PathPoint;PointKind.SMOOTHPOINT 1320.77671051025,157.632973194122 1329.60144639015,158.815977573395 1311.95197463036,156.450204849243 PathPoint;PointKind.SMOOTHPOINT 1367.8198993206,159.583561420441 1376.63861632347,156.605987548828 1359.00118231773,162.56089925766 PathPoint;PointKind.SMOOTHPOINT 1393.30134630203,158.608267307281 1401.46825432777,156.605987548828 1385.13443827629,160.610547065735 PathPoint;PointKind.CORNERPOINT 1803.94702076912,158.608267307281 1803.94702076912,158.608267307281 1803.94702076912,158.608267307281 PathPoint;PointKind.SMOOTHPOINT 1815.70755243301,158.608267307281 1821.34263753891,158.211257457733 1810.07282137871,159.00527715683 PathPoint;PointKind.SMOOTHPOINT 1874.51127290726,158.608267307281 1884.72672343254,157.611021995544 1864.29582238197,159.605276584625 PathPoint;PointKind.SMOOTHPOINT 1912.73397445679,157.632973194122 1919.64789390564,160.021169185638 1905.81970095634,155.245013237 PathPoint;PointKind.SMOOTHPOINT 1932.33462452888,158.608267307281 1943.26667547226,157.410864830017 1921.40328168869,159.805433750153 PathPoint;PointKind.SMOOTHPOINT 2070.52343845367,157.632973194122 2082.55269527435,153.595604896545 2058.494181633,161.670577526093 PathPoint;PointKind.CORNERPOINT 2113.64621400833,159.583561420441 2113.64621400833,159.583561420441 2113.64621400833,159.583561420441 PathPoint;PointKind.SMOOTHPOINT 2121.48668646812,155.682857036591 2126.35879039764,156.005752086639 2116.61493659019,155.359725952148 PathPoint;PointKind.SMOOTHPOINT 2142.06805944443,158.608267307281 2149.16856408119,156.005752086639 2134.96755480766,161.21054649353 PathPoint;PointKind.CORNERPOINT 2334.15981173515,157.632973194122 2334.15981173515,157.632973194122 2334.15981173515,157.632973194122 PathPoint;PointKind.SMOOTHPOINT 2346.90071225166,154.707562923431 2351.79476737976,154.755477905273 2342.00701117516,154.659647941589 PathPoint;PointKind.SMOOTHPOINT 2356.70121431351,156.657915115356 2364.33775305748,157.020463943481 2349.06502962112,156.295366287231 PathPoint;PointKind.SMOOTHPOINT 2430.20586490631,157.632973194122 2437.61651873589,158.425576686859 2422.79521107674,156.840605735779 PathPoint;PointKind.SMOOTHPOINT 2474.30865526199,157.632973194122 2492.32173800468,161.840758323669 2456.2955725193,153.425424098969 PathPoint;PointKind.CORNERPOINT 2581.13557934761,157.632973194122 2581.13557934761,157.632973194122 2581.13557934761,157.632973194122 PathPoint;PointKind.SMOOTHPOINT 2629.15842890739,155.682857036591 2643.71950864792,159.835410118103 2614.59734916687,151.530067920685 PathPoint;PointKind.SMOOTHPOINT 2698.74266624451,156.657915115356 2708.91775488853,157.82534122467 2688.56757760048,155.490489006042 PathPoint;PointKind.SMOOTHPOINT 2754.60634231567,153.732504844666 2763.42258095741,151.599934101105 2745.79010367393,155.864839553833 PathPoint;PointKind.CORNERPOINT 3024.1231584549,156.657915115356 3024.1231584549,156.657915115356 3024.1231584549,156.657915115356 PathPoint;PointKind.CORNERPOINT 3105.46828150749,153.732504844666 3105.46828150749,153.732504844666 3105.46828150749,153.732504844666 PathPoint;PointKind.CORNERPOINT 3891.47697329521,152.757210731506 3891.47697329521,152.757210731506 3891.47697329521,152.757210731506 PathPoint;PointKind.SMOOTHPOINT 3932.63971924782,151.781916618347 3942.42322683334,149.189786911011 3922.85621166229,154.374282360077 PathPoint;PointKind.CORNERPOINT 3952.2410774231,156.657915115356 3952.2410774231,156.657915115356 3952.2410774231,156.657915115356 PathPoint;PointKind.SMOOTHPOINT 4077.68863677979,152.757210731506 4084.64575052261,153.694739341736 4070.73187708855,151.819682121277 PathPoint;PointKind.CORNERPOINT 4677.48601913452,150.806858539581 4677.48601913452,150.806858539581 4677.48601913452,150.806858539581 PathPoint;PointKind.SMOOTHPOINT 4701.98745131493,151.781916618347 4708.47650885582,151.542813777924 4695.49874782562,152.021255493164 PathPoint;PointKind.SMOOTHPOINT 4728.44926714897,148.856506347656 4737.34198093414,150.337858200073 4719.5565533638,147.375154495239 PathPoint;PointKind.SMOOTHPOINT 4919.5316183567,147.653203010559 4920.63555121422,147.013077735901 4919.5316183567,147.653203010559 PathPoint;PointKind.SMOOTHPOINT 5069.51070427895,146.906154155731 5084.95018601418,145.494904518127 5054.0223634243,148.321888446808 PathPoint;PointKind.SMOOTHPOINT 5243.96148204803,147.881212234497 5258.14974546432,148.327789306641 5229.77321863174,147.43510723114 PathPoint;PointKind.SMOOTHPOINT 5434.09320473671,144.955801963806 5445.22387862206,145.312685966492 5422.96253085136,144.598917961121 PathPoint;PointKind.SMOOTHPOINT 5470.35587668419,146.906154155731 5479.13493990898,146.717798709869 5461.57610535622,147.094509601593 PathPoint;PointKind.SMOOTHPOINT 5491.91691040993,142.030391693115 5500.73385715485,141.697583198547 5483.1003177166,142.363200187683 PathPoint;PointKind.SMOOTHPOINT 5651.66675806046,141.054861545563 5658.59342336655,139.287436008453 5644.74044680595,142.822759151459 PathPoint;PointKind.SMOOTHPOINT 5677.14855909348,153.732504844666 5682.21255898476,168.208966255188 5672.0842051506,139.25580739975 PathPoint;PointKind.SMOOTHPOINT 5687.92943000793,207.367308139801 5684.87538099289,218.122923374176 5690.99764108658,196.560709476471 PathPoint;PointKind.SMOOTHPOINT 5686.53942346573,234.195213317871 5685.64615130424,243.349099159241 5687.53395438194,224.009149074554 PathPoint;PointKind.SMOOTHPOINT 5676.16854429245,247.349410057068 5675.11382460594,265.167174339294 5677.16236710548,230.55107831955 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,279.530339241028 5685.46912550926,296.802864074707 5686.46896719933,262.258050441742 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,353.64372253418 5684.02671933174,364.235057830811 5687.91137337685,343.052859306335 PathPoint;PointKind.SMOOTHPOINT 5683.02864789963,397.52676486969 5682.81550884247,409.427382946014 5683.24214100838,385.626618862152 PathPoint;PointKind.SMOOTHPOINT 5689.88945960999,442.385101318359 5688.26790332794,454.014987945557 5691.51066184044,430.755214691162 PathPoint;PointKind.SMOOTHPOINT 5684.00901675224,502.846255302429 5682.61440753937,514.668509960175 5685.40327191353,491.024000644684 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,544.778709411621 5683.82561802864,557.045888900757 5686.1524450779,532.511529922485 PathPoint;PointKind.SMOOTHPOINT 5688.90944480896,597.438454627991 5688.67010593414,611.674160957336 5689.14842963219,583.202748298645 PathPoint;PointKind.SMOOTHPOINT 5683.02864789963,630.594441890717 5679.38333272934,643.61079454422 5686.67431712151,617.578089237213 PathPoint;PointKind.CORNERPOINT 5681.06861829758,667.651133537292 5681.06861829758,667.651133537292 5681.06861829758,667.651133537292 PathPoint;PointKind.SMOOTHPOINT 5681.06861829758,700.807120800018 5676.15721464157,716.519694328308 5685.98037600517,685.094783306122 PathPoint;PointKind.SMOOTHPOINT 5682.0486330986,744.690163135529 5681.00134849548,763.517446517944 5683.09627175331,725.863115787506 PathPoint;PointKind.SMOOTHPOINT 5680.08860349655,774.920976161957 5678.98148417473,787.414040565491 5681.19607686996,762.427911758423 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,802.225670814514 5685.03682851791,832.206287384033 5684.94123458862,772.245526313782 PathPoint;PointKind.SMOOTHPOINT 5683.02864789963,881.215288639069 5681.98277950287,890.892698764801 5684.07487034798,871.537878513336 PathPoint;PointKind.SMOOTHPOINT 5684.00901675224,909.495277404785 5683.39473724365,921.019420623779 5684.62329626083,897.971606254578 PathPoint;PointKind.SMOOTHPOINT 5680.08860349655,968.00607919693 5679.07389163971,978.479161262512 5682.22990751266,945.90381860733 PathPoint;PointKind.SMOOTHPOINT 5681.93816900253,1000.24766921997 5682.30355024338,1002.81312704086 5680.33006668091,988.947050571442 PathPoint;PointKind.SMOOTHPOINT 5683.06546926498,1008.08283090591 5683.2835650444,1009.61516618729 5682.68663406372,1005.42177915573 PathPoint;PointKind.SMOOTHPOINT 5683.71125936508,1012.7338886261 5682.66220450401,1013.92680644989 5684.76066827774,1011.54097080231 PathPoint;PointKind.SMOOTHPOINT 5684.30500388145,1017.35213756561 5685.24288654327,1025.05393981934 5684.11487817764,1015.79336643219 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,1042.11969852448 5685.97648143768,1046.49908065796 5685.95453023911,1033.2412648201 PathPoint;PointKind.SMOOTHPOINT 5686.29194140434,1054.36138629913 5687.73717999458,1056.65516853333 5684.49973225594,1051.51646375656 PathPoint;PointKind.SMOOTHPOINT 5687.99988627434,1073.99991989136 5688.73135685921,1085.57551860809 5687.62388348579,1068.04972887039 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,1105.50602674484 5678.34950208664,1123.87068271637 5688.73277306557,1095.15119791031 PathPoint;PointKind.SMOOTHPOINT 5682.0486330986,1160.11612415314 5681.37982964516,1176.89392089844 5682.71814465523,1143.33856344223 PathPoint;PointKind.SMOOTHPOINT 5688.90944480896,1212.77586936951 5689.31908249855,1216.45186901093 5687.96129465103,1204.27037000656 PathPoint;PointKind.SMOOTHPOINT 5690.60853838921,1219.448325634 5692.98564076424,1220.82889080048 5687.86888718605,1217.8572177887 PathPoint;PointKind.SMOOTHPOINT 5696.00003600121,1225.99993228912 5697.33481049538,1227.63116598129 5693.10991287231,1222.46838569641 PathPoint;PointKind.SMOOTHPOINT 5702.63000607491,1231.3040971756 5704.34786438942,1234.06640768051 5700.90223431587,1228.52644443512 PathPoint;PointKind.SMOOTHPOINT 5706.44597411156,1239.84358549118 5707.31906533241,1242.81573057175 5705.58987736702,1236.92808866501 PathPoint;PointKind.SMOOTHPOINT 5707.95954465866,1248.87945413589 5707.13991522789,1250.46489715576 5709.35627818108,1246.17874860764 PathPoint;PointKind.SMOOTHPOINT 5707.8065943718,1256.4054107666 5707.63381719589,1258.33711624146 5708.02964687347,1253.90981912613 PathPoint;PointKind.SMOOTHPOINT 5705.9998691082,1262.9999756813 5703.93114566803,1264.79407310486 5707.45148062706,1261.74120426178 PathPoint;PointKind.SMOOTHPOINT 5706.1938893795,1266.33136510849 5705.87028622627,1267.76338577271 5706.50510072708,1264.9548125267 PathPoint;PointKind.SMOOTHPOINT 5705.14766693115,1270.55756092072 5705.24361491203,1273.93238067627 5705.10695099831,1269.12624835968 PathPoint;PointKind.SMOOTHPOINT 5702.63000607491,1279.08784389496 5700.47949671745,1285.94346284866 5703.46946239471,1276.41215801239 PathPoint;PointKind.SMOOTHPOINT 5700.00011086464,1297.00002193451 5701.21556997299,1299.23267126083 5699.5253276825,1296.12811088562 PathPoint;PointKind.SMOOTHPOINT 5700.76840281487,1303.4751534462 5700.25609016418,1305.08726835251 5701.38657689095,1301.53141021729 PathPoint;PointKind.SMOOTHPOINT 5701.64999127388,1308.34312677383 5702.41934537888,1312.40740299225 5701.38268232346,1306.93211317062 PathPoint;PointKind.SMOOTHPOINT 5704.57622766495,1327.16970205307 5704.70014572144,1328.8410615921 5703.98991823196,1319.25334453583 PathPoint;PointKind.SMOOTHPOINT 5703.99983167648,1332.99998760223 5705.75026273727,1334.07347202301 5702.6055765152,1332.14483499527 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1338.57370376587 5704.20128703117,1343.37629556656 5704.7613966465,1336.45977973938 PathPoint;PointKind.SMOOTHPOINT 5702.33437299728,1356.3702249527 5701.08634114265,1357.91625022888 5703.2934987545,1355.18226385117 PathPoint;PointKind.SMOOTHPOINT 5701.46977901459,1361.4688038826 5699.96895432472,1369.84094381332 5701.76966071129,1359.79602813721 PathPoint;PointKind.SMOOTHPOINT 5696.74956321716,1379.53133583069 5693.89272093773,1383.96547794342 5698.21285843849,1377.26044893265 PathPoint;PointKind.SMOOTHPOINT 5702.63000607491,1401.96026802063 5703.1663942337,1405.17694473267 5701.17627024651,1393.24092149734 PathPoint;PointKind.SMOOTHPOINT 5702.29684352875,1417.14270830154 5702.16265797615,1418.52539777756 5702.94617414474,1410.45467376709 PathPoint;PointKind.SMOOTHPOINT 5701.84188723564,1421.46591424942 5700.03941059113,1423.62633705139 5702.80738592148,1420.30887365341 PathPoint;PointKind.SMOOTHPOINT 5701.25805616379,1426.41319513321 5701.0424387455,1428.16763877869 5701.46800875664,1424.70713853836 PathPoint;PointKind.SMOOTHPOINT 5700.57084202766,1431.84245824814 5698.94539117813,1433.44418764114 5701.90844893456,1430.5242061615 PathPoint;PointKind.SMOOTHPOINT 5699.95337605476,1436.54922008514 5696.88658118248,1459.71363544464 5700.16509890556,1434.9489068985 PathPoint;PointKind.SMOOTHPOINT 5693.80951881409,1512.15552091599 5694.56966757774,1527.91058063507 5692.69992113113,1489.16105031967 PathPoint;PointKind.CORNERPOINT 5713.41087698936,1539.46045160294 5713.41087698936,1539.46045160294 5713.41087698936,1539.46045160294 PathPoint;PointKind.SMOOTHPOINT 5713.41087698936,1589.19455051422 5709.36866998672,1593.7856554985 5717.45272994041,1584.60368156433 PathPoint;PointKind.SMOOTHPOINT 5712.43086218834,1609.67336654663 5710.37913322449,1618.68704795837 5714.48259115219,1600.65944910049 PathPoint;PointKind.SMOOTHPOINT 5708.51044893265,1646.73005819321 5705.33354401588,1656.84908866882 5711.68735384941,1636.6107916832 PathPoint;PointKind.SMOOTHPOINT 5709.49081778526,1664.28322792053 5708.56001615524,1669.50478076935 5710.4209113121,1659.06167507172 PathPoint;PointKind.SMOOTHPOINT 5708.51044893265,1685.73710203171 5710.579880476,1691.59618377686 5706.4410173893,1679.87825632095 PathPoint;PointKind.SMOOTHPOINT 5708.51044893265,1724.7443819046 5708.15745949745,1738.79385709763 5708.86308431625,1710.69467067719 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1788.13094615936 5699.07214164734,1798.64722251892 5710.10828375816,1777.61443376541 PathPoint;PointKind.SMOOTHPOINT 5705.57005047798,1816.41093492508 5704.92638468742,1823.75349283218 5706.21407032013,1809.06861305237 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1892.47490644455 5702.91147708893,1906.49818181992 5706.26894831657,1878.45163106918 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1946.10970973969 5703.51442694664,1959.12134170532 5705.66599845886,1933.09807777405 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1987.06710577011 5697.86128520966,2000.69856405258 5711.31949424744,1973.43588352203 PathPoint;PointKind.SMOOTHPOINT 5698.7099468708,2023.14873933792 5699.4793009758,2036.65061473846 5697.9409468174,2009.64709997177 PathPoint;PointKind.SMOOTHPOINT 5701.64999127388,2094.33671236038 5697.65982985497,2109.15471553802 5705.64015269279,2079.51894521713 PathPoint;PointKind.SMOOTHPOINT 5693.80951881409,2147.97175168991 5690.19217371941,2165.38802146912 5697.42686390877,2130.55500984192 PathPoint;PointKind.SMOOTHPOINT 5695.76954841614,2202.58161306381 5697.05687999725,2216.40591144562 5694.48257088661,2188.75731468201 PathPoint;PointKind.SMOOTHPOINT 5688.90944480896,2285.47169923782 5686.46790504456,2310.68206071854 5691.35027647018,2260.26133775711 PathPoint;PointKind.SMOOTHPOINT 5691.84948921204,2334.23050403595 5689.66853141785,2353.11514377594 5694.03009295464,2315.34610033035 PathPoint;PointKind.SMOOTHPOINT 5687.92943000793,2386.89024925232 5684.2469394207,2402.06726074219 5691.61121249199,2371.71323776245 PathPoint;PointKind.SMOOTHPOINT 5689.88945960999,2443.45069885254 5691.77053570747,2462.0610666275 5688.00802946091,2424.84033107758 PathPoint;PointKind.SMOOTHPOINT 5683.02864789963,2482.45750665665 5682.37294435501,2489.53783035278 5684.23313140869,2469.45767641068 PathPoint;PointKind.SMOOTHPOINT 5678.1285738945,2513.66337776184 5673.88703584671,2520.72009801865 5681.58978223801,2507.90531873703 PathPoint;PointKind.SMOOTHPOINT 5681.06861829758,2530.2414894104 5677.93419957161,2539.73384857178 5682.49615430832,2525.91875553131 PathPoint;PointKind.SMOOTHPOINT 5683.02864789963,2567.29818105698 5683.10158252716,2569.2839384079 5682.82081961632,2561.6095161438 PathPoint;PointKind.SMOOTHPOINT 5680.08860349655,2580.95088243484 5683.0789232254,2584.98376607895 5677.26858258247,2577.14718818665 PathPoint;PointKind.SMOOTHPOINT 5681.06861829758,2599.47911024094 5681.12597465515,2601.04425430298 5680.76979875565,2591.29343748093 PathPoint;PointKind.SMOOTHPOINT 5684.00901675224,2608.2555770874 5679.84466195107,2622.84722328186 5684.39634919167,2606.89790725708 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,2636.53580188751 5683.03572893143,2644.485912323 5686.94233417511,2628.58569145203 PathPoint;PointKind.SMOOTHPOINT 5675.18817543983,2658.96497011185 5672.33699798584,2668.58738422394 5678.03970694542,2649.34231996536 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,2696.99695587158 5686.46790504456,2714.98490095139 5685.47018766403,2679.00901079178 PathPoint;PointKind.SMOOTHPOINT 5676.16854429245,2757.45787382126 5674.35686230659,2771.82316303253 5677.97987222672,2743.09282064438 PathPoint;PointKind.SMOOTHPOINT 5676.16854429245,2788.66350889206 5672.33699798584,2799.93957996368 5679.99973654747,2777.38743782043 PathPoint;PointKind.SMOOTHPOINT 5671.26811623573,2816.94373369217 5671.32688879967,2830.87141513824 5671.2093436718,2803.01628828049 PathPoint;PointKind.SMOOTHPOINT 5679.10858869553,2854.00042533875 5678.39234232903,2864.61323976517 5679.82483506203,2843.38761091232 PathPoint;PointKind.SMOOTHPOINT 5674.20816063881,2875.45453548431 5673.95005702972,2886.9047999382 5674.46661829948,2864.00403499603 PathPoint;PointKind.SMOOTHPOINT 5680.85193872452,2991.83790206909 5680.50213575363,3018.29523324966 5681.16137981415,2968.43886852264 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,3055.86246728897 5684.34253334999,3068.85403633118 5685.6373000145,3042.83643722534 PathPoint;PointKind.SMOOTHPOINT 5681.06861829758,3090.96880674362 5683.80154252052,3107.27500677109 5678.33569407463,3074.66260671616 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,3169.95842456818 5683.19398999214,3185.40451526642 5686.78442716599,3154.51233386993 PathPoint;PointKind.SMOOTHPOINT 5679.10858869553,3211.89087867737 5678.75630736351,3229.18700695038 5679.46122407913,3194.59475040436 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,3248.94757032394 5685.12781977654,3257.67871856689 5686.80991888046,3240.21665811539 PathPoint;PointKind.SMOOTHPOINT 5684.00901675224,3323.06118965149 5682.59033203125,3339.0482711792 5685.42734742165,3307.07410812378 PathPoint;PointKind.SMOOTHPOINT 5680.08860349655,3361.09293937683 5682.59033203125,3378.21534633636 5677.58652091026,3343.97100448608 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,3438.13220500946 5685.414955616,3457.34493255615 5686.52349114418,3418.91947746277 PathPoint;PointKind.SMOOTHPOINT 5681.06861829758,3505.41947364807 5680.57046771049,3528.04384231567 5681.56712293625,3482.79510498047 PathPoint;PointKind.SMOOTHPOINT 5682.0486330986,3651.69636011124 5677.94234275818,3668.84614706039 5686.15527749062,3634.54633712769 PathPoint;PointKind.SMOOTHPOINT 5679.10858869553,3710.20692586899 5677.33939290047,3722.0693063736 5680.87813854218,3698.34430932999 PathPoint;PointKind.SMOOTHPOINT 5680.08860349655,3748.23891162872 5680.56586503983,3768.06674480438 5679.61169600487,3728.41084241867 PathPoint;PointKind.CORNERPOINT 5676.16854429245,3775.54384231567 5676.16854429245,3775.54384231567 5676.16854429245,3775.54384231567 PathPoint;PointKind.SMOOTHPOINT 5658.52721571922,3797.97277450562 5645.44394731522,3802.00872659683 5671.61083817482,3793.93705844879 PathPoint;PointKind.SMOOTHPOINT 5511.51791453362,3801.87347888947 5498.48846197128,3801.6039276123 5524.54772114754,3802.14350223541 PathPoint;PointKind.SMOOTHPOINT 5196.91864728928,3799.92336273193 5182.77393221855,3800.19881486893 5211.06336236,3799.64791059494 PathPoint;PointKind.CORNERPOINT 4852.91716575623,3798.94830465317 4852.91716575623,3798.94830465317 4852.91716575623,3798.94830465317 PathPoint;PointKind.SMOOTHPOINT 4836.25620603561,3804.79912519455 4828.94539475441,3805.05239009857 4843.56666326523,3804.54586029053 PathPoint;PointKind.SMOOTHPOINT 4817.63486266136,3802.84900903702 4810.97975492477,3801.2371301651 4824.28961634636,3804.46041584015 PathPoint;PointKind.SMOOTHPOINT 4785.29295802116,3800.8984208107 4769.999345541,3807.31714010239 4800.58657050133,3794.47970151901 PathPoint;PointKind.SMOOTHPOINT 4751.97068452835,3800.8984208107 4740.50436973572,3804.18850421906 4763.43735337257,3797.60857343674 PathPoint;PointKind.SMOOTHPOINT 4719.62877988815,3801.87347888947 4707.22245812416,3802.84240007401 4732.03510165215,3800.90502977371 PathPoint;PointKind.SMOOTHPOINT 4676.5060043335,3801.87347888947 4663.01451444626,3801.2371301651 4689.99714016914,3802.51029968262 PathPoint;PointKind.SMOOTHPOINT 4626.52277112007,3800.8984208107 4615.16975283623,3802.15247154236 4637.87614345551,3799.64437007904 PathPoint;PointKind.SMOOTHPOINT 4561.83896183968,3803.82406711578 4541.69378042221,3801.2371301651 4581.98378920555,3806.41100406647 PathPoint;PointKind.SMOOTHPOINT 4488.33431124687,3798.94830465317 4471.44498825073,3799.4269824028 4505.22363424301,3798.46915483475 PathPoint;PointKind.SMOOTHPOINT 4437.37106323242,3799.92336273193 4423.79743337631,3805.107858181 4450.94504714012,3794.73863124847 PathPoint;PointKind.SMOOTHPOINT 4392.28825807571,3800.8984208107 4376.16545677185,3807.26261615753 4408.41141343117,3794.53469753265 PathPoint;PointKind.SMOOTHPOINT 4346.22543811798,3801.87347888947 4324.69095826149,3802.84240007401 4367.75991797447,3800.90502977371 PathPoint;PointKind.SMOOTHPOINT 4303.10301661491,3801.87347888947 4285.52895784378,3800.63217401505 4320.67636728287,3803.11525583267 PathPoint;PointKind.SMOOTHPOINT 4202.15618133545,3799.92336273193 4202.1862757206,3800.00880718231 4202.15618133545,3799.92336273193 PathPoint;PointKind.SMOOTHPOINT 4181.25616192818,3798.76750230789 4169.61777806282,3802.42367506027 4192.78408169746,3795.14602661133 PathPoint;PointKind.SMOOTHPOINT 4160.014128685,3799.92336273193 4148.86610627174,3804.04735565186 4171.16179704666,3795.79936981201 PathPoint;PointKind.SMOOTHPOINT 4125.71148633957,3798.94830465317 4112.1258187294,3800.23209571838 4139.29750800133,3797.66427755356 PathPoint;PointKind.SMOOTHPOINT 3997.3238825798,3798.94830465317 3986.17904663086,3799.22800540924 4008.46871852875,3798.6683678627 PathPoint;PointKind.SMOOTHPOINT 3952.2410774231,3799.92336273193 3940.01071929932,3803.13295841217 3964.47108149529,3796.7137670517 PathPoint;PointKind.SMOOTHPOINT 3870.8959543705,3801.87347888947 3858.11115145683,3800.8597111702 3889.74990963936,3803.36899280548 PathPoint;PointKind.SMOOTHPOINT 3834.16982889175,3802.51407623291 3827.30830907822,3805.05994319916 3842.68052101135,3799.3564081192 PathPoint;PointKind.CORNERPOINT 3756.22891187668,3804.79912519455 3756.22891187668,3804.79912519455 3756.22891187668,3804.79912519455 PathPoint;PointKind.SMOOTHPOINT 3734.66752409935,3800.8984208107 3724.62095618248,3797.90762901306 3744.71373796463,3803.88921260834 PathPoint;PointKind.SMOOTHPOINT 3655.2824306488,3798.94830465317 3644.48279500008,3795.9022808075 3666.08242034912,3801.99385643005 PathPoint;PointKind.SMOOTHPOINT 3574.91732239723,3800.8984208107 3566.7960870266,3800.51793336868 3583.03891181946,3801.27914428711 PathPoint;PointKind.SMOOTHPOINT 3529.83451724052,3799.92336273193 3524.51843261719,3796.99205160141 3535.15024781227,3802.85443782806 PathPoint;PointKind.SMOOTHPOINT 3481.81131362915,3799.92336273193 3473.30062150955,3795.49748182297 3490.32271385193,3804.3492436409 PathPoint;PointKind.SMOOTHPOINT 3444.56933498383,3800.8984208107 3432.93201327324,3804.73799228668 3456.20630264282,3797.05908536911 PathPoint;PointKind.SMOOTHPOINT 3425.94799160957,3803.82406711578 3421.42037987709,3805.48716545105 3430.47595739365,3802.16073274612 PathPoint;PointKind.SMOOTHPOINT 3406.34698748589,3796.02265834808 3397.80549287796,3798.71274232864 3414.88812804222,3793.33257436752 PathPoint;PointKind.SMOOTHPOINT 3384.78559970856,3799.92336273193 3376.6087782383,3806.94798231125 3392.96206712723,3792.89850711823 PathPoint;PointKind.SMOOTHPOINT 3310.30093431473,3802.84900903702 3299.1167986393,3805.83932876587 3327.34391570091,3798.29165697098 PathPoint;PointKind.CORNERPOINT 3211.31483674049,3804.79912519455 3211.31483674049,3804.79912519455 3211.31483674049,3804.79912519455 PathPoint;PointKind.SMOOTHPOINT 3186.8130505085,3798.94830465317 3179.18961167336,3801.32281064987 3194.43684339523,3796.57332658768 PathPoint;PointKind.SMOOTHPOINT 3175.05216479301,3802.84900903702 3165.46019911766,3803.0472779274 3184.64448451996,3802.65026807785 PathPoint;PointKind.SMOOTHPOINT 3154.4711458683,3799.92336273193 3140.23260712624,3802.06797122955 3168.70968461037,3797.77851819992 PathPoint;PointKind.SMOOTHPOINT 3137.81018614769,3803.82406711578 3128.7206196785,3804.5928311348 3146.89975261688,3803.05506706238 PathPoint;PointKind.SMOOTHPOINT 3115.26878356934,3799.92336273193 3085.52278518677,3800.72281122208 3145.0147819519,3799.12391424179 PathPoint;PointKind.SMOOTHPOINT 3073.1260228157,3802.84900903702 3067.73275494576,3800.43720960617 3078.51929068565,3805.26057243347 PathPoint;PointKind.SMOOTHPOINT 3018.24271559715,3801.87347888947 3004.26051020622,3804.47906255722 3031.51009082794,3799.40149068832 PathPoint;PointKind.CORNERPOINT 2380.22298574448,3800.8984208107 2380.22298574448,3800.8984208107 2380.22298574448,3800.8984208107 PathPoint;PointKind.SMOOTHPOINT 2363.56167197227,3804.79912519455 2356.64987683296,3803.47568035126 2370.47382116318,3806.12257003784 PathPoint;PointKind.CORNERPOINT 2331.21976733208,3801.87347888947 2331.21976733208,3801.87347888947 2331.21976733208,3801.87347888947 PathPoint;PointKind.CORNERPOINT 2141.0880446434,3802.84900903702 2141.0880446434,3802.84900903702 2141.0880446434,3802.84900903702 PathPoint;PointKind.SMOOTHPOINT 2113.64621400833,3806.74971342087 2102.90712118149,3804.88079309464 2124.38530683517,3808.61839771271 PathPoint;PointKind.SMOOTHPOINT 2075.42386651039,3802.84900903702 2062.53391027451,3798.8555431366 2088.31382274628,3806.84223890305 PathPoint;PointKind.CORNERPOINT 2049.94206547737,3804.79912519455 2049.94206547737,3804.79912519455 2049.94206547737,3804.79912519455 PathPoint;PointKind.SMOOTHPOINT 2022.50058889389,3803.82406711578 2009.15957093239,3808.38165521622 2035.8412528038,3799.26647901535 PathPoint;PointKind.SMOOTHPOINT 1998.97917151451,3806.74971342087 1993.95836591721,3806.54577970505 2003.99962306023,3806.95341110229 PathPoint;PointKind.SMOOTHPOINT 1951.93598270416,3800.8984208107 1930.11613726616,3803.15632581711 1973.75618219376,3798.64051580429 PathPoint;PointKind.SMOOTHPOINT 1924.49450612068,3804.79912519455 1916.78998947144,3804.48071479797 1932.19866871834,3805.11753559113 PathPoint;PointKind.SMOOTHPOINT 1846.08978152275,3804.79912519455 1834.94600772858,3804.46490049362 1857.23284721375,3805.13358592987 PathPoint;PointKind.SMOOTHPOINT 1824.52839374542,3805.77441930771 1814.84508275986,3809.22972679138 1834.21099662781,3802.31911182404 PathPoint;PointKind.SMOOTHPOINT 1801.00662231445,3803.82406711578 1792.49734640121,3809.91517066956 1809.51625227928,3797.73272752762 PathPoint;PointKind.SMOOTHPOINT 1767.68434882164,3806.74971342087 1760.89293122292,3805.01415252686 1774.47647452354,3808.48503828049 PathPoint;PointKind.SMOOTHPOINT 1752.00375795364,3803.82406711578 1741.42505049706,3805.32477378845 1762.58211135864,3802.32336044312 PathPoint;PointKind.SMOOTHPOINT 1731.42238497734,3808.6998295784 1721.41440868378,3809.11501407623 1741.4303612709,3808.28488111496 PathPoint;PointKind.SMOOTHPOINT 1709.86099720001,3805.77441930771 1702.87095665932,3810.97590923309 1716.85103774071,3800.57292938232 PathPoint;PointKind.SMOOTHPOINT 1689.27962422371,3808.6998295784 1678.33234906197,3808.02453517914 1700.22760748863,3809.37536001205 PathPoint;PointKind.SMOOTHPOINT 1653.99767518044,3807.72477149963 1631.49628043175,3807.62445688248 1676.49871587753,3807.82508611679 PathPoint;PointKind.SMOOTHPOINT 1596.17396950722,3807.72477149963 1586.07748031616,3808.82941246033 1606.27010464668,3806.61989450455 PathPoint;PointKind.SMOOTHPOINT 1579.51300978661,3807.72477149963 1568.95129680634,3811.20580673218 1590.07472276688,3804.24373626709 PathPoint;PointKind.SMOOTHPOINT 1546.19073629379,3809.67512369156 1537.78271913528,3810.17504453659 1554.59910750389,3809.17520284653 PathPoint;PointKind.CORNERPOINT 1493.26745867729,3809.67512369156 1493.26745867729,3809.67512369156 1493.26745867729,3809.67512369156 PathPoint;PointKind.SMOOTHPOINT 1469.74604129791,3808.6998295784 1461.55611991882,3809.86017465591 1477.935962677,3807.53948450089 PathPoint;PointKind.SMOOTHPOINT 1446.22462391853,3808.6998295784 1435.5135011673,3814.08519029617 1448.29228520393,3807.66033411026 PathPoint;PointKind.SMOOTHPOINT 1416.82276368141,3810.65018177032 1409.24712181091,3809.42964792252 1424.39840555191,3811.87071561813 PathPoint;PointKind.SMOOTHPOINT 1381.54046058655,3807.72477149963 1372.70793557167,3807.42429971695 1390.37298560143,3808.02500724792 PathPoint;PointKind.CORNERPOINT 1358.99905800819,3811.62547588348 1358.99905800819,3811.62547588348 1358.99905800819,3811.62547588348 PathPoint;PointKind.CORNERPOINT 789.583904743195,3815.52618026733 789.583904743195,3815.52618026733 789.583904743195,3815.52618026733 PathPoint;PointKind.SMOOTHPOINT 762.141720056534,3815.52618026733 754.187242984772,3814.66819524765 770.096551179886,3816.38416528702 PathPoint;PointKind.SMOOTHPOINT 729.799815416336,3816.50147438049 721.401357650757,3817.05308675766 738.198273181915,3815.94962596893 PathPoint;PointKind.SMOOTHPOINT 680.796951055527,3814.55088615417 667.851762771606,3815.58825731277 693.742139339447,3813.51375102997 PathPoint;PointKind.SMOOTHPOINT 615.132772922516,3817.47653245926 596.24235033989,3817.85395145416 634.023195505142,3817.09887742996 PathPoint;PointKind.SMOOTHPOINT 561.22948050499,3818.45159053802 551.983069181442,3818.59863996506 570.475891828537,3818.30477714539 PathPoint;PointKind.SMOOTHPOINT 514.186645746231,3819.42688465118 502.926034927368,3819.60367441177 525.446902513504,3819.25009489059 PathPoint;PointKind.SMOOTHPOINT 454.402556419373,3817.47653245926 441.561813354492,3815.98857164383 467.243653535843,3818.96449327469 PathPoint;PointKind.SMOOTHPOINT 402.459293603897,3816.50147438049 390.489871501923,3814.98330116272 414.429069757462,3818.01941156387 PathPoint;PointKind.SMOOTHPOINT 358.356503248215,3820.40217876434 348.302500247955,3818.39871883392 368.411214351654,3822.40540266037 PathPoint;PointKind.SMOOTHPOINT 313.274052143097,3818.45159053802 302.476540803909,3818.39871883392 324.071209430695,3818.50469827652 PathPoint;PointKind.CORNERPOINT 244.66982960701,3816.50147438049 244.66982960701,3816.50147438049 244.66982960701,3816.50147438049 PathPoint;PointKind.CORNERPOINT 240.749416351318,3809.67512369156 240.749416351318,3809.67512369156 240.749416351318,3809.67512369156 PathPoint;PointKind.CORNERPOINT 244.66982960701,3794.07207012177 244.66982960701,3794.07207012177 244.66982960701,3794.07207012177 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3778.46948862076 239.70036149025,3769.19074058533 241.798471212387,3787.7480006218 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3677.05093860626 235.459177494049,3659.32947635651 246.039655208588,3694.77192878723 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,3654.62177038193 241.514875888824,3646.07378482819 236.063897609711,3663.16951990128 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,3631.21754407883 239.092454910278,3627.79764175415 238.486318588257,3634.63721036911 PathPoint;PointKind.SMOOTHPOINT 246.629859209061,3623.41613531113 244.745950698853,3613.93699407578 248.513413667679,3632.89504051208 PathPoint;PointKind.SMOOTHPOINT 236.829003095627,3606.83802366257 234.650169610977,3600.48138141632 239.008190631866,3613.19466590881 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,3577.5825047493 238.082345724106,3565.33420801163 239.496073722839,3589.83127355576 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3556.12863063812 240.705513954163,3545.24815320969 240.793318748474,3567.00934410095 PathPoint;PointKind.SMOOTHPOINT 236.829003095627,3532.72440433502 238.283447027206,3525.76729059219 235.374913215637,3539.68175411224 PathPoint;PointKind.SMOOTHPOINT 239.769047498703,3511.27053022385 242.926833629608,3493.63049983978 236.611615419388,3528.9110326767 PathPoint;PointKind.SMOOTHPOINT 248.589888811111,3482.01524734497 247.972422838211,3473.94924402237 249.207354784012,3490.08125066757 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,3461.53643131256 239.092454910278,3446.63251161575 238.486318588257,3476.44035100937 PathPoint;PointKind.SMOOTHPOINT 246.629859209061,3437.15714693069 247.369118928909,3429.36163902283 245.890245437622,3444.95241880417 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3386.44798994064 238.484548330307,3366.29796981812 243.01428437233,3406.59777402878 PathPoint;PointKind.SMOOTHPOINT 243.689814805984,3347.44071006775 242.524631023407,3337.77651786804 244.854290485382,3357.10490226746 PathPoint;PointKind.SMOOTHPOINT 237.809017896652,3324.03624773026 236.670033931732,3306.64476156235 238.948001861572,3341.42796993256 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3290.88026046753 242.122782468796,3282.14321136475 239.376050233841,3299.61730957031 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3227.49393224716 238.593950271606,3218.26545953751 245.335800647736,3247.12986946106 PathPoint;PointKind.SMOOTHPOINT 236.000168323517,3199.99993801117 232.986481189728,3193.9617061615 238.673965930939,3205.35791873932 PathPoint;PointKind.SMOOTHPOINT 240.464758872986,3177.19618320465 245.711095333099,3169.15637969971 239.305948019028,3178.97257804871 PathPoint;PointKind.SMOOTHPOINT 236.829003095627,3131.92620277405 237.184470891953,3119.12818193436 236.515667438507,3143.21832418442 PathPoint;PointKind.SMOOTHPOINT 243.689814805984,3088.04339647293 246.674823760986,3082.39367723465 237.128176689148,3100.461165905 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3048.06105852127 234.951821565628,3029.7122168541 246.547011137009,3066.40942811966 PathPoint;PointKind.SMOOTHPOINT 246.999843120575,3002.99996852875 236.769168376923,2986.00077152252 252.405502796173,3011.981549263 PathPoint;PointKind.SMOOTHPOINT 239.769047498703,2955.41897535324 240.403861999512,2943.54762554169 239.134587049484,2967.29032516479 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,2888.13194274902 238.991904258728,2869.63841199875 242.506928443909,2906.6252374649 PathPoint;PointKind.SMOOTHPOINT 241.729785203934,2855.95101356506 249.831901788712,2839.30752038956 233.627314567566,2872.59403467178 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,2822.79502630234 238.901975154877,2806.34413719177 238.676444292068,2839.24544334412 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,2792.56421327591 244.037493467331,2781.46375179291 245.301811695099,2803.6651468277 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,2763.30893039703 234.348517656326,2741.69620513916 243.229901790619,2784.92165565491 PathPoint;PointKind.SMOOTHPOINT 230.948914289474,2726.25223875046 219.408248662949,2717.19489097595 242.48922586441,2735.30935049057 PathPoint;PointKind.CORNERPOINT 226.048486232758,2703.82330656052 226.048486232758,2703.82330656052 226.048486232758,2703.82330656052 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,2677.49319791794 239.193005561829,2661.96189880371 242.305827140808,2693.02473306656 PathPoint;PointKind.CORNERPOINT 244.808971881866,2636.51101827621 244.808971881866,2636.51101827621 244.808971881866,2636.51101827621 PathPoint;PointKind.SMOOTHPOINT 240.888912677765,2605.30538320541 241.951775550842,2587.94812202454 239.826049804688,2622.66264438629 PathPoint;PointKind.SMOOTHPOINT 246.769001483917,2571.17410182953 248.007473945618,2550.9957575798 245.531237125397,2591.35244607925 PathPoint;PointKind.SMOOTHPOINT 247.749724388123,2528.26611757278 248.610423803329,2510.42356967926 246.888316869736,2546.1089015007 PathPoint;PointKind.SMOOTHPOINT 241.86892747879,2480.48260688782 243.765935897827,2471.05633735657 239.971919059753,2489.90864038467 PathPoint;PointKind.SMOOTHPOINT 255.669858455658,2416.17055177689 256.851682662964,2403.56253862381 254.487680196762,2428.77809286118 PathPoint;PointKind.SMOOTHPOINT 250.769076347351,2388.86538505554 245.951850414276,2373.64069461823 255.587010383606,2404.09031152725 PathPoint;PointKind.SMOOTHPOINT 245.869002342224,2351.80869340897 244.534935951233,2335.07857561111 247.203422784805,2368.53881120682 PathPoint;PointKind.SMOOTHPOINT 250.769076347351,2297.19883203506 253.012347221375,2275.22521018982 248.526159524918,2319.17221784592 PathPoint;PointKind.SMOOTHPOINT 244.888987541199,2261.11719846725 243.730530738831,2255.94403266907 246.047090291977,2266.29012823105 PathPoint;PointKind.CORNERPOINT 248.8090467453,2185.05322694778 248.8090467453,2185.05322694778 248.8090467453,2185.05322694778 PathPoint;PointKind.SMOOTHPOINT 252.729460000992,2169.45017337799 252.383197546005,2153.44963788986 253.075722455978,2185.45118093491 PathPoint;PointKind.SMOOTHPOINT 248.8090467453,2137.26948022842 249.379069805145,2117.7614736557 248.239023685455,2156.77748680115 PathPoint;PointKind.SMOOTHPOINT 247.829031944275,2093.38643789291 246.757671833038,2086.29218816757 249.304364919662,2103.1535410881 PathPoint;PointKind.SMOOTHPOINT 244.817115068436,2071.82044744492 242.202090024948,2066.97088479996 249.445277452469,2080.40289402008 PathPoint;PointKind.SMOOTHPOINT 244.888987541199,2058.28009843826 245.746146440506,2038.22685241699 244.654251337051,2063.76813411713 PathPoint;PointKind.SMOOTHPOINT 255.669858455658,2018.2977604866 255.96230506897,2012.66338348389 255.296688079834,2025.48028707504 PathPoint;PointKind.SMOOTHPOINT 248.000038862228,2005.99989652634 247.25334405899,2003.54348659515 250.717384815216,2014.94087934494 PathPoint;PointKind.SMOOTHPOINT 243.908972740173,1995.86859226227 246.152951717377,1974.55822706223 243.42533826828,2000.4615855217 PathPoint;PointKind.SMOOTHPOINT 251.749445199966,1952.96084403992 252.811245918274,1943.04551124573 250.687290430069,1962.87594079971 PathPoint;PointKind.SMOOTHPOINT 250.999917984009,1923.9998960495 250.213923454285,1921.547498703 253.338782787323,1931.29737138748 PathPoint;PointKind.SMOOTHPOINT 252.512780427933,1911.46174907684 252.567304372787,1907.21549034119 252.473834753036,1914.47095155716 PathPoint;PointKind.SMOOTHPOINT 262.769300937653,1882.8720831871 262.204234600067,1879.12904977798 264.113280773163,1891.77530050278 PathPoint;PointKind.SMOOTHPOINT 259.080083370209,1864.53575134277 258.390390872955,1860.60483455658 259.617179632187,1867.5973534584 PathPoint;PointKind.SMOOTHPOINT 252.776194810867,1855.18713712692 249.186111688614,1851.7901301384 255.704555511475,1857.95794487 PathPoint;PointKind.SMOOTHPOINT 249.557865858078,1843.67314338684 245.377932786942,1836.44600629807 251.585873365402,1847.17967033386 PathPoint;PointKind.SMOOTHPOINT 248.828873634338,1819.46073532104 250.612939596176,1810.8386349678 247.172620296478,1827.46749401093 PathPoint;PointKind.SMOOTHPOINT 252.511718273163,1801.51173591614 250.713490247726,1798.1999373436 252.929499149323,1802.28120803833 PathPoint;PointKind.SMOOTHPOINT 257.649714946747,1778.50310325623 262.088105678558,1759.65976953506 254.738702774048,1790.86186408997 PathPoint;PointKind.SMOOTHPOINT 255.689685344696,1751.19840860367 254.834296703339,1746.50958538055 261.401953697205,1782.50388622284 PathPoint;PointKind.SMOOTHPOINT 253.191143274307,1736.56286001205 254.047948122025,1728.04791927338 252.681308984756,1741.62957429886 PathPoint;PointKind.SMOOTHPOINT 250.440516471863,1717.20544338226 249.391461610794,1708.74337434769 251.243151426315,1723.67939472198 PathPoint;PointKind.SMOOTHPOINT 248.138118982315,1692.63827562332 249.183633327484,1689.06542301178 245.527696609497,1701.55801534653 PathPoint;PointKind.SMOOTHPOINT 247.786191701889,1681.97754621506 247.738748788834,1673.60044956207 247.805310487747,1685.34858942032 PathPoint;PointKind.SMOOTHPOINT 249.809242486954,1661.48197174072 254.8215508461,1644.57341194153 248.330368995667,1666.47055864334 PathPoint;PointKind.SMOOTHPOINT 253.729655742645,1630.27610063553 253.610694408417,1621.07689619064 253.848263025284,1639.47530508041 PathPoint;PointKind.SMOOTHPOINT 252.999955415726,1587.99998044968 252.970215082169,1575.0742650032 253.06333065033,1615.43118953705 PathPoint;PointKind.SMOOTHPOINT 249.275686740875,1537.86957979202 248.877024650574,1534.14542913437 251.29590511322,1556.75327539444 PathPoint;PointKind.SMOOTHPOINT 248.049606084824,1526.66880369186 244.486076831818,1522.15747833252 250.280485153198,1529.49295520782 PathPoint;PointKind.SMOOTHPOINT 246.152243614197,1509.76779699326 244.87978219986,1498.4046292305 246.769001483917,1515.27707576752 PathPoint;PointKind.SMOOTHPOINT 243.000122308731,1479.00000572205 242.123490571976,1468.40111732483 243.724157810211,1487.7592420578 PathPoint;PointKind.SMOOTHPOINT 247,1452 247.215263366699,1444.88828372955 246.739772081375,1460.60274553299 PathPoint;PointKind.SMOOTHPOINT 243.675652742386,1430.14277458191 246.436547040939,1423.57204914093 241.092846393585,1436.2895822525 PathPoint;PointKind.SMOOTHPOINT 246.000001430511,1413.00006866455 249.171949625015,1392.04233884811 245.114872455597,1418.84687662125 PathPoint;PointKind.SMOOTHPOINT 249.569903612137,1367.82922267914 254.731621742249,1343.12185049057 244.408539533615,1392.53635883331 PathPoint;PointKind.SMOOTHPOINT 247.609874010086,1309.31842088699 247.062864303589,1285.88351011276 248.156883716583,1332.75333166122 PathPoint;PointKind.SMOOTHPOINT 245.649844408035,1264.46008443832 241.220659017563,1258.53160858154 256.955419778824,1279.59390163422 PathPoint;PointKind.SMOOTHPOINT 234.372239112854,1251.67976617813 227.688099145889,1253.22130680084 241.052838563919,1250.13916969299 PathPoint;PointKind.SMOOTHPOINT 224.088456630707,1235.20480155945 220.614856481552,1221.81008577347 226.201082468033,1243.35247278214 PathPoint;PointKind.SMOOTHPOINT 232.000093460083,1167.9999089241 231.82483792305,1145.63281774521 232.174640893936,1190.36723613739 PathPoint;PointKind.SMOOTHPOINT 239.999889135361,1085.0000667572 240.312870740891,1049.57319259644 239.686907529831,1120.42670488358 PathPoint;PointKind.SMOOTHPOINT 236.630026102066,1028.39264631271 237.264132499695,1007.92303562164 235.995919704437,1048.86225700378 PathPoint;PointKind.SMOOTHPOINT 232.709612846375,1003.03806781769 231.178339719772,986.862630844116 234.240531921387,1019.21350479126 PathPoint;PointKind.SMOOTHPOINT 237.610040903091,976.708431243896 238.153864145279,968.956825733185 237.065509557724,984.459800720215 PathPoint;PointKind.SMOOTHPOINT 239.999889135361,933.9998960495 236.611615419388,898.227231502533 242.220146656036,957.44188785553 PathPoint;PointKind.SMOOTHPOINT 243.689814805984,886.091287136078 238.333722352982,869.74071264267 251.881152391434,911.098659038544 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,846.108949184418 231.594350337982,820.246896743774 253.296650648117,863.173055648804 PathPoint;PointKind.SMOOTHPOINT 248.589888811111,806.126375198364 248.312312364578,787.171161174774 248.867465257645,825.082061290741 PathPoint;PointKind.SMOOTHPOINT 245.649844408035,771.020271778107 241.648707389832,748.813683986664 249.650627374649,793.226623535156 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,738.839342594147 249.523168802261,722.302300930023 239.816136360168,755.37638425827 PathPoint;PointKind.SMOOTHPOINT 241.729785203934,706.658413410187 241.447960138321,695.790681838989 242.011256217957,717.525908946991 PathPoint;PointKind.SMOOTHPOINT 249.569903612137,688.129949569702 248.111211061478,672.289681434631 251.028950214386,703.970453739166 PathPoint;PointKind.SMOOTHPOINT 239.769047498703,668.626427650452 239.427387714386,653.008267879486 240.1114153862,684.244351387024 PathPoint;PointKind.SMOOTHPOINT 242.709800004959,614.991624355316 240.899534225464,590.856871604919 244.519357681274,639.126377105713 PathPoint;PointKind.SMOOTHPOINT 242.709800004959,566.232583522797 247.706176042557,552.430944442749 236.701898574829,582.827217578888 PathPoint;PointKind.SMOOTHPOINT 242.709800004959,543.803651332855 242.419123649597,526.258270740509 242.997997999191,561.228182315826 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,508.697075843811 244.679034948349,494.539496898651 244.660270214081,522.854890823364 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,480.416851043701 242.859563827515,451.361961364746 246.479387283325,509.472212791443 PathPoint;PointKind.SMOOTHPOINT 245.649844408035,428.732635974884 246.698899269104,418.667893409729 244.600435495377,438.797378540039 PathPoint;PointKind.SMOOTHPOINT 246.523997783661,398.026685714722 247.388237714767,377.182724475861 245.697995424271,417.949404716492 PathPoint;PointKind.SMOOTHPOINT 245.649844408035,358.519957065582 247.379032373428,343.924298286438 244.020144939423,372.273681163788 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,333.165142536163 247.709008455276,311.216776371002 241.630296707153,355.113508701324 PathPoint;PointKind.SMOOTHPOINT 247.609874010086,289.282100200653 247.853815555573,274.628140926361 247.335484027863,305.768630504608 PathPoint;PointKind.SMOOTHPOINT 249.416599273682,264.004232883453 249.439612627029,263.469378948212 248.928008079529,275.511617660522 PathPoint;PointKind.SMOOTHPOINT 252.510302066803,261.002111434937 252.320884466171,258.16545009613 252.656525373459,263.200535774231 PathPoint;PointKind.SMOOTHPOINT 255.450346469879,250.275056362152 255.96265912056,248.016679286957 254.895547628403,252.720844745636 PathPoint;PointKind.SMOOTHPOINT 253.490316867828,245.399057865143 253.528908491135,243.573567867279 253.47827911377,245.966484546661 PathPoint;PointKind.SMOOTHPOINT 248.954916000366,251.488037109375 248.19087266922,245.177893638611 249.32560801506,254.549167156219 PathPoint;PointKind.SMOOTHPOINT 247.609874010086,231.746828556061 247.731313705444,230.540928840637 247.05613732338,237.234392166138 PathPoint;PointKind.SMOOTHPOINT 252.510302066803,230.771298408508 252.891261577606,225.47327041626 252.43488907814,231.818110942841 PathPoint;PointKind.SMOOTHPOINT 251.529933214188,221.994831562042 251.30263209343,220.027248859406 251.887879371643,225.088062286377 PathPoint;PointKind.SMOOTHPOINT 247.271400690079,225.413081645966 246.995948553085,223.042824268341 247.471793889999,227.137076854706 PathPoint;PointKind.SMOOTHPOINT 246.629859209061,219.069421291351 246.440795660019,216.480123996735 246.764752864838,220.91591835022 PathPoint;PointKind.SMOOTHPOINT 246.629859209061,201.516015529633 246.833084821701,199.795088768005 245.374038219452,212.142283916473 PathPoint;PointKind.SMOOTHPOINT 251.529933214188,201.516015529633 252.489413022995,196.520347595215 250.789965391159,205.370457172394 PathPoint;PointKind.SMOOTHPOINT 251.529933214188,168.360028266907 251.566400527954,164.899764060974 251.481428146362,173.012266159058 PathPoint";
	
	mask35mm[1] = "PointKind.CORNERPOINT 246.629859209061,173.235790729523 246.629859209061,173.235790729523 246.629859209061,173.235790729523 PathPoint;PointKind.SMOOTHPOINT 249.569903612137,155.682857036591 250.197991132736,155.570032596588 244.761528968811,156.544382572174 PathPoint;PointKind.SMOOTHPOINT 260.350420475006,155.682857036591 275.499933958054,155.846428871155 259.622136354446,155.674831867218 PathPoint;PointKind.CORNERPOINT 337.775484323502,154.707562923431 337.775484323502,154.707562923431 337.775484323502,154.707562923431 PathPoint;PointKind.SMOOTHPOINT 356.396473646164,155.682857036591 366.033049821854,154.210002422333 346.759897470474,157.155475616455 PathPoint;PointKind.SMOOTHPOINT 469.103486537933,153.732504844666 475.238138437271,152.605204582214 462.968834638596,154.859805107117 PathPoint;PointKind.CORNERPOINT 481.844741106033,158.608267307281 481.844741106033,158.608267307281 481.844741106033,158.608267307281 PathPoint;PointKind.CORNERPOINT 946.393353939056,159.583561420441 946.393353939056,159.583561420441 946.393353939056,159.583561420441 PathPoint;PointKind.CORNERPOINT 995.396572351456,157.632973194122 995.396572351456,157.632973194122 995.396572351456,157.632973194122 PathPoint;PointKind.SMOOTHPOINT 1014.01756167412,153.732504844666 1020.87589502335,150.795056819916 1007.15958237648,156.669716835022 PathPoint;PointKind.CORNERPOINT 1035.57894945145,159.583561420441 1035.57894945145,159.583561420441 1035.57894945145,159.583561420441 PathPoint;PointKind.SMOOTHPOINT 1264.91303443909,156.657915115356 1281.28190159798,157.625420093536 1248.54487538338,155.69064617157 PathPoint;PointKind.SMOOTHPOINT 1302.15572118759,156.657915115356 1311.43505930901,154.595918655396 1292.87602901459,158.719675540924 PathPoint;PointKind.SMOOTHPOINT 1320.77671051025,157.632973194122 1329.60144639015,158.815977573395 1311.95197463036,156.450204849243 PathPoint;PointKind.SMOOTHPOINT 1367.8198993206,159.583561420441 1376.63861632347,156.605987548828 1359.00118231773,162.56089925766 PathPoint;PointKind.SMOOTHPOINT 1393.30134630203,158.608267307281 1401.46825432777,156.605987548828 1385.13443827629,160.610547065735 PathPoint;PointKind.CORNERPOINT 1803.94702076912,158.608267307281 1803.94702076912,158.608267307281 1803.94702076912,158.608267307281 PathPoint;PointKind.SMOOTHPOINT 1815.70755243301,158.608267307281 1821.34263753891,158.211257457733 1810.07282137871,159.00527715683 PathPoint;PointKind.SMOOTHPOINT 1874.51127290726,158.608267307281 1884.72672343254,157.611021995544 1864.29582238197,159.605276584625 PathPoint;PointKind.SMOOTHPOINT 1912.73397445679,157.632973194122 1919.64789390564,160.021169185638 1905.81970095634,155.245013237 PathPoint;PointKind.SMOOTHPOINT 1932.33462452888,158.608267307281 1943.26667547226,157.410864830017 1921.40328168869,159.805433750153 PathPoint;PointKind.SMOOTHPOINT 2070.52343845367,157.632973194122 2082.55269527435,153.595604896545 2058.494181633,161.670577526093 PathPoint;PointKind.CORNERPOINT 2113.64621400833,159.583561420441 2113.64621400833,159.583561420441 2113.64621400833,159.583561420441 PathPoint;PointKind.SMOOTHPOINT 2121.48668646812,155.682857036591 2126.35879039764,156.005752086639 2116.61493659019,155.359725952148 PathPoint;PointKind.SMOOTHPOINT 2142.06805944443,158.608267307281 2149.16856408119,156.005752086639 2134.96755480766,161.21054649353 PathPoint;PointKind.CORNERPOINT 2334.15981173515,157.632973194122 2334.15981173515,157.632973194122 2334.15981173515,157.632973194122 PathPoint;PointKind.SMOOTHPOINT 2346.90071225166,154.707562923431 2351.79476737976,154.755477905273 2342.00701117516,154.659647941589 PathPoint;PointKind.SMOOTHPOINT 2356.70121431351,156.657915115356 2364.33775305748,157.020463943481 2349.06502962112,156.295366287231 PathPoint;PointKind.SMOOTHPOINT 2430.20586490631,157.632973194122 2437.61651873589,158.425576686859 2422.79521107674,156.840605735779 PathPoint;PointKind.SMOOTHPOINT 2474.30865526199,157.632973194122 2492.32173800468,161.840758323669 2456.2955725193,153.425424098969 PathPoint;PointKind.CORNERPOINT 2581.13557934761,157.632973194122 2581.13557934761,157.632973194122 2581.13557934761,157.632973194122 PathPoint;PointKind.SMOOTHPOINT 2629.15842890739,155.682857036591 2643.71950864792,159.835410118103 2614.59734916687,151.530067920685 PathPoint;PointKind.SMOOTHPOINT 2698.74266624451,156.657915115356 2708.91775488853,157.82534122467 2688.56757760048,155.490489006042 PathPoint;PointKind.SMOOTHPOINT 2754.60634231567,153.732504844666 2763.42258095741,151.599934101105 2745.79010367393,155.864839553833 PathPoint;PointKind.CORNERPOINT 3024.1231584549,156.657915115356 3024.1231584549,156.657915115356 3024.1231584549,156.657915115356 PathPoint;PointKind.CORNERPOINT 3105.46828150749,153.732504844666 3105.46828150749,153.732504844666 3105.46828150749,153.732504844666 PathPoint;PointKind.CORNERPOINT 3891.47697329521,152.757210731506 3891.47697329521,152.757210731506 3891.47697329521,152.757210731506 PathPoint;PointKind.SMOOTHPOINT 3932.63971924782,151.781916618347 3942.42322683334,149.189786911011 3922.85621166229,154.374282360077 PathPoint;PointKind.CORNERPOINT 3952.2410774231,156.657915115356 3952.2410774231,156.657915115356 3952.2410774231,156.657915115356 PathPoint;PointKind.SMOOTHPOINT 4077.68863677979,152.757210731506 4084.64575052261,153.694739341736 4070.73187708855,151.819682121277 PathPoint;PointKind.CORNERPOINT 4677.48601913452,150.806858539581 4677.48601913452,150.806858539581 4677.48601913452,150.806858539581 PathPoint;PointKind.SMOOTHPOINT 4701.98745131493,151.781916618347 4708.47650885582,151.542813777924 4695.49874782562,152.021255493164 PathPoint;PointKind.SMOOTHPOINT 4728.44926714897,148.856506347656 4737.34198093414,150.337858200073 4719.5565533638,147.375154495239 PathPoint;PointKind.SMOOTHPOINT 4919.5316183567,147.653203010559 4920.63555121422,147.013077735901 4919.5316183567,147.653203010559 PathPoint;PointKind.SMOOTHPOINT 5069.51070427895,146.906154155731 5084.95018601418,145.494904518127 5054.0223634243,148.321888446808 PathPoint;PointKind.SMOOTHPOINT 5243.96148204803,147.881212234497 5258.14974546432,148.327789306641 5229.77321863174,147.43510723114 PathPoint;PointKind.SMOOTHPOINT 5434.09320473671,144.955801963806 5445.22387862206,145.312685966492 5422.96253085136,144.598917961121 PathPoint;PointKind.SMOOTHPOINT 5470.35587668419,146.906154155731 5479.13493990898,146.717798709869 5461.57610535622,147.094509601593 PathPoint;PointKind.SMOOTHPOINT 5491.91691040993,142.030391693115 5500.73385715485,141.697583198547 5483.1003177166,142.363200187683 PathPoint;PointKind.SMOOTHPOINT 5651.66675806046,141.054861545563 5658.59342336655,139.287436008453 5644.74044680595,142.822759151459 PathPoint;PointKind.SMOOTHPOINT 5677.14855909348,153.732504844666 5678.60353628539,168.999956211552 5676.5658221664,147.618777437524 PathPoint;PointKind.SMOOTHPOINT 5687.92943000793,207.367308139801 5684.87538099289,218.122923374176 5690.99764108658,196.560709476471 PathPoint;PointKind.SMOOTHPOINT 5687,229 5686.10672783852,238.15388584137 5687.99453091621,218.813935756683 PathPoint;PointKind.SMOOTHPOINT 5675,253 5673.94528031349,270.817764282227 5675.99382281303,236.201668262482 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,279.530339241028 5685.46912550926,296.802864074707 5686.46896719933,262.258050441742 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,353.64372253418 5684.02671933174,364.235057830811 5687.91137337685,343.052859306335 PathPoint;PointKind.SMOOTHPOINT 5683.02864789963,397.52676486969 5682.81550884247,409.427382946014 5683.24214100838,385.626618862152 PathPoint;PointKind.SMOOTHPOINT 5689.88945960999,442.385101318359 5688.26790332794,454.014987945557 5691.51066184044,430.755214691162 PathPoint;PointKind.SMOOTHPOINT 5684.00901675224,502.846255302429 5682.61440753937,514.668509960175 5685.40327191353,491.024000644684 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,544.778709411621 5683.82561802864,557.045888900757 5686.1524450779,532.511529922485 PathPoint;PointKind.SMOOTHPOINT 5688.90944480896,597.438454627991 5688.67010593414,611.674160957336 5689.14842963219,583.202748298645 PathPoint;PointKind.SMOOTHPOINT 5683.02864789963,630.594441890717 5679.38333272934,643.61079454422 5686.67431712151,617.578089237213 PathPoint;PointKind.CORNERPOINT 5681.06861829758,667.651133537292 5681.06861829758,667.651133537292 5681.06861829758,667.651133537292 PathPoint;PointKind.SMOOTHPOINT 5681.06861829758,700.807120800018 5676.15721464157,716.519694328308 5685.98037600517,685.094783306122 PathPoint;PointKind.SMOOTHPOINT 5682.0486330986,744.690163135529 5681.00134849548,763.517446517944 5683.09627175331,725.863115787506 PathPoint;PointKind.SMOOTHPOINT 5680.08860349655,774.920976161957 5678.98148417473,787.414040565491 5681.19607686996,762.427911758423 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,802.225670814514 5685.03682851791,832.206287384033 5684.94123458862,772.245526313782 PathPoint;PointKind.SMOOTHPOINT 5683.02864789963,881.215288639069 5681.98277950287,890.892698764801 5684.07487034798,871.537878513336 PathPoint;PointKind.SMOOTHPOINT 5684.00901675224,909.495277404785 5683.39473724365,921.019420623779 5684.62329626083,897.971606254578 PathPoint;PointKind.SMOOTHPOINT 5680.08860349655,968.00607919693 5679.07389163971,978.479161262512 5682.22990751266,945.90381860733 PathPoint;PointKind.SMOOTHPOINT 5681.93816900253,1000.24766921997 5682.30355024338,1002.81312704086 5680.33006668091,988.947050571442 PathPoint;PointKind.SMOOTHPOINT 5683.06546926498,1008.08283090591 5683.2835650444,1009.61516618729 5682.68663406372,1005.42177915573 PathPoint;PointKind.SMOOTHPOINT 5683.71125936508,1012.7338886261 5682.66220450401,1013.92680644989 5684.76066827774,1011.54097080231 PathPoint;PointKind.SMOOTHPOINT 5684.30500388145,1017.35213756561 5685.24288654327,1025.05393981934 5684.11487817764,1015.79336643219 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,1042.11969852448 5685.97648143768,1046.49908065796 5685.95453023911,1033.2412648201 PathPoint;PointKind.SMOOTHPOINT 5686.29194140434,1054.36138629913 5687.73717999458,1056.65516853333 5684.49973225594,1051.51646375656 PathPoint;PointKind.SMOOTHPOINT 5687.99988627434,1073.99991989136 5688.73135685921,1085.57551860809 5687.62388348579,1068.04972887039 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,1105.50602674484 5678.34950208664,1123.87068271637 5688.73277306557,1095.15119791031 PathPoint;PointKind.SMOOTHPOINT 5682.0486330986,1160.11612415314 5681.37982964516,1176.89392089844 5682.71814465523,1143.33856344223 PathPoint;PointKind.SMOOTHPOINT 5688.90944480896,1212.77586936951 5689.31908249855,1216.45186901093 5687.96129465103,1204.27037000656 PathPoint;PointKind.SMOOTHPOINT 5690.60853838921,1219.448325634 5692.98564076424,1220.82889080048 5687.86888718605,1217.8572177887 PathPoint;PointKind.SMOOTHPOINT 5694.00003600121,1227.99993228912 5695.33481049538,1229.63116598129 5691.10991287231,1224.46838569641 PathPoint;PointKind.SMOOTHPOINT 5700.63000607491,1233.3040971756 5702.34786438942,1236.06640768051 5698.90223431587,1230.52644443512 PathPoint;PointKind.SMOOTHPOINT 5704.44597411156,1241.84358549118 5705.31906533241,1244.81573057175 5703.58987736702,1238.92808866501 PathPoint;PointKind.SMOOTHPOINT 5705.95954465866,1250.87945413589 5705.13991522789,1252.46489715576 5707.35627818108,1248.17874860764 PathPoint;PointKind.SMOOTHPOINT 5705.8065943718,1258.4054107666 5705.63381719589,1260.33711624146 5706.02964687347,1255.90981912613 PathPoint;PointKind.SMOOTHPOINT 5703.9998691082,1264.9999756813 5701.93114566803,1266.79407310486 5705.45148062706,1263.74120426178 PathPoint;PointKind.SMOOTHPOINT 5704.1938893795,1268.33136510849 5703.87028622627,1269.76338577271 5704.50510072708,1266.9548125267 PathPoint;PointKind.SMOOTHPOINT 5703.14766693115,1272.55756092072 5703.24361491203,1275.93238067627 5703.10695099831,1271.12624835968 PathPoint;PointKind.SMOOTHPOINT 5700.63000607491,1281.08784389496 5698.47949671745,1287.94346284866 5701.46946239471,1278.41215801239 PathPoint;PointKind.SMOOTHPOINT 5700.00011086464,1297.00002193451 5701.21556997299,1299.23267126083 5699.5253276825,1296.12811088562 PathPoint;PointKind.SMOOTHPOINT 5700.76840281487,1303.4751534462 5700.25609016418,1305.08726835251 5701.38657689095,1301.53141021729 PathPoint;PointKind.SMOOTHPOINT 5701.64999127388,1308.34312677383 5702.41934537888,1312.40740299225 5701.38268232346,1306.93211317062 PathPoint;PointKind.SMOOTHPOINT 5704.57622766495,1327.16970205307 5704.70014572144,1328.8410615921 5703.98991823196,1319.25334453583 PathPoint;PointKind.SMOOTHPOINT 5703.99983167648,1332.99998760223 5705.75026273727,1334.07347202301 5702.6055765152,1332.14483499527 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1338.57370376587 5704.20128703117,1343.37629556656 5704.7613966465,1336.45977973938 PathPoint;PointKind.SMOOTHPOINT 5702.33437299728,1356.3702249527 5701.08634114265,1357.91625022888 5703.2934987545,1355.18226385117 PathPoint;PointKind.SMOOTHPOINT 5701.46977901459,1361.4688038826 5699.96895432472,1369.84094381332 5701.76966071129,1359.79602813721 PathPoint;PointKind.SMOOTHPOINT 5696.74956321716,1379.53133583069 5693.89272093773,1383.96547794342 5698.21285843849,1377.26044893265 PathPoint;PointKind.SMOOTHPOINT 5702.63000607491,1401.96026802063 5703.1663942337,1405.17694473267 5701.17627024651,1393.24092149734 PathPoint;PointKind.SMOOTHPOINT 5702.29684352875,1417.14270830154 5702.16265797615,1418.52539777756 5702.94617414474,1410.45467376709 PathPoint;PointKind.SMOOTHPOINT 5701.84188723564,1421.46591424942 5700.03941059113,1423.62633705139 5702.80738592148,1420.30887365341 PathPoint;PointKind.SMOOTHPOINT 5701.25805616379,1426.41319513321 5701.0424387455,1428.16763877869 5701.46800875664,1424.70713853836 PathPoint;PointKind.SMOOTHPOINT 5700.57084202766,1431.84245824814 5698.94539117813,1433.44418764114 5701.90844893456,1430.5242061615 PathPoint;PointKind.SMOOTHPOINT 5699.95337605476,1436.54922008514 5696.88658118248,1459.71363544464 5700.16509890556,1434.9489068985 PathPoint;PointKind.SMOOTHPOINT 5693.80951881409,1512.15552091599 5694.56966757774,1527.91058063507 5692.69992113113,1489.16105031967 PathPoint;PointKind.CORNERPOINT 5713.41087698936,1539.46045160294 5713.41087698936,1539.46045160294 5713.41087698936,1539.46045160294 PathPoint;PointKind.SMOOTHPOINT 5713.41087698936,1589.19455051422 5709.36866998672,1593.7856554985 5717.45272994041,1584.60368156433 PathPoint;PointKind.SMOOTHPOINT 5712.43086218834,1609.67336654663 5710.37913322449,1618.68704795837 5714.48259115219,1600.65944910049 PathPoint;PointKind.SMOOTHPOINT 5708.51044893265,1646.73005819321 5705.33354401588,1656.84908866882 5711.68735384941,1636.6107916832 PathPoint;PointKind.SMOOTHPOINT 5709.49081778526,1664.28322792053 5708.56001615524,1669.50478076935 5710.4209113121,1659.06167507172 PathPoint;PointKind.SMOOTHPOINT 5708.51044893265,1685.73710203171 5710.579880476,1691.59618377686 5706.4410173893,1679.87825632095 PathPoint;PointKind.SMOOTHPOINT 5708.51044893265,1724.7443819046 5708.15745949745,1738.79385709763 5708.86308431625,1710.69467067719 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1788.13094615936 5699.07214164734,1798.64722251892 5710.10828375816,1777.61443376541 PathPoint;PointKind.SMOOTHPOINT 5705.57005047798,1816.41093492508 5704.92638468742,1823.75349283218 5706.21407032013,1809.06861305237 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1892.47490644455 5702.91147708893,1906.49818181992 5706.26894831657,1878.45163106918 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1946.10970973969 5703.51442694664,1959.12134170532 5705.66599845886,1933.09807777405 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1987.06710577011 5697.86128520966,2000.69856405258 5711.31949424744,1973.43588352203 PathPoint;PointKind.SMOOTHPOINT 5698.7099468708,2023.14873933792 5699.4793009758,2036.65061473846 5697.9409468174,2009.64709997177 PathPoint;PointKind.SMOOTHPOINT 5701.64999127388,2094.33671236038 5697.65982985497,2109.15471553802 5705.64015269279,2079.51894521713 PathPoint;PointKind.SMOOTHPOINT 5693.80951881409,2147.97175168991 5690.19217371941,2165.38802146912 5697.42686390877,2130.55500984192 PathPoint;PointKind.SMOOTHPOINT 5695.76954841614,2202.58161306381 5697.05687999725,2216.40591144562 5694.48257088661,2188.75731468201 PathPoint;PointKind.SMOOTHPOINT 5688.90944480896,2285.47169923782 5686.46790504456,2310.68206071854 5691.35027647018,2260.26133775711 PathPoint;PointKind.SMOOTHPOINT 5691.84948921204,2334.23050403595 5689.66853141785,2353.11514377594 5694.03009295464,2315.34610033035 PathPoint;PointKind.SMOOTHPOINT 5687.92943000793,2386.89024925232 5684.2469394207,2402.06726074219 5691.61121249199,2371.71323776245 PathPoint;PointKind.SMOOTHPOINT 5689.88945960999,2443.45069885254 5691.77053570747,2462.0610666275 5688.00802946091,2424.84033107758 PathPoint;PointKind.SMOOTHPOINT 5683.02864789963,2482.45750665665 5682.37294435501,2489.53783035278 5684.23313140869,2469.45767641068 PathPoint;PointKind.SMOOTHPOINT 5678.1285738945,2513.66337776184 5673.88703584671,2520.72009801865 5681.58978223801,2507.90531873703 PathPoint;PointKind.SMOOTHPOINT 5681.06861829758,2530.2414894104 5677.93419957161,2539.73384857178 5682.49615430832,2525.91875553131 PathPoint;PointKind.SMOOTHPOINT 5683.02864789963,2567.29818105698 5683.10158252716,2569.2839384079 5682.82081961632,2561.6095161438 PathPoint;PointKind.SMOOTHPOINT 5680.08860349655,2580.95088243484 5683.0789232254,2584.98376607895 5677.26858258247,2577.14718818665 PathPoint;PointKind.SMOOTHPOINT 5681.06861829758,2599.47911024094 5681.12597465515,2601.04425430298 5680.76979875565,2591.29343748093 PathPoint;PointKind.SMOOTHPOINT 5684.00901675224,2608.2555770874 5679.84466195107,2622.84722328186 5684.39634919167,2606.89790725708 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,2636.53580188751 5683.03572893143,2644.485912323 5686.94233417511,2628.58569145203 PathPoint;PointKind.SMOOTHPOINT 5675.18817543983,2658.96497011185 5672.33699798584,2668.58738422394 5678.03970694542,2649.34231996536 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,2696.99695587158 5686.46790504456,2714.98490095139 5685.47018766403,2679.00901079178 PathPoint;PointKind.SMOOTHPOINT 5681.16854429245,2763.45787382126 5679.35686230659,2777.82316303253 5682.97987222672,2749.09282064438 PathPoint;PointKind.SMOOTHPOINT 5681.16854429245,2794.66350889206 5677.33699798584,2805.93957996368 5684.99973654747,2783.38743782043 PathPoint;PointKind.SMOOTHPOINT 5676.26811623573,2822.94373369217 5676.32688879967,2836.87141513824 5676.2093436718,2809.01628828049 PathPoint;PointKind.SMOOTHPOINT 5684.10858869553,2860.00042533875 5683.39234232903,2870.61323976517 5684.82483506203,2849.38761091232 PathPoint;PointKind.SMOOTHPOINT 5679.20816063881,2881.45453548431 5678.95005702972,2892.9047999382 5679.46661829948,2870.00403499603 PathPoint;PointKind.SMOOTHPOINT 5680.85193872452,2991.83790206909 5680.50213575363,3018.29523324966 5681.16137981415,2968.43886852264 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,3055.86246728897 5684.34253334999,3068.85403633118 5685.6373000145,3042.83643722534 PathPoint;PointKind.SMOOTHPOINT 5681.06861829758,3090.96880674362 5683.80154252052,3107.27500677109 5678.33569407463,3074.66260671616 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,3169.95842456818 5683.19398999214,3185.40451526642 5686.78442716599,3154.51233386993 PathPoint;PointKind.SMOOTHPOINT 5679.10858869553,3211.89087867737 5678.75630736351,3229.18700695038 5679.46122407913,3194.59475040436 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,3248.94757032394 5685.12781977654,3257.67871856689 5686.80991888046,3240.21665811539 PathPoint;PointKind.SMOOTHPOINT 5684.00901675224,3323.06118965149 5682.59033203125,3339.0482711792 5685.42734742165,3307.07410812378 PathPoint;PointKind.SMOOTHPOINT 5680.08860349655,3361.09293937683 5682.59033203125,3378.21534633636 5677.58652091026,3343.97100448608 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,3438.13220500946 5685.414955616,3457.34493255615 5686.52349114418,3418.91947746277 PathPoint;PointKind.SMOOTHPOINT 5681.06861829758,3505.41947364807 5680.57046771049,3528.04384231567 5681.56712293625,3482.79510498047 PathPoint;PointKind.SMOOTHPOINT 5682.0486330986,3651.69636011124 5677.94234275818,3668.84614706039 5686.15527749062,3634.54633712769 PathPoint;PointKind.SMOOTHPOINT 5679.10858869553,3710.20692586899 5677.33939290047,3722.0693063736 5680.87813854218,3698.34430932999 PathPoint;PointKind.SMOOTHPOINT 5680.08860349655,3748.23891162872 5680.56586503983,3768.06674480438 5679.61169600487,3728.41084241867 PathPoint;PointKind.CORNERPOINT 5676.16854429245,3775.54384231567 5676.16854429245,3775.54384231567 5676.16854429245,3775.54384231567 PathPoint;PointKind.SMOOTHPOINT 5669,3789 5665.10695887856,3791.97799156 5674.61422117688,3784.70538744411 PathPoint;PointKind.SMOOTHPOINT 5658.52721571922,3797.97277450562 5645.44394731522,3802.00872659683 5663.6951930802,3796.37868316831 PathPoint;PointKind.SMOOTHPOINT 5511.51791453362,3801.87347888947 5498.48846197128,3801.6039276123 5524.54772114754,3802.14350223541 PathPoint;PointKind.SMOOTHPOINT 5196.91864728928,3799.92336273193 5182.77393221855,3800.19881486893 5211.06336236,3799.64791059494 PathPoint;PointKind.CORNERPOINT 4852.91716575623,3798.94830465317 4852.91716575623,3798.94830465317 4852.91716575623,3798.94830465317 PathPoint;PointKind.SMOOTHPOINT 4836.25620603561,3804.79912519455 4828.94539475441,3805.05239009857 4843.56666326523,3804.54586029053 PathPoint;PointKind.SMOOTHPOINT 4817.63486266136,3802.84900903702 4810.97975492477,3801.2371301651 4824.28961634636,3804.46041584015 PathPoint;PointKind.SMOOTHPOINT 4785.29295802116,3800.8984208107 4769.999345541,3807.31714010239 4800.58657050133,3794.47970151901 PathPoint;PointKind.SMOOTHPOINT 4751.97068452835,3800.8984208107 4740.50436973572,3804.18850421906 4763.43735337257,3797.60857343674 PathPoint;PointKind.SMOOTHPOINT 4719.62877988815,3801.87347888947 4707.22245812416,3802.84240007401 4732.03510165215,3800.90502977371 PathPoint;PointKind.SMOOTHPOINT 4676.5060043335,3801.87347888947 4663.01451444626,3801.2371301651 4689.99714016914,3802.51029968262 PathPoint;PointKind.SMOOTHPOINT 4626.52277112007,3800.8984208107 4615.16975283623,3802.15247154236 4637.87614345551,3799.64437007904 PathPoint;PointKind.SMOOTHPOINT 4561.83896183968,3803.82406711578 4541.69378042221,3801.2371301651 4581.98378920555,3806.41100406647 PathPoint;PointKind.SMOOTHPOINT 4488.33431124687,3798.94830465317 4471.44498825073,3799.4269824028 4505.22363424301,3798.46915483475 PathPoint;PointKind.SMOOTHPOINT 4437.37106323242,3799.92336273193 4418.57120690701,3806.26381165639 4451.13953751189,3795.27970084743 PathPoint;PointKind.SMOOTHPOINT 4395,3799 4378.91274897297,3805.45353071503 4402.64234587203,3795.93450249928 PathPoint;PointKind.SMOOTHPOINT 4346.22543811798,3801.87347888947 4324.69095826149,3802.84240007401 4367.75991797447,3800.90502977371 PathPoint;PointKind.SMOOTHPOINT 4303.10301661491,3801.87347888947 4285.52895784378,3800.63217401505 4320.67636728287,3803.11525583267 PathPoint;PointKind.SMOOTHPOINT 4202.15618133545,3799.92336273193 4202.1862757206,3800.00880718231 4202.15618133545,3799.92336273193 PathPoint;PointKind.SMOOTHPOINT 4185,3799 4173.36161613464,3802.65617275238 4196.52791976929,3795.37852430344 PathPoint;PointKind.SMOOTHPOINT 4160.014128685,3799.92336273193 4148.86610627174,3804.04735565186 4171.16179704666,3795.79936981201 PathPoint;PointKind.SMOOTHPOINT 4125.71148633957,3798.94830465317 4112.1258187294,3800.23209571838 4139.29750800133,3797.66427755356 PathPoint;PointKind.SMOOTHPOINT 3997.3238825798,3798.94830465317 3986.17904663086,3799.22800540924 4008.46871852875,3798.6683678627 PathPoint;PointKind.SMOOTHPOINT 3952.2410774231,3799.92336273193 3940.01071929932,3803.13295841217 3964.47108149529,3796.7137670517 PathPoint;PointKind.SMOOTHPOINT 3870.8959543705,3801.87347888947 3858.11115145683,3800.8597111702 3889.74990963936,3803.36899280548 PathPoint;PointKind.SMOOTHPOINT 3834.16982889175,3802.51407623291 3827.30830907822,3805.05994319916 3842.68052101135,3799.3564081192 PathPoint;PointKind.CORNERPOINT 3756.22891187668,3804.79912519455 3756.22891187668,3804.79912519455 3756.22891187668,3804.79912519455 PathPoint;PointKind.SMOOTHPOINT 3734.66752409935,3800.8984208107 3724.62095618248,3797.90762901306 3744.71373796463,3803.88921260834 PathPoint;PointKind.SMOOTHPOINT 3655.2824306488,3798.94830465317 3644.48279500008,3795.9022808075 3666.08242034912,3801.99385643005 PathPoint;PointKind.SMOOTHPOINT 3574.91732239723,3800.8984208107 3566.7960870266,3800.51793336868 3583.03891181946,3801.27914428711 PathPoint;PointKind.SMOOTHPOINT 3529.83451724052,3799.92336273193 3524.51843261719,3796.99205160141 3535.15024781227,3802.85443782806 PathPoint;PointKind.SMOOTHPOINT 3481.81131362915,3799.92336273193 3473.30062150955,3795.49748182297 3490.32271385193,3804.3492436409 PathPoint;PointKind.SMOOTHPOINT 3444.56933498383,3800.8984208107 3432.93201327324,3804.73799228668 3456.20630264282,3797.05908536911 PathPoint;PointKind.SMOOTHPOINT 3425.94799160957,3803.82406711578 3421.42037987709,3805.48716545105 3430.47595739365,3802.16073274612 PathPoint;PointKind.SMOOTHPOINT 3406.34698748589,3796.02265834808 3397.80549287796,3798.71274232864 3414.88812804222,3793.33257436752 PathPoint;PointKind.SMOOTHPOINT 3384.78559970856,3799.92336273193 3376.6087782383,3806.94798231125 3392.96206712723,3792.89850711823 PathPoint;PointKind.SMOOTHPOINT 3310.30093431473,3802.84900903702 3299.1167986393,3805.83932876587 3327.34391570091,3798.29165697098 PathPoint;PointKind.CORNERPOINT 3211.31483674049,3804.79912519455 3211.31483674049,3804.79912519455 3211.31483674049,3804.79912519455 PathPoint;PointKind.SMOOTHPOINT 3186.8130505085,3798.94830465317 3179.18961167336,3801.32281064987 3194.43684339523,3796.57332658768 PathPoint;PointKind.SMOOTHPOINT 3175.05216479301,3802.84900903702 3165.46019911766,3803.0472779274 3184.64448451996,3802.65026807785 PathPoint;PointKind.SMOOTHPOINT 3154.4711458683,3799.92336273193 3140.23260712624,3802.06797122955 3168.70968461037,3797.77851819992 PathPoint;PointKind.SMOOTHPOINT 3137.81018614769,3803.82406711578 3128.7206196785,3804.5928311348 3146.89975261688,3803.05506706238 PathPoint;PointKind.SMOOTHPOINT 3115.26878356934,3799.92336273193 3085.52278518677,3800.72281122208 3145.0147819519,3799.12391424179 PathPoint;PointKind.SMOOTHPOINT 3073.1260228157,3802.84900903702 3067.73275494576,3800.43720960617 3078.51929068565,3805.26057243347 PathPoint;PointKind.SMOOTHPOINT 3018.24271559715,3801.87347888947 3004.26051020622,3804.47906255722 3031.51009082794,3799.40149068832 PathPoint;PointKind.CORNERPOINT 2380.22298574448,3800.8984208107 2380.22298574448,3800.8984208107 2380.22298574448,3800.8984208107 PathPoint;PointKind.SMOOTHPOINT 2363.56167197227,3804.79912519455 2356.64987683296,3803.47568035126 2370.47382116318,3806.12257003784 PathPoint;PointKind.CORNERPOINT 2331.21976733208,3801.87347888947 2331.21976733208,3801.87347888947 2331.21976733208,3801.87347888947 PathPoint;PointKind.CORNERPOINT 2141.0880446434,3802.84900903702 2141.0880446434,3802.84900903702 2141.0880446434,3802.84900903702 PathPoint;PointKind.SMOOTHPOINT 2113.64621400833,3806.74971342087 2102.90712118149,3804.88079309464 2124.38530683517,3808.61839771271 PathPoint;PointKind.SMOOTHPOINT 2075.42386651039,3802.84900903702 2062.53391027451,3798.8555431366 2088.31382274628,3806.84223890305 PathPoint;PointKind.CORNERPOINT 2049.94206547737,3804.79912519455 2049.94206547737,3804.79912519455 2049.94206547737,3804.79912519455 PathPoint;PointKind.SMOOTHPOINT 2022.50058889389,3803.82406711578 2009.15957093239,3808.38165521622 2035.8412528038,3799.26647901535 PathPoint;PointKind.SMOOTHPOINT 1998.97917151451,3806.74971342087 1993.95836591721,3806.54577970505 2003.99962306023,3806.95341110229 PathPoint;PointKind.SMOOTHPOINT 1951.93598270416,3800.8984208107 1930.11613726616,3803.15632581711 1973.75618219376,3798.64051580429 PathPoint;PointKind.SMOOTHPOINT 1924.49450612068,3804.79912519455 1916.78998947144,3804.48071479797 1932.19866871834,3805.11753559113 PathPoint;PointKind.SMOOTHPOINT 1846.08978152275,3804.79912519455 1834.94600772858,3804.46490049362 1857.23284721375,3805.13358592987 PathPoint;PointKind.SMOOTHPOINT 1824.52839374542,3805.77441930771 1814.84508275986,3809.22972679138 1834.21099662781,3802.31911182404 PathPoint;PointKind.SMOOTHPOINT 1801.00662231445,3803.82406711578 1792.49734640121,3809.91517066956 1809.51625227928,3797.73272752762 PathPoint;PointKind.SMOOTHPOINT 1767.68434882164,3806.74971342087 1760.89293122292,3805.01415252686 1774.47647452354,3808.48503828049 PathPoint;PointKind.SMOOTHPOINT 1752.00375795364,3803.82406711578 1741.42505049706,3805.32477378845 1762.58211135864,3802.32336044312 PathPoint;PointKind.SMOOTHPOINT 1731.42238497734,3808.6998295784 1721.41440868378,3809.11501407623 1741.4303612709,3808.28488111496 PathPoint;PointKind.SMOOTHPOINT 1709.86099720001,3805.77441930771 1702.87095665932,3810.97590923309 1716.85103774071,3800.57292938232 PathPoint;PointKind.SMOOTHPOINT 1689.27962422371,3808.6998295784 1678.33234906197,3808.02453517914 1700.22760748863,3809.37536001205 PathPoint;PointKind.SMOOTHPOINT 1653.99767518044,3807.72477149963 1631.49628043175,3807.62445688248 1676.49871587753,3807.82508611679 PathPoint;PointKind.SMOOTHPOINT 1596.17396950722,3807.72477149963 1586.07748031616,3808.82941246033 1606.27010464668,3806.61989450455 PathPoint;PointKind.SMOOTHPOINT 1579.51300978661,3807.72477149963 1568.95129680634,3811.20580673218 1590.07472276688,3804.24373626709 PathPoint;PointKind.SMOOTHPOINT 1546.19073629379,3809.67512369156 1537.78271913528,3810.17504453659 1554.59910750389,3809.17520284653 PathPoint;PointKind.CORNERPOINT 1493.26745867729,3809.67512369156 1493.26745867729,3809.67512369156 1493.26745867729,3809.67512369156 PathPoint;PointKind.SMOOTHPOINT 1469.74604129791,3808.6998295784 1461.55611991882,3809.86017465591 1477.935962677,3807.53948450089 PathPoint;PointKind.SMOOTHPOINT 1446.22462391853,3808.6998295784 1435.5135011673,3814.08519029617 1448.29228520393,3807.66033411026 PathPoint;PointKind.SMOOTHPOINT 1416.82276368141,3810.65018177032 1409.24712181091,3809.42964792252 1424.39840555191,3811.87071561813 PathPoint;PointKind.SMOOTHPOINT 1381.54046058655,3807.72477149963 1372.70793557167,3807.42429971695 1390.37298560143,3808.02500724792 PathPoint;PointKind.CORNERPOINT 1358.99905800819,3811.62547588348 1358.99905800819,3811.62547588348 1358.99905800819,3811.62547588348 PathPoint;PointKind.CORNERPOINT 789.583904743195,3815.52618026733 789.583904743195,3815.52618026733 789.583904743195,3815.52618026733 PathPoint;PointKind.SMOOTHPOINT 762.141720056534,3815.52618026733 754.187242984772,3814.66819524765 770.096551179886,3816.38416528702 PathPoint;PointKind.SMOOTHPOINT 729.799815416336,3816.50147438049 721.401357650757,3817.05308675766 738.198273181915,3815.94962596893 PathPoint;PointKind.SMOOTHPOINT 680.796951055527,3814.55088615417 667.851762771606,3815.58825731277 693.742139339447,3813.51375102997 PathPoint;PointKind.SMOOTHPOINT 615.132772922516,3817.47653245926 596.24235033989,3817.85395145416 634.023195505142,3817.09887742996 PathPoint;PointKind.SMOOTHPOINT 561.22948050499,3818.45159053802 551.983069181442,3818.59863996506 570.475891828537,3818.30477714539 PathPoint;PointKind.SMOOTHPOINT 514.186645746231,3819.42688465118 502.926034927368,3819.60367441177 525.446902513504,3819.25009489059 PathPoint;PointKind.SMOOTHPOINT 454.402556419373,3817.47653245926 441.561813354492,3815.98857164383 467.243653535843,3818.96449327469 PathPoint;PointKind.SMOOTHPOINT 402.459293603897,3816.50147438049 390.489871501923,3814.98330116272 414.429069757462,3818.01941156387 PathPoint;PointKind.SMOOTHPOINT 358.356503248215,3820.40217876434 348.302500247955,3818.39871883392 368.411214351654,3822.40540266037 PathPoint;PointKind.SMOOTHPOINT 313.274052143097,3818.45159053802 302.476540803909,3818.39871883392 324.071209430695,3818.50469827652 PathPoint;PointKind.CORNERPOINT 251,3817 251,3817 251,3817 PathPoint;PointKind.SMOOTHPOINT 245,3815 244.391082494267,3814.46720997425 247.255077909294,3816.97314579732 PathPoint;PointKind.SMOOTHPOINT 241,3809 240.612408710367,3807.10980361596 241.387591289633,3810.89019638404 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,3794.07207012177 244.406414484103,3792.22853164652 244.933244729917,3795.91560859701 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3778.46948862076 239.70036149025,3769.19074058533 241.798471212387,3787.7480006218 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3677.05093860626 235.459177494049,3659.32947635651 246.039655208588,3694.77192878723 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,3654.62177038193 241.514875888824,3646.07378482819 236.063897609711,3663.16951990128 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,3631.21754407883 239.092454910278,3627.79764175415 238.486318588257,3634.63721036911 PathPoint;PointKind.SMOOTHPOINT 246.629859209061,3623.41613531113 244.745950698853,3613.93699407578 248.513413667679,3632.89504051208 PathPoint;PointKind.SMOOTHPOINT 236.829003095627,3606.83802366257 234.650169610977,3600.48138141632 239.008190631866,3613.19466590881 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,3577.5825047493 238.082345724106,3565.33420801163 239.496073722839,3589.83127355576 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3556.12863063812 240.705513954163,3545.24815320969 240.793318748474,3567.00934410095 PathPoint;PointKind.SMOOTHPOINT 236.829003095627,3532.72440433502 238.283447027206,3525.76729059219 235.374913215637,3539.68175411224 PathPoint;PointKind.SMOOTHPOINT 239.769047498703,3511.27053022385 242.926833629608,3493.63049983978 236.611615419388,3528.9110326767 PathPoint;PointKind.SMOOTHPOINT 248.589888811111,3482.01524734497 247.972422838211,3473.94924402237 249.207354784012,3490.08125066757 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,3461.53643131256 239.092454910278,3446.63251161575 238.486318588257,3476.44035100937 PathPoint;PointKind.SMOOTHPOINT 246.629859209061,3437.15714693069 247.369118928909,3429.36163902283 245.890245437622,3444.95241880417 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3386.44798994064 238.484548330307,3366.29796981812 243.01428437233,3406.59777402878 PathPoint;PointKind.SMOOTHPOINT 243.689814805984,3347.44071006775 242.524631023407,3337.77651786804 244.854290485382,3357.10490226746 PathPoint;PointKind.SMOOTHPOINT 237.809017896652,3324.03624773026 236.670033931732,3306.64476156235 238.948001861572,3341.42796993256 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3290.88026046753 242.122782468796,3282.14321136475 239.376050233841,3299.61730957031 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3227.49393224716 238.593950271606,3218.26545953751 245.335800647736,3247.12986946106 PathPoint;PointKind.SMOOTHPOINT 236.000168323517,3199.99993801117 232.986481189728,3193.9617061615 238.673965930939,3205.35791873932 PathPoint;PointKind.SMOOTHPOINT 240.464758872986,3177.19618320465 245.711095333099,3169.15637969971 239.305948019028,3178.97257804871 PathPoint;PointKind.SMOOTHPOINT 236.829003095627,3131.92620277405 237.184470891953,3119.12818193436 236.515667438507,3143.21832418442 PathPoint;PointKind.SMOOTHPOINT 243.689814805984,3088.04339647293 246.674823760986,3082.39367723465 237.128176689148,3100.461165905 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3048.06105852127 234.951821565628,3029.7122168541 246.547011137009,3066.40942811966 PathPoint;PointKind.SMOOTHPOINT 246.999843120575,3002.99996852875 236.769168376923,2986.00077152252 252.405502796173,3011.981549263 PathPoint;PointKind.SMOOTHPOINT 239.769047498703,2955.41897535324 240.403861999512,2943.54762554169 239.134587049484,2967.29032516479 PathPoint;PointKind.SMOOTHPOINT 236.749416351318,2890.13194274902 234.991904258728,2871.63841199875 238.506928443909,2908.6252374649 PathPoint;PointKind.SMOOTHPOINT 237.729785203934,2857.95101356506 245.831901788712,2841.30752038956 229.627314567566,2874.59403467178 PathPoint;PointKind.SMOOTHPOINT 234.789032697678,2824.79502630234 234.901975154877,2808.34413719177 234.676444292068,2841.24544334412 PathPoint;PointKind.SMOOTHPOINT 235.66982960701,2795.56421327591 235.037493467331,2784.46375179291 236.301811695099,2806.6651468277 PathPoint;PointKind.SMOOTHPOINT 229.789032697678,2766.30893039703 225.348517656326,2744.69620513916 234.229901790619,2787.92165565491 PathPoint;PointKind.SMOOTHPOINT 226.948914289474,2728.25223875046 215.408248662949,2719.19489097595 238.48922586441,2737.30935049057 PathPoint;PointKind.CORNERPOINT 222.048486232758,2705.82330656052 222.048486232758,2705.82330656052 222.048486232758,2705.82330656052 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,2677.49319791794 239.193005561829,2661.96189880371 242.305827140808,2693.02473306656 PathPoint;PointKind.CORNERPOINT 244.808971881866,2636.51101827621 244.808971881866,2636.51101827621 244.808971881866,2636.51101827621 PathPoint;PointKind.SMOOTHPOINT 240.888912677765,2605.30538320541 241.951775550842,2587.94812202454 239.826049804688,2622.66264438629 PathPoint;PointKind.SMOOTHPOINT 246.769001483917,2571.17410182953 248.007473945618,2550.9957575798 245.531237125397,2591.35244607925 PathPoint;PointKind.SMOOTHPOINT 247.749724388123,2528.26611757278 248.610423803329,2510.42356967926 246.888316869736,2546.1089015007 PathPoint;PointKind.SMOOTHPOINT 241.86892747879,2480.48260688782 243.765935897827,2471.05633735657 239.971919059753,2489.90864038467 PathPoint;PointKind.SMOOTHPOINT 255.669858455658,2416.17055177689 256.851682662964,2403.56253862381 254.487680196762,2428.77809286118 PathPoint;PointKind.SMOOTHPOINT 250.769076347351,2388.86538505554 245.951850414276,2373.64069461823 255.587010383606,2404.09031152725 PathPoint;PointKind.SMOOTHPOINT 243.869002342224,2354.80869340897 242.534935951233,2338.07857561111 245.203422784805,2371.53881120682 PathPoint;PointKind.SMOOTHPOINT 248.769076347351,2300.19883203506 251.012347221375,2278.22521018982 246.526159524918,2322.17221784592 PathPoint;PointKind.SMOOTHPOINT 242.888987541199,2264.11719846725 241.730530738831,2258.94403266907 244.047090291977,2269.29012823105 PathPoint;PointKind.CORNERPOINT 246.8090467453,2188.05322694778 246.8090467453,2188.05322694778 246.8090467453,2188.05322694778 PathPoint;PointKind.SMOOTHPOINT 250.729460000992,2172.45017337799 250.383197546005,2156.44963788986 251.075722455978,2188.45118093491 PathPoint;PointKind.SMOOTHPOINT 246.8090467453,2140.26948022842 247.379069805145,2120.7614736557 246.239023685455,2159.77748680115 PathPoint;PointKind.SMOOTHPOINT 245.829031944275,2096.38643789291 244.757671833038,2089.29218816757 247.304364919662,2106.1535410881 PathPoint;PointKind.SMOOTHPOINT 242.817115068436,2074.82044744492 240.202090024948,2069.97088479996 247.445277452469,2083.40289402008 PathPoint;PointKind.SMOOTHPOINT 242.888987541199,2061.28009843826 243.746146440506,2041.22685241699 242.654251337051,2066.76813411713 PathPoint;PointKind.SMOOTHPOINT 253.669858455658,2021.2977604866 253.96230506897,2015.66338348389 253.296688079834,2028.48028707504 PathPoint;PointKind.SMOOTHPOINT 246.000038862228,2008.99989652634 245.25334405899,2006.54348659515 248.717384815216,2017.94087934494 PathPoint;PointKind.SMOOTHPOINT 241.908972740173,1998.86859226227 244.152951717377,1977.55822706223 241.42533826828,2003.4615855217 PathPoint;PointKind.SMOOTHPOINT 249.749445199966,1955.96084403992 250.811245918274,1946.04551124573 248.687290430069,1965.87594079971 PathPoint;PointKind.SMOOTHPOINT 248.999917984009,1926.9998960495 248.213923454285,1924.547498703 251.338782787323,1934.29737138748 PathPoint;PointKind.SMOOTHPOINT 250.512780427933,1914.46174907684 250.567304372787,1910.21549034119 250.473834753036,1917.47095155716 PathPoint;PointKind.SMOOTHPOINT 260.769300937653,1885.8720831871 260.204234600067,1882.12904977798 262.113280773163,1894.77530050278 PathPoint;PointKind.SMOOTHPOINT 257.080083370209,1867.53575134277 256.390390872955,1863.60483455658 257.617179632187,1870.5973534584 PathPoint;PointKind.SMOOTHPOINT 250.776194810867,1858.18713712692 247.186111688614,1854.7901301384 253.704555511475,1860.95794487 PathPoint;PointKind.SMOOTHPOINT 247.557865858078,1846.67314338684 243.377932786942,1839.44600629807 249.585873365402,1850.17967033386 PathPoint;PointKind.SMOOTHPOINT 246.828873634338,1822.46073532104 248.612939596176,1813.8386349678 245.172620296478,1830.46749401093 PathPoint;PointKind.SMOOTHPOINT 250.511718273163,1804.51173591614 248.713490247726,1801.1999373436 250.929499149323,1805.28120803833 PathPoint;PointKind.SMOOTHPOINT 255.649714946747,1781.50310325623 260.088105678558,1762.65976953506 252.738702774048,1793.86186408997 PathPoint;PointKind.SMOOTHPOINT 253.689685344696,1754.19840860367 252.834296703339,1749.50958538055 259.401953697205,1785.50388622284 PathPoint;PointKind.SMOOTHPOINT 251.191143274307,1739.56286001205 252.047948122025,1731.04791927338 250.681308984756,1744.62957429886 PathPoint;PointKind.SMOOTHPOINT 248.440516471863,1720.20544338226 247.391461610794,1711.74337434769 249.243151426315,1726.67939472198 PathPoint;PointKind.SMOOTHPOINT 248.138118982315,1692.63827562332 249.183633327484,1689.06542301178 245.527696609497,1701.55801534653 PathPoint;PointKind.SMOOTHPOINT 247.786191701889,1681.97754621506 247.738748788834,1673.60044956207 247.805310487747,1685.34858942032 PathPoint;PointKind.SMOOTHPOINT 249.809242486954,1661.48197174072 254.8215508461,1644.57341194153 248.330368995667,1666.47055864334 PathPoint;PointKind.SMOOTHPOINT 253.729655742645,1630.27610063553 253.610694408417,1621.07689619064 253.848263025284,1639.47530508041 PathPoint;PointKind.SMOOTHPOINT 252.999955415726,1587.99998044968 252.970215082169,1575.0742650032 253.06333065033,1615.43118953705 PathPoint;PointKind.SMOOTHPOINT 249.275686740875,1537.86957979202 248.877024650574,1534.14542913437 251.29590511322,1556.75327539444 PathPoint;PointKind.SMOOTHPOINT 248.049606084824,1526.66880369186 244.486076831818,1522.15747833252 250.280485153198,1529.49295520782 PathPoint;PointKind.SMOOTHPOINT 246.152243614197,1509.76779699326 244.87978219986,1498.4046292305 246.769001483917,1515.27707576752 PathPoint;PointKind.SMOOTHPOINT 243.000122308731,1479.00000572205 242.123490571976,1468.40111732483 243.724157810211,1487.7592420578 PathPoint;PointKind.SMOOTHPOINT 247,1452 247.215263366699,1444.88828372955 246.739772081375,1460.60274553299 PathPoint;PointKind.SMOOTHPOINT 243.675652742386,1430.14277458191 246.436547040939,1423.57204914093 241.092846393585,1436.2895822525 PathPoint;PointKind.SMOOTHPOINT 246.000001430511,1413.00006866455 249.171949625015,1392.04233884811 245.114872455597,1418.84687662125 PathPoint;PointKind.SMOOTHPOINT 249.569903612137,1367.82922267914 254.731621742249,1343.12185049057 244.408539533615,1392.53635883331 PathPoint;PointKind.SMOOTHPOINT 247.609874010086,1309.31842088699 247.062864303589,1285.88351011276 248.156883716583,1332.75333166122 PathPoint;PointKind.SMOOTHPOINT 245.649844408035,1264.46008443832 241.220659017563,1258.53160858154 256.955419778824,1279.59390163422 PathPoint;PointKind.SMOOTHPOINT 234.372239112854,1251.67976617813 227.688099145889,1253.22130680084 241.052838563919,1250.13916969299 PathPoint;PointKind.SMOOTHPOINT 224.088456630707,1235.20480155945 220.614856481552,1221.81008577347 226.201082468033,1243.35247278214 PathPoint;PointKind.SMOOTHPOINT 232.000093460083,1167.9999089241 231.82483792305,1145.63281774521 232.174640893936,1190.36723613739 PathPoint;PointKind.SMOOTHPOINT 235,1089 235.31298160553,1053.57312583923 234.68701839447,1124.42663812637 PathPoint;PointKind.SMOOTHPOINT 236.630026102066,1028.39264631271 237.264132499695,1007.92303562164 235.995919704437,1048.86225700378 PathPoint;PointKind.SMOOTHPOINT 232.709612846375,1003.03806781769 231.178339719772,986.862630844116 234.240531921387,1019.21350479126 PathPoint;PointKind.SMOOTHPOINT 237.610040903091,976.708431243896 238.153864145279,968.956825733185 237.065509557724,984.459800720215 PathPoint;PointKind.SMOOTHPOINT 239.999889135361,933.9998960495 236.611615419388,898.227231502533 242.220146656036,957.44188785553 PathPoint;PointKind.SMOOTHPOINT 243.689814805984,886.091287136078 238.333722352982,869.74071264267 251.881152391434,911.098659038544 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,846.108949184418 230.009913251889,816.360928200728 253.121593237062,863.260434899799 PathPoint;PointKind.SMOOTHPOINT 248.589888811111,806.126375198364 252.968872080823,787.681817928336 244.978081979499,821.339511621867 PathPoint;PointKind.SMOOTHPOINT 245.649844408035,771.020271778107 241.648707389832,748.813683986664 249.650627374649,793.226623535156 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,738.839342594147 249.523168802261,722.302300930023 239.816136360168,755.37638425827 PathPoint;PointKind.SMOOTHPOINT 240.729785203934,697.658413410187 240.447960138321,686.790681838989 241.011256217957,708.525908946991 PathPoint;PointKind.SMOOTHPOINT 248.569903612137,679.129949569702 252.585031425716,662.856010077016 244.759752583819,694.574467641554 PathPoint;PointKind.SMOOTHPOINT 238.769047498703,659.626427650452 238.427387714386,644.008267879486 239.1114153862,675.244351387024 PathPoint;PointKind.SMOOTHPOINT 242.709800004959,614.991624355316 240.899534225464,590.856871604919 244.519357681274,639.126377105713 PathPoint;PointKind.SMOOTHPOINT 242.709800004959,566.232583522797 247.706176042557,552.430944442749 236.701898574829,582.827217578888 PathPoint;PointKind.SMOOTHPOINT 242.709800004959,543.803651332855 242.419123649597,526.258270740509 242.997997999191,561.228182315826 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,508.697075843811 244.679034948349,494.539496898651 244.660270214081,522.854890823364 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,480.416851043701 242.859563827515,451.361961364746 246.479387283325,509.472212791443 PathPoint;PointKind.SMOOTHPOINT 245.649844408035,428.732635974884 246.698899269104,418.667893409729 244.600435495377,438.797378540039 PathPoint;PointKind.SMOOTHPOINT 246.523997783661,398.026685714722 247.388237714767,377.182724475861 245.697995424271,417.949404716492 PathPoint;PointKind.SMOOTHPOINT 245.649844408035,358.519957065582 247.379032373428,343.924298286438 244.020144939423,372.273681163788 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,333.165142536163 247.709008455276,311.216776371002 241.630296707153,355.113508701324 PathPoint;PointKind.SMOOTHPOINT 247.609874010086,289.282100200653 247.853815555573,274.628140926361 247.335484027863,305.768630504608 PathPoint;PointKind.SMOOTHPOINT 249.416599273682,264.004232883453 249.439612627029,263.469378948212 248.928008079529,275.511617660522 PathPoint;PointKind.SMOOTHPOINT 252.510302066803,261.002111434937 252.320884466171,258.16545009613 252.656525373459,263.200535774231 PathPoint;PointKind.SMOOTHPOINT 255.450346469879,256.275056362152 255.96265912056,254.016679286957 254.895547628403,258.720844745636 PathPoint;PointKind.SMOOTHPOINT 253.490316867828,251.399057865143 253.528908491135,249.573567867279 253.47827911377,251.966484546661 PathPoint;PointKind.SMOOTHPOINT 248.954916000366,251.488037109375 248.19087266922,245.177893638611 249.32560801506,254.549167156219 PathPoint;PointKind.SMOOTHPOINT 247,237 247.121439695358,235.794100284576 246.446263313293,242.487563610077 PathPoint;PointKind.SMOOTHPOINT 251.510302066803,232.771298408508 255.333106766525,230.35542739081 250.158363243721,233.625420224058 PathPoint;PointKind.SMOOTHPOINT 250.529933214188,223.994831562042 250.30263209343,222.027248859406 250.887879371643,227.088062286377 PathPoint;PointKind.SMOOTHPOINT 247.271400690079,225.413081645966 246.995948553085,223.042824268341 247.471793889999,227.137076854706 PathPoint;PointKind.SMOOTHPOINT 246.629859209061,219.069421291351 246.440795660019,216.480123996735 246.764752864838,220.91591835022 PathPoint;PointKind.SMOOTHPOINT 246.629859209061,201.516015529633 246.833084821701,199.795088768005 245.374038219452,212.142283916473 PathPoint;PointKind.SMOOTHPOINT 249.529933214188,200.516015529633 250.489413022995,195.520347595215 248.789965391159,204.370457172394 PathPoint;PointKind.SMOOTHPOINT 249,175 249.036467313766,171.539735794067 248.951494932175,179.652237892151 PathPoint";
	
	mask35mm[2] = "PointKind.CORNERPOINT 246.629859209061,173.235790729523 246.629859209061,173.235790729523 246.629859209061,173.235790729523 PathPoint;PointKind.SMOOTHPOINT 249.569903612137,155.682857036591 250.197991132736,155.570032596588 244.761528968811,156.544382572174 PathPoint;PointKind.SMOOTHPOINT 260.350420475006,155.682857036591 275.499933958054,155.846428871155 259.622136354446,155.674831867218 PathPoint;PointKind.CORNERPOINT 337.775484323502,154.707562923431 337.775484323502,154.707562923431 337.775484323502,154.707562923431 PathPoint;PointKind.SMOOTHPOINT 356.396473646164,155.682857036591 366.033049821854,154.210002422333 346.759897470474,157.155475616455 PathPoint;PointKind.SMOOTHPOINT 469.103486537933,153.732504844666 475.238138437271,152.605204582214 462.968834638596,154.859805107117 PathPoint;PointKind.CORNERPOINT 481.844741106033,158.608267307281 481.844741106033,158.608267307281 481.844741106033,158.608267307281 PathPoint;PointKind.CORNERPOINT 946.393353939056,159.583561420441 946.393353939056,159.583561420441 946.393353939056,159.583561420441 PathPoint;PointKind.CORNERPOINT 995.396572351456,157.632973194122 995.396572351456,157.632973194122 995.396572351456,157.632973194122 PathPoint;PointKind.SMOOTHPOINT 1014.01756167412,153.732504844666 1020.87589502335,150.795056819916 1007.15958237648,156.669716835022 PathPoint;PointKind.CORNERPOINT 1035.57894945145,159.583561420441 1035.57894945145,159.583561420441 1035.57894945145,159.583561420441 PathPoint;PointKind.SMOOTHPOINT 1264.91303443909,156.657915115356 1281.28190159798,157.625420093536 1248.54487538338,155.69064617157 PathPoint;PointKind.SMOOTHPOINT 1302.15572118759,156.657915115356 1311.43505930901,154.595918655396 1292.87602901459,158.719675540924 PathPoint;PointKind.SMOOTHPOINT 1320.77671051025,157.632973194122 1329.60144639015,158.815977573395 1311.95197463036,156.450204849243 PathPoint;PointKind.SMOOTHPOINT 1367.8198993206,159.583561420441 1376.63861632347,156.605987548828 1359.00118231773,162.56089925766 PathPoint;PointKind.SMOOTHPOINT 1393.30134630203,158.608267307281 1401.46825432777,156.605987548828 1385.13443827629,160.610547065735 PathPoint;PointKind.CORNERPOINT 1803.94702076912,158.608267307281 1803.94702076912,158.608267307281 1803.94702076912,158.608267307281 PathPoint;PointKind.SMOOTHPOINT 1815.70755243301,158.608267307281 1821.34263753891,158.211257457733 1810.07282137871,159.00527715683 PathPoint;PointKind.SMOOTHPOINT 1874.51127290726,158.608267307281 1884.72672343254,157.611021995544 1864.29582238197,159.605276584625 PathPoint;PointKind.SMOOTHPOINT 1912.73397445679,157.632973194122 1919.64789390564,160.021169185638 1905.81970095634,155.245013237 PathPoint;PointKind.SMOOTHPOINT 1932.33462452888,158.608267307281 1943.26667547226,157.410864830017 1921.40328168869,159.805433750153 PathPoint;PointKind.SMOOTHPOINT 2070.52343845367,157.632973194122 2082.55269527435,153.595604896545 2058.494181633,161.670577526093 PathPoint;PointKind.CORNERPOINT 2113.64621400833,159.583561420441 2113.64621400833,159.583561420441 2113.64621400833,159.583561420441 PathPoint;PointKind.SMOOTHPOINT 2121.48668646812,155.682857036591 2126.35879039764,156.005752086639 2116.61493659019,155.359725952148 PathPoint;PointKind.SMOOTHPOINT 2142.06805944443,158.608267307281 2149.16856408119,156.005752086639 2134.96755480766,161.21054649353 PathPoint;PointKind.CORNERPOINT 2334.15981173515,157.632973194122 2334.15981173515,157.632973194122 2334.15981173515,157.632973194122 PathPoint;PointKind.SMOOTHPOINT 2346.90071225166,154.707562923431 2351.79476737976,154.755477905273 2342.00701117516,154.659647941589 PathPoint;PointKind.SMOOTHPOINT 2356.70121431351,156.657915115356 2364.33775305748,157.020463943481 2349.06502962112,156.295366287231 PathPoint;PointKind.SMOOTHPOINT 2430.20586490631,157.632973194122 2437.61651873589,158.425576686859 2422.79521107674,156.840605735779 PathPoint;PointKind.SMOOTHPOINT 2474.30865526199,157.632973194122 2492.32173800468,161.840758323669 2456.2955725193,153.425424098969 PathPoint;PointKind.CORNERPOINT 2581.13557934761,157.632973194122 2581.13557934761,157.632973194122 2581.13557934761,157.632973194122 PathPoint;PointKind.SMOOTHPOINT 2629.15842890739,155.682857036591 2643.71950864792,159.835410118103 2614.59734916687,151.530067920685 PathPoint;PointKind.SMOOTHPOINT 2698.74266624451,156.657915115356 2708.91775488853,157.82534122467 2688.56757760048,155.490489006042 PathPoint;PointKind.SMOOTHPOINT 2754.60634231567,153.732504844666 2763.42258095741,151.599934101105 2745.79010367393,155.864839553833 PathPoint;PointKind.CORNERPOINT 3024.1231584549,156.657915115356 3024.1231584549,156.657915115356 3024.1231584549,156.657915115356 PathPoint;PointKind.CORNERPOINT 3105.46828150749,153.732504844666 3105.46828150749,153.732504844666 3105.46828150749,153.732504844666 PathPoint;PointKind.CORNERPOINT 3891.47697329521,152.757210731506 3891.47697329521,152.757210731506 3891.47697329521,152.757210731506 PathPoint;PointKind.SMOOTHPOINT 3932.63971924782,151.781916618347 3942.42322683334,149.189786911011 3922.85621166229,154.374282360077 PathPoint;PointKind.CORNERPOINT 3952.2410774231,156.657915115356 3952.2410774231,156.657915115356 3952.2410774231,156.657915115356 PathPoint;PointKind.SMOOTHPOINT 4077.68863677979,152.757210731506 4084.64575052261,153.694739341736 4070.73187708855,151.819682121277 PathPoint;PointKind.CORNERPOINT 4677.48601913452,150.806858539581 4677.48601913452,150.806858539581 4677.48601913452,150.806858539581 PathPoint;PointKind.SMOOTHPOINT 4701.98745131493,151.781916618347 4708.47650885582,151.542813777924 4695.49874782562,152.021255493164 PathPoint;PointKind.SMOOTHPOINT 4728.44926714897,148.856506347656 4737.34198093414,150.337858200073 4719.5565533638,147.375154495239 PathPoint;PointKind.SMOOTHPOINT 4919.5316183567,147.653203010559 4920.63555121422,147.013077735901 4919.5316183567,147.653203010559 PathPoint;PointKind.SMOOTHPOINT 5069.51070427895,146.906154155731 5084.95018601418,145.494904518127 5054.0223634243,148.321888446808 PathPoint;PointKind.SMOOTHPOINT 5243.96148204803,147.881212234497 5258.14974546432,148.327789306641 5229.77321863174,147.43510723114 PathPoint;PointKind.SMOOTHPOINT 5434.09320473671,144.955801963806 5445.22387862206,145.312685966492 5422.96253085136,144.598917961121 PathPoint;PointKind.SMOOTHPOINT 5470.35587668419,146.906154155731 5479.13493990898,146.717798709869 5461.57610535622,147.094509601593 PathPoint;PointKind.SMOOTHPOINT 5491.91691040993,142.030391693115 5500.73385715485,141.697583198547 5483.1003177166,142.363200187683 PathPoint;PointKind.SMOOTHPOINT 5651.66675806046,141.054861545563 5658.59342336655,139.287436008453 5644.74044680595,142.822759151459 PathPoint;PointKind.SMOOTHPOINT 5677.14855909348,153.732504844666 5678.60353628539,168.999956211552 5676.5658221664,147.618777437524 PathPoint;PointKind.SMOOTHPOINT 5687.92943000793,207.367308139801 5684.87538099289,218.122923374176 5690.99764108658,196.560709476471 PathPoint;PointKind.SMOOTHPOINT 5687,229 5686.10672783852,238.15388584137 5687.99453091621,218.813935756683 PathPoint;PointKind.SMOOTHPOINT 5675,253 5673.94528031349,270.817764282227 5675.99382281303,236.201668262482 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,279.530339241028 5685.46912550926,296.802864074707 5686.46896719933,262.258050441742 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,353.64372253418 5684.02671933174,364.235057830811 5687.91137337685,343.052859306335 PathPoint;PointKind.SMOOTHPOINT 5683.02864789963,397.52676486969 5682.81550884247,409.427382946014 5683.24214100838,385.626618862152 PathPoint;PointKind.SMOOTHPOINT 5689.88945960999,442.385101318359 5688.26790332794,454.014987945557 5691.51066184044,430.755214691162 PathPoint;PointKind.SMOOTHPOINT 5684.00901675224,502.846255302429 5682.61440753937,514.668509960175 5685.40327191353,491.024000644684 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,544.778709411621 5683.82561802864,557.045888900757 5686.1524450779,532.511529922485 PathPoint;PointKind.SMOOTHPOINT 5688.90944480896,597.438454627991 5688.67010593414,611.674160957336 5689.14842963219,583.202748298645 PathPoint;PointKind.SMOOTHPOINT 5683.02864789963,630.594441890717 5679.38333272934,643.61079454422 5686.67431712151,617.578089237213 PathPoint;PointKind.CORNERPOINT 5687.06861829758,668.651133537292 5687.06861829758,668.651133537292 5687.06861829758,668.651133537292 PathPoint;PointKind.SMOOTHPOINT 5687.06861829758,701.807120800018 5682.15721464157,717.519694328308 5691.98037600517,686.094783306122 PathPoint;PointKind.SMOOTHPOINT 5688.0486330986,745.690163135529 5687.00134849548,764.517446517944 5689.09627175331,726.863115787506 PathPoint;PointKind.SMOOTHPOINT 5686.08860349655,775.920976161957 5684.98148417473,788.414040565491 5687.19607686996,763.427911758423 PathPoint;PointKind.SMOOTHPOINT 5690.98903155327,803.225670814514 5691.03682851791,833.206287384033 5690.94123458862,773.245526313782 PathPoint;PointKind.SMOOTHPOINT 5689.02864789963,882.215288639069 5687.98277950287,891.892698764801 5690.07487034798,872.537878513336 PathPoint;PointKind.SMOOTHPOINT 5690.00901675224,910.495277404785 5689.39473724365,922.019420623779 5690.62329626083,898.971606254578 PathPoint;PointKind.SMOOTHPOINT 5686.08860349655,969.00607919693 5685.07389163971,979.479161262512 5688.22990751266,946.90381860733 PathPoint;PointKind.SMOOTHPOINT 5687.93816900253,1001.24766921997 5688.30355024338,1003.81312704086 5686.33006668091,989.947050571442 PathPoint;PointKind.SMOOTHPOINT 5689.06546926498,1009.08283090591 5689.2835650444,1010.61516618729 5688.68663406372,1006.42177915573 PathPoint;PointKind.SMOOTHPOINT 5689.71125936508,1013.7338886261 5688.66220450401,1014.92680644989 5690.76066827774,1012.54097080231 PathPoint;PointKind.SMOOTHPOINT 5690.30500388145,1018.35213756561 5691.24288654327,1026.05393981934 5690.11487817764,1016.79336643219 PathPoint;PointKind.SMOOTHPOINT 5691.96904635429,1043.11969852448 5691.97648143768,1047.49908065796 5691.95453023911,1034.2412648201 PathPoint;PointKind.SMOOTHPOINT 5692.29194140434,1055.36138629913 5693.73717999458,1057.65516853333 5690.49973225594,1052.51646375656 PathPoint;PointKind.SMOOTHPOINT 5693.99988627434,1074.99991989136 5694.73135685921,1086.57551860809 5693.62388348579,1069.04972887039 PathPoint;PointKind.SMOOTHPOINT 5690.98903155327,1106.50602674484 5684.34950208664,1124.87068271637 5694.73277306557,1096.15119791031 PathPoint;PointKind.SMOOTHPOINT 5682.0486330986,1160.11612415314 5681.37982964516,1176.89392089844 5682.71814465523,1143.33856344223 PathPoint;PointKind.SMOOTHPOINT 5688.90944480896,1212.77586936951 5689.31908249855,1216.45186901093 5687.96129465103,1204.27037000656 PathPoint;PointKind.SMOOTHPOINT 5690.60853838921,1219.448325634 5692.98564076424,1220.82889080048 5687.86888718605,1217.8572177887 PathPoint;PointKind.SMOOTHPOINT 5694.00003600121,1227.99993228912 5695.33481049538,1229.63116598129 5691.10991287231,1224.46838569641 PathPoint;PointKind.SMOOTHPOINT 5700.63000607491,1233.3040971756 5702.34786438942,1236.06640768051 5698.90223431587,1230.52644443512 PathPoint;PointKind.SMOOTHPOINT 5704.44597411156,1241.84358549118 5705.31906533241,1244.81573057175 5703.58987736702,1238.92808866501 PathPoint;PointKind.SMOOTHPOINT 5705.95954465866,1250.87945413589 5705.13991522789,1252.46489715576 5707.35627818108,1248.17874860764 PathPoint;PointKind.SMOOTHPOINT 5705.8065943718,1258.4054107666 5705.63381719589,1260.33711624146 5706.02964687347,1255.90981912613 PathPoint;PointKind.SMOOTHPOINT 5703.9998691082,1264.9999756813 5701.93114566803,1266.79407310486 5705.45148062706,1263.74120426178 PathPoint;PointKind.SMOOTHPOINT 5704.1938893795,1268.33136510849 5703.87028622627,1269.76338577271 5704.50510072708,1266.9548125267 PathPoint;PointKind.SMOOTHPOINT 5703.14766693115,1272.55756092072 5703.24361491203,1275.93238067627 5703.10695099831,1271.12624835968 PathPoint;PointKind.SMOOTHPOINT 5700.63000607491,1281.08784389496 5698.47949671745,1287.94346284866 5701.46946239471,1278.41215801239 PathPoint;PointKind.SMOOTHPOINT 5700.00011086464,1297.00002193451 5701.21556997299,1299.23267126083 5699.5253276825,1296.12811088562 PathPoint;PointKind.SMOOTHPOINT 5700.76840281487,1303.4751534462 5700.25609016418,1305.08726835251 5701.38657689095,1301.53141021729 PathPoint;PointKind.SMOOTHPOINT 5701.64999127388,1308.34312677383 5702.41934537888,1312.40740299225 5701.38268232346,1306.93211317062 PathPoint;PointKind.SMOOTHPOINT 5704.57622766495,1327.16970205307 5704.70014572144,1328.8410615921 5703.98991823196,1319.25334453583 PathPoint;PointKind.SMOOTHPOINT 5703.99983167648,1332.99998760223 5705.75026273727,1334.07347202301 5702.6055765152,1332.14483499527 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1338.57370376587 5704.20128703117,1343.37629556656 5704.7613966465,1336.45977973938 PathPoint;PointKind.SMOOTHPOINT 5702.33437299728,1356.3702249527 5701.08634114265,1357.91625022888 5703.2934987545,1355.18226385117 PathPoint;PointKind.SMOOTHPOINT 5701.46977901459,1361.4688038826 5699.96895432472,1369.84094381332 5701.76966071129,1359.79602813721 PathPoint;PointKind.SMOOTHPOINT 5696.74956321716,1379.53133583069 5693.89272093773,1383.96547794342 5698.21285843849,1377.26044893265 PathPoint;PointKind.SMOOTHPOINT 5699,1401 5699.5363881588,1404.21667671204 5697.5462641716,1392.28065347672 PathPoint;PointKind.SMOOTHPOINT 5702.29684352875,1417.14270830154 5702.16265797615,1418.52539777756 5702.94617414474,1410.45467376709 PathPoint;PointKind.SMOOTHPOINT 5701.84188723564,1421.46591424942 5700.03941059113,1423.62633705139 5702.80738592148,1420.30887365341 PathPoint;PointKind.SMOOTHPOINT 5701.25805616379,1426.41319513321 5701.0424387455,1428.16763877869 5701.46800875664,1424.70713853836 PathPoint;PointKind.SMOOTHPOINT 5700.57084202766,1431.84245824814 5698.94539117813,1433.44418764114 5701.90844893456,1430.5242061615 PathPoint;PointKind.SMOOTHPOINT 5699.95337605476,1436.54922008514 5696.88658118248,1459.71363544464 5700.16509890556,1434.9489068985 PathPoint;PointKind.SMOOTHPOINT 5694,1498 5694.76014876366,1513.75505971909 5692.89040231705,1475.00552940369 PathPoint;PointKind.CORNERPOINT 5713.41087698936,1539.46045160294 5713.41087698936,1539.46045160294 5713.41087698936,1539.46045160294 PathPoint;PointKind.SMOOTHPOINT 5713.41087698936,1589.19455051422 5709.36866998672,1593.7856554985 5717.45272994041,1584.60368156433 PathPoint;PointKind.SMOOTHPOINT 5712.43086218834,1609.67336654663 5710.37913322449,1618.68704795837 5714.48259115219,1600.65944910049 PathPoint;PointKind.SMOOTHPOINT 5708.51044893265,1646.73005819321 5705.33354401588,1656.84908866882 5711.68735384941,1636.6107916832 PathPoint;PointKind.SMOOTHPOINT 5709.49081778526,1664.28322792053 5708.56001615524,1669.50478076935 5710.4209113121,1659.06167507172 PathPoint;PointKind.SMOOTHPOINT 5708.51044893265,1685.73710203171 5710.579880476,1691.59618377686 5706.4410173893,1679.87825632095 PathPoint;PointKind.SMOOTHPOINT 5708.51044893265,1724.7443819046 5708.15745949745,1738.79385709763 5708.86308431625,1710.69467067719 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1788.13094615936 5699.07214164734,1798.64722251892 5710.10828375816,1777.61443376541 PathPoint;PointKind.SMOOTHPOINT 5705.57005047798,1816.41093492508 5704.92638468742,1823.75349283218 5706.21407032013,1809.06861305237 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1892.47490644455 5702.91147708893,1906.49818181992 5706.26894831657,1878.45163106918 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1946.10970973969 5703.51442694664,1959.12134170532 5705.66599845886,1933.09807777405 PathPoint;PointKind.SMOOTHPOINT 5704.59003567696,1987.06710577011 5697.86128520966,2000.69856405258 5711.31949424744,1973.43588352203 PathPoint;PointKind.SMOOTHPOINT 5698.7099468708,2023.14873933792 5699.4793009758,2036.65061473846 5697.9409468174,2009.64709997177 PathPoint;PointKind.SMOOTHPOINT 5701.64999127388,2094.33671236038 5697.65982985497,2109.15471553802 5705.64015269279,2079.51894521713 PathPoint;PointKind.SMOOTHPOINT 5693.80951881409,2147.97175168991 5690.19217371941,2165.38802146912 5697.42686390877,2130.55500984192 PathPoint;PointKind.SMOOTHPOINT 5695.76954841614,2202.58161306381 5697.05687999725,2216.40591144562 5694.48257088661,2188.75731468201 PathPoint;PointKind.SMOOTHPOINT 5693,2286 5680.12360758614,2307.8110513459 5697.01667331968,2279.1958087249 PathPoint;PointKind.SMOOTHPOINT 5691.84948921204,2334.23050403595 5689.66853141785,2353.11514377594 5694.03009295464,2315.34610033035 PathPoint;PointKind.SMOOTHPOINT 5687.92943000793,2386.89024925232 5684.2469394207,2402.06726074219 5691.61121249199,2371.71323776245 PathPoint;PointKind.SMOOTHPOINT 5689.88945960999,2443.45069885254 5691.77053570747,2462.0610666275 5688.00802946091,2424.84033107758 PathPoint;PointKind.SMOOTHPOINT 5683.02864789963,2482.45750665665 5682.37294435501,2489.53783035278 5684.23313140869,2469.45767641068 PathPoint;PointKind.SMOOTHPOINT 5683.1285738945,2519.66337776184 5678.88703584671,2526.72009801865 5686.58978223801,2513.90531873703 PathPoint;PointKind.SMOOTHPOINT 5686.06861829758,2536.2414894104 5682.93419957161,2545.73384857178 5687.49615430832,2531.91875553131 PathPoint;PointKind.SMOOTHPOINT 5688.02864789963,2573.29818105698 5688.10158252716,2575.2839384079 5687.82081961632,2567.6095161438 PathPoint;PointKind.SMOOTHPOINT 5685.08860349655,2586.95088243484 5688.0789232254,2590.98376607895 5682.26858258247,2583.14718818665 PathPoint;PointKind.SMOOTHPOINT 5686.06861829758,2605.47911024094 5686.12597465515,2607.04425430298 5685.76979875565,2597.29343748093 PathPoint;PointKind.SMOOTHPOINT 5689.00901675224,2614.2555770874 5684.84466195107,2628.84722328186 5689.39634919167,2612.89790725708 PathPoint;PointKind.SMOOTHPOINT 5689.98903155327,2642.53580188751 5688.03572893143,2650.485912323 5691.94233417511,2634.58569145203 PathPoint;PointKind.SMOOTHPOINT 5680.18817543983,2664.96497011185 5677.33699798584,2674.58738422394 5683.03970694542,2655.34231996536 PathPoint;PointKind.SMOOTHPOINT 5690.96904635429,2702.99695587158 5691.46790504456,2720.98490095139 5690.47018766403,2685.00901079178 PathPoint;PointKind.SMOOTHPOINT 5686.16854429245,2769.45787382126 5684.35686230659,2783.82316303253 5687.97987222672,2755.09282064438 PathPoint;PointKind.SMOOTHPOINT 5686.16854429245,2800.66350889206 5682.33699798584,2811.93957996368 5689.99973654747,2789.38743782043 PathPoint;PointKind.SMOOTHPOINT 5681.26811623573,2828.94373369217 5681.32688879967,2842.87141513824 5681.2093436718,2815.01628828049 PathPoint;PointKind.SMOOTHPOINT 5689.10858869553,2866.00042533875 5688.39234232903,2876.61323976517 5689.82483506203,2855.38761091232 PathPoint;PointKind.SMOOTHPOINT 5684.20816063881,2887.45453548431 5683.95005702972,2898.9047999382 5684.46661829948,2876.00403499603 PathPoint;PointKind.SMOOTHPOINT 5680.85193872452,2991.83790206909 5680.50213575363,3018.29523324966 5681.16137981415,2968.43886852264 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,3055.86246728897 5684.34253334999,3068.85403633118 5685.6373000145,3042.83643722534 PathPoint;PointKind.SMOOTHPOINT 5681.06861829758,3090.96880674362 5683.80154252052,3107.27500677109 5678.33569407463,3074.66260671616 PathPoint;PointKind.SMOOTHPOINT 5684.98903155327,3169.95842456818 5683.19398999214,3185.40451526642 5686.78442716599,3154.51233386993 PathPoint;PointKind.SMOOTHPOINT 5679.10858869553,3211.89087867737 5678.75630736351,3229.18700695038 5679.46122407913,3194.59475040436 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,3248.94757032394 5685.12781977654,3257.67871856689 5686.80991888046,3240.21665811539 PathPoint;PointKind.SMOOTHPOINT 5684.00901675224,3323.06118965149 5682.59033203125,3339.0482711792 5685.42734742165,3307.07410812378 PathPoint;PointKind.SMOOTHPOINT 5680.08860349655,3361.09293937683 5682.59033203125,3378.21534633636 5677.58652091026,3343.97100448608 PathPoint;PointKind.SMOOTHPOINT 5685.96904635429,3438.13220500946 5685.414955616,3457.34493255615 5686.52349114418,3418.91947746277 PathPoint;PointKind.SMOOTHPOINT 5681.06861829758,3505.41947364807 5680.57046771049,3528.04384231567 5681.56712293625,3482.79510498047 PathPoint;PointKind.SMOOTHPOINT 5682.0486330986,3651.69636011124 5677.94234275818,3668.84614706039 5686.15527749062,3634.54633712769 PathPoint;PointKind.SMOOTHPOINT 5679.10858869553,3710.20692586899 5677.33939290047,3722.0693063736 5680.87813854218,3698.34430932999 PathPoint;PointKind.SMOOTHPOINT 5680.08860349655,3748.23891162872 5680.56586503983,3768.06674480438 5679.61169600487,3728.41084241867 PathPoint;PointKind.CORNERPOINT 5676.16854429245,3775.54384231567 5676.16854429245,3775.54384231567 5676.16854429245,3775.54384231567 PathPoint;PointKind.SMOOTHPOINT 5669,3789 5665.10695887856,3791.97799156 5674.61422117688,3784.70538744411 PathPoint;PointKind.SMOOTHPOINT 5658.52721571922,3797.97277450562 5645.44394731522,3802.00872659683 5663.6951930802,3796.37868316831 PathPoint;PointKind.SMOOTHPOINT 5511.51791453362,3801.87347888947 5498.48846197128,3801.6039276123 5524.54772114754,3802.14350223541 PathPoint;PointKind.SMOOTHPOINT 5196.91864728928,3799.92336273193 5182.77393221855,3800.19881486893 5211.06336236,3799.64791059494 PathPoint;PointKind.CORNERPOINT 4852.91716575623,3798.94830465317 4852.91716575623,3798.94830465317 4852.91716575623,3798.94830465317 PathPoint;PointKind.SMOOTHPOINT 4836.25620603561,3804.79912519455 4828.94539475441,3805.05239009857 4843.56666326523,3804.54586029053 PathPoint;PointKind.SMOOTHPOINT 4817.63486266136,3802.84900903702 4810.97975492477,3801.2371301651 4824.28961634636,3804.46041584015 PathPoint;PointKind.SMOOTHPOINT 4785.29295802116,3800.8984208107 4769.999345541,3807.31714010239 4800.58657050133,3794.47970151901 PathPoint;PointKind.SMOOTHPOINT 4751.97068452835,3800.8984208107 4740.50436973572,3804.18850421906 4763.43735337257,3797.60857343674 PathPoint;PointKind.SMOOTHPOINT 4719.62877988815,3801.87347888947 4707.22245812416,3802.84240007401 4732.03510165215,3800.90502977371 PathPoint;PointKind.SMOOTHPOINT 4676.5060043335,3801.87347888947 4663.01451444626,3801.2371301651 4689.99714016914,3802.51029968262 PathPoint;PointKind.SMOOTHPOINT 4626.52277112007,3800.8984208107 4615.16975283623,3802.15247154236 4637.87614345551,3799.64437007904 PathPoint;PointKind.SMOOTHPOINT 4561.83896183968,3803.82406711578 4541.69378042221,3801.2371301651 4581.98378920555,3806.41100406647 PathPoint;PointKind.SMOOTHPOINT 4488.33431124687,3798.94830465317 4471.44498825073,3799.4269824028 4505.22363424301,3798.46915483475 PathPoint;PointKind.SMOOTHPOINT 4437.37106323242,3799.92336273193 4418.57120690701,3806.26381165639 4451.13953751189,3795.27970084743 PathPoint;PointKind.SMOOTHPOINT 4395,3799 4378.91274897297,3805.45353071503 4402.64234587203,3795.93450249928 PathPoint;PointKind.SMOOTHPOINT 4346.22543811798,3801.87347888947 4324.69095826149,3802.84240007401 4367.75991797447,3800.90502977371 PathPoint;PointKind.SMOOTHPOINT 4303.10301661491,3801.87347888947 4285.52895784378,3800.63217401505 4320.67636728287,3803.11525583267 PathPoint;PointKind.SMOOTHPOINT 4202.15618133545,3799.92336273193 4202.1862757206,3800.00880718231 4202.15618133545,3799.92336273193 PathPoint;PointKind.SMOOTHPOINT 4185,3799 4173.36161613464,3802.65617275238 4196.52791976929,3795.37852430344 PathPoint;PointKind.SMOOTHPOINT 4160.014128685,3799.92336273193 4148.86610627174,3804.04735565186 4171.16179704666,3795.79936981201 PathPoint;PointKind.SMOOTHPOINT 4125.71148633957,3798.94830465317 4112.1258187294,3800.23209571838 4139.29750800133,3797.66427755356 PathPoint;PointKind.SMOOTHPOINT 3997.3238825798,3798.94830465317 3986.17904663086,3799.22800540924 4008.46871852875,3798.6683678627 PathPoint;PointKind.SMOOTHPOINT 3952.2410774231,3799.92336273193 3940.01071929932,3803.13295841217 3964.47108149529,3796.7137670517 PathPoint;PointKind.SMOOTHPOINT 3870.8959543705,3801.87347888947 3858.11115145683,3800.8597111702 3889.74990963936,3803.36899280548 PathPoint;PointKind.SMOOTHPOINT 3834.16982889175,3802.51407623291 3827.30830907822,3805.05994319916 3842.68052101135,3799.3564081192 PathPoint;PointKind.CORNERPOINT 3756.22891187668,3804.79912519455 3756.22891187668,3804.79912519455 3756.22891187668,3804.79912519455 PathPoint;PointKind.SMOOTHPOINT 3734.66752409935,3800.8984208107 3724.62095618248,3797.90762901306 3744.71373796463,3803.88921260834 PathPoint;PointKind.SMOOTHPOINT 3655.2824306488,3798.94830465317 3644.48279500008,3795.9022808075 3666.08242034912,3801.99385643005 PathPoint;PointKind.SMOOTHPOINT 3574.91732239723,3800.8984208107 3566.7960870266,3800.51793336868 3583.03891181946,3801.27914428711 PathPoint;PointKind.SMOOTHPOINT 3529.83451724052,3799.92336273193 3524.51843261719,3796.99205160141 3535.15024781227,3802.85443782806 PathPoint;PointKind.SMOOTHPOINT 3481.81131362915,3799.92336273193 3473.30062150955,3795.49748182297 3490.32271385193,3804.3492436409 PathPoint;PointKind.SMOOTHPOINT 3444.56933498383,3800.8984208107 3432.93201327324,3804.73799228668 3456.20630264282,3797.05908536911 PathPoint;PointKind.SMOOTHPOINT 3425.94799160957,3803.82406711578 3421.42037987709,3805.48716545105 3430.47595739365,3802.16073274612 PathPoint;PointKind.SMOOTHPOINT 3406.34698748589,3796.02265834808 3397.80549287796,3798.71274232864 3414.88812804222,3793.33257436752 PathPoint;PointKind.SMOOTHPOINT 3384.78559970856,3799.92336273193 3376.6087782383,3806.94798231125 3392.96206712723,3792.89850711823 PathPoint;PointKind.SMOOTHPOINT 3310.30093431473,3802.84900903702 3299.1167986393,3805.83932876587 3327.34391570091,3798.29165697098 PathPoint;PointKind.CORNERPOINT 3211.31483674049,3804.79912519455 3211.31483674049,3804.79912519455 3211.31483674049,3804.79912519455 PathPoint;PointKind.SMOOTHPOINT 3186.8130505085,3798.94830465317 3179.18961167336,3801.32281064987 3194.43684339523,3796.57332658768 PathPoint;PointKind.SMOOTHPOINT 3175.05216479301,3802.84900903702 3165.46019911766,3803.0472779274 3184.64448451996,3802.65026807785 PathPoint;PointKind.SMOOTHPOINT 3154.4711458683,3799.92336273193 3140.23260712624,3802.06797122955 3168.70968461037,3797.77851819992 PathPoint;PointKind.SMOOTHPOINT 3137.81018614769,3803.82406711578 3128.7206196785,3804.5928311348 3146.89975261688,3803.05506706238 PathPoint;PointKind.SMOOTHPOINT 3115.26878356934,3799.92336273193 3085.52278518677,3800.72281122208 3145.0147819519,3799.12391424179 PathPoint;PointKind.SMOOTHPOINT 3073.1260228157,3802.84900903702 3067.73275494576,3800.43720960617 3078.51929068565,3805.26057243347 PathPoint;PointKind.SMOOTHPOINT 3018.24271559715,3801.87347888947 3004.26051020622,3804.47906255722 3031.51009082794,3799.40149068832 PathPoint;PointKind.CORNERPOINT 2380.22298574448,3800.8984208107 2380.22298574448,3800.8984208107 2380.22298574448,3800.8984208107 PathPoint;PointKind.SMOOTHPOINT 2363.56167197227,3804.79912519455 2356.64987683296,3803.47568035126 2370.47382116318,3806.12257003784 PathPoint;PointKind.CORNERPOINT 2331.21976733208,3801.87347888947 2331.21976733208,3801.87347888947 2331.21976733208,3801.87347888947 PathPoint;PointKind.CORNERPOINT 2141.0880446434,3802.84900903702 2141.0880446434,3802.84900903702 2141.0880446434,3802.84900903702 PathPoint;PointKind.SMOOTHPOINT 2113.64621400833,3806.74971342087 2102.90712118149,3804.88079309464 2124.38530683517,3808.61839771271 PathPoint;PointKind.SMOOTHPOINT 2075.42386651039,3802.84900903702 2062.53391027451,3798.8555431366 2088.31382274628,3806.84223890305 PathPoint;PointKind.CORNERPOINT 2049.94206547737,3804.79912519455 2049.94206547737,3804.79912519455 2049.94206547737,3804.79912519455 PathPoint;PointKind.SMOOTHPOINT 2022.50058889389,3803.82406711578 2009.15957093239,3808.38165521622 2035.8412528038,3799.26647901535 PathPoint;PointKind.SMOOTHPOINT 1998.97917151451,3806.74971342087 1993.95836591721,3806.54577970505 2003.99962306023,3806.95341110229 PathPoint;PointKind.SMOOTHPOINT 1951.93598270416,3800.8984208107 1930.11613726616,3803.15632581711 1973.75618219376,3798.64051580429 PathPoint;PointKind.SMOOTHPOINT 1924.49450612068,3804.79912519455 1916.78998947144,3804.48071479797 1932.19866871834,3805.11753559113 PathPoint;PointKind.SMOOTHPOINT 1846.08978152275,3804.79912519455 1834.94600772858,3804.46490049362 1857.23284721375,3805.13358592987 PathPoint;PointKind.SMOOTHPOINT 1824.52839374542,3805.77441930771 1814.84508275986,3809.22972679138 1834.21099662781,3802.31911182404 PathPoint;PointKind.SMOOTHPOINT 1801.00662231445,3803.82406711578 1792.49734640121,3809.91517066956 1809.51625227928,3797.73272752762 PathPoint;PointKind.SMOOTHPOINT 1767.68434882164,3806.74971342087 1760.89293122292,3805.01415252686 1774.47647452354,3808.48503828049 PathPoint;PointKind.SMOOTHPOINT 1752.00375795364,3803.82406711578 1741.42505049706,3805.32477378845 1762.58211135864,3802.32336044312 PathPoint;PointKind.SMOOTHPOINT 1731.42238497734,3808.6998295784 1721.41440868378,3809.11501407623 1741.4303612709,3808.28488111496 PathPoint;PointKind.SMOOTHPOINT 1709.86099720001,3805.77441930771 1702.87095665932,3810.97590923309 1716.85103774071,3800.57292938232 PathPoint;PointKind.SMOOTHPOINT 1689.27962422371,3808.6998295784 1678.33234906197,3808.02453517914 1700.22760748863,3809.37536001205 PathPoint;PointKind.SMOOTHPOINT 1653.99767518044,3807.72477149963 1631.49628043175,3807.62445688248 1676.49871587753,3807.82508611679 PathPoint;PointKind.SMOOTHPOINT 1596.17396950722,3807.72477149963 1586.07748031616,3808.82941246033 1606.27010464668,3806.61989450455 PathPoint;PointKind.SMOOTHPOINT 1579.51300978661,3807.72477149963 1568.95129680634,3811.20580673218 1590.07472276688,3804.24373626709 PathPoint;PointKind.SMOOTHPOINT 1546.19073629379,3809.67512369156 1537.78271913528,3810.17504453659 1554.59910750389,3809.17520284653 PathPoint;PointKind.CORNERPOINT 1493.26745867729,3809.67512369156 1493.26745867729,3809.67512369156 1493.26745867729,3809.67512369156 PathPoint;PointKind.SMOOTHPOINT 1469.74604129791,3808.6998295784 1461.55611991882,3809.86017465591 1477.935962677,3807.53948450089 PathPoint;PointKind.SMOOTHPOINT 1446.22462391853,3808.6998295784 1435.5135011673,3814.08519029617 1448.29228520393,3807.66033411026 PathPoint;PointKind.SMOOTHPOINT 1416.82276368141,3810.65018177032 1409.24712181091,3809.42964792252 1424.39840555191,3811.87071561813 PathPoint;PointKind.SMOOTHPOINT 1381.54046058655,3807.72477149963 1372.70793557167,3807.42429971695 1390.37298560143,3808.02500724792 PathPoint;PointKind.CORNERPOINT 1358.99905800819,3811.62547588348 1358.99905800819,3811.62547588348 1358.99905800819,3811.62547588348 PathPoint;PointKind.CORNERPOINT 789.583904743195,3815.52618026733 789.583904743195,3815.52618026733 789.583904743195,3815.52618026733 PathPoint;PointKind.SMOOTHPOINT 762.141720056534,3815.52618026733 754.187242984772,3814.66819524765 770.096551179886,3816.38416528702 PathPoint;PointKind.SMOOTHPOINT 729.799815416336,3816.50147438049 721.401357650757,3817.05308675766 738.198273181915,3815.94962596893 PathPoint;PointKind.SMOOTHPOINT 680.796951055527,3814.55088615417 667.851762771606,3815.58825731277 693.742139339447,3813.51375102997 PathPoint;PointKind.SMOOTHPOINT 615.132772922516,3817.47653245926 596.24235033989,3817.85395145416 634.023195505142,3817.09887742996 PathPoint;PointKind.SMOOTHPOINT 561.22948050499,3818.45159053802 551.983069181442,3818.59863996506 570.475891828537,3818.30477714539 PathPoint;PointKind.SMOOTHPOINT 514.186645746231,3819.42688465118 502.926034927368,3819.60367441177 525.446902513504,3819.25009489059 PathPoint;PointKind.SMOOTHPOINT 454.402556419373,3817.47653245926 441.561813354492,3815.98857164383 467.243653535843,3818.96449327469 PathPoint;PointKind.SMOOTHPOINT 402.459293603897,3816.50147438049 390.489871501923,3814.98330116272 414.429069757462,3818.01941156387 PathPoint;PointKind.SMOOTHPOINT 358.356503248215,3820.40217876434 348.302500247955,3818.39871883392 368.411214351654,3822.40540266037 PathPoint;PointKind.SMOOTHPOINT 313.274052143097,3818.45159053802 302.476540803909,3818.39871883392 324.071209430695,3818.50469827652 PathPoint;PointKind.CORNERPOINT 251,3817 251,3817 251,3817 PathPoint;PointKind.SMOOTHPOINT 245,3815 244.391082494267,3814.46720997425 247.255077909294,3816.97314579732 PathPoint;PointKind.SMOOTHPOINT 241,3809 240.612408710367,3807.10980361596 241.387591289633,3810.89019638404 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,3794.07207012177 244.406414484103,3792.22853164652 244.933244729917,3795.91560859701 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3778.46948862076 239.70036149025,3769.19074058533 241.798471212387,3787.7480006218 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3677.05093860626 235.459177494049,3659.32947635651 246.039655208588,3694.77192878723 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,3654.62177038193 241.514875888824,3646.07378482819 236.063897609711,3663.16951990128 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,3631.21754407883 239.092454910278,3627.79764175415 238.486318588257,3634.63721036911 PathPoint;PointKind.SMOOTHPOINT 244,3621 242.116091489792,3611.52085876465 245.883554458618,3630.47890520096 PathPoint;PointKind.SMOOTHPOINT 236.829003095627,3606.83802366257 234.650169610977,3600.48138141632 239.008190631866,3613.19466590881 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,3577.5825047493 238.082345724106,3565.33420801163 239.496073722839,3589.83127355576 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3556.12863063812 240.705513954163,3545.24815320969 240.793318748474,3567.00934410095 PathPoint;PointKind.SMOOTHPOINT 236.829003095627,3532.72440433502 238.283447027206,3525.76729059219 235.374913215637,3539.68175411224 PathPoint;PointKind.SMOOTHPOINT 239.769047498703,3511.27053022385 242.926833629608,3493.63049983978 236.611615419388,3528.9110326767 PathPoint;PointKind.SMOOTHPOINT 248.589888811111,3482.01524734497 247.972422838211,3473.94924402237 249.207354784012,3490.08125066757 PathPoint;PointKind.SMOOTHPOINT 238.789032697678,3461.53643131256 239.092454910278,3446.63251161575 238.486318588257,3476.44035100937 PathPoint;PointKind.SMOOTHPOINT 246.629859209061,3437.15714693069 247.369118928909,3429.36163902283 245.890245437622,3444.95241880417 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3386.44798994064 238.484548330307,3366.29796981812 243.01428437233,3406.59777402878 PathPoint;PointKind.SMOOTHPOINT 243.689814805984,3347.44071006775 242.524631023407,3337.77651786804 244.854290485382,3357.10490226746 PathPoint;PointKind.SMOOTHPOINT 237.809017896652,3324.03624773026 236.670033931732,3306.64476156235 238.948001861572,3341.42796993256 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3290.88026046753 242.122782468796,3282.14321136475 239.376050233841,3299.61730957031 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3227.49393224716 238.593950271606,3218.26545953751 245.335800647736,3247.12986946106 PathPoint;PointKind.SMOOTHPOINT 236.000168323517,3199.99993801117 232.986481189728,3193.9617061615 238.673965930939,3205.35791873932 PathPoint;PointKind.SMOOTHPOINT 240.464758872986,3177.19618320465 245.711095333099,3169.15637969971 239.305948019028,3178.97257804871 PathPoint;PointKind.SMOOTHPOINT 236.829003095627,3131.92620277405 237.184470891953,3119.12818193436 236.515667438507,3143.21832418442 PathPoint;PointKind.SMOOTHPOINT 243.689814805984,3088.04339647293 246.674823760986,3082.39367723465 237.128176689148,3100.461165905 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,3048.06105852127 234.951821565628,3029.7122168541 246.547011137009,3066.40942811966 PathPoint;PointKind.SMOOTHPOINT 246.999843120575,3002.99996852875 236.769168376923,2986.00077152252 252.405502796173,3011.981549263 PathPoint;PointKind.SMOOTHPOINT 239.769047498703,2955.41897535324 240.403861999512,2943.54762554169 239.134587049484,2967.29032516479 PathPoint;PointKind.SMOOTHPOINT 236.749416351318,2890.13194274902 234.991904258728,2871.63841199875 238.506928443909,2908.6252374649 PathPoint;PointKind.SMOOTHPOINT 237.729785203934,2857.95101356506 245.831901788712,2841.30752038956 229.627314567566,2874.59403467178 PathPoint;PointKind.SMOOTHPOINT 234.789032697678,2824.79502630234 234.901975154877,2808.34413719177 234.676444292068,2841.24544334412 PathPoint;PointKind.SMOOTHPOINT 235.66982960701,2795.56421327591 235.037493467331,2784.46375179291 236.301811695099,2806.6651468277 PathPoint;PointKind.SMOOTHPOINT 229.789032697678,2766.30893039703 225.348517656326,2744.69620513916 234.229901790619,2787.92165565491 PathPoint;PointKind.SMOOTHPOINT 226.948914289474,2728.25223875046 215.408248662949,2719.19489097595 238.48922586441,2737.30935049057 PathPoint;PointKind.CORNERPOINT 222.048486232758,2705.82330656052 222.048486232758,2705.82330656052 222.048486232758,2705.82330656052 PathPoint;PointKind.SMOOTHPOINT 240.749416351318,2677.49319791794 239.193005561829,2661.96189880371 242.305827140808,2693.02473306656 PathPoint;PointKind.CORNERPOINT 244.808971881866,2636.51101827621 244.808971881866,2636.51101827621 244.808971881866,2636.51101827621 PathPoint;PointKind.SMOOTHPOINT 240.888912677765,2605.30538320541 241.951775550842,2587.94812202454 239.826049804688,2622.66264438629 PathPoint;PointKind.SMOOTHPOINT 246.769001483917,2571.17410182953 248.007473945618,2550.9957575798 245.531237125397,2591.35244607925 PathPoint;PointKind.SMOOTHPOINT 247.749724388123,2528.26611757278 248.610423803329,2510.42356967926 246.888316869736,2546.1089015007 PathPoint;PointKind.SMOOTHPOINT 241.86892747879,2480.48260688782 243.765935897827,2471.05633735657 239.971919059753,2489.90864038467 PathPoint;PointKind.SMOOTHPOINT 245.669858455658,2415.17055177689 246.851682662964,2402.56253862381 244.487680196762,2427.77809286118 PathPoint;PointKind.SMOOTHPOINT 240.769076347351,2387.86538505554 235.951850414276,2372.64069461823 245.587010383606,2403.09031152725 PathPoint;PointKind.SMOOTHPOINT 233.869002342224,2353.80869340897 232.534935951233,2337.07857561111 235.203422784805,2370.53881120682 PathPoint;PointKind.SMOOTHPOINT 238.769076347351,2299.19883203506 241.012347221375,2277.22521018982 236.526159524918,2321.17221784592 PathPoint;PointKind.SMOOTHPOINT 232.888987541199,2263.11719846725 231.730530738831,2257.94403266907 234.047090291977,2268.29012823105 PathPoint;PointKind.CORNERPOINT 236.8090467453,2187.05322694778 236.8090467453,2187.05322694778 236.8090467453,2187.05322694778 PathPoint;PointKind.SMOOTHPOINT 240.729460000992,2171.45017337799 240.383197546005,2155.44963788986 241.075722455978,2187.45118093491 PathPoint;PointKind.SMOOTHPOINT 236.8090467453,2139.26948022842 237.379069805145,2119.7614736557 236.239023685455,2158.77748680115 PathPoint;PointKind.SMOOTHPOINT 235.829031944275,2095.38643789291 234.757671833038,2088.29218816757 237.304364919662,2105.1535410881 PathPoint;PointKind.SMOOTHPOINT 232.817115068436,2073.82044744492 230.202090024948,2068.97088479996 237.445277452469,2082.40289402008 PathPoint;PointKind.SMOOTHPOINT 232.888987541199,2060.28009843826 233.746146440506,2040.22685241699 232.654251337051,2065.76813411713 PathPoint;PointKind.SMOOTHPOINT 244,2027 244.292446613312,2021.36562299728 243.626829624176,2034.18252658844 PathPoint;PointKind.SMOOTHPOINT 236.000038862228,2007.99989652634 235.25334405899,2005.54348659515 238.717384815216,2016.94087934494 PathPoint;PointKind.SMOOTHPOINT 231.908972740173,1997.86859226227 234.152951717377,1976.55822706223 231.42533826828,2002.4615855217 PathPoint;PointKind.SMOOTHPOINT 239.749445199966,1954.96084403992 240.811245918274,1945.04551124573 238.687290430069,1964.87594079971 PathPoint;PointKind.SMOOTHPOINT 238.999917984009,1925.9998960495 238.213923454285,1923.547498703 241.338782787323,1933.29737138748 PathPoint;PointKind.SMOOTHPOINT 240.512780427933,1913.46174907684 240.567304372787,1909.21549034119 240.473834753036,1916.47095155716 PathPoint;PointKind.SMOOTHPOINT 250.769300937653,1884.8720831871 250.204234600067,1881.12904977798 252.113280773163,1893.77530050278 PathPoint;PointKind.SMOOTHPOINT 247.080083370209,1866.53575134277 246.390390872955,1862.60483455658 247.617179632187,1869.5973534584 PathPoint;PointKind.SMOOTHPOINT 240.776194810867,1857.18713712692 237.186111688614,1853.7901301384 243.704555511475,1859.95794487 PathPoint;PointKind.SMOOTHPOINT 237.557865858078,1845.67314338684 233.377932786942,1838.44600629807 239.585873365402,1849.17967033386 PathPoint;PointKind.SMOOTHPOINT 236.828873634338,1821.46073532104 238.612939596176,1812.8386349678 235.172620296478,1829.46749401093 PathPoint;PointKind.SMOOTHPOINT 240.511718273163,1803.51173591614 238.713490247726,1800.1999373436 240.929499149323,1804.28120803833 PathPoint;PointKind.SMOOTHPOINT 245.649714946747,1780.50310325623 250.088105678558,1761.65976953506 242.738702774048,1792.86186408997 PathPoint;PointKind.SMOOTHPOINT 243.689685344696,1753.19840860367 242.834296703339,1748.50958538055 249.401953697205,1784.50388622284 PathPoint;PointKind.SMOOTHPOINT 241.191143274307,1738.56286001205 242.047948122025,1730.04791927338 240.681308984756,1743.62957429886 PathPoint;PointKind.SMOOTHPOINT 238.440516471863,1719.20544338226 237.391461610794,1710.74337434769 239.243151426315,1725.67939472198 PathPoint;PointKind.SMOOTHPOINT 238.138118982315,1691.63827562332 239.183633327484,1688.06542301178 235.527696609497,1700.55801534653 PathPoint;PointKind.SMOOTHPOINT 237.786191701889,1680.97754621506 237.738748788834,1672.60044956207 237.805310487747,1684.34858942032 PathPoint;PointKind.SMOOTHPOINT 239.809242486954,1660.48197174072 244.8215508461,1643.57341194153 238.330368995667,1665.47055864334 PathPoint;PointKind.SMOOTHPOINT 243.729655742645,1629.27610063553 243.610694408417,1620.07689619064 243.848263025284,1638.47530508041 PathPoint;PointKind.SMOOTHPOINT 242.999955415726,1586.99998044968 242.970215082169,1574.0742650032 243.06333065033,1614.43118953705 PathPoint;PointKind.SMOOTHPOINT 239.275686740875,1536.86957979202 238.877024650574,1533.14542913437 241.29590511322,1555.75327539444 PathPoint;PointKind.SMOOTHPOINT 238.049606084824,1525.66880369186 234.486076831818,1521.15747833252 240.280485153198,1528.49295520782 PathPoint;PointKind.SMOOTHPOINT 236.152243614197,1508.76779699326 234.87978219986,1497.4046292305 236.769001483917,1514.27707576752 PathPoint;PointKind.SMOOTHPOINT 233.000122308731,1478.00000572205 232.123490571976,1467.40111732483 233.724157810211,1486.7592420578 PathPoint;PointKind.SMOOTHPOINT 237,1451 237.215263366699,1443.88828372955 236.739772081375,1459.60274553299 PathPoint;PointKind.SMOOTHPOINT 233.675652742386,1429.14277458191 236.436547040939,1422.57204914093 231.092846393585,1435.2895822525 PathPoint;PointKind.SMOOTHPOINT 236.000001430511,1412.00006866455 239.171949625015,1391.04233884811 235.114872455597,1417.84687662125 PathPoint;PointKind.SMOOTHPOINT 239.569903612137,1366.82922267914 244.731621742249,1342.12185049057 234.408539533615,1391.53635883331 PathPoint;PointKind.SMOOTHPOINT 237.609874010086,1308.31842088699 237.062864303589,1284.88351011276 238.156883716583,1331.75333166122 PathPoint;PointKind.SMOOTHPOINT 246,1270 241.570814609528,1264.07152414322 257.305575370789,1285.13381719589 PathPoint;PointKind.SMOOTHPOINT 234.372239112854,1251.67976617813 229.13885050066,1246.81815412265 239.395164184944,1256.34603559553 PathPoint;PointKind.SMOOTHPOINT 224.088456630707,1235.20480155945 220.614856481552,1221.81008577347 226.201082468033,1243.35247278214 PathPoint;PointKind.SMOOTHPOINT 232.000093460083,1167.9999089241 231.82483792305,1145.63281774521 232.174640893936,1190.36723613739 PathPoint;PointKind.SMOOTHPOINT 235,1089 235.31298160553,1053.57312583923 234.68701839447,1124.42663812637 PathPoint;PointKind.SMOOTHPOINT 236.630026102066,1028.39264631271 237.264132499695,1007.92303562164 235.995919704437,1048.86225700378 PathPoint;PointKind.SMOOTHPOINT 232.709612846375,1003.03806781769 231.178339719772,986.862630844116 234.240531921387,1019.21350479126 PathPoint;PointKind.SMOOTHPOINT 237.610040903091,976.708431243896 238.153864145279,968.956825733185 237.065509557724,984.459800720215 PathPoint;PointKind.SMOOTHPOINT 239.999889135361,933.9998960495 236.611615419388,898.227231502533 242.220146656036,957.44188785553 PathPoint;PointKind.SMOOTHPOINT 243.689814805984,886.091287136078 238.333722352982,869.74071264267 251.881152391434,911.098659038544 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,846.108949184418 230.009913251889,816.360928200728 253.121593237062,863.260434899799 PathPoint;PointKind.SMOOTHPOINT 248.589888811111,806.126375198364 252.968872080823,787.681817928336 244.978081979499,821.339511621867 PathPoint;PointKind.SMOOTHPOINT 245.649844408035,771.020271778107 241.648707389832,748.813683986664 249.650627374649,793.226623535156 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,738.839342594147 249.523168802261,722.302300930023 239.816136360168,755.37638425827 PathPoint;PointKind.SMOOTHPOINT 240.729785203934,697.658413410187 240.447960138321,686.790681838989 241.011256217957,708.525908946991 PathPoint;PointKind.SMOOTHPOINT 248.569903612137,679.129949569702 252.585031425716,662.856010077016 244.759752583819,694.574467641554 PathPoint;PointKind.SMOOTHPOINT 238.769047498703,659.626427650452 238.427387714386,644.008267879486 239.1114153862,675.244351387024 PathPoint;PointKind.SMOOTHPOINT 242.709800004959,614.991624355316 240.899534225464,590.856871604919 244.519357681274,639.126377105713 PathPoint;PointKind.SMOOTHPOINT 242.709800004959,566.232583522797 247.706176042557,552.430944442749 236.701898574829,582.827217578888 PathPoint;PointKind.SMOOTHPOINT 242.709800004959,543.803651332855 242.419123649597,526.258270740509 242.997997999191,561.228182315826 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,508.697075843811 244.679034948349,494.539496898651 244.660270214081,522.854890823364 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,480.416851043701 242.859563827515,451.361961364746 246.479387283325,509.472212791443 PathPoint;PointKind.SMOOTHPOINT 245.649844408035,428.732635974884 246.698899269104,418.667893409729 244.600435495377,438.797378540039 PathPoint;PointKind.SMOOTHPOINT 246.523997783661,398.026685714722 247.388237714767,377.182724475861 245.697995424271,417.949404716492 PathPoint;PointKind.SMOOTHPOINT 245.649844408035,358.519957065582 247.379032373428,343.924298286438 244.020144939423,372.273681163788 PathPoint;PointKind.SMOOTHPOINT 244.66982960701,333.165142536163 247.709008455276,311.216776371002 241.630296707153,355.113508701324 PathPoint;PointKind.SMOOTHPOINT 247.609874010086,289.282100200653 247.853815555573,274.628140926361 247.335484027863,305.768630504608 PathPoint;PointKind.SMOOTHPOINT 249.416599273682,264.004232883453 249.439612627029,263.469378948212 248.928008079529,275.511617660522 PathPoint;PointKind.SMOOTHPOINT 252.510302066803,261.002111434937 252.320884466171,258.16545009613 252.656525373459,263.200535774231 PathPoint;PointKind.SMOOTHPOINT 255.450346469879,256.275056362152 255.96265912056,254.016679286957 254.895547628403,258.720844745636 PathPoint;PointKind.SMOOTHPOINT 253.490316867828,251.399057865143 253.528908491135,249.573567867279 253.47827911377,251.966484546661 PathPoint;PointKind.SMOOTHPOINT 248.954916000366,251.488037109375 248.19087266922,245.177893638611 249.32560801506,254.549167156219 PathPoint;PointKind.SMOOTHPOINT 247,237 247.899310181131,228.069823682417 246.446263313293,242.487563610077 PathPoint;PointKind.SMOOTHPOINT 246.629859209061,201.516015529633 246.833084821701,199.795088768005 245.526765433916,210.849965676616 PathPoint;PointKind.SMOOTHPOINT 249.529933214188,200.516015529633 250.489413022995,195.520347595215 248.789965391159,204.370457172394 PathPoint;PointKind.SMOOTHPOINT 249,175 249.036467313766,171.539735794067 248.951494932175,179.652237892151 PathPoint";
	
	shadow35mm[0] = "PointKind.CORNERPOINT 238.899518251419,157.751462459564 238.899518251419,157.751462459564 238.899518251419,157.751462459564 PathPoint;PointKind.SMOOTHPOINT 236.935240030289,280.606892108917 235.874855518341,298.051249980927 237.995624542236,263.162062168121 PathPoint;PointKind.SMOOTHPOINT 233.989530801773,383.961160182953 231.577731370926,396.45870923996 236.40133023262,371.463611125946 PathPoint;PointKind.SMOOTHPOINT 231.043821573257,486.340842247009 230.721988677979,501.180324554443 231.364946365356,471.501123905182 PathPoint;PointKind.SMOOTHPOINT 228.097758293152,539.968328475952 229.345082044601,560.358159542084 226.849726438522,519.578025341034 PathPoint;PointKind.SMOOTHPOINT 227.115619182587,678.423979282379 226.25385761261,698.848979473114 227.977734804153,657.999451160431 PathPoint;PointKind.SMOOTHPOINT 234.971315860748,735.951697826385 234.156289100647,752.06104516983 235.78705072403,719.842586517334 PathPoint;PointKind.SMOOTHPOINT 232.025606632233,780.803897380829 231.406724452972,797.426383495331 232.644488811493,764.181175231934 PathPoint;PointKind.SMOOTHPOINT 228.097758293152,882.208049297333 228.661054372787,916.546804904938 227.534462213516,847.869529724121 PathPoint;PointKind.SMOOTHPOINT 231.043821573257,965.086805820465 231.064356565475,987.155313491821 231.022932529449,943.018298149109 PathPoint;PointKind.SMOOTHPOINT 228.097758293152,1057.71590709686 229.174429178238,1101.08227014542 227.021087408066,1014.34930801392 PathPoint;PointKind.SMOOTHPOINT 222.205631732941,1168.87087583542 214.057134389877,1193.01034927368 230.354129076004,1144.73116636276 PathPoint;PointKind.SMOOTHPOINT 208.458162546158,1241.02375745773 212.856191396713,1239.22918796539 204.060133695602,1242.81856298447 PathPoint;PointKind.SMOOTHPOINT 228.097758293152,1276.12537622452 240.168793201447,1298.5812163353 216.026723384857,1253.66977214813 PathPoint;PointKind.SMOOTHPOINT 233.989530801773,1311.2269949913 235.186933279037,1338.49014759064 232.792128324509,1283.96384239197 PathPoint;PointKind.SMOOTHPOINT 227.115619182587,1390.20528316498 223.336826562881,1433.12388896942 230.894411802292,1347.28691339493 PathPoint;PointKind.SMOOTHPOINT 221.223846673965,1473.08403968811 219.245461329307,1516.70897132847 223.210175218387,1429.28395433081 PathPoint;PointKind.SMOOTHPOINT 238.779032823961,1531.68835509433 243.422109133145,1565.14447483805 234.292672256078,1499.36146525284 PathPoint;PointKind.SMOOTHPOINT 247.223846673965,1612.59004640579 247.617906093597,1632.60340261459 246.829787254333,1592.57669019699 PathPoint;PointKind.SMOOTHPOINT 237.403871774673,1685.71845817566 238.16720700264,1714.52881622314 236.640536546707,1656.90739202499 PathPoint;PointKind.SMOOTHPOINT 243.295644283295,1744.22076272964 249.162279129028,1768.25048017502 237.429717540741,1720.19104528427 PathPoint;PointKind.SMOOTHPOINT 241.331366062164,1793.94778060913 242.704732179642,1809.2975692749 241.331366062164,1793.94778060913 PathPoint;PointKind.SMOOTHPOINT 236.422086715698,1841.72515439987 231.983695983887,1865.9788684845 240.85976934433,1817.47144031525 PathPoint;PointKind.SMOOTHPOINT 239.367795944214,1874.87665700912 246.24099946022,1894.1217212677 232.494592428207,1855.63135671616 PathPoint;PointKind.SMOOTHPOINT 248.205631732941,1909.97803974152 246.24099946022,1923.11429786682 250.170264005661,1896.84178161621 PathPoint;PointKind.SMOOTHPOINT 243.295644283295,1952.87988710403 242.460790634155,1975.8125166893 244.130851984024,1929.94725751877 PathPoint;PointKind.SMOOTHPOINT 239.367795944214,2020.15771436691 244.351072072983,2034.69955730438 234.384519815445,2005.61634349823 PathPoint;PointKind.SMOOTHPOINT 245.259922504425,2067.93508815765 244.868341445923,2078.53185224533 245.651149511337,2057.33808803558 PathPoint;PointKind.SMOOTHPOINT 235.439947605133,2110.83693552017 235.246989488602,2135.49757289886 235.632905721664,2086.17629814148 PathPoint;PointKind.SMOOTHPOINT 247.223846673965,2152.76372480392 251.911489725113,2198.08940935135 242.535849571228,2107.4380402565 PathPoint;PointKind.SMOOTHPOINT 245.259922504425,2215.16626167297 241.605756044388,2242.43555116653 248.914088964462,2187.89768028259 PathPoint;PointKind.SMOOTHPOINT 247.223846673965,2273.66903829575 251.740482807159,2295.81732559204 242.707210540771,2251.52075099945 PathPoint;PointKind.SMOOTHPOINT 241.331366062164,2348.74733018875 241.409965515137,2376.97019863129 241.253828763962,2320.52446174622 PathPoint;PointKind.SMOOTHPOINT 244.27813744545,2395.54917383194 250.343041181564,2413.29990434647 238.212525606155,2377.7989153862 PathPoint;PointKind.SMOOTHPOINT 225.151340961456,2452.02700853348 224.685409069061,2460.78152418137 225.617980957031,2443.2722568512 PathPoint;PointKind.SMOOTHPOINT 212.385656833649,2479.32816267014 213.349031209946,2504.10445690155 211.422990560532,2454.55186843872 PathPoint;PointKind.SMOOTHPOINT 220.2417075634,2531.00529670715 220.904846191406,2559.01927471161 219.578214883804,2502.99155473709 PathPoint;PointKind.SMOOTHPOINT 217.295644283295,2570.98220586777 204.073587656021,2613.93834114075 230.518054962158,2528.02607059479 PathPoint;PointKind.SMOOTHPOINT 214.349581003189,2643.13532352448 223.996778726578,2661.56866550446 204.70273733139,2624.70198154449 PathPoint;PointKind.SMOOTHPOINT 205.512453317642,2703.58798027039 208.195810317993,2723.30700159073 202.828388214111,2683.86895895004 PathPoint;PointKind.SMOOTHPOINT 215.331366062164,2749.4150018692 219.361181259155,2765.09264230728 211.302613019943,2733.73712539673 PathPoint;PointKind.SMOOTHPOINT 222.205631732941,2804.99260425568 225.545046329498,2831.77778720856 218.866571187973,2778.20694923401 PathPoint;PointKind.SMOOTHPOINT 229.079543352127,2865.44502496719 224.856415987015,2884.82014417648 233.302670717239,2846.0701417923 PathPoint;PointKind.CORNERPOINT 225.151340961456,2908.34710836411 225.151340961456,2908.34710836411 225.151340961456,2908.34710836411 PathPoint;PointKind.SMOOTHPOINT 225.151340961456,2962.94941663742 224.343041181564,2992.47401475906 225.960348844528,2933.42505455017 PathPoint;PointKind.SMOOTHPOINT 226.133480072021,3028.27712774277 228.294610977173,3039.37617301941 223.97305727005,3017.17831850052 PathPoint;PointKind.SMOOTHPOINT 230.061328411102,3078.00438165665 226.746343374252,3098.38831186295 233.377021551132,3057.62045145035 PathPoint;PointKind.SMOOTHPOINT 215.331366062164,3136.50692224503 222.717236280441,3173.85983705521 214.435969591141,3131.97529792786 PathPoint;PointKind.SMOOTHPOINT 224.169555902481,3194.03464078903 223.996778726578,3211.46224021912 224.342687129974,3176.60680532455 PathPoint;PointKind.SMOOTHPOINT 222.205631732941,3238.88660430908 220.391825437546,3256.31774425507 224.019438028336,3221.45499229431 PathPoint;PointKind.SMOOTHPOINT 221.223846673965,3299.3390250206 226.746343374252,3322.323346138 215.700995922089,3276.35493993759 PathPoint;PointKind.SMOOTHPOINT 225.151340961456,3343.21593046188 225.716053247452,3368.7121295929 224.587336778641,3317.71996736526 PathPoint;PointKind.SMOOTHPOINT 224.169555902481,3375.39237499237 228.465617895126,3407.93750524521 219.873847961426,3342.84748077393 PathPoint;PointKind.SMOOTHPOINT 225.151340961456,3441.69561624527 226.917350292206,3476.90793514252 223.385685682297,3406.48282527924 PathPoint;PointKind.SMOOTHPOINT 223.187770843506,3512.87343978882 223.654764890671,3531.31291866302 222.720776796341,3494.43396091461 PathPoint;PointKind.SMOOTHPOINT 215.331366062164,3569.42610025406 224.685409069061,3593.39138031006 205.978385210037,3545.46082019806 PathPoint;PointKind.SMOOTHPOINT 223.187770843506,3617.20323801041 227.088711261749,3639.61399555206 219.286476373672,3594.79224443436 PathPoint;PointKind.SMOOTHPOINT 224.169555902481,3660.10508537292 223.483403921127,3681.05597019196 224.856061935425,3639.15372848511 PathPoint;PointKind.SMOOTHPOINT 223.187770843506,3720.55750608444 225.027422904968,3730.51862955093 221.348118782043,3710.59661865234 PathPoint;PointKind.SMOOTHPOINT 222.205631732941,3776.13487243652 225.202678442001,3789.3568110466 219.20893907547,3762.91316986084 PathPoint;PointKind.SMOOTHPOINT 223.187770843506,3813.18660736084 229.14964556694,3822.78636217117 217.225896120071,3803.58685255051 PathPoint;PointKind.SMOOTHPOINT 269.34051990509,3821.96213006973 282.402545213699,3821.93309783936 256.278848648071,3821.99116230011 PathPoint;PointKind.SMOOTHPOINT 2762.59589195251,3808.31131696701 2783.97848367691,3809.77449417114 2741.21330022812,3806.84837579727 PathPoint;PointKind.SMOOTHPOINT 3203.50589632988,3804.41108465195 3217.467212677,3801.41816854477 3189.54493403435,3807.40423679352 PathPoint;PointKind.SMOOTHPOINT 3732.79532074928,3803.43626260757 3746.88267946243,3801.58811330795 3718.70725393295,3805.2844119072 PathPoint;PointKind.SMOOTHPOINT 5259.77840423584,3799.53603029251 5273.91674637794,3801.64051294327 5245.64077019691,3797.43154764175 PathPoint;PointKind.CORNERPOINT 5277.45442986488,3805.38637876511 5277.45442986488,3805.38637876511 5277.45442986488,3805.38637876511 PathPoint;PointKind.CORNERPOINT 5672.21168518066,3807.33625888824 5672.21168518066,3807.33625888824 5672.21168518066,3807.33625888824 PathPoint;PointKind.CORNERPOINT 5684.97736930847,3796.61085605621 5684.97736930847,3796.61085605621 5684.97736930847,3796.61085605621 PathPoint;PointKind.SMOOTHPOINT 5681.0491669178,3704.95704889297 5682.5241458416,3694.25383329391 5679.574187994,3715.66002845764 PathPoint;PointKind.SMOOTHPOINT 5684.97736930847,3671.80531024933 5686.30470871925,3657.75843143463 5683.65002989769,3685.85242509842 PathPoint;PointKind.SMOOTHPOINT 5691.85092687607,3619.15311813354 5690.42693138123,3599.93944644928 5693.2752764225,3638.36678981781 PathPoint;PointKind.SMOOTHPOINT 5687.92307853699,3567.47574806213 5683.55903863907,3549.11368846893 5692.28711843491,3585.83804368973 PathPoint;PointKind.SMOOTHPOINT 5687.92307853699,3532.37460136414 5686.30470871925,3518.58429193497 5689.54180240631,3546.16420269012 PathPoint;PointKind.SMOOTHPOINT 5686.94129347801,3495.32286643982 5690.94420075417,3482.94239044189 5682.93838620186,3507.70287036896 PathPoint;PointKind.SMOOTHPOINT 5691.85092687607,3461.19606971741 5688.5366499424,3443.20316791534 5695.16520380974,3479.18897151947 PathPoint;PointKind.SMOOTHPOINT 5687.92307853699,3409.51917171478 5687.5063598156,3388.79794836044 5688.34015130997,3430.23992300034 PathPoint;PointKind.SMOOTHPOINT 5688.90521764755,3367.59191036224 5690.59793829918,3348.71505975723 5687.21249699593,3386.46899700165 PathPoint;PointKind.SMOOTHPOINT 5692.83271193504,3337.36581802368 5689.39664125443,3318.18542718887 5696.26984477043,3356.5459728241 PathPoint;PointKind.SMOOTHPOINT 5691.85092687607,3298.36396694183 5690.25592446327,3284.41622257233 5693.44663739204,3312.31171131134 PathPoint;PointKind.SMOOTHPOINT 5691.85092687607,3264.23764228821 5693.00548911095,3242.29069232941 5690.69707274437,3286.18435621262 PathPoint;PointKind.SMOOTHPOINT 5690.86914181709,3210.61015605927 5686.47536158562,3179.69909191132 5695.26292204857,3241.52145624161 PathPoint;PointKind.SMOOTHPOINT 5687.92307853699,3140.40715456009 5691.8038380146,3123.41692686081 5684.04267311096,3157.39738225937 PathPoint;PointKind.SMOOTHPOINT 5690.86914181709,3104.33047771454 5691.97519898415,3088.79445791245 5689.76379275322,3119.86673355103 PathPoint;PointKind.SMOOTHPOINT 5687.92307853699,3015.6016087532 5684.45903778076,2986.12775802612 5691.38711929321,3045.07569551468 PathPoint;PointKind.SMOOTHPOINT 5683.01344513893,2960.02400636673 5681.36745929718,2941.44172668457 5684.6587228775,2978.60675811768 PathPoint;PointKind.SMOOTHPOINT 5682.03130602837,2908.34710836411 5681.70947313309,2885.84335327148 5682.35313892365,2930.85062742233 PathPoint;PointKind.SMOOTHPOINT 5680.06702780724,2863.49490880966 5682.22284793854,2851.90420389175 5677.91156172752,2875.08584976196 PathPoint;PointKind.SMOOTHPOINT 5675.15739440918,2786.46673679352 5674.66667890549,2760.14606952667 5675.64846396446,2812.78740406036 PathPoint;PointKind.SMOOTHPOINT 5682.03130602837,2734.78936672211 5688.58161449432,2706.42039299011 5675.48099756241,2763.15810441971 PathPoint;PointKind.SMOOTHPOINT 5710.50873756409,2684.08729076385 5711.77199363708,2661.73861026764 5709.24583554268,2706.43573522568 PathPoint;PointKind.SMOOTHPOINT 5699.70697760582,2644.11014556885 5696.13813757896,2620.97617864609 5703.27617168427,2667.24482059479 PathPoint;PointKind.SMOOTHPOINT 5696.7612683773,2602.18359231949 5695.45375585556,2559.23760652542 5698.06842684746,2645.12934207916 PathPoint;PointKind.SMOOTHPOINT 5688.90521764755,2547.58081197739 5685.14341950417,2531.94801807404 5692.66666173935,2563.21431398392 PathPoint;PointKind.SMOOTHPOINT 5689.88700270653,2455.92724084854 5701.30729079247,2424.38336849213 5678.46706867218,2487.47087717056 PathPoint;PointKind.SMOOTHPOINT 5689.52695250511,2416.90044784546 5700.54645419121,2392.17442893982 5678.50745081902,2441.6264667511 PathPoint;PointKind.SMOOTHPOINT 5696.4008641243,2348.64732646942 5691.95928692818,2307.74941110611 5700.84208726883,2389.54547786713 PathPoint;PointKind.SMOOTHPOINT 5702.29263663292,2274.54432868958 5702.43638157845,2264.94008922577 5702.1485376358,2284.14809608459 PathPoint;PointKind.SMOOTHPOINT 5697.38264918327,2214.09167194366 5691.78863406181,2158.34624910355 5702.97701835632,2269.83709478378 PathPoint;PointKind.SMOOTHPOINT 5705.296875,2120 5703.01253414154,2082.42521286011 5707.58192396164,2157.5745511055 PathPoint;PointKind.SMOOTHPOINT 5712.296875,1999 5714.08023285866,1946.68958568573 5710.51387119293,2051.31017827988 PathPoint;PointKind.CORNERPOINT 5713.296875,1543 5713.296875,1543 5713.296875,1543 PathPoint;PointKind.SMOOTHPOINT 5705.296875,1517 5697.18413686752,1493.76265001297 5713.41032123566,1540.23758602142 PathPoint;PointKind.SMOOTHPOINT 5699.70697760582,1479.90944623947 5699.79194998741,1463.43920230865 5699.62200522423,1496.37945413589 PathPoint;PointKind.SMOOTHPOINT 5723.296875,1443 5732.26429367065,1413.17469406128 5714.32910227776,1472.82530593872 PathPoint;PointKind.SMOOTHPOINT 5733.296875,1413 5729.23023843765,1405.8266787529 5737.36315751076,1420.1733212471 PathPoint;PointKind.SMOOTHPOINT 5702.65268683434,1386.30528688431 5709.27522182465,1355.29980897903 5696.0308599472,1417.31052875519 PathPoint;PointKind.SMOOTHPOINT 5714.43658590317,1343.40343952179 5715.80074667931,1318.46074104309 5713.07313323021,1368.3456659317 PathPoint;PointKind.SMOOTHPOINT 5713.45480084419,1308.3020567894 5709.09996628761,1287.25180149078 5717.80998945236,1329.35184001923 PathPoint;PointKind.SMOOTHPOINT 5712.47266173363,1274.17526006699 5716.83103680611,1244.95656251907 5708.11428666115,1303.3939576149 PathPoint;PointKind.SMOOTHPOINT 5712.47266173363,1233.22329282761 5701.71480417252,1219.54344749451 5723.23087334633,1246.90361022949 PathPoint;PointKind.SMOOTHPOINT 5687.92307853699,1208.84731292725 5684.19456124306,1179.46457147598 5691.65194988251,1238.2302904129 PathPoint;PointKind.SMOOTHPOINT 5683.01344513893,1151.31983041763 5688.31678390503,1128.29514741898 5677.70975232124,1174.34474945068 PathPoint;PointKind.SMOOTHPOINT 5689.88700270653,1113.29327344894 5687.11513280869,1080.02965450287 5692.65887260437,1146.55689239502 PathPoint;PointKind.SMOOTHPOINT 5688.90521764755,1063.56601953506 5690.72008609772,1040.63433408737 5687.09034919739,1086.49794101715 PathPoint;PointKind.SMOOTHPOINT 5688.90521764755,1029.43945884705 5688.82980465889,999.188346862793 5688.98027658463,1059.69104290009 PathPoint;PointKind.SMOOTHPOINT 5687.92307853699,964.111511707306 5694.471616745,930.913510322571 5681.37454032898,997.309749126434 PathPoint;PointKind.SMOOTHPOINT 5694.79734420776,911.459319591522 5690.34974813461,885.887825489044 5699.24494028091,937.030813694 PathPoint;PointKind.SMOOTHPOINT 5687.92307853699,874.407820701599 5692.4106824398,852.632467746735 5683.43582868576,896.183173656464 PathPoint;PointKind.SMOOTHPOINT 5689.88700270653,819.80527639389 5690.00738024712,795.49703836441 5689.76733326912,844.113986492157 PathPoint;PointKind.SMOOTHPOINT 5683.01344513893,777.878487110138 5682.10459470749,755.074260234833 5683.92158746719,800.682713985443 PathPoint;PointKind.SMOOTHPOINT 5681.0491669178,736.926991939545 5681.93394184113,706.978712081909 5680.16510009766,766.874563694 PathPoint;PointKind.SMOOTHPOINT 5688.90521764755,670.623750686646 5688.63047361374,642.854068279266 5689.17960762978,698.393433094025 PathPoint;PointKind.SMOOTHPOINT 5688.90521764755,635.522131919861 5689.49011087418,613.517825603485 5688.32032442093,657.52667427063 PathPoint;PointKind.SMOOTHPOINT 5697.74305343628,596.520516872406 5696.70462012291,572.071602344513 5698.78184080124,620.969431400299 PathPoint;PointKind.SMOOTHPOINT 5689.88700270653,544.843382835388 5689.49011087418,509.310057163239 5690.28424859047,580.376472473145 PathPoint;PointKind.SMOOTHPOINT 5691.85092687607,488.290958404541 5689.73015785217,461.165885925293 5693.97204995155,515.415558815002 PathPoint;PointKind.SMOOTHPOINT 5690.86914181709,438.563704490662 5693.51072072983,407.270264625549 5688.22791695595,469.856908321381 PathPoint;PointKind.SMOOTHPOINT 5696.7612683773,390.786566734314 5694.71237182617,367.021443843842 5698.80981087685,414.551453590393 PathPoint;PointKind.SMOOTHPOINT 5691.85092687607,358.610122203827 5689.38778996468,322.505593299866 5694.31406378746,394.714651107788 PathPoint;PointKind.SMOOTHPOINT 5692.83271193504,289.382178783417 5689.73015785217,262.474021911621 5695.9356200695,316.290099620819 PathPoint;PointKind.SMOOTHPOINT 5687.92307853699,244.530215263367 5694.54101085663,210.794763565063 5681.30550026894,278.265430927277 PathPoint;PointKind.SMOOTHPOINT 5693.8152050972,190.902729034424 5691.79144620895,159.119753837585 5695.83860993385,222.685704231262 PathPoint;PointKind.SMOOTHPOINT 5683.01344513893,144.100885391235 5676.67485952377,136.093182563782 5689.3516767025,152.108116149902 PathPoint;PointKind.CORNERPOINT 5664.35563445091,138.250300884247 5664.35563445091,138.250300884247 5664.35563445091,138.250300884247 PathPoint;PointKind.CORNERPOINT 5304.95007634163,147.02582359314 5304.95007634163,147.02582359314 5304.95007634163,147.02582359314 PathPoint;PointKind.SMOOTHPOINT 5212.64351606369,139.225594997406 5196.87476634979,135.304591655731 5228.41226577759,143.146598339081 PathPoint;PointKind.CORNERPOINT 4634.25563335419,143.125591278076 4634.25563335419,143.125591278076 4634.25563335419,143.125591278076 PathPoint;PointKind.SMOOTHPOINT 4624.4356584549,151.900877952576 4608.81702661514,154.484510421753 4640.05429029465,149.317481517792 PathPoint;PointKind.CORNERPOINT 4196.29098415375,153.851230144501 4196.29098415375,153.851230144501 4196.29098415375,153.851230144501 PathPoint;PointKind.SMOOTHPOINT 694.539484977722,162.626516819 679.462198019028,163.099765777588 709.617125988007,162.153267860413 PathPoint;PointKind.SMOOTHPOINT 551.169834136963,157.751462459564 542.213745117188,158.662791252136 560.126277208328,156.839661598206 PathPoint;PointKind.SMOOTHPOINT 417.620512247086,160.676400661469 399.808530807495,159.176638126373 435.432139635086,162.176399230957 PathPoint;PointKind.SMOOTHPOINT 374.412764310837,151.900877952576 368.544713258743,151.499619483948 380.28152346611,152.30260848999 PathPoint;PointKind.SMOOTHPOINT 328.260015249252,151.900877952576 311.687214374542,151.499619483948 344.832816123962,152.30260848999 PathPoint";
	
	shadow35mm[1] = "PointKind.CORNERPOINT 240.602643251419,157.751462459564 240.602643251419,157.751462459564 240.602643251419,157.751462459564 PathPoint;PointKind.SMOOTHPOINT 238.638365030289,280.606892108917 237.577980518341,298.051249980927 239.698749542236,263.162062168121 PathPoint;PointKind.SMOOTHPOINT 235.692655801773,383.961160182953 233.280856370926,396.45870923996 238.10445523262,371.463611125946 PathPoint;PointKind.SMOOTHPOINT 232.746946573257,486.340842247009 232.425113677979,501.180324554443 233.068071365356,471.501123905182 PathPoint;PointKind.SMOOTHPOINT 229.800883293152,539.968328475952 231.048207044601,560.358159542084 228.552851438522,519.578025341034 PathPoint;PointKind.SMOOTHPOINT 228.818744182587,678.423979282379 227.95698261261,698.848979473114 229.680859804153,657.999451160431 PathPoint;PointKind.SMOOTHPOINT 236.674440860748,735.951697826385 235.859414100647,752.06104516983 237.49017572403,719.842586517334 PathPoint;PointKind.SMOOTHPOINT 233.728731632233,780.803897380829 233.109849452972,797.426383495331 234.347613811493,764.181175231934 PathPoint;PointKind.SMOOTHPOINT 229.800883293152,882.208049297333 230.364179372787,916.546804904938 229.237587213516,847.869529724121 PathPoint;PointKind.SMOOTHPOINT 232.746946573257,965.086805820465 232.767481565475,987.155313491821 232.726057529449,943.018298149109 PathPoint;PointKind.SMOOTHPOINT 229.800883293152,1057.71590709686 230.877554178238,1101.08227014542 228.724212408066,1014.34930801392 PathPoint;PointKind.SMOOTHPOINT 223.908756732941,1168.87087583542 215.760259389877,1193.01034927368 232.057254076004,1144.73116636276 PathPoint;PointKind.SMOOTHPOINT 210.161287546158,1241.02375745773 214.559316396713,1239.22918796539 205.763258695602,1242.81856298447 PathPoint;PointKind.SMOOTHPOINT 229.800883293152,1276.12537622452 241.871918201447,1298.5812163353 217.729848384857,1253.66977214813 PathPoint;PointKind.SMOOTHPOINT 235.692655801773,1311.2269949913 236.890058279037,1338.49014759064 234.495253324509,1283.96384239197 PathPoint;PointKind.SMOOTHPOINT 228.818744182587,1390.20528316498 225.039951562881,1433.12388896942 232.597536802292,1347.28691339493 PathPoint;PointKind.SMOOTHPOINT 223,1452 220.644494771957,1495.78154754639 225.355505228043,1408.21821641922 PathPoint;PointKind.SMOOTHPOINT 202,1515 198.736926020408,1521.90369365609 214.287282274166,1489.00376662701 PathPoint;PointKind.SMOOTHPOINT 200,2437 199.983774633974,2445.76689075414 201.558637013914,1629.40672348412 PathPoint;PointKind.SMOOTHPOINT 214.088781833649,2479.32816267014 215.052156209946,2504.10445690155 213.126115560532,2454.55186843872 PathPoint;PointKind.SMOOTHPOINT 221.9448325634,2531.00529670715 222.607971191406,2559.01927471161 221.281339883804,2502.99155473709 PathPoint;PointKind.SMOOTHPOINT 218.998769283295,2570.98220586777 205.776712656021,2613.93834114075 232.221179962158,2528.02607059479 PathPoint;PointKind.SMOOTHPOINT 216.052706003189,2643.13532352448 225.699903726578,2661.56866550446 206.40586233139,2624.70198154449 PathPoint;PointKind.SMOOTHPOINT 207.215578317642,2703.58798027039 209.898935317993,2723.30700159073 204.531513214111,2683.86895895004 PathPoint;PointKind.SMOOTHPOINT 217.034491062164,2749.4150018692 221.064306259155,2765.09264230728 213.005738019943,2733.73712539673 PathPoint;PointKind.SMOOTHPOINT 223.908756732941,2804.99260425568 227.248171329498,2831.77778720856 220.569696187973,2778.20694923401 PathPoint;PointKind.SMOOTHPOINT 230.782668352127,2865.44502496719 226.559540987015,2884.82014417648 235.005795717239,2846.0701417923 PathPoint;PointKind.CORNERPOINT 226.854465961456,2908.34710836411 226.854465961456,2908.34710836411 226.854465961456,2908.34710836411 PathPoint;PointKind.SMOOTHPOINT 226.854465961456,2962.94941663742 226.046166181564,2992.47401475906 227.663473844528,2933.42505455017 PathPoint;PointKind.SMOOTHPOINT 227.836605072021,3028.27712774277 229.997735977173,3039.37617301941 225.67618227005,3017.17831850052 PathPoint;PointKind.SMOOTHPOINT 231.764453411102,3078.00438165665 228.449468374252,3098.38831186295 235.080146551132,3057.62045145035 PathPoint;PointKind.SMOOTHPOINT 217.034491062164,3136.50692224503 224.420361280441,3173.85983705521 216.139094591141,3131.97529792786 PathPoint;PointKind.SMOOTHPOINT 225.872680902481,3194.03464078903 225.699903726578,3211.46224021912 226.045812129974,3176.60680532455 PathPoint;PointKind.SMOOTHPOINT 223.908756732941,3238.88660430908 222.094950437546,3256.31774425507 225.722563028336,3221.45499229431 PathPoint;PointKind.SMOOTHPOINT 222.926971673965,3299.3390250206 228.449468374252,3322.323346138 217.404120922089,3276.35493993759 PathPoint;PointKind.SMOOTHPOINT 226.854465961456,3343.21593046188 227.419178247452,3368.7121295929 226.290461778641,3317.71996736526 PathPoint;PointKind.SMOOTHPOINT 225.872680902481,3375.39237499237 230.168742895126,3407.93750524521 221.576972961426,3342.84748077393 PathPoint;PointKind.SMOOTHPOINT 226.854465961456,3441.69561624527 228.620475292206,3476.90793514252 225.088810682297,3406.48282527924 PathPoint;PointKind.SMOOTHPOINT 224.890895843506,3512.87343978882 225.357889890671,3531.31291866302 224.423901796341,3494.43396091461 PathPoint;PointKind.SMOOTHPOINT 217.034491062164,3569.42610025406 226.388534069061,3593.39138031006 207.681510210037,3545.46082019806 PathPoint;PointKind.SMOOTHPOINT 224.890895843506,3617.20323801041 228.791836261749,3639.61399555206 220.989601373672,3594.79224443436 PathPoint;PointKind.SMOOTHPOINT 225.872680902481,3660.10508537292 225.186528921127,3681.05597019196 226.559186935425,3639.15372848511 PathPoint;PointKind.SMOOTHPOINT 224.890895843506,3720.55750608444 226.730547904968,3730.51862955093 223.051243782043,3710.59661865234 PathPoint;PointKind.SMOOTHPOINT 223.908756732941,3776.13487243652 226.905803442001,3789.3568110466 220.91206407547,3762.91316986084 PathPoint;PointKind.SMOOTHPOINT 224.890895843506,3813.18660736084 230.85277056694,3822.78636217117 218.929021120071,3803.58685255051 PathPoint;PointKind.SMOOTHPOINT 271.04364490509,3821.96213006973 284.105670213699,3821.93309783936 257.981973648071,3821.99116230011 PathPoint;PointKind.SMOOTHPOINT 2764.29901695251,3808.31131696701 2785.68160867691,3809.77449417114 2742.91642522812,3806.84837579727 PathPoint;PointKind.SMOOTHPOINT 3205.20902132988,3804.41108465195 3219.170337677,3801.41816854477 3191.24805903435,3807.40423679352 PathPoint;PointKind.SMOOTHPOINT 3734.49844574928,3803.43626260757 3748.58580446243,3801.58811330795 3720.41037893295,3805.2844119072 PathPoint;PointKind.SMOOTHPOINT 5261.48152923584,3799.53603029251 5275.61987137794,3801.64051294327 5247.34389519691,3797.43154764175 PathPoint;PointKind.CORNERPOINT 5279.15755486488,3805.38637876511 5279.15755486488,3805.38637876511 5279.15755486488,3805.38637876511 PathPoint;PointKind.CORNERPOINT 5673.91481018066,3807.33625888824 5673.91481018066,3807.33625888824 5673.91481018066,3807.33625888824 PathPoint;PointKind.CORNERPOINT 5686.68049430847,3796.61085605621 5686.68049430847,3796.61085605621 5686.68049430847,3796.61085605621 PathPoint;PointKind.SMOOTHPOINT 5682.7522919178,3704.95704889297 5684.2272708416,3694.25383329391 5681.277312994,3715.66002845764 PathPoint;PointKind.SMOOTHPOINT 5686.68049430847,3671.80531024933 5688.00783371925,3657.75843143463 5685.35315489769,3685.85242509842 PathPoint;PointKind.SMOOTHPOINT 5693.55405187607,3619.15311813354 5692.13005638123,3599.93944644928 5694.9784014225,3638.36678981781 PathPoint;PointKind.SMOOTHPOINT 5689.62620353699,3567.47574806213 5685.26216363907,3549.11368846893 5693.99024343491,3585.83804368973 PathPoint;PointKind.SMOOTHPOINT 5689.62620353699,3532.37460136414 5688.00783371925,3518.58429193497 5691.24492740631,3546.16420269012 PathPoint;PointKind.SMOOTHPOINT 5688.64441847801,3495.32286643982 5692.64732575417,3482.94239044189 5684.64151120186,3507.70287036896 PathPoint;PointKind.SMOOTHPOINT 5693.55405187607,3461.19606971741 5690.2397749424,3443.20316791534 5696.86832880974,3479.18897151947 PathPoint;PointKind.SMOOTHPOINT 5689.62620353699,3409.51917171478 5689.2094848156,3388.79794836044 5690.04327630997,3430.23992300034 PathPoint;PointKind.SMOOTHPOINT 5690.60834264755,3367.59191036224 5692.30106329918,3348.71505975723 5688.91562199593,3386.46899700165 PathPoint;PointKind.SMOOTHPOINT 5694.53583693504,3337.36581802368 5691.09976625443,3318.18542718887 5697.97296977043,3356.5459728241 PathPoint;PointKind.SMOOTHPOINT 5693.55405187607,3298.36396694183 5691.95904946327,3284.41622257233 5695.14976239204,3312.31171131134 PathPoint;PointKind.SMOOTHPOINT 5693.55405187607,3264.23764228821 5694.70861411095,3242.29069232941 5692.40019774437,3286.18435621262 PathPoint;PointKind.SMOOTHPOINT 5692.57226681709,3210.61015605927 5688.17848658562,3179.69909191132 5696.96604704857,3241.52145624161 PathPoint;PointKind.SMOOTHPOINT 5689.62620353699,3140.40715456009 5693.5069630146,3123.41692686081 5685.74579811096,3157.39738225937 PathPoint;PointKind.SMOOTHPOINT 5692.57226681709,3104.33047771454 5693.67832398415,3088.79445791245 5691.46691775322,3119.86673355103 PathPoint;PointKind.SMOOTHPOINT 5689.62620353699,3015.6016087532 5686.16216278076,2986.12775802612 5693.09024429321,3045.07569551468 PathPoint;PointKind.SMOOTHPOINT 5684.71657013893,2960.02400636673 5683.07058429718,2941.44172668457 5686.3618478775,2978.60675811768 PathPoint;PointKind.SMOOTHPOINT 5683.73443102837,2908.34710836411 5683.41259813309,2885.84335327148 5684.05626392365,2930.85062742233 PathPoint;PointKind.SMOOTHPOINT 5681.77015280724,2863.49490880966 5683.92597293854,2851.90420389175 5679.61468672752,2875.08584976196 PathPoint;PointKind.SMOOTHPOINT 5676.86051940918,2786.46673679352 5676.36980390549,2760.14606952667 5677.35158896446,2812.78740406036 PathPoint;PointKind.SMOOTHPOINT 5683.73443102837,2734.78936672211 5690.28473949432,2706.42039299011 5677.18412256241,2763.15810441971 PathPoint;PointKind.SMOOTHPOINT 5712.21186256409,2684.08729076385 5713.47511863708,2661.73861026764 5710.94896054268,2706.43573522568 PathPoint;PointKind.SMOOTHPOINT 5701.41010260582,2644.11014556885 5697.84126257896,2620.97617864609 5704.97929668427,2667.24482059479 PathPoint;PointKind.SMOOTHPOINT 5698.4643933773,2602.18359231949 5697.15688085556,2559.23760652542 5699.77155184746,2645.12934207916 PathPoint;PointKind.SMOOTHPOINT 5705.66314333433,2565.976675439 5703.39036846483,2552.16335888427 5708.27370764323,2581.84298567903 PathPoint;PointKind.SMOOTHPOINT 5710,2483 5720.89632568646,2451.27132291226 5698.99366156467,2515.04901984227 PathPoint;PointKind.CORNERPOINT 5739,2403 5739,2403 5739,2403 PathPoint;PointKind.CORNERPOINT 5740,1542 5740,1542 5740,1542 PathPoint;PointKind.SMOOTHPOINT 5719,1508 5710.88726186752,1484.76265001297 5727.11344623566,1531.23758602142 PathPoint;PointKind.SMOOTHPOINT 5716,1463 5716.08497238159,1446.52975606918 5715.91502761841,1479.47000789642 PathPoint;PointKind.SMOOTHPOINT 5722,1434 5724.12262240598,1417.70139612249 5717.97759625108,1464.8834921927 PathPoint;PointKind.SMOOTHPOINT 5718.1039891243,1398.98080587387 5714.03735256195,1391.80748462677 5722.17027163506,1406.15412712097 PathPoint;PointKind.SMOOTHPOINT 5704.35581183434,1386.30528688431 5710.97834682465,1355.29980897903 5697.7339849472,1417.31052875519 PathPoint;PointKind.SMOOTHPOINT 5716.13971090317,1343.40343952179 5717.50387167931,1318.46074104309 5714.77625823021,1368.3456659317 PathPoint;PointKind.SMOOTHPOINT 5715.15792584419,1308.3020567894 5710.80309128761,1287.25180149078 5719.51311445236,1329.35184001923 PathPoint;PointKind.SMOOTHPOINT 5714.17578673363,1274.17526006699 5718.53416180611,1244.95656251907 5709.81741166115,1303.3939576149 PathPoint;PointKind.SMOOTHPOINT 5714.17578673363,1233.22329282761 5703.41792917252,1219.54344749451 5724.93399834633,1246.90361022949 PathPoint;PointKind.SMOOTHPOINT 5689.62620353699,1208.84731292725 5685.89768624306,1179.46457147598 5693.35507488251,1238.2302904129 PathPoint;PointKind.SMOOTHPOINT 5684.71657013893,1151.31983041763 5690.01990890503,1128.29514741898 5679.41287732124,1174.34474945068 PathPoint;PointKind.SMOOTHPOINT 5691.59012770653,1113.29327344894 5688.81825780869,1080.02965450287 5694.36199760437,1146.55689239502 PathPoint;PointKind.SMOOTHPOINT 5690.60834264755,1063.56601953506 5692.42321109772,1040.63433408737 5688.79347419739,1086.49794101715 PathPoint;PointKind.SMOOTHPOINT 5690.60834264755,1029.43945884705 5690.53292965889,999.188346862793 5690.68340158463,1059.69104290009 PathPoint;PointKind.SMOOTHPOINT 5689.62620353699,964.111511707306 5696.174741745,930.913510322571 5683.07766532898,997.309749126434 PathPoint;PointKind.SMOOTHPOINT 5696.50046920776,911.459319591522 5692.05287313461,885.887825489044 5700.94806528091,937.030813694 PathPoint;PointKind.SMOOTHPOINT 5689.62620353699,874.407820701599 5694.1138074398,852.632467746735 5685.13895368576,896.183173656464 PathPoint;PointKind.SMOOTHPOINT 5691.59012770653,819.80527639389 5691.71050524712,795.49703836441 5691.47045826912,844.113986492157 PathPoint;PointKind.SMOOTHPOINT 5684.71657013893,777.878487110138 5683.80771970749,755.074260234833 5685.62471246719,800.682713985443 PathPoint;PointKind.SMOOTHPOINT 5682.7522919178,736.926991939545 5683.63706684113,706.978712081909 5681.86822509766,766.874563694 PathPoint;PointKind.SMOOTHPOINT 5690.60834264755,670.623750686646 5690.33359861374,642.854068279266 5690.88273262978,698.393433094025 PathPoint;PointKind.SMOOTHPOINT 5690.60834264755,635.522131919861 5691.19323587418,613.517825603485 5690.02344942093,657.52667427063 PathPoint;PointKind.SMOOTHPOINT 5699.44617843628,596.520516872406 5698.40774512291,572.071602344513 5700.48496580124,620.969431400299 PathPoint;PointKind.SMOOTHPOINT 5691.59012770653,544.843382835388 5691.19323587418,509.310057163239 5691.98737359047,580.376472473145 PathPoint;PointKind.SMOOTHPOINT 5693.55405187607,488.290958404541 5691.43328285217,461.165885925293 5695.67517495155,515.415558815002 PathPoint;PointKind.SMOOTHPOINT 5692.57226681709,438.563704490662 5695.21384572983,407.270264625549 5689.93104195595,469.856908321381 PathPoint;PointKind.SMOOTHPOINT 5698.4643933773,390.786566734314 5696.41549682617,367.021443843842 5700.51293587685,414.551453590393 PathPoint;PointKind.SMOOTHPOINT 5693.55405187607,358.610122203827 5691.09091496468,322.505593299866 5696.01718878746,394.714651107788 PathPoint;PointKind.SMOOTHPOINT 5694.53583693504,289.382178783417 5691.43328285217,262.474021911621 5697.6387450695,316.290099620819 PathPoint;PointKind.SMOOTHPOINT 5689.62620353699,244.530215263367 5696.24413585663,210.794763565063 5683.00862526894,278.265430927277 PathPoint;PointKind.SMOOTHPOINT 5695.5183300972,190.902729034424 5693.49457120895,159.119753837585 5697.54173493385,222.685704231262 PathPoint;PointKind.SMOOTHPOINT 5684.71657013893,144.100885391235 5678.37798452377,136.093182563782 5691.0548017025,152.108116149902 PathPoint;PointKind.CORNERPOINT 5666.05875945091,138.250300884247 5666.05875945091,138.250300884247 5666.05875945091,138.250300884247 PathPoint;PointKind.CORNERPOINT 5306.65320134163,147.02582359314 5306.65320134163,147.02582359314 5306.65320134163,147.02582359314 PathPoint;PointKind.SMOOTHPOINT 5214.34664106369,139.225594997406 5198.57789134979,135.304591655731 5230.11539077759,143.146598339081 PathPoint;PointKind.CORNERPOINT 4635.95875835419,143.125591278076 4635.95875835419,143.125591278076 4635.95875835419,143.125591278076 PathPoint;PointKind.SMOOTHPOINT 4626.1387834549,151.900877952576 4610.52015161514,154.484510421753 4641.75741529465,149.317481517792 PathPoint;PointKind.CORNERPOINT 4197.99410915375,153.851230144501 4197.99410915375,153.851230144501 4197.99410915375,153.851230144501 PathPoint;PointKind.SMOOTHPOINT 696.242609977722,162.626516819 681.165323019028,163.099765777588 711.320250988007,162.153267860413 PathPoint;PointKind.SMOOTHPOINT 552.872959136963,157.751462459564 543.916870117188,158.662791252136 561.829402208328,156.839661598206 PathPoint;PointKind.SMOOTHPOINT 419.323637247086,160.676400661469 401.511655807495,159.176638126373 437.135264635086,162.176399230957 PathPoint;PointKind.SMOOTHPOINT 376.115889310837,151.900877952576 370.247838258743,151.499619483948 381.98464846611,152.30260848999 PathPoint;PointKind.SMOOTHPOINT 329.963140249252,151.900877952576 313.390339374542,151.499619483948 346.535941123962,152.30260848999 PathPoint";
	
	shadow35mm[2] = "PointKind.CORNERPOINT 241.102643251419,157.751462459564 241.102643251419,157.751462459564 241.102643251419,157.751462459564 PathPoint;PointKind.SMOOTHPOINT 239.138365030289,280.606892108917 238.077980518341,298.051249980927 240.198749542236,263.162062168121 PathPoint;PointKind.SMOOTHPOINT 236.192655801773,383.961160182953 233.780856370926,396.45870923996 238.60445523262,371.463611125946 PathPoint;PointKind.SMOOTHPOINT 233.246946573257,486.340842247009 232.925113677979,501.180324554443 233.568071365356,471.501123905182 PathPoint;PointKind.SMOOTHPOINT 230.300883293152,539.968328475952 231.548207044601,560.358159542084 229.052851438522,519.578025341034 PathPoint;PointKind.SMOOTHPOINT 229.318744182587,678.423979282379 228.45698261261,698.848979473114 230.180859804153,657.999451160431 PathPoint;PointKind.SMOOTHPOINT 237.174440860748,735.951697826385 236.359414100647,752.06104516983 237.99017572403,719.842586517334 PathPoint;PointKind.SMOOTHPOINT 234.228731632233,780.803897380829 233.609849452972,797.426383495331 234.847613811493,764.181175231934 PathPoint;PointKind.SMOOTHPOINT 230.300883293152,882.208049297333 230.864179372787,916.546804904938 229.737587213516,847.869529724121 PathPoint;PointKind.SMOOTHPOINT 233.246946573257,965.086805820465 233.267481565475,987.155313491821 233.226057529449,943.018298149109 PathPoint;PointKind.SMOOTHPOINT 230.300883293152,1057.71590709686 231.377554178238,1101.08227014542 229.224212408066,1014.34930801392 PathPoint;PointKind.SMOOTHPOINT 224.408756732941,1168.87087583542 216.260259389877,1193.01034927368 232.557254076004,1144.73116636276 PathPoint;PointKind.SMOOTHPOINT 199.5,1246 200.092122887253,1264.33157729665 199.346428150477,1241.25232685033 PathPoint;PointKind.SMOOTHPOINT 230.300883293152,1276.12537622452 242.371918201447,1298.5812163353 218.229848384857,1253.66977214813 PathPoint;PointKind.SMOOTHPOINT 236.192655801773,1311.2269949913 237.390058279037,1338.49014759064 234.995253324509,1283.96384239197 PathPoint;PointKind.SMOOTHPOINT 229.318744182587,1390.20528316498 225.539951562881,1433.12388896942 233.097536802292,1347.28691339493 PathPoint;PointKind.SMOOTHPOINT 223.5,1452 221.144494771957,1495.78154754639 225.855505228043,1408.21821641922 PathPoint;PointKind.SMOOTHPOINT 235,1513 233.964312286549,1515.19120704641 247.287282274166,1487.00376662701 PathPoint;PointKind.SMOOTHPOINT 243.89726955966,1568.14539103318 243.887960736723,1570.83013448353 244.041608438801,1526.51683465927 PathPoint;PointKind.SMOOTHPOINT 244,1618 244.779542358971,1622.75114442482 241.277809633028,1601.40883027523 PathPoint;PointKind.SMOOTHPOINT 236,1686 229.391251191226,1705.38296622733 239.147628298033,1676.76824149891 PathPoint;PointKind.SMOOTHPOINT 246,1777 244.541226317457,1797.12832189163 248.087355116963,1748.19844140379 PathPoint;PointKind.SMOOTHPOINT 234,1840 233.643488960581,1851.36771339166 234.748691388777,1816.12722136094 PathPoint;PointKind.SMOOTHPOINT 243,1888 242.764324157706,1914.56719571522 243.108964705917,1875.71665928944 PathPoint;PointKind.SMOOTHPOINT 232,1979 231.990057626723,1999.36198306891 232.014701155468,1948.89202976072 PathPoint;PointKind.SMOOTHPOINT 234,2060 222.887917275904,2094.3613290224 245.123221134132,2025.60422823797 PathPoint;PointKind.SMOOTHPOINT 241,2178 231.909507010505,2213.503300544 250.575342823912,2140.60309815078 PathPoint;PointKind.SMOOTHPOINT 236,2311 230.245935396123,2331.84821053572 238.41096839505,2302.26454425605 PathPoint;PointKind.SMOOTHPOINT 243.5,2434 243.483774633974,2442.76689075414 243.62480391366,2369.33401256672 PathPoint;PointKind.SMOOTHPOINT 214.588781833649,2479.32816267014 215.552156209946,2504.10445690155 213.626115560532,2454.55186843872 PathPoint;PointKind.SMOOTHPOINT 222.4448325634,2531.00529670715 223.107971191406,2559.01927471161 221.781339883804,2502.99155473709 PathPoint;PointKind.SMOOTHPOINT 219.498769283295,2570.98220586777 206.276712656021,2613.93834114075 232.721179962158,2528.02607059479 PathPoint;PointKind.SMOOTHPOINT 216.552706003189,2643.13532352448 226.199903726578,2661.56866550446 206.90586233139,2624.70198154449 PathPoint;PointKind.SMOOTHPOINT 207.715578317642,2703.58798027039 210.398935317993,2723.30700159073 205.031513214111,2683.86895895004 PathPoint;PointKind.SMOOTHPOINT 217.534491062164,2749.4150018692 221.564306259155,2765.09264230728 213.505738019943,2733.73712539673 PathPoint;PointKind.SMOOTHPOINT 224.408756732941,2804.99260425568 227.748171329498,2831.77778720856 221.069696187973,2778.20694923401 PathPoint;PointKind.SMOOTHPOINT 231.282668352127,2865.44502496719 227.059540987015,2884.82014417648 235.505795717239,2846.0701417923 PathPoint;PointKind.CORNERPOINT 227.354465961456,2908.34710836411 227.354465961456,2908.34710836411 227.354465961456,2908.34710836411 PathPoint;PointKind.SMOOTHPOINT 227.354465961456,2962.94941663742 226.546166181564,2992.47401475906 228.163473844528,2933.42505455017 PathPoint;PointKind.SMOOTHPOINT 228.336605072021,3028.27712774277 230.497735977173,3039.37617301941 226.17618227005,3017.17831850052 PathPoint;PointKind.SMOOTHPOINT 232.264453411102,3078.00438165665 228.949468374252,3098.38831186295 235.580146551132,3057.62045145035 PathPoint;PointKind.SMOOTHPOINT 217.534491062164,3136.50692224503 224.920361280441,3173.85983705521 216.639094591141,3131.97529792786 PathPoint;PointKind.SMOOTHPOINT 226.372680902481,3194.03464078903 226.199903726578,3211.46224021912 226.545812129974,3176.60680532455 PathPoint;PointKind.SMOOTHPOINT 224.408756732941,3238.88660430908 222.594950437546,3256.31774425507 226.222563028336,3221.45499229431 PathPoint;PointKind.SMOOTHPOINT 223.426971673965,3299.3390250206 228.949468374252,3322.323346138 217.904120922089,3276.35493993759 PathPoint;PointKind.SMOOTHPOINT 227.354465961456,3343.21593046188 227.919178247452,3368.7121295929 226.790461778641,3317.71996736526 PathPoint;PointKind.SMOOTHPOINT 226.372680902481,3375.39237499237 230.668742895126,3407.93750524521 222.076972961426,3342.84748077393 PathPoint;PointKind.SMOOTHPOINT 227.354465961456,3441.69561624527 229.120475292206,3476.90793514252 225.588810682297,3406.48282527924 PathPoint;PointKind.SMOOTHPOINT 225.390895843506,3512.87343978882 225.857889890671,3531.31291866302 224.923901796341,3494.43396091461 PathPoint;PointKind.SMOOTHPOINT 217.534491062164,3569.42610025406 226.888534069061,3593.39138031006 208.181510210037,3545.46082019806 PathPoint;PointKind.SMOOTHPOINT 225.390895843506,3617.20323801041 229.291836261749,3639.61399555206 221.489601373672,3594.79224443436 PathPoint;PointKind.SMOOTHPOINT 226.372680902481,3660.10508537292 225.686528921127,3681.05597019196 227.059186935425,3639.15372848511 PathPoint;PointKind.SMOOTHPOINT 225.390895843506,3720.55750608444 227.230547904968,3730.51862955093 223.551243782043,3710.59661865234 PathPoint;PointKind.SMOOTHPOINT 224.408756732941,3776.13487243652 227.405803442001,3789.3568110466 221.41206407547,3762.91316986084 PathPoint;PointKind.SMOOTHPOINT 225.390895843506,3813.18660736084 231.35277056694,3822.78636217117 219.429021120071,3803.58685255051 PathPoint;PointKind.SMOOTHPOINT 271.54364490509,3821.96213006973 284.605670213699,3821.93309783936 258.481973648071,3821.99116230011 PathPoint;PointKind.SMOOTHPOINT 2764.79901695251,3808.31131696701 2786.18160867691,3809.77449417114 2743.41642522812,3806.84837579727 PathPoint;PointKind.SMOOTHPOINT 3205.70902132988,3804.41108465195 3219.670337677,3801.41816854477 3191.74805903435,3807.40423679352 PathPoint;PointKind.SMOOTHPOINT 3734.99844574928,3803.43626260757 3749.08580446243,3801.58811330795 3720.91037893295,3805.2844119072 PathPoint;PointKind.SMOOTHPOINT 5261.98152923584,3799.53603029251 5276.11987137794,3801.64051294327 5247.84389519691,3797.43154764175 PathPoint;PointKind.CORNERPOINT 5279.65755486488,3805.38637876511 5279.65755486488,3805.38637876511 5279.65755486488,3805.38637876511 PathPoint;PointKind.CORNERPOINT 5674.41481018066,3807.33625888824 5674.41481018066,3807.33625888824 5674.41481018066,3807.33625888824 PathPoint;PointKind.CORNERPOINT 5687.18049430847,3796.61085605621 5687.18049430847,3796.61085605621 5687.18049430847,3796.61085605621 PathPoint;PointKind.SMOOTHPOINT 5683.2522919178,3704.95704889297 5684.7272708416,3694.25383329391 5681.777312994,3715.66002845764 PathPoint;PointKind.SMOOTHPOINT 5687.18049430847,3671.80531024933 5688.50783371925,3657.75843143463 5685.85315489769,3685.85242509842 PathPoint;PointKind.SMOOTHPOINT 5694.05405187607,3619.15311813354 5692.63005638123,3599.93944644928 5695.4784014225,3638.36678981781 PathPoint;PointKind.SMOOTHPOINT 5690.12620353699,3567.47574806213 5685.76216363907,3549.11368846893 5694.49024343491,3585.83804368973 PathPoint;PointKind.SMOOTHPOINT 5690.12620353699,3532.37460136414 5688.50783371925,3518.58429193497 5691.74492740631,3546.16420269012 PathPoint;PointKind.SMOOTHPOINT 5689.14441847801,3495.32286643982 5693.14732575417,3482.94239044189 5685.14151120186,3507.70287036896 PathPoint;PointKind.SMOOTHPOINT 5694.05405187607,3461.19606971741 5690.7397749424,3443.20316791534 5697.36832880974,3479.18897151947 PathPoint;PointKind.SMOOTHPOINT 5690.12620353699,3409.51917171478 5689.7094848156,3388.79794836044 5690.54327630997,3430.23992300034 PathPoint;PointKind.SMOOTHPOINT 5691.10834264755,3367.59191036224 5692.80106329918,3348.71505975723 5689.41562199593,3386.46899700165 PathPoint;PointKind.SMOOTHPOINT 5695.03583693504,3337.36581802368 5691.59976625443,3318.18542718887 5698.47296977043,3356.5459728241 PathPoint;PointKind.SMOOTHPOINT 5694.05405187607,3298.36396694183 5692.45904946327,3284.41622257233 5695.64976239204,3312.31171131134 PathPoint;PointKind.SMOOTHPOINT 5694.05405187607,3264.23764228821 5695.20861411095,3242.29069232941 5692.90019774437,3286.18435621262 PathPoint;PointKind.SMOOTHPOINT 5693.07226681709,3210.61015605927 5688.67848658562,3179.69909191132 5697.46604704857,3241.52145624161 PathPoint;PointKind.SMOOTHPOINT 5690.12620353699,3140.40715456009 5694.0069630146,3123.41692686081 5686.24579811096,3157.39738225937 PathPoint;PointKind.SMOOTHPOINT 5693.07226681709,3104.33047771454 5694.17832398415,3088.79445791245 5691.96691775322,3119.86673355103 PathPoint;PointKind.SMOOTHPOINT 5690.12620353699,3015.6016087532 5686.66216278076,2986.12775802612 5693.59024429321,3045.07569551468 PathPoint;PointKind.SMOOTHPOINT 5685.21657013893,2960.02400636673 5683.57058429718,2941.44172668457 5686.8618478775,2978.60675811768 PathPoint;PointKind.SMOOTHPOINT 5684.23443102837,2908.34710836411 5683.91259813309,2885.84335327148 5684.55626392365,2930.85062742233 PathPoint;PointKind.SMOOTHPOINT 5682.27015280724,2863.49490880966 5684.42597293854,2851.90420389175 5680.11468672752,2875.08584976196 PathPoint;PointKind.SMOOTHPOINT 5677.36051940918,2786.46673679352 5676.86980390549,2760.14606952667 5677.85158896446,2812.78740406036 PathPoint;PointKind.SMOOTHPOINT 5684.23443102837,2734.78936672211 5690.78473949432,2706.42039299011 5677.68412256241,2763.15810441971 PathPoint;PointKind.SMOOTHPOINT 5712.71186256409,2684.08729076385 5713.97511863708,2661.73861026764 5711.44896054268,2706.43573522568 PathPoint;PointKind.SMOOTHPOINT 5701.91010260582,2644.11014556885 5698.34126257896,2620.97617864609 5705.47929668427,2667.24482059479 PathPoint;PointKind.SMOOTHPOINT 5698.9643933773,2602.18359231949 5697.65688085556,2559.23760652542 5700.27155184746,2645.12934207916 PathPoint;PointKind.SMOOTHPOINT 5706.16314333433,2565.976675439 5703.89036846483,2552.16335888427 5708.77370764323,2581.84298567903 PathPoint;PointKind.SMOOTHPOINT 5710.5,2483 5721.39632568646,2451.27132291226 5699.49366156467,2515.04901984227 PathPoint;PointKind.CORNERPOINT 5739.5,2403 5739.5,2403 5739.5,2403 PathPoint;PointKind.CORNERPOINT 5740.5,1542 5740.5,1542 5740.5,1542 PathPoint;PointKind.SMOOTHPOINT 5719.5,1508 5711.38726186752,1484.76265001297 5727.61344623566,1531.23758602142 PathPoint;PointKind.SMOOTHPOINT 5716.5,1463 5716.58497238159,1446.52975606918 5716.41502761841,1479.47000789642 PathPoint;PointKind.SMOOTHPOINT 5722.5,1434 5724.62262240598,1417.70139612249 5718.47759625108,1464.8834921927 PathPoint;PointKind.SMOOTHPOINT 5718.6039891243,1398.98080587387 5714.53735256195,1391.80748462677 5722.67027163506,1406.15412712097 PathPoint;PointKind.SMOOTHPOINT 5704.85581183434,1386.30528688431 5711.47834682465,1355.29980897903 5698.2339849472,1417.31052875519 PathPoint;PointKind.SMOOTHPOINT 5716.63971090317,1343.40343952179 5718.00387167931,1318.46074104309 5715.27625823021,1368.3456659317 PathPoint;PointKind.SMOOTHPOINT 5715.65792584419,1308.3020567894 5711.30309128761,1287.25180149078 5720.01311445236,1329.35184001923 PathPoint;PointKind.SMOOTHPOINT 5714.67578673363,1274.17526006699 5719.03416180611,1244.95656251907 5710.31741166115,1303.3939576149 PathPoint;PointKind.SMOOTHPOINT 5714.67578673363,1233.22329282761 5703.91792917252,1219.54344749451 5725.43399834633,1246.90361022949 PathPoint;PointKind.SMOOTHPOINT 5690.12620353699,1208.84731292725 5686.39768624306,1179.46457147598 5693.85507488251,1238.2302904129 PathPoint;PointKind.SMOOTHPOINT 5685.21657013893,1151.31983041763 5690.51990890503,1128.29514741898 5679.91287732124,1174.34474945068 PathPoint;PointKind.SMOOTHPOINT 5692.09012770653,1113.29327344894 5689.31825780869,1080.02965450287 5694.86199760437,1146.55689239502 PathPoint;PointKind.SMOOTHPOINT 5691.10834264755,1063.56601953506 5692.92321109772,1040.63433408737 5689.29347419739,1086.49794101715 PathPoint;PointKind.SMOOTHPOINT 5691.10834264755,1029.43945884705 5691.03292965889,999.188346862793 5691.18340158463,1059.69104290009 PathPoint;PointKind.SMOOTHPOINT 5690.12620353699,964.111511707306 5696.674741745,930.913510322571 5683.57766532898,997.309749126434 PathPoint;PointKind.SMOOTHPOINT 5697.00046920776,911.459319591522 5692.55287313461,885.887825489044 5701.44806528091,937.030813694 PathPoint;PointKind.SMOOTHPOINT 5690.12620353699,874.407820701599 5694.6138074398,852.632467746735 5685.63895368576,896.183173656464 PathPoint;PointKind.SMOOTHPOINT 5692.09012770653,819.80527639389 5692.21050524712,795.49703836441 5691.97045826912,844.113986492157 PathPoint;PointKind.SMOOTHPOINT 5685.21657013893,777.878487110138 5684.30771970749,755.074260234833 5686.12471246719,800.682713985443 PathPoint;PointKind.SMOOTHPOINT 5683.2522919178,736.926991939545 5684.13706684113,706.978712081909 5682.36822509766,766.874563694 PathPoint;PointKind.SMOOTHPOINT 5691.10834264755,670.623750686646 5690.83359861374,642.854068279266 5691.38273262978,698.393433094025 PathPoint;PointKind.SMOOTHPOINT 5691.10834264755,635.522131919861 5691.69323587418,613.517825603485 5690.52344942093,657.52667427063 PathPoint;PointKind.SMOOTHPOINT 5699.94617843628,596.520516872406 5698.90774512291,572.071602344513 5700.98496580124,620.969431400299 PathPoint;PointKind.SMOOTHPOINT 5692.09012770653,544.843382835388 5691.69323587418,509.310057163239 5692.48737359047,580.376472473145 PathPoint;PointKind.SMOOTHPOINT 5694.05405187607,488.290958404541 5691.93328285217,461.165885925293 5696.17517495155,515.415558815002 PathPoint;PointKind.SMOOTHPOINT 5693.07226681709,438.563704490662 5695.71384572983,407.270264625549 5690.43104195595,469.856908321381 PathPoint;PointKind.SMOOTHPOINT 5698.9643933773,390.786566734314 5696.91549682617,367.021443843842 5701.01293587685,414.551453590393 PathPoint;PointKind.SMOOTHPOINT 5694.05405187607,358.610122203827 5691.59091496468,322.505593299866 5696.51718878746,394.714651107788 PathPoint;PointKind.SMOOTHPOINT 5695.03583693504,289.382178783417 5691.93328285217,262.474021911621 5698.1387450695,316.290099620819 PathPoint;PointKind.SMOOTHPOINT 5690.12620353699,244.530215263367 5696.74413585663,210.794763565063 5683.50862526894,278.265430927277 PathPoint;PointKind.SMOOTHPOINT 5696.0183300972,190.902729034424 5693.99457120895,159.119753837585 5698.04173493385,222.685704231262 PathPoint;PointKind.SMOOTHPOINT 5685.21657013893,144.100885391235 5678.87798452377,136.093182563782 5691.5548017025,152.108116149902 PathPoint;PointKind.CORNERPOINT 5666.55875945091,138.250300884247 5666.55875945091,138.250300884247 5666.55875945091,138.250300884247 PathPoint;PointKind.CORNERPOINT 5307.15320134163,147.02582359314 5307.15320134163,147.02582359314 5307.15320134163,147.02582359314 PathPoint;PointKind.SMOOTHPOINT 5214.84664106369,139.225594997406 5199.07789134979,135.304591655731 5230.61539077759,143.146598339081 PathPoint;PointKind.CORNERPOINT 4636.45875835419,143.125591278076 4636.45875835419,143.125591278076 4636.45875835419,143.125591278076 PathPoint;PointKind.SMOOTHPOINT 4626.6387834549,151.900877952576 4611.02015161514,154.484510421753 4642.25741529465,149.317481517792 PathPoint;PointKind.CORNERPOINT 4198.49410915375,153.851230144501 4198.49410915375,153.851230144501 4198.49410915375,153.851230144501 PathPoint;PointKind.SMOOTHPOINT 696.742609977722,162.626516819 681.665323019028,163.099765777588 711.820250988007,162.153267860413 PathPoint;PointKind.SMOOTHPOINT 553.372959136963,157.751462459564 544.416870117188,158.662791252136 562.329402208328,156.839661598206 PathPoint;PointKind.SMOOTHPOINT 419.823637247086,160.676400661469 402.011655807495,159.176638126373 437.635264635086,162.176399230957 PathPoint;PointKind.SMOOTHPOINT 376.615889310837,151.900877952576 370.747838258743,151.499619483948 382.48464846611,152.30260848999 PathPoint;PointKind.SMOOTHPOINT 330.463140249252,151.900877952576 313.890339374542,151.499619483948 347.035941123962,152.30260848999 PathPoint";
	
	subshadow35mm[0] = "PointKind.SMOOTHPOINT 239.172470569611,156.061928272247 241.166489124298,147.909300327301 237.178452014923,164.214792251587 PathPoint;PointKind.SMOOTHPOINT 287.266130447388,148.062014579773 284.621719121933,147.750449180603 301.293654441833,149.714963436127 PathPoint;PointKind.SMOOTHPOINT 973.605405092239,151.06201171875 987.176910638809,150.7461977005 953.571749925613,151.528179645538 PathPoint;PointKind.SMOOTHPOINT 4529.28073167801,143.15226316452 4589.45958852768,144.095928668976 4491.10193252563,142.553443908691 PathPoint;PointKind.SMOOTHPOINT 5649.73186612129,134.062578678131 5662.22493052483,134.994914531708 5637.23880171776,133.130006790161 PathPoint;PointKind.SMOOTHPOINT 5688.81998205185,158.061847686768 5694.71140050888,165.787961483002 5682.92820954323,150.335733890533 PathPoint;PointKind.SMOOTHPOINT 5694.71848154068,192.881169319153 5695.8047118187,207.818841934204 5693.63189721107,177.943732738495 PathPoint;PointKind.SMOOTHPOINT 5694.71848154068,234.810082912445 5694.98472833633,238.446900844574 5694.45294284821,231.173264980316 PathPoint;PointKind.SMOOTHPOINT 5694.71848154068,260.162301063538 5693.8110473156,267.445142269135 5695.62626981735,252.879223823547 PathPoint;PointKind.SMOOTHPOINT 5695.70062065125,296.240394115448 5696.15805530548,305.060291290283 5695.24247789383,287.420260906219 PathPoint;PointKind.SMOOTHPOINT 5690.82391405106,378.056523799896 5690.25495314598,390.766267776489 5691.39287495613,365.346071720123 PathPoint;PointKind.SMOOTHPOINT 5693.82981204987,413.055467605591 5693.91974115372,422.337048053741 5693.73952889442,403.77388715744 PathPoint;PointKind.SMOOTHPOINT 5694.71848154068,501.983077526093 5693.21305418015,511.797387599945 5696.22461700439,492.169003486633 PathPoint;PointKind.SMOOTHPOINT 5692.75491142273,537.086112499237 5695.5575838089,550.809860229492 5689.95188498497,523.362600803375 PathPoint;PointKind.SMOOTHPOINT 5696.68240571022,596.566307544708 5697.4347653389,614.393749237061 5695.93040013313,578.738865852356 PathPoint;PointKind.SMOOTHPOINT 5695.70062065125,634.59451675415 5692.97690176964,643.624248504639 5698.42469358444,625.565021038055 PathPoint;PointKind.SMOOTHPOINT 5692.75491142273,664.822497367859 5693.21305418015,674.249475002289 5692.29641461372,655.395047664642 PathPoint;PointKind.SMOOTHPOINT 5692.75491142273,719.426929950714 5695.5575838089,740.164439678192 5689.95188498497,698.689892292023 PathPoint;PointKind.SMOOTHPOINT 5688.68685865402,761.230981349945 5688.42733883858,770.683214664459 5688.94673252106,751.778748035431 PathPoint;PointKind.SMOOTHPOINT 5693.59649205208,806.084833145142 5692.76588702202,831.588349342346 5694.42745113373,780.58155298233 PathPoint;PointKind.SMOOTHPOINT 5690.65078282356,872.390670776367 5691.47536897659,882.943060398102 5689.82619667053,861.838045120239 PathPoint;PointKind.SMOOTHPOINT 5690.65078282356,922.120048999786 5690.65467739105,939.937341213226 5690.64653420448,904.302520751953 PathPoint;PointKind.SMOOTHPOINT 5687.70507359505,969.899311065674 5690.41852498055,982.559487819672 5684.99162220955,957.238426208496 PathPoint;PointKind.SMOOTHPOINT 5692.6147069931,1015.72822093964 5692.29570651054,1034.4972038269 5692.93370747566,996.958765983582 PathPoint;PointKind.SMOOTHPOINT 5699.62811493874,1084.10856485367 5702.24066162109,1099.8194861412 5697.01556825638,1068.39740753174 PathPoint;PointKind.SMOOTHPOINT 5690.82391405106,1123.03724527359 5688.86388444901,1128.11646938324 5692.78358960152,1117.95849323273 PathPoint;PointKind.SMOOTHPOINT 5690.54881596565,1159.92446422577 5692.19657206535,1175.7165813446 5688.68367218971,1142.04910755157 PathPoint;PointKind.SMOOTHPOINT 5709.8494720459,1217.0348739624 5719.78274345398,1228.75091314316 5698.04078936577,1203.10695648193 PathPoint;PointKind.SMOOTHPOINT 5726.24878764153,1262.54891395569 5726.07388615608,1283.22505474091 5726.42368912697,1241.87300920486 PathPoint;PointKind.SMOOTHPOINT 5721.33915424347,1298.6270070076 5723.49285006523,1316.64752483368 5719.18510437012,1280.60601711273 PathPoint;PointKind.SMOOTHPOINT 5720.87109804153,1337.03192710876 5721.26869797707,1351.91625595093 5720.47279000282,1322.1475982666 PathPoint;PointKind.SMOOTHPOINT 5715.86126804352,1372.03110694885 5713.76705288887,1396.37262582779 5717.95548319817,1347.68345117569 PathPoint;PointKind.SMOOTHPOINT 5720.88561415672,1414.89259243011 5721.2003660202,1433.38022232056 5720.57652711868,1396.760430336 PathPoint;PointKind.SMOOTHPOINT 5709.8494720459,1470.02857446671 5709.10065293312,1482.7451634407 5710.59793710709,1457.31174945831 PathPoint;PointKind.SMOOTHPOINT 5716.42952084541,1513.14521312714 5720.44446587563,1521.1418223381 5712.41422176361,1505.14907598495 PathPoint;PointKind.CORNERPOINT 5739.01376366615,1542.39813566208 5739.01376366615,1542.39813566208 5739.01376366615,1542.39813566208 PathPoint;PointKind.CORNERPOINT 5739.01376366615,2397.5467300415 5739.01376366615,2397.5467300415 5739.01376366615,2397.5467300415 PathPoint;PointKind.SMOOTHPOINT 5711.51988744736,2424.84930038452 5701.65813446045,2433.20940256119 5721.38199448586,2416.48919820786 PathPoint;PointKind.SMOOTHPOINT 5706.6102540493,2443.37587594986 5705.05879998207,2458.24769496918 5708.16100001335,2428.50429296494 PathPoint;PointKind.SMOOTHPOINT 5703.66454482079,2470.67821025848 5695.9118771553,2483.75239133835 5711.41685843468,2457.60426521301 PathPoint;PointKind.SMOOTHPOINT 5694.68240571022,2516.50712013245 5693.6422021389,2535.84636211395 5695.68791222572,2497.82098531723 PathPoint;PointKind.SMOOTHPOINT 5695.66454482079,2555.51062345505 5708.92094445229,2567.08763837814 5689.12733626366,2549.80142354965 PathPoint;PointKind.SMOOTHPOINT 5689.82588005066,2594.99988555908 5688.90322160721,2615.76123476028 5690.74818444252,2574.23853635788 PathPoint;PointKind.SMOOTHPOINT 5700.57417821884,2647.16844320297 5702.68822026253,2653.98157596588 5698.46013617516,2640.35554647446 PathPoint;PointKind.SMOOTHPOINT 5693.83374404907,2669.99816179276 5695.8932621479,2677.25551128387 5691.77422595024,2662.74034023285 PathPoint;PointKind.SMOOTHPOINT 5696.83964204788,2706.99726104736 5687.2979516983,2715.67459344864 5706.38204050064,2698.31969261169 PathPoint;PointKind.SMOOTHPOINT 5687.80884814262,2734.92603063583 5683.92313194275,2744.93436098099 5691.6945643425,2724.91770029068 PathPoint;PointKind.SMOOTHPOINT 5686.82706308365,2764.17871713638 5686.62100505829,2772.99955844879 5687.03276705742,2755.35787582397 PathPoint;PointKind.SMOOTHPOINT 5680.93529057503,2788.55587720871 5680.03847789764,2792.92558193207 5681.83281135559,2784.18617248535 PathPoint;PointKind.SMOOTHPOINT 5680.93529057503,2820.73350191116 5680.03847789764,2838.92538070679 5681.83281135559,2802.54185914993 PathPoint;PointKind.SMOOTHPOINT 5685.84527802467,2868.51252794266 5684.84402012825,2880.73273658752 5686.84618186951,2856.29255533218 PathPoint;PointKind.SMOOTHPOINT 5681.91742968559,2924.09225463867 5682.02895593643,2933.36887836456 5681.80519533157,2914.81563091278 PathPoint;PointKind.SMOOTHPOINT 5688.79134130478,2972.84657478333 5690.23976635933,2981.23287677765 5687.34256219864,2964.46003675461 PathPoint;PointKind.SMOOTHPOINT 5687.82194805145,3003.9896607399 5688.4765894413,3019.52166795731 5687.16730666161,2988.4574174881 PathPoint;PointKind.SMOOTHPOINT 5687.82194805145,3080.9876203537 5686.55762982368,3103.7847661972 5689.08626627922,3058.1902384758 PathPoint;PointKind.SMOOTHPOINT 5693.83374404907,3134.98638868332 5692.75955152512,3160.50217866898 5694.91537165642,3109.30254220963 PathPoint;PointKind.SMOOTHPOINT 5684.81605005264,3216.98426485062 5690.84944319725,3233.02587032318 5676.57089662552,3195.06186246872 PathPoint;PointKind.SMOOTHPOINT 5695.66454482079,3260.49649715424 5696.08267974854,3280.35336256027 5695.24570178986,3240.6396317482 PathPoint;PointKind.SMOOTHPOINT 5688.82391405106,3345.98083734512 5688.68547987938,3364.38443899155 5688.96199417114,3327.57747173309 PathPoint;PointKind.SMOOTHPOINT 5694.83571004868,3384.97985601425 5694.19735503197,3407.06465005875 5695.47441911697,3362.89482593536 PathPoint;PointKind.SMOOTHPOINT 5689.82588005066,3469.97772932053 5688.58917784691,3478.44428300858 5691.06258225441,3461.51141166687 PathPoint;PointKind.SMOOTHPOINT 5684.81605005264,3531.97617530823 5685.53512883186,3562.22917556763 5684.09130644798,3501.48100376129 PathPoint;PointKind.SMOOTHPOINT 5687.51852583885,3604.9277973175 5690.9995610714,3625.68418979645 5683.36479258537,3580.16306877136 PathPoint;PointKind.SMOOTHPOINT 5685.81801605225,3663.97274494171 5683.37718439102,3690.07366418839 5688.25884771347,3637.87182569504 PathPoint;PointKind.SMOOTHPOINT 5684.81605005264,3707.97168016434 5682.79618573189,3730.18298864365 5686.8359143734,3685.76060771942 PathPoint;PointKind.SMOOTHPOINT 5684.81605005264,3770.9699678421 5684.62911081314,3785.43533563614 5685.00334334373,3756.50483608246 PathPoint;PointKind.SMOOTHPOINT 5663.75939011574,3805.96938371658 5662.78149962425,3806.57079935074 5667.28999257088,3803.79692316055 PathPoint;PointKind.SMOOTHPOINT 5321.09055876732,3806.96898937225 5039.65530395508,3811.59785985947 5462.17799305916,3804.6490073204 PathPoint;PointKind.SMOOTHPOINT 4754.14172887802,3810.44388771057 4769.05969262123,3809.33405399323 4720.05151748657,3812.98054933548 PathPoint;PointKind.SMOOTHPOINT 3720.96749782562,3810.96906423569 3684.76820111275,3811.10454797745 4336.93724870682,3808.66230010986 PathPoint;PointKind.SMOOTHPOINT 3571.90257310867,3808.49377155304 3505.28705835342,3808.74774456024 3609.22244310379,3808.35167884827 PathPoint;PointKind.SMOOTHPOINT 3367.27739453316,3808.96914482117 2992.82853841782,3810.56190490723 3436.82056188583,3808.67339372635 PathPoint;PointKind.SMOOTHPOINT 2181.96400880814,3807.96906709671 1799.19741868973,3809.8287820816 2579.53207969666,3806.03759765625 PathPoint;PointKind.SMOOTHPOINT 1116.88512682915,3821.96873903275 608.087500333786,3825.9291601181 1428.4884095192,3819.54324960709 PathPoint;PointKind.SMOOTHPOINT 242.170150518417,3827.9688167572 232.40859413147,3828.5159444809 244.912634134293,3827.81492233276 PathPoint;PointKind.SMOOTHPOINT 231.148524522781,3792.96963691711 228.270793199539,3781.98530435562 234.026255846024,3803.95396947861 PathPoint;PointKind.SMOOTHPOINT 227.53436589241,3660.40564060211 226.969299554825,3635.37726163864 228.099432229996,3685.43378353119 PathPoint;PointKind.SMOOTHPOINT 227.53436589241,3592.14968681335 227.495420217514,3576.69887542725 227.573311567307,3607.60026216507 PathPoint;PointKind.SMOOTHPOINT 228.516505002975,3472.21447467804 229.345693826675,3453.04446935654 227.686608076096,3491.38424396515 PathPoint;PointKind.SMOOTHPOINT 232.150844573975,3405.97944736481 231.526651620865,3392.97843694687 232.774329423904,3418.98092985153 PathPoint;PointKind.SMOOTHPOINT 224,3322 221.917447080385,3318.62537579211 236.236773191287,3341.82805743957 PathPoint;PointKind.SMOOTHPOINT 232.150844573975,3255.98313093185 224.350025892258,3222.37159729004 237.722200393677,3279.98971700668 PathPoint;PointKind.SMOOTHPOINT 231.148524522781,3172.98541307449 231.431887117325,3172.33234373284 213.626425456955,3213.36878596306 PathPoint;PointKind.SMOOTHPOINT 224,3126 228.726195944051,3121.96744207823 218.572944863473,3130.63055583005 PathPoint;PointKind.SMOOTHPOINT 230.480075120926,3089.00602817535 230.719413995743,3047.21401453018 230.373151540756,3107.72072315216 PathPoint;PointKind.SMOOTHPOINT 227.53436589241,2997.34844446182 229.962818343206,2981.63294640485 226.179186519762,3006.11836962183 PathPoint;PointKind.SMOOTHPOINT 230.146912574768,2902.99227952957 232.985698223114,2881.38545513153 227.308126926422,2924.59933996201 PathPoint;PointKind.SMOOTHPOINT 234.154776573181,2852.99358606339 235.996906995773,2824.17142629623 232.312292098999,2881.81621789932 PathPoint;PointKind.SMOOTHPOINT 232,2779 230.618136644363,2745.7642145596 233.080459153206,2805.01151350768 PathPoint;PointKind.SMOOTHPOINT 221.751174926758,2726.12532997131 218.402909040451,2706.72519111633 225.099440813065,2745.52546882629 PathPoint;PointKind.SMOOTHPOINT 227.129218578339,2696.99750566483 235.750374794006,2686.4625825882 218.51620554924,2707.52275133133 PathPoint;PointKind.SMOOTHPOINT 230.154776573181,2638.99882078171 224.225474596024,2603.41144323349 236.241277456284,2675.53246021271 PathPoint;PointKind.SMOOTHPOINT 229.152456521988,2574.00037765503 232.733334302902,2549.72424030304 225.571932792664,2598.27698707581 PathPoint;PointKind.SMOOTHPOINT 227.148524522781,2486.00274324417 226.565047502518,2468.84540319443 227.731647491455,2503.16031932831 PathPoint;PointKind.SMOOTHPOINT 198.98619890213,2424.84930038452 202.103977203369,2438.93606901169 206.251337528229,2457.67365932465 PathPoint;PointKind.CORNERPOINT 201.931908130646,1518.02097558975 201.931908130646,1518.02097558975 201.931908130646,1518.02097558975 PathPoint;PointKind.SMOOTHPOINT 228.150844573975,1472.02849388123 229.897381067276,1460.17791509628 226.403599977493,1483.87930870056 PathPoint;PointKind.SMOOTHPOINT 231.156388521194,1429.02940034866 231.158866882324,1414.05278205872 231.154264211655,1444.00672674179 PathPoint;PointKind.SMOOTHPOINT 239.172470569611,1363.03135156631 240.372705459595,1345.36370515823 237.971881628036,1380.69876194 PathPoint;PointKind.SMOOTHPOINT 238.170150518417,1282.03331708908 237.770426273346,1263.62405061722 238.570228815079,1300.44258356094 PathPoint;PointKind.SMOOTHPOINT 222,1237 218.936391592026,1212.72457075119 223.420454978943,1248.25010728836 PathPoint;PointKind.SMOOTHPOINT 227.172600030899,1164.50730800629 229.591834545135,1146.3704252243 224.627323150635,1183.58927249908 PathPoint;PointKind.SMOOTHPOINT 230.407569408417,1082.15821266174 226.928304433823,1063.56696367264 233.848242759705,1100.53915500641 PathPoint;PointKind.SMOOTHPOINT 227.461860179901,1004.15144205093 235.704535245895,977.646431922913 223.899747133255,1015.60619115829 PathPoint;PointKind.SMOOTHPOINT 230.154776573181,945.04182100296 230.187703371048,934.811382293701 230.122557878494,954.864864349365 PathPoint;PointKind.SMOOTHPOINT 229.152456521988,889.043369293213 230.263470411301,875.521667003632 228.173857927322,900.948235988617 PathPoint;PointKind.SMOOTHPOINT 232.158354520798,794.045898914337 232.802374362946,777.836472988129 231.51468873024,810.254852771759 PathPoint;PointKind.SMOOTHPOINT 237,630 236.48627114296,606.990423202515 237.51408290863,653.009340763092 PathPoint;PointKind.SMOOTHPOINT 229.152456521988,540.052120685577 227.458673715591,529.455592632294 230.945373773575,551.267058849335 PathPoint;PointKind.SMOOTHPOINT 231.974247694016,473.042900562286 230.152298212051,459.05172586441 235.457053184509,499.790081977844 PathPoint;PointKind.SMOOTHPOINT 235.164252519608,395.055956840515 238.388954401016,377.014195919037 231.939550638199,413.097717761993 PathPoint;PointKind.SMOOTHPOINT 236.166218519211,286.058578491211 241.618613004684,256.817693710327 230.713469982147,315.299699306488 PathPoint;PointKind.CORNERPOINT 235.164252519608,205.060544013977 235.164252519608,205.060544013977 235.164252519608,205.060544013977 PathPoint";
	
} else if (mask_variant_35mm == 4) {
	
	mask35mm[0] = "PointKind.CORNERPOINT 445.243241786957,3793.27639818192 445.243241786957,3793.27639818192 445.243241786957,3793.27639818192 PathPoint;PointKind.SMOOTHPOINT 400.849066972733,3790.98190784454 392.109657526016,3787.94792175293 409.588122367859,3794.01589393616 PathPoint;PointKind.SMOOTHPOINT 387.998056411743,3793.27639818192 381.284884214401,3788.19457769394 394.710874557495,3798.35845470428 PathPoint;PointKind.SMOOTHPOINT 359.95964884758,3792.12927103043 352.342936992645,3790.34107446671 367.576006650925,3793.91723155975 PathPoint;PointKind.SMOOTHPOINT 338.93075466156,3795.57088851929 333.64618062973,3792.26357460022 344.21532869339,3798.87820243835 PathPoint;PointKind.SMOOTHPOINT 319.070230722427,3797.86537885666 313.397616147995,3796.32832288742 324.74249124527,3799.40267086029 PathPoint;PointKind.CORNERPOINT 307.387236356735,3800.16010522842 307.387236356735,3800.16010522842 307.387236356735,3800.16010522842 PathPoint;PointKind.SMOOTHPOINT 299.209352731705,3801.30723237991 293.504873514175,3798.84704589844 304.913831949234,3803.76765489578 PathPoint;PointKind.SMOOTHPOINT 288.69508266449,3804.74908590317 279.759528636932,3804.33673381805 297.630636692047,3805.16143798828 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,3802.4545955658 266.087118387222,3798.3719086647 276.254771947861,3806.5370464325 PathPoint;PointKind.SMOOTHPOINT 265.656591653824,3789.98183012009 260.189327001572,3790.00873804092 271.123856306076,3789.95515823364 PathPoint;PointKind.SMOOTHPOINT 259.815094470978,3780.8038687706 256.346805095673,3775.23345708847 263.283383846283,3786.37428045273 PathPoint;PointKind.SMOOTHPOINT 258.319934606552,3763.44778776169 258.397471904755,3756.87352180481 258.24239730835,3770.02205371857 PathPoint;PointKind.SMOOTHPOINT 253.973951339722,3740.35536289215 255.461676120758,3728.29117298126 252.486226558685,3752.41955280304 PathPoint;PointKind.SMOOTHPOINT 257.805497646332,3716.41014575958 264.806159734726,3708.58560562134 250.805189609528,3724.23492193222 PathPoint;PointKind.SMOOTHPOINT 256.637481451035,3695.75949668884 256.421509981155,3690.20183086395 256.774145364761,3699.28679466248 PathPoint;PointKind.SMOOTHPOINT 261.310254335403,3687.72866249084 266.024451255798,3682.02394723892 256.596411466599,3693.43361377716 PathPoint;PointKind.SMOOTHPOINT 257.478708028793,3672.96164274216 257.323633432388,3667.73182868958 257.633782625198,3678.19145679474 PathPoint;PointKind.SMOOTHPOINT 262.151834964752,3659.19446468353 262.37984418869,3650.59006690979 261.923471689224,3667.79909849167 PathPoint;PointKind.SMOOTHPOINT 259.815094470978,3644.28015947342 263.507144451141,3638.10479164124 256.123398542404,3650.45576334 PathPoint;PointKind.SMOOTHPOINT 259.488304853439,3626.92407846451 258.643891811371,3620.03163814545 260.332717895508,3633.81651878357 PathPoint;PointKind.SMOOTHPOINT 261.824691295624,3617.74611711502 263.508914709091,3612.26067781448 260.140821933746,3623.23132038116 PathPoint;PointKind.SMOOTHPOINT 260.656675100327,3606.27342939377 259.876345396042,3601.83244228363 261.437004804611,3610.7146525383 PathPoint;PointKind.SMOOTHPOINT 261.824691295624,3594.80097770691 260.236769914627,3585.13442516327 263.41296672821,3604.46753025055 PathPoint;PointKind.SMOOTHPOINT 264.161431789398,3578.73930931091 264.900691509247,3573.58998298645 263.42217206955,3583.88839960098 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,3567.26662158966 266.963396072388,3559.81855630875 263.695853948593,3574.71492290497 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,3547.7633357048 265.115246772766,3540.67357063293 265.544003248215,3554.85310077667 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,3533.99615764618 267.205213308334,3528.40332269669 268.127163648605,3539.58922863007 PathPoint;PointKind.SMOOTHPOINT 264.161431789398,3522.52370595932 263.463242053986,3517.82709360123 264.859621524811,3527.22031831741 PathPoint;PointKind.SMOOTHPOINT 264.161431789398,3493.84222269058 262.030041217804,3486.77936553955 266.292468309402,3500.90507984161 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,3482.36977100372 266.903915405273,3476.16725921631 266.091721057892,3488.57204675674 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,3457.12990522385 272.63601064682,3443.86925697327 265.033106803894,3470.39078950882 PathPoint;PointKind.SMOOTHPOINT 264.161431789398,3441.06847286224 263.663989305496,3433.25715065002 264.6588742733,3448.87955904007 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,3403.20879220963 261.359467506409,3396.93476200104 271.636523008347,3409.48305845261 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,3392.88346767426 266.903915405273,3384.89299535751 266.091721057892,3400.873939991 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,3369.93832826614 268.620003461838,3360.49600839615 266.712373495102,3379.38088417053 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,3342.40420818329 266.333538293839,3329.50658082962 266.662098169327,3355.30183553696 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,3322.90092229843 271.992344856262,3313.8796877861 272.685931921005,3331.92215681076 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,3309.13374423981 263.253289461136,3300.58316230774 272.079087495804,3317.68432617188 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,3299.95578289032 272.197694778442,3294.19701576233 272.480581998825,3305.71431398392 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,3289.63045835495 266.233341693878,3284.35579776764 266.762648820877,3294.90511894226 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,3279.30513381958 271.280347108841,3268.35691452026 271.061543226242,3290.2533531189 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,3260.94897508621 269.473267793655,3254.70185279846 268.195495605469,3267.19609737396 PathPoint;PointKind.SMOOTHPOINT 262.993061542511,3252.91814088821 261.811237335205,3247.5448179245 264.175239801407,3258.29146385193 PathPoint;PointKind.SMOOTHPOINT 264.161431789398,3228.82563829422 263.540779352188,3223.15207958221 264.782084226608,3234.49919700623 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,3217.35318660736 269.811033010483,3211.74689769745 265.521343946457,3222.95947551727 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,3207.02786207199 267.789398431778,3200.10402917862 269.879364967346,3213.95169496536 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,3196.70253753662 270.888057947159,3190.45541524887 271.453832387924,3202.94965982437 PathPoint;PointKind.SMOOTHPOINT 262.993061542511,3186.37721300125 262.062259912491,3180.43032646179 263.924217224121,3192.32409954071 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,3165.72656393051 267.113867998123,3157.8302693367 270.554895401001,3173.62285852432 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,3150.8122587204 266.662098169327,3143.75837087631 263.997151851654,3157.86614656448 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,3135.89795351028 265.343255996704,3130.8517742157 272.32550740242,3140.94389677048 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,3126.7197561264 272.216105461121,3118.87727737427 267.789398431778,3134.56247091293 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,3116.39443159103 267.679996490479,3110.17870187759 265.315994024277,3122.61039733887 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,3101.48012638092 270.728380680084,3093.55692386627 269.277123212814,3109.40332889557 PathPoint;PointKind.SMOOTHPOINT 264.161431789398,3085.41845798492 262.532086372375,3076.41067743301 265.790423154831,3094.42623853683 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,3056.73721075058 264.599393606186,3049.75484132767 266.059856414795,3063.7193441391 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,3046.41188621521 266.967998743057,3038.28238964081 270.701118707657,3054.54114675522 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,3034.93919849396 270.545690059662,3027.65682935715 271.796200275421,3042.22156763077 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,3018.87753009796 267.346833944321,3011.38461828232 279.668183326721,3026.370677948 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2992.49077320099 266.967998743057,2982.21005916595 266.027991771698,3002.77125120163 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2962.66192674637 264.932556152344,2954.20552253723 268.063080310822,2971.1185669899 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2927.09697246552 269.870513677597,2920.66597938538 265.461863279343,2933.52796554565 PathPoint;PointKind.CORNERPOINT 265.329802036285,2915.62452077866 265.329802036285,2915.62452077866 265.329802036285,2915.62452077866 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2908.74081373215 267.451633214951,2903.30494165421 270.217130184174,2914.17692184448 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,2897.26836204529 266.612176895142,2890.83736896515 264.047427177429,2903.69911909103 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2889.23752784729 271.202809810638,2883.51463794708 266.465953588486,2894.9604177475 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2876.61771297455 262.710174322128,2870.50489425659 272.622202634811,2882.73029565811 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2865.1450252533 269.044511318207,2858.31537008286 268.624606132507,2871.97491645813 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,2853.67257356644 264.293847084045,2847.3402428627 266.365402936935,2860.00490427017 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2841.0527586937 270.290064811707,2833.83293867111 267.378698587418,2848.27234268188 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2813.51840257645 267.675393819809,2801.81298494339 269.993723630905,2825.2240562439 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,2780.24793863297 270.285816192627,2771.09688520432 269.719687700272,2789.39922809601 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2758.45016241074 265.215443372726,2748.73427867889 267.780193090439,2768.16604614258 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,2738.94664049149 269.2176425457,2728.39731931686 270.787507295609,2749.4961977005 PathPoint;PointKind.SMOOTHPOINT 264.161431789398,2721.737844944 263.161944150925,2712.8601193428 265.160919427872,2730.6155705452 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,2704.52904939651 269.902378320694,2696.84778213501 270.103125572205,2712.21031665802 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2695.35085201263 264.594790935516,2689.55644369125 268.400845527649,2701.14549636841 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,2668.96409511566 271.81000828743,2658.74168157578 270.532236099243,2679.18627262115 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,2633.39914083481 272.768071889877,2625.34588336945 267.237077951431,2641.45216226578 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2625.36830663681 266.73538684845,2620.2100110054 266.260603666306,2630.52636623383 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,2617.33747243881 272.571927309036,2610.1714682579 267.433576583862,2624.50324058533 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2603.57029438019 270.507452487946,2597.75251865387 266.771500110626,2610.74385166168 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2584.06700849533 269.036722183228,2577.14270353317 268.572560548782,2593.03985595703 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,2569.15270328522 269.103637933731,2559.74602460861 273.238252401352,2578.55914592743 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,2547.35469102859 272.64061331749,2538.10497522354 272.038017511368,2556.60440683365 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,2504.90626573563 272.307450771332,2492.33554601669 272.371180057526,2517.47674942017 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,2472.78292894363 272.895884513855,2464.76554870605 271.782392263412,2480.80030918121 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2461.31047725677 266.534285545349,2454.7359752655 266.461350917816,2467.88474321365 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,2452.13227987289 274.055049419403,2442.36730098724 268.28684091568,2461.89749479294 PathPoint;PointKind.SMOOTHPOINT 274.675701856613,2433.77612113953 273.019094467163,2425.95606565475 276.332309246063,2441.59641265869 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,2417.71468877792 268.90289068222,2406.64538383484 273.438999652863,2428.78375768661 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2400.50565719604 269.496281147003,2391.9012594223 265.836095809937,2409.11029100418 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,2384.44422483444 272.576529979706,2376.95107698441 272.102100849152,2391.93713665009 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2367.23519325256 267.031728029251,2361.28382205963 268.300648927689,2373.18680047989 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,2354.61537837982 268.510601520538,2345.03851890564 271.49490237236,2364.1924738884 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,2339.70107316971 263.358088731766,2330.26748657227 267.301161289215,2349.13465976715 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2325.93389511108 266.671303510666,2319.26120281219 266.324332952499,2332.60682344437 PathPoint;PointKind.SMOOTHPOINT 260.656675100327,2316.7559337616 260.784487724304,2311.17206811905 260.528862476349,2322.33979940414 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2307.57797241211 272.01535820961,2302.64815807343 265.653759241104,2312.5075507164 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2290.36894083023 262.080316543579,2282.71906614304 270.915319919586,2298.01881551743 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2281.19097948074 272.923500537872,2273.08839082718 264.745616912842,2289.29356813431 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,2266.27667427063 268.432710170746,2256.32782459259 273.909180164337,2276.22552394867 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,2254.80398654938 272.544665336609,2246.69714927673 272.133965492249,2262.91105985641 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2234.15333747864 269.386525154114,2227.57458686829 268.28223824501,2240.73232412338 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,2219.23903226852 275.757329463959,2210.12810468674 271.257687807083,2228.34995985031 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2202.03023672104 265.411942005157,2195.50506591797 269.920434951782,2208.55517148972 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2187.11593151093 268.980427980423,2180.92238903046 266.351948976517,2193.309237957 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2176.79060697556 267.949075698853,2171.15292549133 265.046560764313,2182.42828845978 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2167.61240959167 270.97940325737,2158.64947557449 266.689714193344,2176.57534360886 PathPoint;PointKind.SMOOTHPOINT 262.993061542511,2154.99259471893 262.372409105301,2146.41510486603 263.613713979721,2163.57008457184 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2143.52014303207 272.266380786896,2138.82801532745 263.065996170044,2148.21227073669 PathPoint;PointKind.SMOOTHPOINT 264.161431789398,2130.90032815933 264.010605812073,2121.69522285461 264.311903715134,2140.10519742966 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2099.92435455322 269.537351131439,2088.20076227188 265.7950258255,2111.64771080017 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,2060.91754674911 264.804743528366,2053.06586265564 265.854506492615,2068.7689948082 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2041.41402482986 270.413274765015,2032.72465467453 264.919102191925,2050.10363101959 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2009.29092407227 272.047222852707,1996.67110919952 263.285154104233,2021.91073894501 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,1996.67110919952 266.497818231583,1985.58386564255 266.497818231583,2007.7583527565 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,1980.60944080353 268.264181613922,1967.49678611755 267.068195343018,1993.7223315239 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,1951.92795753479 269.071773290634,1940.42859792709 268.59699010849,1963.42755317688 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,1932.42467164993 275.278297662735,1917.19667673111 267.063946723938,1947.65266656876 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1886.53439283371 272.936954498291,1879.89734172821 271.741322278976,1893.17144393921 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1875.06170511246 269.153913259506,1866.86069011688 270.851590633392,1883.26295614243 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1861.29476308823 273.470864295959,1853.30429077148 273.544152975082,1869.28523540497 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,1847.5275850296 268.487588167191,1840.64859867096 269.181175231934,1854.40657138824 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,1833.76040697098 272.261778116226,1824.42123413086 270.080466270447,1843.09981584549 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1817.69897460938 267.520319223404,1808.1041765213 272.485184669495,1827.29377269745 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1790.16461849213 276.893835067749,1783.69349956512 270.121536254883,1796.63597345352 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1770.66133260727 276.177234649658,1760.73042154312 268.501396179199,1780.59224367142 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1741.97984933853 275.048518180847,1732.17120409012 266.471618413925,1748.84467363358 PathPoint;PointKind.SMOOTHPOINT 274.675701856613,1723.62369060516 274.849187135696,1717.20638751984 274.50257062912,1730.04122972488 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,1713.29836606979 268.761270046234,1703.31812381744 268.90749335289,1723.27860832214 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,1693.79508018494 269.021497964859,1685.9032702446 266.310878992081,1701.68689012527 PathPoint;PointKind.SMOOTHPOINT 275.8440721035,1680.02790212631 276.697336435318,1672.66056060791 274.990807771683,1687.39547967911 PathPoint;PointKind.SMOOTHPOINT 274.675701856613,1663.96646976471 273.827040195465,1656.32556438446 275.524717569351,1671.60737514496 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,1654.78827238083 268.28684091568,1646.87403917313 269.381922483444,1662.70250558853 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1642.16845750809 272.571927309036,1633.01740407944 272.106703519821,1651.31974697113 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1614.63433742523 269.003441333771,1607.00240135193 275.675189495087,1622.26627349854 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1600.86715936661 275.264489650726,1593.5354590416 271.750527620316,1608.19885969162 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1583.65836381912 277.021647691727,1576.40290260315 267.656983137131,1590.9138250351 PathPoint;PointKind.SMOOTHPOINT 274.675701856613,1567.59669542313 273.146907091141,1561.42581224442 276.204496622086,1573.76781463623 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,1557.27137088776 268.259578943253,1547.60481834412 264.736411571503,1566.9379234314 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1528.58988761902 276.861616373062,1514.49580192566 270.15340089798,1542.68420934677 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,1511.38109207153 267.967486381531,1499.25435304642 269.701631069183,1523.50806713104 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1466.63817644119 274.141792058945,1453.02347660065 270.536838769913,1480.25287628174 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1445.98752737045 270.742188692093,1435.92207670212 269.263315200806,1456.05274200439 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1423.04238796234 269.769963026047,1407.87694215775 270.235540866852,1438.20759773254 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1393.21354150772 271.399308443069,1384.67641353607 268.606195449829,1401.75090551376 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1377.15210914612 273.831642866135,1361.90145492554 266.173861026764,1392.40252733231 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1357.64858722687 271.946672201157,1346.01468801498 275.068345069885,1369.28248643875 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,1335.85081100464 260.510451793671,1322.84106731415 270.14879822731,1348.86055469513 PathPoint;PointKind.SMOOTHPOINT 262.993061542511,1323.2309961319 262.79691696167,1318.22966337204 263.189206123352,1328.23232889175 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,1319.78914260864 277.733291387558,1315.2001619339 264.608598947525,1324.37812328339 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1310.61094522476 273.05591583252,1301.59891605377 273.959455490112,1319.62321043015 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1302.58034706116 277.217029051627,1302.04410040155 267.027125358582,1303.51693153381 PathPoint;PointKind.SMOOTHPOINT 282.411103925511,1300.59828037425 282.479076301278,1300.56270078243 280.642962621716,1301.52379967761 PathPoint;PointKind.SMOOTHPOINT 282.327776247595,1286.78291052021 280.206659503904,1284.14410594485 282.172368870359,1286.58957382655 PathPoint;PointKind.SMOOTHPOINT 274.675701856613,1276.19335412979 271.764335632324,1262.96858310699 276.803757788825,1285.85879234525 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,1258.98455858231 266.853994131088,1251.24050617218 268.478382825851,1266.72837495804 PathPoint;PointKind.SMOOTHPOINT 275.8440721035,1247.51187086105 280.580928325653,1242.68543958664 271.107215881348,1252.33853816986 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1236.03941917419 264.576734304428,1228.26397418976 275.42876958847,1243.81462812424 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1221.12487792969 275.807604789734,1213.0584025383 264.197899103165,1229.19158935547 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1206.21057271957 268.218508958817,1190.592648983 271.786994934082,1221.82849645615 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1186.70728683472 279.654729366302,1179.2769241333 265.023901462555,1194.13741350174 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1170.64561843872 273.735694885254,1164.39849615097 266.269809007645,1176.89274072647 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,1158.02580356598 267.031728029251,1147.56145477295 270.637035369873,1168.49015235901 PathPoint;PointKind.SMOOTHPOINT 277.012442350388,1132.7861738205 277.91598200798,1129.49679851532 274.141792058945,1143.23683261871 PathPoint;PointKind.SMOOTHPOINT 276.88675403595,1122.33055830002 283.418651819229,1117.48972892761 273.816772699356,1124.60592985153 PathPoint;PointKind.SMOOTHPOINT 277.012442350388,1108.6936712265 273.423067331314,1105.73852062225 284.463812112808,1114.82867717743 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1093.77936601639 276.332309246063,1077.38606929779 272.586797475815,1099.12318468094 PathPoint;PointKind.SMOOTHPOINT 274.675701856613,1068.5397362709 275.104812383652,1053.99742126465 274.246945381165,1083.08205127716 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1045.59459686279 271.859929561615,1030.20963907242 272.818347215652,1060.97955465317 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1020.35496711731 275.793796777725,1005.15364408493 268.884479999542,1035.5560541153 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,995.115101337433 272.599543333054,982.056262493134 274.415827989578,1008.17417621613 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,967.580981254578 274.150997400284,957.811517715454 272.864019870758,977.350680828094 PathPoint;PointKind.SMOOTHPOINT 274.675701856613,952.666676044464 275.930814743042,936.658823490143 273.420943021774,968.674528598785 PathPoint;PointKind.SMOOTHPOINT 275.999854803085,928.999979496002 271.687506437302,909.770021438599 280.312557220459,948.229937553406 PathPoint;PointKind.SMOOTHPOINT 275.8440721035,899.892926216125 277.108036279678,878.927643299103 275.12676358223,911.789767742157 PathPoint;PointKind.SMOOTHPOINT 284,876 283.987217401532,859.074578155342 284.01397957869,893.929009648644 PathPoint;PointKind.SMOOTHPOINT 278.507602214813,852.85528421402 277.867122888565,849.019725322723 281.925616264343,873.326547145844 PathPoint;PointKind.SMOOTHPOINT 278.507602214813,835.646488666534 280.151817798615,832.249009609222 276.46578669548,839.864895343781 PathPoint;PointKind.SMOOTHPOINT 280.517199039459,829.910144805908 280.705908536911,827.250273227692 280.233249664307,833.908331394196 PathPoint;PointKind.SMOOTHPOINT 280.740251541138,821.833755970001 280.710865259171,819.179785251617 280.769991874695,824.538474082947 PathPoint;PointKind.SMOOTHPOINT 278.507602214813,813.848476409912 277.665313482285,801.701910495758 278.686752319336,816.433053016663 PathPoint;PointKind.SMOOTHPOINT 281.685569286346,793.197827339172 280.845758914948,785.467228889465 282.073963880539,796.776344776154 PathPoint;PointKind.SMOOTHPOINT 279.6759724617,782.872502803802 278.242417573929,777.029943466187 282.126363515854,792.861714363098 PathPoint;PointKind.SMOOTHPOINT 279.348828792572,765.663707256317 278.903785943985,761.064341068268 279.975854158401,772.144267559052 PathPoint;PointKind.SMOOTHPOINT 277.339231967926,749.602038860321 282.254176139832,736.036670207977 275.299186706543,755.233111381531 PathPoint;PointKind.SMOOTHPOINT 279.6759724617,717.478938102722 271.671220064163,707.695784568787 287.680370807648,727.261855602264 PathPoint;PointKind.SMOOTHPOINT 282.012358903885,696.828289031982 281.95748090744,689.738523960114 282.06723690033,703.918054103851 PathPoint;PointKind.SMOOTHPOINT 285,669 285.013563904995,668.771104078853 283.559600230729,693.300973963208 PathPoint;PointKind.SMOOTHPOINT 285.190325975418,614.225692749023 285.79717040062,598.51359128952 284.583127498627,629.937794208527 PathPoint;PointKind.SMOOTHPOINT 282.675851583481,580.955228805542 280.412399768829,572.547919750214 284.939303398132,589.36253786087 PathPoint;PointKind.SMOOTHPOINT 286.180608272552,520.150644779205 283.903348445892,507.248296737671 288.457868099213,533.052756786346 PathPoint;PointKind.SMOOTHPOINT 280.339111089706,483.438327312469 282.315427064896,466.977760791779 278.363149166107,499.89889383316 PathPoint;PointKind.SMOOTHPOINT 281.507481336594,439.842538833618 280.430456399918,425.811002254486 282.58450627327,453.87407541275 PathPoint;PointKind.SMOOTHPOINT 284.999846220016,408.000082969666 285.821599960327,390.410327911377 284.178446531296,425.589838027954 PathPoint;PointKind.SMOOTHPOINT 286.999883651733,359.000051021576 288.524075746536,332.057433128357 285.475691556931,385.942668914795 PathPoint;PointKind.SMOOTHPOINT 286.999883651733,314.999935626984 287.574863433838,292.243151664734 286.424903869629,337.756955623627 PathPoint;PointKind.SMOOTHPOINT 286.00004196167,278.999969959259 287.65204668045,255.373635292053 284.348037242889,302.626304626465 PathPoint;PointKind.SMOOTHPOINT 288.000079393387,244.999923706055 286.279388666153,233.339116573334 289.720416069031,256.660730838776 PathPoint;PointKind.SMOOTHPOINT 288.99992108345,228.000018596649 289.172344207764,212.530796527863 288.807317018509,245.291426181793 PathPoint;PointKind.SMOOTHPOINT 295.999875068665,199.999966621399 302.100538015366,192.820508480072 291.116087436676,205.747876167297 PathPoint;PointKind.SMOOTHPOINT 313.000016212463,189.999897480011 309.747698307037,191.731445789337 306.391997337341,193.517990112305 PathPoint;PointKind.SMOOTHPOINT 328.999961614609,184.999980926514 334.523166418076,182.27826833725 317.632427215576,190.601785182953 PathPoint;PointKind.SMOOTHPOINT 354.603910446167,181.942391395569 359.765274524689,183.080785274506 349.442546367645,180.804233551025 PathPoint;PointKind.SMOOTHPOINT 377.969191074371,184.237117767334 384.294322729111,183.914458751678 371.644059419632,184.55977678299 PathPoint;PointKind.SMOOTHPOINT 393.156588077545,183.089754581451 402.279081344604,183.197386264801 384.034094810486,182.982122898102 PathPoint;PointKind.SMOOTHPOINT 414.185482263565,188.826098442078 429.738260507584,190.139157772064 398.633058071136,187.513039112091 PathPoint;PointKind.SMOOTHPOINT 444.560630321503,188.826098442078 456.211051940918,188.599269390106 427.063754796982,189.166696071625 PathPoint;PointKind.SMOOTHPOINT 467.000066041946,189.000055789948 471.478110551834,189.240338802338 458.099917173386,188.522322177887 PathPoint;PointKind.SMOOTHPOINT 482.553906440735,181.680629253387 490.768257379532,182.023587226868 475.838963985443,181.400456428528 PathPoint;PointKind.SMOOTHPOINT 503.000031709671,181.999983787537 514.252145290375,182.367017269135 494.93438243866,181.737041473389 PathPoint;PointKind.SMOOTHPOINT 527.999968528748,180.99990606308 536.935522556305,180.959780216217 522.79541015625,181.023509502411 PathPoint;PointKind.SMOOTHPOINT 563.000092506409,183.999903202057 584.704163074493,185.236959457397 541.295667886734,182.76308298111 PathPoint;PointKind.SMOOTHPOINT 605.296157598495,178.26780796051 611.959054470062,177.429885864258 598.633614778519,179.105966091156 PathPoint;PointKind.SMOOTHPOINT 630.000107288361,177.000067234039 632.422174215317,175.54633140564 614.889539480209,186.068508625031 PathPoint;PointKind.SMOOTHPOINT 650.522353649139,176.64790391922 653.672350645065,177.492198944092 646.397298574448,175.542554855347 PathPoint;PointKind.SMOOTHPOINT 659.868607521057,181.237120628357 662.095237970352,180.9250831604 655.672742128372,181.8248462677 PathPoint;PointKind.SMOOTHPOINT 665.709750652313,175.500776767731 675.136020183563,174.448535442352 662.566480636597,175.85152387619 PathPoint;PointKind.SMOOTHPOINT 683.233888149261,178.942394256592 686.629242897034,179.359939098358 678.905961513519,178.41037273407 PathPoint;PointKind.SMOOTHPOINT 696.084898710251,176.64790391922 708.429261445999,177.642788887024 690.657641887665,176.210532188416 PathPoint;PointKind.SMOOTHPOINT 715.945422649384,183.531610965729 734.473650455475,187.815871238708 697.417548894882,179.247350692749 PathPoint;PointKind.SMOOTHPOINT 763.01268696785,187.445769309998 802.108833789825,187.445769309998 723.916894197464,187.445769309998 PathPoint;PointKind.SMOOTHPOINT 849.464650154114,186.298642158508 883.924137353897,185.559146404266 815.00551700592,187.03813791275 PathPoint;PointKind.SMOOTHPOINT 961.618634462357,187.445769309998 1009.35824275017,186.052222251892 913.879380226135,188.839552402496 PathPoint;PointKind.SMOOTHPOINT 1195,188 1238.97426962852,187.874429702759 1151.02537631989,188.125570297241 PathPoint;PointKind.SMOOTHPOINT 1377.52303719521,186.298642158508 1400.01204013824,186.043252944946 1355.03368020058,186.55403137207 PathPoint;PointKind.SMOOTHPOINT 1475.65764069557,184.004151821136 1493.74755263329,181.745538711548 1457.56772875786,186.262764930725 PathPoint;PointKind.SMOOTHPOINT 1520.0518155098,177.120444774628 1536.86395525932,175.78944683075 1503.23967576027,178.451442718506 PathPoint;PointKind.SMOOTHPOINT 1539.91269350052,180.562298297882 1556.38246536255,182.395341396332 1523.4425675869,178.729491233826 PathPoint;PointKind.SMOOTHPOINT 1569.11947131157,175.973317623138 1581.71627283096,171.357192993164 1556.38813018799,180.638537406921 PathPoint;PointKind.SMOOTHPOINT 1602.99902200699,173.678827285767 1602.99902200699,173.678827285767 1591.94588541985,175.674734115601 PathPoint;PointKind.SMOOTHPOINT 1621.69152975082,177.120444774628 1645.49512624741,181.091251373291 1597.88793325424,173.149874210358 PathPoint;PointKind.SMOOTHPOINT 1669.59046125412,179.415171146393 1690.24052023888,180.078427791595 1648.94040226936,178.75191450119 PathPoint;PointKind.SMOOTHPOINT 1705.8071064949,175.973317623138 1716.64073109627,170.752472877502 1694.97312784195,181.194162368774 PathPoint;PointKind.SMOOTHPOINT 1737.35027074814,174.825954437256 1747.80541419983,175.861201286316 1726.89512729645,173.790707588196 PathPoint;PointKind.SMOOTHPOINT 1760.71555137634,180.562298297882 1772.29799509048,180.383148193359 1749.13346171379,180.741684436798 PathPoint;PointKind.SMOOTHPOINT 1782.91281580925,179.415171146393 1797.71252632141,178.505258560181 1768.11310529709,180.324847698212 PathPoint;PointKind.CORNERPOINT 1816.79272055626,178.26780796051 1816.79272055626,178.26780796051 1816.79272055626,178.26780796051 PathPoint;PointKind.SMOOTHPOINT 1826.13897442818,172.531464099884 1832.20387816429,166.436820030212 1820.07371664047,178.626344203949 PathPoint;PointKind.CORNERPOINT 1838.98963093758,173.678827285767 1838.98963093758,173.678827285767 1838.98963093758,173.678827285767 PathPoint;PointKind.SMOOTHPOINT 1845.99949836731,174.825954437256 1853.81235480309,168.959791660309 1838.18664193153,180.692353248596 PathPoint;PointKind.SMOOTHPOINT 1862.35526561737,172.531464099884 1871.13539099693,172.621157169342 1853.57478618622,172.442007064819 PathPoint;PointKind.SMOOTHPOINT 1879.87940311432,174.825954437256 1882.70367264748,174.999439716339 1861.930757761,173.723673820496 PathPoint;PointKind.SMOOTHPOINT 1889.22530293465,185.151278972626 1906.07674241066,187.595415115356 1886.07849240303,184.695024490356 PathPoint;PointKind.SMOOTHPOINT 1925.44194817543,177.120444774628 1925.72943806648,169.627532958984 1925.1994228363,183.434600830078 PathPoint;PointKind.SMOOTHPOINT 1935.95621824265,171.384336948395 1940.08162736893,176.036102771759 1931.83080911636,166.732571125031 PathPoint;PointKind.SMOOTHPOINT 1951.14361524582,177.120444774628 1960.9781062603,177.250499725342 1941.30912423134,176.990625858307 PathPoint;PointKind.SMOOTHPOINT 1972.17250943184,177.120444774628 1979.32824611664,169.999523162842 1965.01677274704,184.241602420807 PathPoint;PointKind.SMOOTHPOINT 1993.20140361786,172.531464099884 2001.87672972679,176.085433959961 1984.52607750893,168.9777302742 PathPoint;PointKind.SMOOTHPOINT 2010.72554111481,175.973317623138 2016.32486701012,171.805422306061 2005.12586116791,180.140976905823 PathPoint;PointKind.SMOOTHPOINT 2022.40818142891,173.678827285767 2039.41186308861,173.149874210358 2005.40449976921,174.207544326782 PathPoint;PointKind.SMOOTHPOINT 2044.60544586182,174.825954437256 2052.36802697182,173.929731845856 2036.84286475182,175.722413063049 PathPoint;PointKind.SMOOTHPOINT 2060.96121311188,177.120444774628 2072.63004541397,178.716037273407 2049.29202675819,175.525088310242 PathPoint;PointKind.SMOOTHPOINT 2079.65336680412,177.120444774628 2096.81247711182,172.719819545746 2062.49461054802,181.521306037903 PathPoint;PointKind.SMOOTHPOINT 2103.01900148392,173.678827285767 2120.49746632576,170.192127227783 2085.54053664207,177.165291309357 PathPoint;PointKind.SMOOTHPOINT 2121.71115517616,173.678827285767 2133.30705285072,176.762144565582 2110.1152575016,170.595510005951 PathPoint;PointKind.SMOOTHPOINT 2145.07643580437,175.973317623138 2157.18358397484,175.520603656769 2132.96964168549,176.426031589508 PathPoint;PointKind.CORNERPOINT 2159.09581661224,178.26780796051 2159.09581661224,178.26780796051 2159.09581661224,178.26780796051 PathPoint;PointKind.SMOOTHPOINT 2173.11519742012,171.384336948395 2190.07780909538,170.46993970871 2156.15223169327,172.298498153687 PathPoint;PointKind.SMOOTHPOINT 2187.13422417641,177.120444774628 2195.19916534424,175.805733203888 2167.88550138474,180.258758068085 PathPoint;PointKind.SMOOTHPOINT 2202.32197523117,170.236973762512 2207.3735833168,175.695505142212 2197.27001309395,164.778678417206 PathPoint;PointKind.SMOOTHPOINT 2230.36038279533,174.825954437256 2250.76862454414,173.140904903412 2209.95214104652,176.5110039711 PathPoint;PointKind.SMOOTHPOINT 2266.57667398453,177.120444774628 2278.45581293106,176.927840709686 2254.69788908958,177.313284873962 PathPoint;PointKind.SMOOTHPOINT 2285.26918172836,175.973317623138 2293.08628678322,176.076464653015 2277.45172262192,175.870170593262 PathPoint;PointKind.SMOOTHPOINT 2302.79296517372,175.973317623138 2323.63952279091,174.803531169891 2281.94676160812,177.142868041992 PathPoint;PointKind.CORNERPOINT 2355.36537766457,174.825954437256 2355.36537766457,174.825954437256 2355.36537766457,174.825954437256 PathPoint;PointKind.CORNERPOINT 2370.55277466774,171.384336948395 2370.55277466774,171.384336948395 2370.55277466774,171.384336948395 PathPoint;PointKind.SMOOTHPOINT 2381.06704473495,174.825954437256 2379.19163346291,168.798344135284 2382.94281005859,180.853564739227 PathPoint;PointKind.CORNERPOINT 2389.24492835999,171.384336948395 2389.24492835999,171.384336948395 2389.24492835999,171.384336948395 PathPoint;PointKind.SMOOTHPOINT 2399.75955247879,175.973317623138 2405.69664359093,174.4362616539 2393.82246136665,177.510373592377 PathPoint;PointKind.CORNERPOINT 2412.61056303978,178.26780796051 2412.61056303978,178.26780796051 2412.61056303978,178.26780796051 PathPoint;PointKind.SMOOTHPOINT 2423.12483310699,177.120444774628 2428.89339566231,168.753733634949 2417.35662460327,185.4873919487 PathPoint;PointKind.SMOOTHPOINT 2433.6394572258,174.825954437256 2438.70947599411,176.340823173523 2428.56943845749,173.311321735382 PathPoint;PointKind.CORNERPOINT 2448.82685422897,174.825954437256 2448.82685422897,174.825954437256 2448.82685422897,174.825954437256 PathPoint;PointKind.SMOOTHPOINT 2457.004737854,174.825954437256 2464.47062373161,174.973948001862 2449.53885197639,174.678196907043 PathPoint;PointKind.SMOOTHPOINT 2472.19213485718,175.973317623138 2479.32521224022,174.23445224762 2465.05941152573,177.712182998657 PathPoint;PointKind.CORNERPOINT 2488.54825615883,178.26780796051 2488.54825615883,178.26780796051 2488.54825615883,178.26780796051 PathPoint;PointKind.SMOOTHPOINT 2501.39891266823,175.973317623138 2510.26613473892,175.870170593262 2492.53204464912,176.076464653015 PathPoint;PointKind.SMOOTHPOINT 2514.24992322922,178.26780796051 2527.8950715065,181.31076335907 2500.60512900352,175.224852561951 PathPoint;PointKind.SMOOTHPOINT 2536.44718766212,179.415171146393 2548.92396569252,178.079688549042 2523.97040963173,180.750653743744 PathPoint;PointKind.SMOOTHPOINT 2553.97132515907,181.709661483765 2563.0527484417,185.151278972626 2544.88990187645,178.26780796051 PathPoint;PointKind.SMOOTHPOINT 2571.49510860443,181.709661483765 2577.46902108192,173.311321735382 2565.52155017853,190.107765197754 PathPoint;PointKind.SMOOTHPOINT 2586.68285965919,178.26780796051 2592.03116297722,183.03617477417 2581.33420228958,173.499441146851 PathPoint;PointKind.SMOOTHPOINT 2597.19712972641,178.26780796051 2607.4971985817,175.977802276611 2586.89741492271,180.557813644409 PathPoint;PointKind.CORNERPOINT 2612.38488078117,182.856788635254 2612.38488078117,182.856788635254 2612.38488078117,182.856788635254 PathPoint;PointKind.CORNERPOINT 2626.40390753746,187.445769309998 2626.40390753746,187.445769309998 2626.40390753746,187.445769309998 PathPoint;PointKind.SMOOTHPOINT 2632.24540472031,177.120444774628 2640.37761569023,177.183229923248 2624.11319375038,177.0578956604 PathPoint;PointKind.CORNERPOINT 2647.43280172348,184.004151821136 2647.43280172348,184.004151821136 2647.43280172348,184.004151821136 PathPoint;PointKind.SMOOTHPOINT 2656.7790555954,180.562298297882 2663.4373497963,177.156322002411 2650.1207613945,183.968274593353 PathPoint;PointKind.CORNERPOINT 2668.4616959095,179.415171146393 2668.4616959095,179.415171146393 2668.4616959095,179.415171146393 PathPoint;PointKind.SMOOTHPOINT 2676.63957953453,182.856788635254 2689.52245473862,184.895889759064 2663.75670433044,180.817687511444 PathPoint;PointKind.SMOOTHPOINT 2692.99534678459,179.415171146393 2700.29235005379,171.057193279266 2685.6983435154,187.772912979126 PathPoint;PointKind.SMOOTHPOINT 2712.85587072372,174.825954437256 2733.27331781387,176.09888792038 2692.43877768517,173.553256988525 PathPoint;PointKind.SMOOTHPOINT 2772.43779659271,177.120444774628 2784.85969662666,176.242160797119 2760.01589655876,177.99896478653 PathPoint;PointKind.SMOOTHPOINT 2791.12995028496,177.120444774628 2796.15004777908,179.016273021698 2786.11020684242,175.224852561951 PathPoint;PointKind.SMOOTHPOINT 2802.81294465065,182.856788635254 2813.46883535385,181.763477325439 2792.15705394745,183.950335979462 PathPoint;PointKind.SMOOTHPOINT 2826.17822527885,178.26780796051 2837.94300556183,179.41068649292 2814.41344499588,177.124929428101 PathPoint;PointKind.SMOOTHPOINT 2843.7023627758,179.415171146393 2849.85400915146,179.661591053009 2837.55071640015,179.168515205383 PathPoint;PointKind.SMOOTHPOINT 2854.21663284302,178.26780796051 2863.84117126465,181.480944156647 2844.59209442139,175.054671764374 PathPoint;PointKind.SMOOTHPOINT 2864.73125696182,184.004151821136 2870.61347007751,184.358203411102 2858.84868979454,183.650100231171 PathPoint;PointKind.SMOOTHPOINT 2877.58226752281,178.26780796051 2887.52155780792,175.973317623138 2867.64262318611,180.562298297882 PathPoint;PointKind.CORNERPOINT 2890.43292403221,179.415171146393 2890.43292403221,179.415171146393 2890.43292403221,179.415171146393 PathPoint;PointKind.SMOOTHPOINT 2899.77917790413,178.26780796051 2910.70450186729,175.480241775513 2888.85420799255,181.055374145508 PathPoint;PointKind.CORNERPOINT 2919.63970184326,180.562298297882 2919.63970184326,180.562298297882 2919.63970184326,180.562298297882 PathPoint;PointKind.SMOOTHPOINT 2927.81758546829,177.120444774628 2937.05904006958,174.476387500763 2918.57648491859,179.764738082886 PathPoint;PointKind.SMOOTHPOINT 2947.67846345901,179.415171146393 2955.97955703735,180.436964035034 2939.37736988068,178.393378257751 PathPoint;PointKind.SMOOTHPOINT 2964.03423070908,180.562298297882 2981.55801415443,181.62445306778 2946.51009321213,179.500143527985 PathPoint;PointKind.SMOOTHPOINT 2981.55801415443,180.562298297882 2995.66413760185,173.020055294037 2967.45224475861,188.104541301727 PathPoint;PointKind.CORNERPOINT 3001.41889214516,178.26780796051 3001.41889214516,178.26780796051 3001.41889214516,178.26780796051 PathPoint;PointKind.SMOOTHPOINT 3007.26003527641,186.298642158508 3016.28455782221,182.659848504179 3003.30317016751,187.894096718706 PathPoint;PointKind.SMOOTHPOINT 3018.94267559052,179.415171146393 3024.17272567749,178.007934093475 3013.71297955513,180.822172164917 PathPoint;PointKind.CORNERPOINT 3025.95254302025,180.562298297882 3025.95254302025,180.562298297882 3025.95254302025,180.562298297882 PathPoint;PointKind.SMOOTHPOINT 3031.7936861515,184.004151821136 3039.78463053703,181.265916824341 3023.80309581757,186.742386817932 PathPoint;PointKind.SMOOTHPOINT 3043.47632646561,178.26780796051 3048.06837558746,176.979060173035 3035.84616065025,180.40958404541 PathPoint;PointKind.SMOOTHPOINT 3056.3273370266,177.120444774628 3069.43078637123,180.411944389343 3051.89638137817,176.007542610168 PathPoint;PointKind.SMOOTHPOINT 3068.01033139229,184.004151821136 3078.08663964272,184.376142024994 3068.01033139229,184.004151821136 PathPoint;PointKind.CORNERPOINT 3085.53411483765,178.26780796051 3085.53411483765,178.26780796051 3085.53411483765,178.26780796051 PathPoint;PointKind.SMOOTHPOINT 3093.71199846268,177.120444774628 3116.29093050957,183.818628787994 3086.25531792641,174.908566474915 PathPoint;PointKind.CORNERPOINT 3118.24564933777,184.004151821136 3118.24564933777,184.004151821136 3118.24564933777,184.004151821136 PathPoint;PointKind.SMOOTHPOINT 3127.59190320969,175.973317623138 3132.35637545586,171.800937652588 3122.82743096352,180.145461559296 PathPoint;PointKind.SMOOTHPOINT 3135.76978683472,179.415171146393 3149.65675234795,177.425401210785 3135.76978683472,179.415171146393 PathPoint;PointKind.CORNERPOINT 3169.64969158173,179.415171146393 3169.64969158173,179.415171146393 3169.64969158173,179.415171146393 PathPoint;PointKind.CORNERPOINT 3181.33233189583,174.825954437256 3181.33233189583,174.825954437256 3181.33233189583,174.825954437256 PathPoint;PointKind.SMOOTHPOINT 3195.3517127037,177.120444774628 3208.75008702278,180.723745822906 3181.95298433304,173.517379760742 PathPoint;PointKind.CORNERPOINT 3218.71699333191,182.856788635254 3218.71699333191,182.856788635254 3218.71699333191,182.856788635254 PathPoint;PointKind.CORNERPOINT 3233.90439033508,178.26780796051 3233.90439033508,178.26780796051 3233.90439033508,178.26780796051 PathPoint;PointKind.SMOOTHPOINT 3247.92377114296,177.120444774628 3259.9261200428,174.534687995911 3235.92177629471,179.706437587738 PathPoint;PointKind.SMOOTHPOINT 3263.11116814613,178.26780796051 3275.38259625435,180.517451763153 3250.83974003792,176.018164157867 PathPoint;PointKind.CORNERPOINT 3289.981559515,179.415171146393 3289.981559515,179.415171146393 3289.981559515,179.415171146393 PathPoint;PointKind.SMOOTHPOINT 3296.99107289314,174.825954437256 3302.58615016937,174.74995136261 3291.3963496685,174.902193546295 PathPoint;PointKind.SMOOTHPOINT 3325.02948045731,175.973317623138 3344.41097259521,173.875916004181 3305.64834237099,178.070719242096 PathPoint;PointKind.SMOOTHPOINT 3354.23625826836,177.120444774628 3364.46339249611,178.348531723022 3344.00947809219,175.892593860626 PathPoint;PointKind.SMOOTHPOINT 3376.43352270126,174.825954437256 3383.3198261261,172.957270145416 3369.54721927643,176.694874763489 PathPoint;PointKind.CORNERPOINT 3388.11616301537,177.120444774628 3388.11616301537,177.120444774628 3388.11616301537,177.120444774628 PathPoint;PointKind.CORNERPOINT 3405.64030051231,177.120444774628 3405.64030051231,177.120444774628 3405.64030051231,177.120444774628 PathPoint;PointKind.SMOOTHPOINT 3413.81818413734,172.531464099884 3436.92506134533,171.495170017328 3405.25089626182,172.915776098577 PathPoint;PointKind.SMOOTHPOINT 3445.36134839058,174.825954437256 3451.88262462616,180.011157989502 3438.840072155,169.640986919403 PathPoint;PointKind.SMOOTHPOINT 3458.21235895157,179.415171146393 3467.97851800919,175.471272468567 3448.44655394554,183.358833789825 PathPoint;PointKind.SMOOTHPOINT 3473.40011000633,174.825954437256 3489.29029941559,176.981656551361 3457.50956654549,172.670488357544 PathPoint;PointKind.SMOOTHPOINT 3492.09226369858,175.973317623138 3508.12867641449,169.623048305511 3476.05585098267,182.323586940765 PathPoint;PointKind.CORNERPOINT 3508.44803094864,172.531464099884 3508.44803094864,172.531464099884 3508.44803094864,172.531464099884 PathPoint;PointKind.SMOOTHPOINT 3516.62591457367,178.26780796051 3521.32630348206,179.764738082886 3511.92552566528,176.771113872528 PathPoint;PointKind.SMOOTHPOINT 3529.47692513466,174.825954437256 3540.73966026306,164.442565441132 3518.21419000626,185.209579467773 PathPoint;PointKind.CORNERPOINT 3547.00106263161,171.384336948395 3547.00106263161,171.384336948395 3547.00106263161,171.384336948395 PathPoint;PointKind.SMOOTHPOINT 3556.34731650352,170.236973762512 3563.10580730438,166.916205883026 3549.58847165108,173.557741641998 PathPoint;PointKind.SMOOTHPOINT 3570.36634325981,169.089846611023 3578.62176418304,170.528240203857 3562.11092233658,167.651216983795 PathPoint;PointKind.SMOOTHPOINT 3587.89048075676,170.236973762512 3599.00274395943,171.335005760193 3576.77821755409,169.138941764832 PathPoint;PointKind.SMOOTHPOINT 3603.07787775993,172.531464099884 3611.69407725334,167.933514118195 3594.46203231812,177.129414081573 PathPoint;PointKind.SMOOTHPOINT 3620.60201525688,165.647993087769 3630.555113554,166.454758644104 3610.64891695976,164.841227531433 PathPoint;PointKind.SMOOTHPOINT 3635.78941226006,170.236973762512 3647.66855120659,172.011716365814 3623.91062736511,168.462467193604 PathPoint;PointKind.CORNERPOINT 3680.18394112587,167.94248342514 3680.18394112587,167.94248342514 3680.18394112587,167.94248342514 PathPoint;PointKind.SMOOTHPOINT 3703.54922175407,169.089846611023 3721.54778838158,168.637132644653 3685.55065512657,169.542324542999 PathPoint;PointKind.SMOOTHPOINT 3729.25124287605,171.384336948395 3733.6779499054,169.972615242004 3724.82453584671,172.795822620392 PathPoint;PointKind.SMOOTHPOINT 3764.29916381836,164.500629901886 3793.58808159828,163.985366821289 3735.01024603844,165.016129016876 PathPoint;PointKind.SMOOTHPOINT 3809.86170887947,170.236973762512 3818.40497374535,170.971984863281 3801.31879806519,169.501962661743 PathPoint;PointKind.CORNERPOINT 3832.05897331238,162.206139564514 3832.05897331238,162.206139564514 3832.05897331238,162.206139564514 PathPoint;PointKind.CORNERPOINT 3843.74161362648,166.795356273651 3843.74161362648,166.795356273651 3843.74161362648,166.795356273651 PathPoint;PointKind.SMOOTHPOINT 3861.26575112343,166.795356273651 3877.11026787758,170.806052684784 3845.42088031769,162.784423828125 PathPoint;PointKind.SMOOTHPOINT 3878.78988862038,165.647993087769 3885.3203701973,162.896304130554 3872.25940704346,168.399682044983 PathPoint;PointKind.SMOOTHPOINT 3895.14565587044,171.384336948395 3904.18600916862,173.208174705505 3886.10530257225,169.560263156891 PathPoint;PointKind.SMOOTHPOINT 3913.83780956268,166.795356273651 3928.05793762207,163.59543800354 3899.6176815033,169.995038509369 PathPoint;PointKind.CORNERPOINT 3933.69833350182,167.94248342514 3933.69833350182,167.94248342514 3933.69833350182,167.94248342514 PathPoint;PointKind.SMOOTHPOINT 3940.70820093155,167.94248342514 3945.75095772743,164.379780292511 3935.66544413567,171.50518655777 PathPoint;PointKind.SMOOTHPOINT 3979.26087856293,166.795356273651 4005.62462210655,169.416990280151 3952.89748907089,164.173486232758 PathPoint;PointKind.CORNERPOINT 4008.46765637398,174.825954437256 4008.46765637398,174.825954437256 4008.46765637398,174.825954437256 PathPoint;PointKind.SMOOTHPOINT 4016.64553999901,169.089846611023 4024.89671230316,162.264440059662 4008.39472174644,175.915017127991 PathPoint;PointKind.SMOOTHPOINT 4033.00130724907,165.647993087769 4037.73851752281,166.459243297577 4028.26445102692,164.83674287796 PathPoint;PointKind.CORNERPOINT 4048.18905830383,166.795356273651 4048.18905830383,166.795356273651 4048.18905830383,166.795356273651 PathPoint;PointKind.SMOOTHPOINT 4054.03020143509,162.206139564514 4072.88002835557,162.526488303584 4052.76587367848,162.184664745701 PathPoint;PointKind.SMOOTHPOINT 4076.227465868,171.384336948395 4087.62261629105,170.492362976074 4064.83231544495,172.276074886322 PathPoint;PointKind.SMOOTHPOINT 4089.07847642899,167.94248342514 4094.99751091003,161.507005691528 4083.15944194794,174.377961158752 PathPoint;PointKind.SMOOTHPOINT 4108.93900036812,163.353502750397 4121.77160024643,166.423366069794 4096.10640048981,160.283639431 PathPoint;PointKind.SMOOTHPOINT 4133.47265124321,165.647993087769 4140.38196802139,163.254840373993 4126.56333446503,168.041145801544 PathPoint;PointKind.SMOOTHPOINT 4150.99678874016,159.911649227142 4160.50271987915,160.624237060547 4141.49085760117,159.199061393738 PathPoint;PointKind.SMOOTHPOINT 4173.19405317307,163.353502750397 4186.47842288017,165.517938137054 4159.90932941437,161.188831329346 PathPoint;PointKind.CORNERPOINT 4201.23246073723,161.059012413025 4201.23246073723,161.059012413025 4201.23246073723,161.059012413025 PathPoint;PointKind.SMOOTHPOINT 4215.25148749352,159.911649227142 4226.86579585075,160.646660327911 4203.63753318787,159.176638126373 PathPoint;PointKind.SMOOTHPOINT 4225.76611161232,171.384336948395 4225.19254803658,175.44294834137 4226.90226316452,163.344533443451 PathPoint;PointKind.SMOOTHPOINT 4238.61712217331,172.531464099884 4244.54500794411,173.789527416229 4232.57381558418,171.249089241028 PathPoint;PointKind.CORNERPOINT 4249.13139224052,180.562298297882 4249.13139224052,180.562298297882 4249.13139224052,180.562298297882 PathPoint;PointKind.SMOOTHPOINT 4257.30927586555,167.94248342514 4260.19798278809,159.140996932983 4254.42056894302,176.744205951691 PathPoint;PointKind.SMOOTHPOINT 4271.32865667343,162.206139564514 4282.92455434799,167.059714794159 4259.73275899887,157.352800369263 PathPoint;PointKind.SMOOTHPOINT 4287.68442392349,163.353502750397 4300.54463982582,160.597329139709 4274.82420802116,166.109676361084 PathPoint;PointKind.CORNERPOINT 4323.90071511269,161.059012413025 4323.90071511269,161.059012413025 4323.90071511269,161.059012413025 PathPoint;PointKind.SMOOTHPOINT 4336.75172567368,156.470031738281 4351.73377275467,157.460432052612 4321.76967859268,155.47963142395 PathPoint;PointKind.SMOOTHPOINT 4354.27586317062,161.059012413025 4360.34536957741,164.308025836945 4348.20635676384,157.809998989105 PathPoint;PointKind.SMOOTHPOINT 4370.63163042068,159.911649227142 4391.19034409523,154.354691505432 4350.07291674614,165.468842983246 PathPoint;PointKind.CORNERPOINT 4388.15576791763,162.206139564514 4388.15576791763,162.206139564514 4388.15576791763,162.206139564514 PathPoint;PointKind.SMOOTHPOINT 4399.83840823174,156.470031738281 4412.77616143227,154.256029129028 4386.9006550312,158.683798313141 PathPoint;PointKind.SMOOTHPOINT 4415.02580523491,162.206139564514 4426.14727377892,165.110306739807 4403.9043366909,159.302208423615 PathPoint;PointKind.SMOOTHPOINT 4434.88632917404,162.206139564514 4456.92851901054,160.45405626297 4412.84449338913,163.958458900452 PathPoint;PointKind.SMOOTHPOINT 4465.26147723198,156.470031738281 4483.72562170029,155.506303310394 4446.79733276367,157.433524131775 PathPoint;PointKind.SMOOTHPOINT 4494.46825504303,157.617158889771 4514.15069103241,162.089774608612 4474.78546500206,153.144779205322 PathPoint;PointKind.SMOOTHPOINT 4535.35767316818,159.911649227142 4560.85894703865,160.924472808838 4509.85639929771,158.898825645447 PathPoint;PointKind.SMOOTHPOINT 4577.41546154022,159.911649227142 4583.10153007507,157.912909984589 4571.72939300537,161.910388469696 PathPoint;PointKind.SMOOTHPOINT 4586.76171541214,162.206139564514 4592.48885393143,164.886074066162 4581.03422284126,159.526205062866 PathPoint;PointKind.SMOOTHPOINT 4599.61272597313,163.353502750397 4619.71046447754,163.676161766052 4579.51463341713,163.030843734741 PathPoint;PointKind.SMOOTHPOINT 4625.31439304352,158.764522075653 4642.65159130096,156.214406490326 4607.97754883766,161.314401626587 PathPoint;PointKind.SMOOTHPOINT 4652.18478441238,157.617158889771 4663.07328701019,161.063497066498 4641.29592776299,154.170820713043 PathPoint;PointKind.SMOOTHPOINT 4679.05482172966,157.617158889771 4689.28195595741,158.638951778412 4668.8280415535,156.595366001129 PathPoint;PointKind.SMOOTHPOINT 4694.24257278442,163.353502750397 4707.18457460403,166.746025085449 4681.30021691322,159.960980415344 PathPoint;PointKind.SMOOTHPOINT 4712.93472647667,162.206139564514 4738.60028028488,159.768376350403 4687.26917266846,164.644138813019 PathPoint;PointKind.SMOOTHPOINT 4740.97313404083,164.500629901886 4748.72226119041,165.894412994385 4733.22436094284,163.107082843781 PathPoint;PointKind.SMOOTHPOINT 4764.33876872063,167.94248342514 4777.80582904816,176.264584064484 4750.8717083931,159.620382785797 PathPoint;PointKind.SMOOTHPOINT 4783.03092241287,163.353502750397 4794.5220208168,158.943672180176 4771.53982400894,167.763333320618 PathPoint;PointKind.SMOOTHPOINT 4802.89144635201,163.353502750397 4827.31109261513,167.552554607391 4778.47215414047,159.154214859009 PathPoint;PointKind.SMOOTHPOINT 4836.77135109901,166.795356273651 4849.82310891151,169.457352161407 4823.71959328651,164.133360385895 PathPoint;PointKind.CORNERPOINT 4861.30500197411,169.089846611023 4861.30500197411,169.089846611023 4861.30500197411,169.089846611023 PathPoint;PointKind.SMOOTHPOINT 4877.66076922417,162.206139564514 4893.28187942505,160.987257957458 4862.04001307487,163.425257205963 PathPoint;PointKind.SMOOTHPOINT 4903.36279034615,165.647993087769 4913.24295401573,169.394567012787 4893.48262667656,161.90141916275 PathPoint;PointKind.SMOOTHPOINT 4917.38217115402,165.647993087769 4923.14117431641,161.605668067932 4911.62281394005,169.690318107605 PathPoint;PointKind.SMOOTHPOINT 4931.40119791031,166.795356273651 4938.27404737473,166.804089546204 4924.52870249748,166.786386966705 PathPoint;PointKind.SMOOTHPOINT 4939.57908153534,166.795356273651 4952.94594526291,168.879067897797 4926.21257185936,164.711408615112 PathPoint;PointKind.SMOOTHPOINT 4964.11273241043,169.089846611023 4989.61860895157,168.39519739151 4938.60720992088,169.784495830536 PathPoint;PointKind.SMOOTHPOINT 5002.6657640934,166.795356273651 5013.44026207924,170.098185539246 4991.89126610756,163.492290973663 PathPoint;PointKind.SMOOTHPOINT 5023.69465827942,170.236973762512 5028.78769040108,173.078355789185 5018.60162615776,167.395827770233 PathPoint;PointKind.CORNERPOINT 5040.05042552948,178.26780796051 5040.05042552948,178.26780796051 5040.05042552948,178.26780796051 PathPoint;PointKind.SMOOTHPOINT 5042.38716602325,170.236973762512 5044.06486958891,167.979372632023 5038.59674355009,175.337239235799 PathPoint;PointKind.SMOOTHPOINT 5051.73306584358,166.795356273651 5068.53053740119,164.9832065915 5050.0645128914,166.97534723288 PathPoint;PointKind.SMOOTHPOINT 5063.41570615768,175.973317623138 5071.74441576004,178.680160045624 5055.08735060692,173.266475200653 PathPoint;PointKind.SMOOTHPOINT 5078.60345721245,172.531464099884 5082.46403574944,164.720377922058 5074.74252462387,180.342786312103 PathPoint;PointKind.SMOOTHPOINT 5097.29561090469,164.500629901886 5113.97993803024,166.320219039917 5080.61128377914,162.681276798248 PathPoint;PointKind.SMOOTHPOINT 5117.15648889542,166.795356273651 5123.81442904472,168.444528579712 5110.49819469452,165.145947933197 PathPoint;PointKind.SMOOTHPOINT 5133.51225614548,171.384336948395 5155.78210115433,163.980882167816 5111.24205708504,178.78755569458 PathPoint;PointKind.SMOOTHPOINT 5168.56017708778,167.94248342514 5181.03695511818,165.276002883911 5156.08339905739,170.60896396637 PathPoint;PointKind.SMOOTHPOINT 5181.41118764877,164.500629901886 5190.75744152069,163.371441364288 5172.06493377686,165.630054473877 PathPoint;PointKind.SMOOTHPOINT 5193.09382796288,169.089846611023 5200.93394637108,172.526979446411 5185.25370955467,165.652477741241 PathPoint;PointKind.SMOOTHPOINT 5209.44959521294,173.678827285767 5218.4626865387,168.928399085999 5200.43650388718,178.429255485535 PathPoint;PointKind.SMOOTHPOINT 5233.98324608803,169.089846611023 5246.28653883934,166.911721229553 5221.67995333672,171.267735958099 PathPoint;PointKind.SMOOTHPOINT 5249.17099714279,165.647993087769 5253.76623272896,160.664598941803 5244.57540750504,170.631387233734 PathPoint;PointKind.SMOOTHPOINT 5263.19002389908,165.647993087769 5269.88938808441,164.948859214783 5256.49065971375,166.347126960754 PathPoint;PointKind.SMOOTHPOINT 5279.54579114914,165.647993087769 5296.32606625557,168.265142440796 5262.7658700943,163.030843734741 PathPoint;PointKind.SMOOTHPOINT 5313.42569589615,170.236973762512 5319.58194494247,168.440043926239 5307.26944684982,172.034139633179 PathPoint;PointKind.SMOOTHPOINT 5333.28621983528,167.94248342514 5353.96849751472,166.033437252045 5312.60429620743,169.851529598236 PathPoint;PointKind.SMOOTHPOINT 5355.48348426819,162.206139564514 5370.51120400429,157.567827701569 5340.45576453209,166.84445142746 PathPoint;PointKind.SMOOTHPOINT 5391.69977545738,159.911649227142 5404.08981084824,161.507005691528 5379.30974006653,158.316292762756 PathPoint;PointKind.CORNERPOINT 5411.56029939651,166.795356273651 5411.56029939651,166.795356273651 5411.56029939651,166.795356273651 PathPoint;PointKind.SMOOTHPOINT 5418.57016682625,161.059012413025 5441.01668357849,165.581667423248 5410.74704289436,159.482774734497 PathPoint;PointKind.SMOOTHPOINT 5452.45007157326,157.617158889771 5465.02244353294,155.121095180511 5439.87734556198,160.113458633423 PathPoint;PointKind.SMOOTHPOINT 5471.1422252655,162.206139564514 5479.54386949539,167.691578865051 5462.74058103561,156.72093629837 PathPoint;PointKind.SMOOTHPOINT 5486.32962226868,164.500629901886 5495.60187935829,164.527537822723 5471.64710283279,164.45814371109 PathPoint;PointKind.CORNERPOINT 5502.68538951874,163.353502750397 5502.68538951874,163.353502750397 5502.68538951874,163.353502750397 PathPoint;PointKind.CORNERPOINT 5507.3585164547,175.973317623138 5507.3585164547,175.973317623138 5507.3585164547,175.973317623138 PathPoint;PointKind.SMOOTHPOINT 5534.22890782356,174.825954437256 5546.5137898922,173.23059797287 5521.94367170334,176.421546936035 PathPoint;PointKind.CORNERPOINT 5547.07991838455,174.825954437256 5547.07991838455,174.825954437256 5547.07991838455,174.825954437256 PathPoint;PointKind.SMOOTHPOINT 5561.09894514084,172.531464099884 5572.88673877716,168.53847026825 5549.31150555611,176.524457931519 PathPoint;PointKind.SMOOTHPOINT 5579.79145288467,174.825954437256 5598.47440123558,177.78370141983 5561.10815048218,171.868207454681 PathPoint;PointKind.SMOOTHPOINT 5607.82986044884,172.531464099884 5622.42882370949,172.132565975189 5593.23089718819,172.930362224579 PathPoint;PointKind.SMOOTHPOINT 5628.85875463486,171.384336948395 5638.88939023018,167.135717868805 5618.82811903954,175.632719993591 PathPoint;PointKind.SMOOTHPOINT 5652.22403526306,172.531464099884 5664.42713141441,171.240828037262 5640.0212931633,173.822100162506 PathPoint;PointKind.CORNERPOINT 5660.40191888809,186.298642158508 5660.40191888809,186.298642158508 5660.40191888809,186.298642158508 PathPoint;PointKind.SMOOTHPOINT 5667.41178631783,195.476603507996 5678.25001358986,201.898627281189 5656.5732049942,189.054815769196 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,217.274615764618 5673.68664264679,223.701124191284 5675.15595674515,210.848107337952 PathPoint;PointKind.CORNERPOINT 5675.58966994286,244.808735847473 5675.58966994286,244.808735847473 5675.58966994286,244.808735847473 PathPoint;PointKind.CORNERPOINT 5675.58966994286,265.459384918213 5675.58966994286,265.459384918213 5675.58966994286,265.459384918213 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,284.96267080307 5673.73337745667,309.301121234894 5673.02846074104,273.594074249268 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,353.798325061798 5671.70607805252,364.746544361115 5674.01838898659,297.9075050354 PathPoint;PointKind.SMOOTHPOINT 5681.43081307411,384.774298667908 5681.06118321419,403.860747814178 5681.80044293404,365.687613487244 PathPoint;PointKind.SMOOTHPOINT 5684.93556976318,457.051334381104 5680.46354413033,473.740382194519 5689.40794944763,440.362286567688 PathPoint;PointKind.SMOOTHPOINT 5684.93556976318,479.996473789215 5684.34253334999,490.259249210358 5685.52896022797,469.733934402466 PathPoint;PointKind.SMOOTHPOINT 5677.92605638504,502.941613197327 5673.44022274017,514.74592924118 5682.41189002991,491.137533187866 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,539.653930664062 5671.92948460579,574.076242446899 5679.24950122833,505.231854915619 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,577.513375282288 5670.91194033623,586.046254634857 5675.59427261353,568.980731964111 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,611.931202411652 5666.97347044945,622.274465560913 5670.1861345768,601.58793926239 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,645.201666355133 5673.57421659305,681.408920284191 5674.93064588896,623.415342673974 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,708.300740718842 5671.26776218414,723.398916721344 5667.58368838655,686.795421839034 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,745.013058185577 5669.04538035393,760.796914100647 5670.45096516609,729.229202270508 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,777.136158943176 5670.29589056969,795.788068771362 5671.53719544411,758.484485149384 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,818.437457084656 5668.33798527718,830.429892539978 5668.82161974907,806.445021629333 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,847.118940353394 5671.72873735428,867.052516937256 5670.10399460793,827.185363769531 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,878.094913959503 5669.15017962456,886.399075984955 5668.00942540169,869.790751934052 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,901.040053367615 5671.85654997826,909.595119953156 5672.31292247772,892.484986782074 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,917.101721763611 5671.64210146987,925.376693344982 5665.73383880746,909.411333229172 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,934.310517311096 5672.68255233765,942.708857059479 5673.82330656052,925.912177562714 PathPoint;PointKind.SMOOTHPOINT 5667.41178631783,958.40301990509 5669.61115479469,992.148385047913 5667.41178631783,958.40301990509 PathPoint;PointKind.SMOOTHPOINT 5667.41178631783,999.70431804657 5666.28199463333,1007.42478150638 5668.37059514008,993.151986594475 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,1014.61862325668 5668.47500324249,1019.33765888214 5668.68495583534,1009.89958763123 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,1029.5329284668 5671.29962682724,1039.50868606567 5672.86949157715,1019.55717086792 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,1044.44723367691 5665.30801177025,1054.31559562683 5671.85194730759,1034.57910776138 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,1065.09788274765 5669.35588359833,1075.89385986328 5670.14081597328,1054.30214166641 PathPoint;PointKind.SMOOTHPOINT 5666.24341607094,1085.74853181839 5665.1299238205,1091.92862033844 5667.35690832138,1079.56867933273 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,1102.95732736588 5669.62956547737,1112.11310148239 5674.53990697861,1093.80178928375 PathPoint;PointKind.CORNERPOINT 5668.57980251312,1116.7245054245 5668.57980251312,1116.7245054245 5668.57980251312,1116.7245054245 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,1127.04982995987 5673.18920016289,1132.87138223648 5670.98027229309,1121.22851371765 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,1138.52251768112 5666.93700313568,1152.5313949585 5672.55934238434,1124.51340436935 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,1162.61478424072 5668.32417726517,1171.8600153923 5668.83542776108,1153.36955308914 PathPoint;PointKind.SMOOTHPOINT 5667.41178631783,1200.47422885895 5661.70270442963,1211.40923023224 5673.12051415443,1189.53946352005 PathPoint;PointKind.SMOOTHPOINT 5667.41178631783,1232.59756565094 5667.73114085197,1243.91329050064 5667.09207773209,1221.28184080124 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,1256.68983221054 5674.90953683853,1263.93207550049 5676.26944899559,1249.44782495499 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1269.30988311768 5675.74474453926,1279.61726903915 5673.09785485268,1259.0024971962 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,1288.81316900253 5673.39915275574,1309.32030916214 5673.10706019402,1268.30602884293 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,1316.34728908539 5667.84974813461,1326.22910499573 5676.31972432137,1306.46570920944 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,1345.02877235413 5668.00482273102,1361.13528728485 5673.82790923119,1328.9222574234 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,1372.56289243698 5670.72464704514,1380.20379781723 5671.10808491707,1364.92198705673 PathPoint;PointKind.CORNERPOINT 5670.9165430069,1398.94988536835 5670.9165430069,1398.94988536835 5670.9165430069,1398.94988536835 PathPoint;PointKind.SMOOTHPOINT 5667.41178631783,1409.27520990372 5666.78653120995,1418.42177867889 5668.03668737411,1400.12840509415 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,1427.63136863708 5670.69278240204,1439.15315151215 5666.46682262421,1416.10934972763 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,1445.98752737045 5674.21594977379,1452.85305976868 5672.28990912437,1439.12175893784 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1470.07979393005 5674.13841247559,1481.94241046906 5674.70418691635,1458.21741342545 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1493.02493333817 5673.11591148376,1509.68707323074 5675.72633385658,1476.36279344559 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1518.26456308365 5675.89061379433,1530.80389022827 5672.95163154602,1505.72547197342 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1541.20993852615 5672.4725997448,1548.68491172791 5676.36999964714,1533.73472929001 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1559.56586122513 5675.45725464821,1574.17993068695 5673.38534474373,1544.95179176331 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,1593.98368835449 5668.23318600655,1606.19563579559 5673.59990000725,1581.77174091339 PathPoint;PointKind.SMOOTHPOINT 5676.75768613815,1615.78146457672 5677.21405863762,1627.51402616501 5676.30131363869,1604.04913902283 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1636.43211364746 5677.08624601364,1650.04232883453 5671.75599932671,1622.82189846039 PathPoint;PointKind.SMOOTHPOINT 5676.75768613815,1663.96646976471 5675.29297471046,1680.27007341385 5678.22275161743,1647.66286611557 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,1690.35322666168 5667.57606625557,1699.16840314865 5671.92027926445,1681.53828620911 PathPoint;PointKind.SMOOTHPOINT 5677.92605638504,1723.62369060516 5674.60823893547,1738.19314956665 5681.24387383461,1709.05446767807 PathPoint;PointKind.SMOOTHPOINT 5676.75768613815,1750.01068353653 5676.30131363869,1761.19186878204 5677.21405863762,1738.82949829102 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1777.54480361938 5676.7031621933,1792.5577712059 5672.13943719864,1762.53183603287 PathPoint;PointKind.CORNERPOINT 5677.92605638504,1799.34281587601 5677.92605638504,1799.34281587601 5677.92605638504,1799.34281587601 PathPoint;PointKind.CORNERPOINT 5674.42129969597,1808.52077722549 5674.42129969597,1808.52077722549 5674.42129969597,1808.52077722549 PathPoint;PointKind.CORNERPOINT 5679.09442663193,1815.404484272 5679.09442663193,1815.404484272 5679.09442663193,1815.404484272 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,1849.82207536697 5672.24883913994,1864.4361448288 5678.93014669418,1835.20800590515 PathPoint;PointKind.SMOOTHPOINT 5676.75768613815,1872.76721477509 5681.33521914482,1891.0157418251 5672.18050718307,1854.51868772507 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,1904.89055156708 5671.09427690506,1913.5487651825 5675.4115819931,1896.23233795166 PathPoint;PointKind.CORNERPOINT 5672.08455920219,1923.24671030045 5672.08455920219,1923.24671030045 5672.08455920219,1923.24671030045 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,1930.13018131256 5670.69278240204,1946.83716773987 5668.80356311798,1913.42319488525 PathPoint;PointKind.CORNERPOINT 5669.74817276001,1955.36981105804 5669.74817276001,1955.36981105804 5669.74817276001,1955.36981105804 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,1964.54777240753 5677.43321657181,1972.80283927917 5673.74576926231,1956.29294157028 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,1977.16782331467 5669.50175285339,1995.52374601364 5674.66771960258,1958.8116645813 PathPoint;PointKind.CORNERPOINT 5673.25292944908,2005.84907054901 5673.25292944908,2005.84907054901 5673.25292944908,2005.84907054901 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,2017.32175827026 5676.3607943058,2032.94416666031 5670.14506459236,2001.69934988022 PathPoint;PointKind.CORNERPOINT 5676.75768613815,2044.85587835312 5676.75768613815,2044.85587835312 5676.75768613815,2044.85587835312 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,2051.73934936523 5671.28479139678,2062.05854718943 5674.61980680788,2044.57282967951 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,2073.53736162186 5670.56496977806,2078.99589300156 5671.26776218414,2068.07883024216 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,2085.00981330872 5676.68475151062,2092.90634393692 5672.15784788132,2077.1135187149 PathPoint;PointKind.SMOOTHPOINT 5667.41178631783,2091.89352035522 5667.1834230423,2109.53709125519 5667.63979554176,2074.24994945526 PathPoint;PointKind.SMOOTHPOINT 5680.26244282722,2109.10231590271 5682.12900280952,2111.75982713699 5678.39623689651,2106.44480466843 PathPoint;PointKind.CORNERPOINT 5674.42129969597,2133.1948184967 5674.42129969597,2133.1948184967 5674.42129969597,2133.1948184967 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,2149.25625085831 5672.28105783463,2163.71807813644 5676.56154155731,2134.79465961456 PathPoint;PointKind.CORNERPOINT 5675.58966994286,2168.75977277756 5675.58966994286,2168.75977277756 5675.58966994286,2168.75977277756 PathPoint;PointKind.CORNERPOINT 5680.26244282722,2187.11593151093 5680.26244282722,2187.11593151093 5680.26244282722,2187.11593151093 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,2199.73574638367 5674.23400640488,2215.658390522 5676.94497942924,2183.81310224533 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,2230.71171998978 5669.37394022942,2247.91154623032 5679.46865916252,2213.51165771484 PathPoint;PointKind.CORNERPOINT 5670.9165430069,2255.95134973526 5670.9165430069,2255.95134973526 5670.9165430069,2255.95134973526 PathPoint;PointKind.SMOOTHPOINT 5667.41178631783,2273.16014528275 5670.40529251099,2297.83069610596 5664.41792607307,2248.48959445953 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,2309.87246274948 5668.04589271545,2318.4813451767 5676.12357974052,2301.26358032227 PathPoint;PointKind.SMOOTHPOINT 5667.41178631783,2325.93389511108 5669.41040754318,2334.79391813278 5665.41281104088,2317.07410812378 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,2338.55394601822 5671.28617286682,2364.67185974121 5668.2101726532,2312.43579626083 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,2372.97153711319 5667.81788349152,2384.49804067612 5671.6784620285,2361.44526958466 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,2397.06403970718 5674.84053072735,2406.78137415817 5671.67220457517,2387.38877990899 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,2420.0091791153 5671.01553347589,2428.65182514086 5666.27832011076,2411.84165347062 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,2445.24880886078 5662.25467085838,2463.56012105942 5674.90493416786,2426.93749666214 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,2483.108253479 5667.80867815018,2498.2243680954 5676.3607943058,2467.992374897 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,2515.231590271 5673.28479409218,2521.66234731674 5673.22106480598,2508.80059719086 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,2538.17672967911 5675.50292730331,2550.81448316574 5671.00328564644,2525.53897619247 PathPoint;PointKind.SMOOTHPOINT 5679.09442663193,2561.12186908722 5680.45433878899,2572.17772006989 5677.73451447487,2550.06601810455 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,2585.21413564682 5671.62854075432,2605.79326629639 5677.21405863762,2564.63524103165 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,2627.66279697418 5671.65120005608,2642.23201990128 5672.5182723999,2613.09357404709 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,2654.04978990555 5679.58726644516,2671.62609100342 5669.25533294678,2636.47325277328 PathPoint;PointKind.SMOOTHPOINT 5676.75768613815,2694.20372486115 5673.54849370618,2704.74275044126 5679.22223925591,2686.11101317413 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,2718.29599142075 5671.40938282013,2730.46781301498 5672.76008963585,2706.1244058609 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,2740.09400367737 5674.37562704086,2746.65033102036 5674.46697235107,2733.53767633438 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,2757.30279922485 5661.7108476162,2785.83392858505 5676.6256248951,2755.17329692841 PathPoint;PointKind.SMOOTHPOINT 5677.92605638504,2806.63493156433 5679.60992574692,2820.34829378128 5676.24218702316,2792.92156934738 PathPoint;PointKind.SMOOTHPOINT 5679.09442663193,2839.90539550781 5679.15815591812,2850.03811597824 5679.03034329414,2829.77291107178 PathPoint;PointKind.SMOOTHPOINT 5677.92605638504,2865.1450252533 5678.13140630722,2871.1008810997 5677.72070646286,2859.18916940689 PathPoint;PointKind.SMOOTHPOINT 5676.75768613815,2888.09016466141 5676.13703370094,2905.51870822906 5677.37833857536,2870.66185712814 PathPoint;PointKind.SMOOTHPOINT 5680.26244282722,2925.94984531403 5679.27676320076,2936.03299856186 5681.24847650528,2915.8664560318 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,2952.336602211 5673.50395202637,2962.02109336853 5677.67503380775,2942.65211105347 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,2975.28174161911 5674.80013489723,2988.35875511169 5674.04246449471,2962.20496416092 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,3005.11058807373 5676.59340620041,3023.26045274734 5672.24883913994,2986.96048736572 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,3040.67554235458 5667.9984498024,3046.81243658066 5674.13310170174,3025.29577732086 PathPoint;PointKind.CORNERPOINT 5675.58966994286,3059.03170108795 5675.58966994286,3059.03170108795 5675.58966994286,3059.03170108795 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,3079.68235015869 5680.26704549789,3102.87084102631 5672.17059373856,3062.73248434067 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,3122.13077545166 5673.19380283356,3140.75577735901 5670.97566962242,3103.50577354431 PathPoint;PointKind.CORNERPOINT 5674.42129969597,3153.10674905777 5674.42129969597,3153.10674905777 5674.42129969597,3153.10674905777 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,3164.57920074463 5671.03515028954,3172.69972801208 5673.13432216644,3156.45890951157 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,3177.19925165176 5674.89166460121,3182.32439365641 5673.66823196411,3168.99351596832 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,3223.08953046799 5675.06000876427,3229.12587404251 5673.45590786722,3213.9704552989 PathPoint;PointKind.CORNERPOINT 5670.9165430069,3238.0038356781 5670.9165430069,3238.0038356781 5670.9165430069,3238.0038356781 PathPoint;PointKind.SMOOTHPOINT 5666.24341607094,3265.53795576096 5667.16076374054,3292.5433588028 5665.32606840134,3238.53255271912 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,3306.83925390244 5670.70659041405,3316.6179227829 5668.78975510597,3297.06058502197 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,3334.37337398529 5670.11780261993,3340.0962638855 5671.71492934227,3328.65048408508 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,3365.3493475914 5673.3580827713,3371.69513225555 5673.14813017845,3359.00356292725 PathPoint;PointKind.SMOOTHPOINT 5680.26244282722,3383.70550632477 5683.2835650444,3399.12634134293 5677.24167466164,3368.28467130661 PathPoint;PointKind.SMOOTHPOINT 5679.09442663193,3405.503282547 5678.7885260582,3414.27361249924 5679.39997315407,3396.73318862915 PathPoint;PointKind.SMOOTHPOINT 5677.92605638504,3437.62661933899 5674.47617769241,3446.94360494614 5681.37628912926,3428.30963373184 PathPoint;PointKind.SMOOTHPOINT 5681.43081307411,3455.98277807236 5681.03392124176,3467.38371133804 5681.82805895805,3444.58184480667 PathPoint;PointKind.CORNERPOINT 5677.92605638504,3476.6334271431 5677.92605638504,3476.6334271431 5677.92605638504,3476.6334271431 PathPoint;PointKind.SMOOTHPOINT 5677.92605638504,3501.87305688858 5672.99730420113,3515.79247713089 5682.85480856895,3487.95363664627 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,3530.55454015732 5672.77850031853,3538.51361989975 5669.05458569527,3522.59546041489 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,3554.64680671692 5673.14352750778,3561.17197751999 5675.69907188416,3548.12187194824 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,3568.41398477554 5686.21971487999,3574.51500177383 5661.35821223259,3560.24625062943 PathPoint;PointKind.SMOOTHPOINT 5684.93556976318,3587.9172706604 5682.87534356117,3596.84952020645 5685.90602517128,3583.71113777161 PathPoint;PointKind.SMOOTHPOINT 5680.26244282722,3601.68444871902 5677.60670185089,3614.51032161713 5682.91853785515,3588.85857582092 PathPoint;PointKind.CORNERPOINT 5679.09442663193,3636.10227584839 5679.09442663193,3636.10227584839 5679.09442663193,3636.10227584839 PathPoint;PointKind.SMOOTHPOINT 5676.00001573563,3651.00005865097 5675.29368281364,3651.84718608856 5680.8101606369,3645.23232221603 PathPoint;PointKind.SMOOTHPOINT 5677.57979393005,3671.51994466782 5676.30662441254,3696.49970054626 5677.1651995182,3679.65463399887 PathPoint;PointKind.SMOOTHPOINT 5678.00005316734,3697.99993515015 5671.04046106339,3708.26271057129 5684.95929121971,3687.7373957634 PathPoint;PointKind.SMOOTHPOINT 5678.99989485741,3718.00007343292 5681.07994794846,3726.71823978424 5676.98675751686,3709.56137180328 PathPoint;PointKind.SMOOTHPOINT 5678.00005316734,3731.99998140335 5677.39179253578,3736.44828557968 5679.30083870888,3722.49228000641 PathPoint;PointKind.SMOOTHPOINT 5676.75768613815,3741.64977550507 5687.07120895386,3751.53843641281 5673.37613940239,3738.40737104416 PathPoint;PointKind.SMOOTHPOINT 5679.75013017654,3760.0000333786 5679.76818680763,3763.87642621994 5679.73171949387,3756.12364053726 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,3777.21496582031 5661.71190977097,3779.7558760643 5680.12117624283,3774.67381954193 PathPoint;PointKind.SMOOTHPOINT 5655.72879195213,3776.06760263443 5649.67769622803,3776.22008085251 5661.78024172783,3775.91512441635 PathPoint;PointKind.SMOOTHPOINT 5648.71927857399,3780.65658330917 5640.24469971657,3781.69183015823 5657.19385743141,3779.62133646011 PathPoint;PointKind.SMOOTHPOINT 5634.69989776611,3777.21496582031 5627.86847233772,3776.99970245361 5641.53167724609,3777.42999315262 PathPoint;PointKind.SMOOTHPOINT 5625.35399794579,3781.80394649506 5616.85215711594,3782.40441799164 5633.85583877563,3781.20347499847 PathPoint;PointKind.SMOOTHPOINT 5607.82986044884,3774.92023944855 5603.31641077995,3775.08617162704 5612.34331011772,3774.75454330444 PathPoint;PointKind.SMOOTHPOINT 5596.14722013474,3779.50945615768 5585.30863881111,3780.17719745636 5606.98544740677,3778.84171485901 PathPoint;PointKind.CORNERPOINT 5576.2866961956,3780.65658330917 5576.2866961956,3780.65658330917 5576.2866961956,3780.65658330917 PathPoint;PointKind.SMOOTHPOINT 5559.93092894554,3777.21496582031 5549.99128460884,3777.21496582031 5569.87021923065,3777.21496582031 PathPoint;PointKind.SMOOTHPOINT 5534.22890782356,3780.65658330917 5522.47758150101,3780.29804706573 5545.97988009453,3781.01511955261 PathPoint;PointKind.SMOOTHPOINT 5505,3773 5502.17094587521,3772.43329674858 5512.40122807649,3774.48236335763 PathPoint;PointKind.SMOOTHPOINT 5485.16160607338,3773.77311229706 5466.98362751554,3775.63280534753 5491.6268746156,3773.11160141952 PathPoint;PointKind.CORNERPOINT 5454.78645801544,3778.3620929718 5454.78645801544,3778.3620929718 5454.78645801544,3778.3620929718 PathPoint;PointKind.SMOOTHPOINT 5438.43069076538,3777.21496582031 5426.84824705124,3779.96193408966 5450.01313447952,3774.46776151657 PathPoint;PointKind.CORNERPOINT 5420.90655326843,3781.80394649506 5420.90655326843,3781.80394649506 5420.90655326843,3781.80394649506 PathPoint;PointKind.SMOOTHPOINT 5413.89703989029,3772.62574911118 5400.6261241436,3772.79168128967 5427.16795563698,3772.46005296707 PathPoint;PointKind.CORNERPOINT 5396.37290239334,3776.06760263443 5396.37290239334,3776.06760263443 5396.37290239334,3776.06760263443 PathPoint;PointKind.SMOOTHPOINT 5387.02664852142,3780.65658330917 5377.55293607712,3781.23014688492 5396.50071501732,3780.08301973343 PathPoint;PointKind.SMOOTHPOINT 5367.16612458229,3776.06760263443 5349.53718781471,3776.11244916916 5384.79506134987,3776.0227560997 PathPoint;PointKind.SMOOTHPOINT 5342.6324737072,3781.80394649506 5333.85234832764,3783.59190702438 5351.41259908676,3780.01574993134 PathPoint;PointKind.SMOOTHPOINT 5311.08930945396,3782.95107364655 5305.64470410347,3782.91519641876 5316.53356075287,3782.98695087433 PathPoint;PointKind.CORNERPOINT 5298.23829889297,3784.09843683243 5298.23829889297,3784.09843683243 5298.23829889297,3784.09843683243 PathPoint;PointKind.SMOOTHPOINT 5284.2189180851,3786.3929271698 5275.48871397972,3783.97735118866 5292.94912219048,3788.80850315094 PathPoint;PointKind.SMOOTHPOINT 5262.02200770378,3784.09843683243 5249.91025686264,3785.25004863739 5274.13340449333,3782.94658899307 PathPoint;PointKind.SMOOTHPOINT 5248.0026268959,3790.98190784454 5236.68501377106,3791.06263160706 5259.32024002075,3790.90118408203 PathPoint;PointKind.SMOOTHPOINT 5224.6373462677,3786.3929271698 5215.85027815321,3785.04051844946 5233.83141460419,3787.80798141832 PathPoint;PointKind.SMOOTHPOINT 5212.95435190201,3792.12927103043 5206.78925156593,3792.51023054123 5219.11980628967,3791.74831151962 PathPoint;PointKind.SMOOTHPOINT 5193.09382796288,3786.3929271698 5182.49195509716,3788.2362635889 5206.32801276354,3784.09191046826 PathPoint;PointKind.SMOOTHPOINT 5183.74757409096,3793.27639818192 5177.94750094414,3796.09087228775 5189.54800128937,3790.46216011047 PathPoint;PointKind.CORNERPOINT 5163.88705015182,3793.27639818192 5163.88705015182,3793.27639818192 5163.88705015182,3793.27639818192 PathPoint;PointKind.SMOOTHPOINT 5152.20440983772,3790.98190784454 5142.08242893219,3790.51597595215 5162.32639074326,3791.44807577133 PathPoint;PointKind.CORNERPOINT 5132.34388589859,3793.27639818192 5132.34388589859,3793.27639818192 5132.34388589859,3793.27639818192 PathPoint;PointKind.SMOOTHPOINT 5115.98811864853,3795.57088851929 5108.45814943314,3795.63367366791 5123.51808786392,3795.50833940506 PathPoint;PointKind.SMOOTHPOINT 5099.63235139847,3793.27639818192 5083.12115550041,3791.82903528214 5116.14319324493,3794.72399711609 PathPoint;PointKind.CORNERPOINT 5073.93033027649,3793.27639818192 5073.93033027649,3793.27639818192 5073.93033027649,3793.27639818192 PathPoint;PointKind.SMOOTHPOINT 5059.91094946861,3793.27639818192 5053.59042048454,3792.44744539261 5066.23147845268,3794.10558700562 PathPoint;PointKind.CORNERPOINT 5047.05993890762,3792.12927103043 5047.05993890762,3792.12927103043 5047.05993890762,3792.12927103043 PathPoint;PointKind.CORNERPOINT 5038.88205528259,3793.27639818192 5038.88205528259,3793.27639818192 5038.88205528259,3793.27639818192 PathPoint;PointKind.SMOOTHPOINT 5027.19941496849,3797.86537885666 5020.54572343826,3796.85727596283 5033.85310649872,3798.87371778488 PathPoint;PointKind.SMOOTHPOINT 5017.85351514816,3792.12927103043 5006.13865613937,3790.66821813583 5029.56802010536,3793.59008789062 PathPoint;PointKind.SMOOTHPOINT 4990.9831237793,3793.27639818192 4972.55084395409,3793.62148046494 5009.41540360451,3792.9313158989 PathPoint;PointKind.SMOOTHPOINT 4958.27158927917,3793.27639818192 4952.26120948792,3793.20912837982 4964.28161501884,3793.34366798401 PathPoint;PointKind.SMOOTHPOINT 4946.58894896507,3789.83478069305 4937.97735214233,3789.51660633087 4955.20019173622,3790.15295505524 PathPoint;PointKind.SMOOTHPOINT 4930.23318171501,3795.57088851929 4908.0221092701,3793.86790037155 4952.44390010834,3797.27387666702 PathPoint;PointKind.SMOOTHPOINT 4897.52164721489,3787.54029035568 4889.62529010395,3787.18011527995 4906.76413673621,3787.9615857723 PathPoint;PointKind.SMOOTHPOINT 4870.65125584602,3792.12927103043 4864.61821675301,3791.69898033142 4876.68429493904,3792.55932569504 PathPoint;PointKind.SMOOTHPOINT 4862.47337222099,3787.54029035568 4852.1276307106,3786.17341518402 4872.81911373138,3788.90692949295 PathPoint;PointKind.SMOOTHPOINT 4826.2570810318,3794.4237613678 4802.26654529572,3788.41857433319 4850.24761676788,3800.4289484024 PathPoint;PointKind.SMOOTHPOINT 4781.86290621758,3786.3929271698 4776.82900071144,3786.30771875381 4786.89645767212,3786.47813558578 PathPoint;PointKind.SMOOTHPOINT 4757.32890129089,3787.54029035568 4735.16526258663,3787.51400438505 4776.23596429825,3787.56247758865 PathPoint;PointKind.SMOOTHPOINT 4693.07420253754,3790.98190784454 4673.32080115006,3789.96015010048 4714.57710970962,3792.09415993176 PathPoint;PointKind.SMOOTHPOINT 4661.5310382843,3787.54029035568 4634.07185912132,3784.7661781311 4688.98986339569,3790.31416654587 PathPoint;PointKind.SMOOTHPOINT 4631.15589022636,3787.54029035568 4619.92962241173,3786.89922094345 4642.382158041,3788.18112373352 PathPoint;PointKind.SMOOTHPOINT 4603.1174826622,3788.68741750717 4589.91950154305,3793.71117353439 4616.31510972977,3783.66366147995 PathPoint;PointKind.SMOOTHPOINT 4575.07872104645,3793.27639818192 4558.18444132805,3792.64004945755 4591.97300076485,3793.91274690628 PathPoint;PointKind.SMOOTHPOINT 4540.03080010414,3789.83478069305 4529.58486199379,3787.65665531158 4550.47673821449,3792.01267004013 PathPoint;PointKind.SMOOTHPOINT 4497.9730117321,3785.24556398392 4456.20271325111,3785.48325061798 4539.74331021309,3785.00811338425 PathPoint;PointKind.SMOOTHPOINT 4434.88632917404,3782.95107364655 4419.28362965584,3782.7091383934 4450.48938274384,3783.19324493408 PathPoint;PointKind.SMOOTHPOINT 4413.85743498802,3784.09843683243 4403.62605214119,3786.65728569031 4424.08917188644,3781.53958797455 PathPoint;PointKind.SMOOTHPOINT 4375.30475735664,3785.24556398392 4361.52719378471,3785.71621656418 4389.08196687698,3784.77514743805 PathPoint;PointKind.SMOOTHPOINT 4354.27586317062,3781.80394649506 4338.39912772179,3780.21307468414 4370.15224456787,3783.39481830597 PathPoint;PointKind.CORNERPOINT 4330.91022849083,3780.65658330917 4330.91022849083,3780.65658330917 4330.91022849083,3780.65658330917 PathPoint;PointKind.CORNERPOINT 4322.7323448658,3787.54029035568 4322.7323448658,3787.54029035568 4322.7323448658,3787.54029035568 PathPoint;PointKind.CORNERPOINT 4312.21807479858,3784.09843683243 4312.21807479858,3784.09843683243 4312.21807479858,3784.09843683243 PathPoint;PointKind.SMOOTHPOINT 4299.36706423759,3781.80394649506 4295.21439313889,3788.35578918457 4303.52008938789,3775.25186777115 PathPoint;PointKind.SMOOTHPOINT 4286.51605367661,3780.65658330917 4274.52326416969,3783.04525136948 4298.50919723511,3778.26791524887 PathPoint;PointKind.SMOOTHPOINT 4271,3776 4268.24968367357,3777.73776744494 4279.53805083024,3770.60555597101 PathPoint;PointKind.SMOOTHPOINT 4252.6361489296,3776.06760263443 4245.59016823769,3781.10929727554 4259.6824836731,3771.02590799332 PathPoint;PointKind.SMOOTHPOINT 4233.94399523735,3778.3620929718 4216.4517223835,3775.71803569794 4251.43591403961,3781.00615024567 PathPoint;PointKind.SMOOTHPOINT 4205.90558767319,3780.65658330917 4195.50957083702,3784.60473060608 4216.30125045776,3776.70843601227 PathPoint;PointKind.SMOOTHPOINT 4189.54982042313,3780.65658330917 4170.88457465172,3775.44470787048 4208.21471214294,3785.86869478226 PathPoint;PointKind.SMOOTHPOINT 4162.67942905426,3779.50945615768 4154.19139623642,3780.28907775879 4171.16781592369,3778.72959852219 PathPoint;PointKind.SMOOTHPOINT 4135.80939173698,3781.80394649506 4117.01208472252,3783.89214277267 4154.60669875145,3779.71551418304 PathPoint;PointKind.SMOOTHPOINT 4111.27574086189,3782.95107364655 4106.37425065041,3782.13557481766 4116.17687702179,3783.76680850983 PathPoint;PointKind.SMOOTHPOINT 4085.57371973991,3781.80394649506 4058.67146372795,3778.1291270256 4112.47562170029,3785.47876596451 PathPoint;PointKind.SMOOTHPOINT 4048.18905830383,3780.65658330917 4032.87809729576,3780.85839271545 4063.49966526031,3780.45500993729 PathPoint;PointKind.SMOOTHPOINT 4014.30915355682,3781.80394649506 4006.08559727669,3784.71236228943 4022.53270983696,3778.89529466629 PathPoint;PointKind.SMOOTHPOINT 3986.27074599266,3784.09843683243 3979.04937019239,3783.92047405232 4000.81907987595,3784.45697307587 PathPoint;PointKind.SMOOTHPOINT 3881.12627506256,3782.95107364655 3822.15154767036,3782.45823383331 3927.08271498948,3783.33530620807 PathPoint;PointKind.SMOOTHPOINT 3816.8715763092,3787.54029035568 3808.05462956429,3787.24430322647 3825.68816900253,3787.8360414505 PathPoint;PointKind.SMOOTHPOINT 3794.6743118763,3787.54029035568 3787.01653003693,3785.28592586517 3802.33209371567,3789.7944188118 PathPoint;PointKind.SMOOTHPOINT 3779.48691487312,3790.98190784454 3770.81619143486,3794.24437522888 3788.15763831139,3787.71944046021 PathPoint;PointKind.SMOOTHPOINT 3768.97229075432,3787.54029035568 3757.41746306419,3788.01519155502 3780.52711844444,3787.06515312195 PathPoint;PointKind.SMOOTHPOINT 3756.12128019333,3793.27639818192 3749.87207723186,3794.69724716821 3765.7969284131,3791.07649604246 PathPoint;PointKind.SMOOTHPOINT 3742.10225343704,3786.3929271698 3732.89720360447,3788.81284928094 3751.79880050512,3783.84379500012 PathPoint;PointKind.SMOOTHPOINT 3725.74648618698,3789.83478069305 3719.26919399866,3788.89559150908 3732.70191355485,3790.84302670715 PathPoint;PointKind.SMOOTHPOINT 3698.87609481812,3788.68741750717 3683.99424433708,3788.57530117035 3713.75794529915,3788.79953384399 PathPoint;PointKind.SMOOTHPOINT 3662.65980362892,3785.24556398392 3650.14921844067,3786.65625142297 3676.64040217033,3783.66911856142 PathPoint;PointKind.SMOOTHPOINT 3636.95778250694,3789.83478069305 3614.08685741839,3792.56559937758 3648.34621223332,3788.47474944661 PathPoint;PointKind.SMOOTHPOINT 3566.86158657074,3787.54029035568 3558.92091751099,3787.53132104874 3576.18898457193,3787.55054877451 PathPoint;PointKind.SMOOTHPOINT 3531.81331157684,3788.68741750717 3518.25065732002,3792.62211084366 3545.37631988525,3784.75272417068 PathPoint;PointKind.SMOOTHPOINT 3510.78477144241,3790.98190784454 3504.13107991219,3790.57852506638 3517.43810892105,3791.38529062271 PathPoint;PointKind.SMOOTHPOINT 3481.57799363136,3787.54029035568 3471.56727752319,3785.57678317626 3492.84341925212,3789.74966434437 PathPoint;PointKind.SMOOTHPOINT 3455.87597250938,3789.83478069305 3443.45124829394,3788.72410969092 3468.19531959387,3790.93579689639 PathPoint;PointKind.SMOOTHPOINT 3426.66919469833,3788.68741750717 3412.50854730606,3788.60669374466 3440.82984209061,3788.76814126968 PathPoint;PointKind.SMOOTHPOINT 3403.30391407013,3787.54029035568 3393.98492217064,3786.35256528854 3412.62255191803,3788.72777938843 PathPoint;PointKind.SMOOTHPOINT 3378.76990914345,3788.68741750717 3358.8959312439,3789.87065792084 3398.64424109459,3787.5044131279 PathPoint;PointKind.SMOOTHPOINT 3340.21723151207,3796.71825170517 3320.52230639098,3793.35016183176 3357.72433749346,3799.71219960428 PathPoint;PointKind.SMOOTHPOINT 3304.00094032288,3787.54029035568 3283.84098140402,3783.54402511437 3323.33248939881,3791.37213393303 PathPoint;PointKind.SMOOTHPOINT 3279.46693539619,3790.98190784454 3263.81043181425,3791.18885982179 3288.28848481178,3790.86554288864 PathPoint;PointKind.SMOOTHPOINT 3244.41901445389,3789.83478069305 3226.74727944553,3790.88945297278 3261.61037120212,3788.80853941322 PathPoint;PointKind.SMOOTHPOINT 3196.519728899,3794.4237613678 3162.22027301788,3793.1779718399 3230.81953883171,3795.66955089569 PathPoint;PointKind.SMOOTHPOINT 3128.76027345657,3788.68741750717 3093.27945202809,3787.48481606873 3152.87068387344,3789.50462559541 PathPoint;PointKind.SMOOTHPOINT 3032.96205639839,3789.83478069305 2998.56465855097,3789.40530715444 3057.57238221315,3790.14186598869 PathPoint;PointKind.SMOOTHPOINT 2914.9665749073,3789.83478069305 2900.65533463298,3791.14383912639 2955.00125537646,3786.17217118249 PathPoint;PointKind.SMOOTHPOINT 2884.59178090096,3790.98190784454 2885.72493462991,3791.00144380594 2898.36438775063,3791.21935844421 PathPoint;PointKind.SMOOTHPOINT 2794.63506102562,3788.68741750717 2781.86883722796,3789.0603720966 2834.57875124017,3787.52049588491 PathPoint;PointKind.SMOOTHPOINT 2760.75515627861,3792.12927103043 2755.86287140846,3793.15106391907 2765.64708709717,3791.10747814178 PathPoint;PointKind.SMOOTHPOINT 2722.20212459564,3792.12927103043 2691.50301933289,3789.85720396042 2752.9012298584,3794.40133810043 PathPoint;PointKind.SMOOTHPOINT 2653.27429890633,3789.83478069305 2628.82278800011,3788.93383741379 2677.72580981255,3790.73548793793 PathPoint;PointKind.SMOOTHPOINT 2597.19712972641,3788.68741750717 2584.83471035957,3788.79056453705 2609.55990314484,3788.58427047729 PathPoint;PointKind.SMOOTHPOINT 2567.99035191536,3790.98190784454 2551.4933180809,3792.58623361588 2584.48773980141,3789.37758207321 PathPoint;PointKind.SMOOTHPOINT 2529.43767428398,3790.98190784454 2518.41215372086,3790.2917432785 2540.46319484711,3791.67207241058 PathPoint;PointKind.SMOOTHPOINT 2502.56728291512,3789.83478069305 2491.48688435555,3789.4627904892 2513.64768147469,3790.20653486252 PathPoint;PointKind.SMOOTHPOINT 2482.70675897598,3792.12927103043 2486.7137930071,3792.29310896944 2489.94003295898,3792.42502212524 PathPoint;PointKind.SMOOTHPOINT 2416.11531972885,3788.68741750717 2409.19254899025,3788.92935276031 2434.24975098968,3788.05365995787 PathPoint;PointKind.SMOOTHPOINT 2397.42316603661,3789.83478069305 2384.07931566238,3790.77584981918 2410.76666235924,3788.89347553253 PathPoint;PointKind.SMOOTHPOINT 2364.71127748489,3790.98190784454 2347.74866580963,3791.29559755325 2381.67424321175,3790.66821813583 PathPoint;PointKind.SMOOTHPOINT 2336.67286992073,3789.83478069305 2324.10049796104,3787.39229679108 2349.24559593201,3792.27702856064 PathPoint;PointKind.SMOOTHPOINT 2319.14873242378,3793.27639818192 2313.16136598587,3793.96207809448 2325.13609886169,3792.59071826935 PathPoint;PointKind.SMOOTHPOINT 2301.62494897842,3793.27639818192 2285.14597177505,3792.45641469955 2318.10392618179,3794.09661769867 PathPoint;PointKind.SMOOTHPOINT 2268.9134144783,3789.83478069305 2246.93991065025,3787.48647451401 2290.88691830635,3792.1830868721 PathPoint;PointKind.SMOOTHPOINT 2233.86513948441,3789.83478069305 2226.71860814095,3791.22384309769 2241.01167082787,3788.44548225403 PathPoint;PointKind.SMOOTHPOINT 2212.83624529839,3796.71825170517 2199.20237363898,3796.51975032659 2225.53451287142,3796.90314090173 PathPoint;PointKind.SMOOTHPOINT 2170.77845692635,3794.4237613678 2161.20419383049,3794.7060585022 2178.33260053172,3794.20102745384 PathPoint;PointKind.SMOOTHPOINT 2127.55265235901,3794.4237613678 2121.16804003716,3792.73422718048 2133.93691062927,3796.11329555511 PathPoint;PointKind.SMOOTHPOINT 2111.19688510895,3796.71825170517 2098.28179121017,3796.51219367981 2124.11162495613,3796.92430973053 PathPoint;PointKind.SMOOTHPOINT 2090.16799092293,3794.4237613678 2077.68200755119,3794.08316373825 2102.65362024307,3794.76435899734 PathPoint;PointKind.SMOOTHPOINT 2066.80235624313,3801.30723237991 2053.84654641151,3799.50133323669 2079.75852012634,3803.11336755753 PathPoint;PointKind.SMOOTHPOINT 2027.08130836487,3793.27639818192 2018.04095506668,3793.56317996979 2036.12166166306,3792.98961639404 PathPoint;PointKind.SMOOTHPOINT 2008.38880062103,3797.86537885666 1993.24707627296,3798.81565332413 2023.53087902069,3796.91534042358 PathPoint;PointKind.SMOOTHPOINT 1978.01400661469,3796.71825170517 1960.44798093409,3796.94243305095 1997.32221007347,3796.47183179855 PathPoint;PointKind.SMOOTHPOINT 1899.73992705345,3797.86537885666 1889.80948805809,3798.34500074387 1911.42236431494,3797.30139625417 PathPoint;PointKind.SMOOTHPOINT 1856.51376843452,3799.01274204254 1841.92861318588,3798.82462263107 1871.09892368317,3799.20086145401 PathPoint;PointKind.SMOOTHPOINT 1823.8022339344,3799.01274204254 1817.55924224854,3798.41227054596 1830.04522562027,3799.61321353912 PathPoint;PointKind.SMOOTHPOINT 1807.44646668434,3790.98190784454 1795.70894837379,3790.43973684311 1819.18398499489,3791.52431488037 PathPoint;PointKind.CORNERPOINT 1798.10021281242,3797.86537885666 1798.10021281242,3797.86537885666 1798.10021281242,3797.86537885666 PathPoint;PointKind.SMOOTHPOINT 1778.23968887329,3792.12927103043 1768.02175998688,3790.01841545105 1788.4576177597,3794.23989057541 PathPoint;PointKind.SMOOTHPOINT 1733.84551405907,3788.68741750717 1726.44335746765,3789.47624444962 1741.24767065048,3787.89859056473 PathPoint;PointKind.SMOOTHPOINT 1709.31186318398,3792.12927103043 1700.33523917198,3792.75216579437 1718.28813314438,3791.50637626648 PathPoint;PointKind.SMOOTHPOINT 1684.77821230888,3793.27639818192 1663.79499077797,3791.92746162415 1705.7614338398,3794.62533473969 PathPoint;PointKind.SMOOTHPOINT 1654.40306425095,3792.12927103043 1647.44807481766,3791.19717121124 1661.35805368423,3793.06137084961 PathPoint;PointKind.SMOOTHPOINT 1639.21566724777,3792.12927103043 1634.2642557621,3792.35775232315 1644.16707873344,3791.90055370331 PathPoint;PointKind.CORNERPOINT 1628.70104312897,3795.57088851929 1628.70104312897,3795.57088851929 1628.70104312897,3795.57088851929 PathPoint;PointKind.SMOOTHPOINT 1621.69152975082,3790.98190784454 1611.48740887642,3791.15680932999 1631.89565062523,3790.80724239349 PathPoint;PointKind.SMOOTHPOINT 1607.67214894295,3793.27639818192 1600.2427303791,3794.55806493759 1615.10156750679,3791.99473142624 PathPoint;PointKind.SMOOTHPOINT 1594.82113838196,3793.27639818192 1587.63353705406,3791.6361951828 1602.00873970985,3794.91660118103 PathPoint;PointKind.SMOOTHPOINT 1581.97048187256,3792.12927103043 1573.564234972,3792.50126123428 1590.37637472153,3791.75728082657 PathPoint;PointKind.SMOOTHPOINT 1565.61436057091,3789.83478069305 1554.91315126419,3789.38655138016 1576.31592392921,3790.28277397156 PathPoint;PointKind.SMOOTHPOINT 1548.09057712555,3789.83478069305 1537.4435377121,3790.70409536362 1558.73726248741,3788.9652299881 PathPoint;PointKind.SMOOTHPOINT 1531.73480987549,3785.24556398392 1511.02987289429,3784.41661119461 1552.4393928051,3786.07475280762 PathPoint;PointKind.SMOOTHPOINT 1506.03278875351,3792.12927103043 1500.43771147728,3793.23603630066 1511.62751197815,3791.0222697258 PathPoint;PointKind.SMOOTHPOINT 1485.00389456749,3792.12927103043 1462.71103620529,3792.49229192734 1507.29675292969,3791.76625013351 PathPoint;PointKind.SMOOTHPOINT 1448.7876033783,3792.12927103043 1415.17677783966,3788.69190216064 1482.39807486534,3795.56640386581 PathPoint;PointKind.SMOOTHPOINT 1402.0566880703,3793.27639818192 1389.79906797409,3792.35326766968 1414.3143081665,3794.19952869415 PathPoint;PointKind.SMOOTHPOINT 1368.17678332329,3793.27639818192 1347.41271972656,3793.05240154266 1388.94084692001,3793.50063085556 PathPoint;PointKind.SMOOTHPOINT 1328.45573544502,3794.4237613678 1317.90464401245,3794.30267572403 1339.006472826,3794.54461097717 PathPoint;PointKind.SMOOTHPOINT 1307.426841259,3793.27639818192 1283.02560567856,3791.70794963837 1331.82807683945,3794.84508275986 PathPoint;PointKind.SMOOTHPOINT 1257.19116926193,3788.68741750717 1245.18917441368,3786.14202260971 1269.19316411018,3791.23281240463 PathPoint;PointKind.SMOOTHPOINT 1232.65751838684,3787.54029035568 1225.90327620506,3788.52620601654 1239.41140651703,3786.55413866043 PathPoint;PointKind.SMOOTHPOINT 1201.11435413361,3788.68741750717 1192.01912283897,3788.51275205612 1210.20923137665,3788.86231899261 PathPoint;PointKind.SMOOTHPOINT 1166.06607913971,3793.27639818192 1149.51416730881,3793.859167099 1182.61799097061,3792.69386529922 PathPoint;PointKind.CORNERPOINT 1141.53242826462,3790.98190784454 1141.53242826462,3790.98190784454 1141.53242826462,3790.98190784454 PathPoint;PointKind.CORNERPOINT 1132.1861743927,3794.4237613678 1132.1861743927,3794.4237613678 1132.1861743927,3794.4237613678 PathPoint;PointKind.CORNERPOINT 1127.51304745674,3789.83478069305 1127.51304745674,3789.83478069305 1127.51304745674,3789.83478069305 PathPoint;PointKind.SMOOTHPOINT 1111.15728020668,3789.83478069305 1097.98231244087,3787.15933084488 1124.33224797249,3792.51023054123 PathPoint;PointKind.SMOOTHPOINT 1086.62362933159,3790.98190784454 1070.57376265526,3785.86421012878 1102.67385005951,3796.0998415947 PathPoint;PointKind.SMOOTHPOINT 1048.07059764862,3790.98190784454 1043.43429207802,3784.99017477036 1052.70725727081,3796.97364091873 PathPoint;PointKind.SMOOTHPOINT 1022.36893057823,3789.83478069305 1013.25528860092,3787.70150184631 1031.48221850395,3791.9678235054 PathPoint;PointKind.SMOOTHPOINT 994.330168962479,3794.4237613678 983.217905759811,3791.85594320297 1005.44243216515,3796.99157953262 PathPoint;PointKind.SMOOTHPOINT 966.291761398315,3793.27639818192 958.364900350571,3790.95051527023 974.21862244606,3795.6022810936 PathPoint;PointKind.SMOOTHPOINT 945.262867212296,3793.27639818192 935.588407516479,3788.93832206726 954.937680959702,3797.61447429657 PathPoint;PointKind.SMOOTHPOINT 926.57071352005,3793.27639818192 917.069385051727,3789.33273553848 936.072041988373,3797.22006082535 PathPoint;PointKind.SMOOTHPOINT 900.868692398071,3792.12927103043 882.176538705826,3792.03957796097 919.561200141907,3792.21872806549 PathPoint;PointKind.CORNERPOINT 871.661914587021,3794.4237613678 871.661914587021,3794.4237613678 871.661914587021,3794.4237613678 PathPoint;PointKind.SMOOTHPOINT 844.791877269745,3793.27639818192 832.52044916153,3792.08890914917 857.06330537796,3794.46412324905 PathPoint;PointKind.SMOOTHPOINT 816.753115653992,3790.98190784454 796.874535083771,3791.40771389008 836.632050275803,3790.55610179901 PathPoint;PointKind.SMOOTHPOINT 786.378321647644,3793.27639818192 764.87004160881,3792.87301540375 807.886247634888,3793.67978096008 PathPoint;PointKind.SMOOTHPOINT 760.676300525665,3794.4237613678 754.844008684158,3794.38788414001 766.508592367172,3794.45963859558 PathPoint;PointKind.SMOOTHPOINT 734.974279403687,3794.4237613678 727.704538106918,3792.76561975479 742.244020700455,3796.0819029808 PathPoint;PointKind.SMOOTHPOINT 715.113755464554,3794.4237613678 705.069311857224,3794.54461097717 725.158199071884,3794.30267572403 PathPoint;PointKind.SMOOTHPOINT 671.887596845627,3794.4237613678 665.270726680756,3793.79638195038 678.504821062088,3795.05114078522 PathPoint;PointKind.CORNERPOINT 633.334919214249,3794.4237613678 633.334919214249,3794.4237613678 633.334919214249,3794.4237613678 PathPoint;PointKind.SMOOTHPOINT 605.296157598495,3793.27639818192 584.705579280853,3794.01589393616 625.887089967728,3792.53690242767 PathPoint;PointKind.SMOOTHPOINT 555.060839653015,3790.98190784454 549.328744411469,3787.53580570221 560.792580842972,3794.42824602127 PathPoint;PointKind.SMOOTHPOINT 525.854061841965,3796.71825170517 516.882040500641,3802.99228191376 534.825729131699,3790.44422149658 PathPoint;PointKind.SMOOTHPOINT 514.171067476273,3792.12927103043 499.353300333023,3790.91015338898 528.989188671112,3793.34815263748 PathPoint";
	
	mask35mm[1] = "PointKind.CORNERPOINT 444.510904788972,3793.18292856217 444.510904788972,3793.18292856217 444.510904788972,3793.18292856217 PathPoint;PointKind.SMOOTHPOINT 400.112481355668,3790.88867425919 391.372363805772,3787.85468816757 408.852598905564,3793.92242431641 PathPoint;PointKind.SMOOTHPOINT 387.260408639909,3793.18292856217 380.546528339387,3788.10134410858 393.973934888841,3798.26498508453 PathPoint;PointKind.SMOOTHPOINT 360.259726285935,3794.90645170212 352.642306327821,3793.11849117279 367.87679219246,3796.69441223145 PathPoint;PointKind.SMOOTHPOINT 338.188504219056,3795.47741889954 332.903576135636,3792.17034101486 343.473786354066,3798.7847328186 PathPoint;PointKind.SMOOTHPOINT 324.256574153901,3797.9064488411 318.583251476289,3796.36939287186 329.929188728333,3799.44374084473 PathPoint;PointKind.CORNERPOINT 312.25564146042,3800.90644598007 312.25564146042,3800.90644598007 312.25564146042,3800.90644598007 PathPoint;PointKind.SMOOTHPOINT 299.254158973695,3801.90652370453 293.549325704575,3799.44633722305 304.959346294404,3804.36671018601 PathPoint;PointKind.SMOOTHPOINT 287.948229551316,3804.65538024902 279.011967420579,3804.24302816391 296.884845733643,3805.06773233414 PathPoint;PointKind.SMOOTHPOINT 272.251706361772,3800.90644598007 267.167525529862,3796.82375907898 277.335887193681,3804.98866081238 PathPoint;PointKind.SMOOTHPOINT 264.907614231111,3789.88859653473 259.93956232071,3787.60496377945 269.316972732545,3791.91542387009 PathPoint;PointKind.SMOOTHPOINT 259.065762996674,3780.71087121964 255.597119569779,3775.14045953751 262.53440642357,3786.28104686737 PathPoint;PointKind.SMOOTHPOINT 257.570249080659,3763.35526227951 257.647786378861,3756.78099632263 257.492711782456,3769.929292202 PathPoint;PointKind.SMOOTHPOINT 253.250111579896,3744.90775823593 254.738190412522,3732.84380435944 251.76238679886,3756.97147607803 PathPoint;PointKind.SMOOTHPOINT 257.055812120439,3716.31880044937 264.057182312013,3708.49449634552 250.054795980454,3724.14334058762 PathPoint;PointKind.SMOOTHPOINT 255.887795925141,3695.66862344742 255.671824455262,3690.11119365692 256.024459838868,3699.19592142105 PathPoint;PointKind.SMOOTHPOINT 260.5609228611,3687.63802528381 265.275473833085,3681.93354606629 255.846725940705,3693.34274053574 PathPoint;PointKind.SMOOTHPOINT 256.7290225029,3672.87147760391 256.573947906495,3667.64166355133 256.884097099305,3678.1010556221 PathPoint;PointKind.SMOOTHPOINT 261.402503490449,3659.10453557968 261.630512714387,3650.50037384033 261.174140214921,3667.70893335342 PathPoint;PointKind.SMOOTHPOINT 259.065762996674,3644.19070243836 262.758167028428,3638.01533460617 255.373713016511,3650.36607027054 PathPoint;PointKind.SMOOTHPOINT 258.738973379136,3626.83509349823 257.894206285478,3619.94265317917 259.583386421205,3633.7272977829 PathPoint;PointKind.SMOOTHPOINT 261.07535982132,3617.65736818314 262.759937286378,3612.1719288826 259.391490459443,3623.14233541489 PathPoint;PointKind.SMOOTHPOINT 259.907343626023,3606.18491649628 259.127013921739,3601.74392938614 260.687673330308,3610.62590360642 PathPoint;PointKind.SMOOTHPOINT 260.25077366829,3594.95841264725 258.662852287293,3585.292096138 261.839049100877,3604.6247291565 PathPoint;PointKind.SMOOTHPOINT 263.412454366685,3578.6515045166 264.151714086534,3573.50217819214 262.673194646836,3583.80035877228 PathPoint;PointKind.SMOOTHPOINT 264.580824613572,3567.17905282974 266.214772701264,3559.73122358322 262.94687652588,3574.62711811066 PathPoint;PointKind.SMOOTHPOINT 264.580824613572,3547.67623901367 264.366269350053,3540.5867099762 264.795025825501,3554.76576805115 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,3533.90953302384 266.456589937211,3528.31669807434 267.378540277482,3539.50236797333 PathPoint;PointKind.SMOOTHPOINT 262.251165151597,3515.96053361893 261.552621364594,3511.26392126083 262.94935488701,3520.65690994263 PathPoint;PointKind.SMOOTHPOINT 263.412454366685,3493.75654220581 261.280709743501,3486.69392108917 265.543490886689,3500.81916332245 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,3482.28432655335 266.15529203415,3476.08205080032 265.342743635179,3488.48660230637 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,3457.04516887665 271.887741327287,3443.78499269486 264.284129381181,3470.30581712723 PathPoint;PointKind.SMOOTHPOINT 263.412454366685,3440.98420858383 262.915011882783,3433.17312240601 263.909896850587,3448.79505872727 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,3403.12547206879 260.610136032105,3396.85167789459 270.888253688813,3409.39950227738 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,3392.80038356781 266.15529203415,3384.81014728546 265.342743635179,3400.79061985016 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,3369.85595226288 267.871380090714,3360.41386842728 265.963396072389,3379.29827213287 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,3342.3225402832 265.584560871125,3329.42514896393 265.913120746613,3355.21969556809 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,3322.81972646713 271.244075536729,3313.7987279892 271.937662601472,3331.84072494507 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,3309.0527844429 262.504312038423,3300.50243854523 271.33081817627,3317.60313034058 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,3299.87505912781 271.449425458909,3294.11652803421 271.732312679292,3305.63359022141 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,3289.54997062683 265.484364271165,3284.27554607391 266.013671398164,3294.82463121414 PathPoint;PointKind.SMOOTHPOINT 270.422675848008,3279.22488212586 270.532077789308,3268.27713489533 270.313273906709,3290.17286539078 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,3260.86919546127 268.724644422532,3254.62230920792 267.446872234345,3267.11631774902 PathPoint;PointKind.SMOOTHPOINT 262.244084119798,3252.83859729767 261.061905860902,3247.46551036835 263.426262378694,3258.21192026138 PathPoint;PointKind.SMOOTHPOINT 263.412454366685,3228.74680280686 262.791801929475,3223.07348012924 264.033106803895,3234.42012548447 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,3217.27458715439 269.062409639359,3211.66853427887 264.772366523744,3222.8808760643 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,3206.94949865341 267.040775060655,3200.02590179443 269.130741596223,3213.87333154678 PathPoint;PointKind.SMOOTHPOINT 270.422675848008,3196.62441015244 270.139788627625,3190.37752389908 270.705563068391,3202.87153244019 PathPoint;PointKind.SMOOTHPOINT 262.244084119798,3186.29955768585 261.312928438188,3180.35267114639 263.175239801408,3192.24620819092 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,3165.6493806839 266.365244627,3157.75332212448 269.806272029878,3173.54543924332 PathPoint;PointKind.SMOOTHPOINT 264.580824613572,3150.73531150818 265.913120746613,3143.68165969849 263.248174428941,3157.78919935227 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,3135.82147836685 264.594278573991,3130.77553510666 271.577238082887,3140.86718559265 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,3126.64351701737 271.467836141587,3118.80127429962 267.040775060655,3134.4859957695 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,3116.31842851639 266.931373119355,3110.10293483734 264.567016601563,3122.53415822983 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,3101.40459537506 269.980111360551,3093.48162889481 268.528499841691,3109.32756185532 PathPoint;PointKind.SMOOTHPOINT 265.251044273377,3084.97164487839 263.621698856355,3075.96410036087 266.8803896904,3093.97918939591 PathPoint;PointKind.SMOOTHPOINT 264.580824613572,3056.66285991669 263.850416183473,3049.68049049378 265.310878992082,3063.64475727081 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,3046.33777141571 266.219375371934,3038.2085108757 269.952849388123,3054.46679592133 PathPoint;PointKind.SMOOTHPOINT 270.422675848008,3034.86531972885 269.797066688539,3027.58318662644 271.047930955888,3042.14745283127 PathPoint;PointKind.SMOOTHPOINT 272.759416341783,3018.80412340164 266.598210573197,3011.31144762039 278.920622110368,3026.29703521729 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,2992.41807460785 266.219375371934,2982.13759660721 265.279014348985,3002.6983165741 PathPoint;PointKind.SMOOTHPOINT 268.251277446748,2963.97475004196 266.686015367509,2955.51858186722 269.816539525987,2972.4311542511 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,2927.02592611313 269.121890306474,2920.59493303299 264.712885856629,2933.45668315888 PathPoint;PointKind.CORNERPOINT 264.580824613572,2915.55371046066 264.580824613572,2915.55371046066 264.580824613572,2915.55371046066 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,2908.67023944855 266.703009843827,2903.23436737061 269.46850681305,2914.10611152649 PathPoint;PointKind.SMOOTHPOINT 264.580824613572,2897.19802379608 265.863199472428,2890.76726675034 263.298449754716,2903.62854480743 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,2889.16742563248 270.454540491105,2883.44453573227 265.716976165772,2894.89007949829 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,2876.54784679413 261.960842847825,2870.43526411057 271.873933315278,2882.66042947769 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,2865.07539510727 268.295887947083,2858.24597597122 267.875982761384,2871.9052863121 PathPoint;PointKind.SMOOTHPOINT 264.580824613572,2853.6034154892 263.544869661332,2847.27108478546 265.616425514222,2859.93551015854 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,2840.98383665085 269.541441440583,2833.76425266266 266.630075216294,2848.20318460465 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,2813.45018863678 266.926770448686,2801.74500703812 269.245100259782,2825.15560626984 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,2780.18066883087 269.537192821504,2771.02985143662 268.971064329148,2789.33172225952 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,2758.38336467743 261.512259483338,2749.41547393799 269.935500860215,2767.2443318367 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,2738.88031482697 268.469019174577,2728.33122968674 270.039237976075,2749.42963600159 PathPoint;PointKind.SMOOTHPOINT 263.412454366685,2721.67199134827 261.066862583161,2712.62786149979 265.654663085938,2730.31958341599 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,2704.46366786957 269.153754949571,2696.78263664246 269.354502201081,2712.14469909668 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,2695.28570652008 263.845813512803,2689.49153423309 267.652222156526,2701.08011484146 PathPoint;PointKind.SMOOTHPOINT 270.422675848008,2668.89965772629 271.061738967896,2658.6774802208 269.78361272812,2679.12159919739 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,2633.33564758301 272.019802570344,2625.28262615204 266.488454580308,2641.38843297958 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,2625.3050494194 265.986409425736,2620.146753788 265.511626243592,2630.46287298203 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,2617.27421522141 271.823657989503,2610.10844707489 266.684953212739,2624.43998336792 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,2603.50750923157 269.758829116822,2597.68996953964 266.022522687913,2610.68083047867 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,2584.0046954155 268.288098812104,2577.08062648773 267.823937177659,2592.9773068428 PathPoint;PointKind.SMOOTHPOINT 270.422675848008,2569.09086227417 268.355014562608,2559.68441963196 272.489983081819,2578.49706888199 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,2547.29332208634 271.892343997956,2538.04384231567 271.289748191834,2556.542801857 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,2504.84607696533 271.559181451798,2492.27559328079 271.622910737992,2517.41608858109 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,2472.72344827652 272.147615194322,2464.70630407333 271.034122943879,2480.74059247971 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,2461.25123262405 265.785308122636,2454.67696666718 265.712373495103,2467.82549858093 PathPoint;PointKind.SMOOTHPOINT 270.422675848008,2452.07327127457 273.30678009987,2442.30852842331 267.538217544557,2461.83825016022 PathPoint;PointKind.SMOOTHPOINT 273.92778658867,2433.71758460999 272.27082514763,2425.89776515961 275.58439397812,2441.53787612915 PathPoint;PointKind.SMOOTHPOINT 270.422675848008,2417.65662431717 268.154267311097,2406.58755540848 272.690730333329,2428.72545719147 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,2400.44806480408 268.74765777588,2391.84390306473 265.087118387223,2409.05246257782 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,2384.38710451126 271.828260660172,2376.89419269562 271.353831529618,2391.87978029251 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,2367.17854499817 266.283104658128,2361.22717380524 267.552025556565,2373.1299161911 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,2354.55896615982 267.761978149415,2344.98234272003 270.746633052827,2364.135825634 PathPoint;PointKind.SMOOTHPOINT 264.580824613572,2339.64513301849 262.609111309052,2330.21178245544 266.552537918092,2349.07848358154 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,2325.87819099426 265.922326087953,2319.20573472977 265.575355529786,2332.55088329315 PathPoint;PointKind.SMOOTHPOINT 259.907343626023,2316.70046567917 260.035156250001,2311.11683607101 259.779531002046,2322.28433132172 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,2307.52274036408 271.267088890077,2302.59316205978 264.904781818391,2312.45231866837 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,2290.31418085098 261.330985069276,2282.66454219818 270.167050600053,2297.96381950378 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,2281.13645553589 272.175231218339,2273.03410291672 263.996639490128,2289.23880815506 PathPoint;PointKind.SMOOTHPOINT 270.422675848008,2266.22262239456 267.684086799622,2256.27400875092 273.160910844804,2276.17123603821 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,2254.7501707077 271.796396017075,2246.64356946945 271.385696172715,2262.85700798035 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,2234.09999370575 268.63790178299,2227.52147912979 267.533614873887,2240.6787443161 PathPoint;PointKind.SMOOTHPOINT 272.759416341783,2219.18616056442 275.009414196015,2210.07546901703 270.50941848755,2228.29685211182 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,2201.97783708572 264.662964582444,2195.45266628265 269.171811580659,2208.50253582001 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,2187.06376791 268.2318046093,2180.87046146393 265.602971553803,2193.25707435608 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,2176.73867940903 267.200452327729,2171.1012339592 264.297583341599,2182.37636089325 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,2167.56071805954 270.231133937837,2158.59802007675 265.940736770631,2176.52341604233 PathPoint;PointKind.SMOOTHPOINT 262.244084119798,2154.94137525559 261.623077630998,2146.36412143707 262.864736557008,2163.5186290741 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,2143.46915960312 271.518111467362,2138.77726793289 262.317018747331,2148.16128730774 PathPoint;PointKind.SMOOTHPOINT 263.412454366685,2130.84958076477 263.261628389359,2121.64471149445 263.56292629242,2140.0542140007 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,2099.87455129623 268.788727760316,2088.15119504929 265.046048402787,2111.5974354744 PathPoint;PointKind.SMOOTHPOINT 264.580824613572,2060.8686876297 264.055766105653,2053.01723957062 265.105529069901,2068.71989965439 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,2041.36563777924 269.664651393891,2032.6765036583 264.170124769212,2050.05500793457 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,2009.24348115921 271.298953533174,1996.62390232086 262.536176681519,2021.86282396317 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,1996.62390232086 265.748840808869,1985.53689479828 265.748840808869,2007.71090984345 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,1980.56270599365 267.515558242799,1967.45028734207 266.319571971894,1993.67512464523 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,1951.88193082809 268.323149919511,1940.38280725479 267.848366737367,1963.38129043579 PathPoint;PointKind.SMOOTHPOINT 270.422675848008,1932.37911701202 274.530382394792,1917.15159416199 266.315323352815,1947.60663986206 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,1886.49001836777 272.188685178758,1879.85320329666 270.993052959443,1893.12683343887 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,1875.01756668091 268.405289888383,1866.81678771973 270.103321313859,1883.21858167648 PathPoint;PointKind.SMOOTHPOINT 272.759416341783,1861.25109672546 272.722594976426,1853.26086044312 272.795883655549,1869.24133300781 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,1847.48415470123 267.738964796067,1840.60540437698 268.43255186081,1854.36290502548 PathPoint;PointKind.SMOOTHPOINT 270.422675848008,1833.7174487114 271.513508796693,1824.37851190567 269.331842899323,1843.05662155151 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,1817.65625238419 266.771695852281,1808.0619263649 271.736915349961,1827.25081443787 PathPoint;PointKind.SMOOTHPOINT 272.759416341783,1790.12260437012 276.145919799806,1783.65172147751 269.372912883759,1796.59395933151 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,1770.62002658844 275.429319381715,1760.68935155869 267.752772808076,1780.5507016182 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,1741.93925142288 274.300602912904,1732.13084220886 265.722640991212,1748.80383968353 PathPoint;PointKind.SMOOTHPOINT 273.92778658867,1723.5835647583 274.101271867753,1717.16626167297 273.754655361176,1730.00086784363 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,1713.25847625732 268.012646675111,1703.27847003937 268.158869981767,1723.23848247528 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,1693.75566244125 268.272874593736,1685.86408853531 265.561901569367,1701.6472363472 PathPoint;PointKind.SMOOTHPOINT 275.096156835557,1679.98872041702 275.949421167375,1672.62161493301 274.242892503739,1687.35629796982 PathPoint;PointKind.SMOOTHPOINT 273.92778658867,1663.92776012421 273.078770875932,1656.28709077835 274.776802301408,1671.56842947006 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,1654.74979877472 267.538217544557,1646.83580160141 268.633299112321,1662.66379594803 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,1642.13045597076 271.823657989503,1632.97963857651 271.358434200288,1651.28150939941 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,1614.59704399109 268.254817962647,1606.96510791779 274.927274227143,1622.22874403 PathPoint;PointKind.SMOOTHPOINT 272.759416341783,1600.83010196686 274.516574382783,1593.49863767624 271.002258300782,1608.16156625748 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,1583.62177848816 276.273732423783,1576.36655330658 266.908359766007,1590.87700366974 PathPoint;PointKind.SMOOTHPOINT 273.92778658867,1567.56058216095 272.398637771607,1561.38969898224 275.456581354142,1573.73146533966 PathPoint;PointKind.SMOOTHPOINT 265.748840808869,1557.23549365997 267.510955572129,1547.56917715073 263.987434148789,1566.90181016922 PathPoint;PointKind.SMOOTHPOINT 272.759416341783,1528.55471849442 276.113701105119,1514.46086883545 269.404777526856,1542.64856815338 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,1511.34639501572 267.218863010407,1499.21989202499 268.95300769806,1523.47289800644 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,1466.60465955734 273.393522739411,1452.99019575119 269.788215398789,1480.2188873291 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,1445.95448255539 269.99391937256,1435.88926792145 268.514691829682,1456.01946115494 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,1423.00981521606 269.021339654923,1407.84484148026 269.486917495728,1438.17478895187 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,1393.18191289902 270.651039123536,1384.64502096176 267.857572078706,1401.71904087067 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,1377.12071657181 273.083373546601,1361.87053442001 265.424883604051,1392.3708987236 PathPoint;PointKind.SMOOTHPOINT 272.759416341783,1357.61790275574 271.198402881623,1345.98423957825 274.320429801942,1369.25132989883 PathPoint;PointKind.SMOOTHPOINT 264.580824613572,1335.8205986023 259.761120319367,1322.8110909462 269.400174856187,1348.829870224 PathPoint;PointKind.SMOOTHPOINT 262.244084119798,1323.20101976395 262.047585487367,1318.19992303848 262.440228700639,1328.2023525238 PathPoint;PointKind.SMOOTHPOINT 270.422675848008,1319.75940227509 276.985376119615,1315.17042160034 263.859621524812,1324.34814691544 PathPoint;PointKind.SMOOTHPOINT 272.759416341783,1310.5814409256 272.307646512986,1301.569647789 273.211186170579,1319.59347009659 PathPoint;PointKind.SMOOTHPOINT 272.759416341783,1302.55107879639 276.469168901444,1302.01480865479 266.278501987458,1303.48742723465 PathPoint;PointKind.SMOOTHPOINT 281.663813829423,1300.56909799576 281.731791734696,1300.53345680237 279.895326137544,1301.49458885193 PathPoint;PointKind.SMOOTHPOINT 281.580611705781,1286.7537689209 279.459134578706,1284.11537647247 281.425183057786,1286.56045675278 PathPoint;PointKind.SMOOTHPOINT 273.92778658867,1276.16455793381 271.016066312791,1262.9402589798 276.055990695954,1285.82969427109 PathPoint;PointKind.SMOOTHPOINT 266.917565107346,1258.95623445511 266.105370759965,1251.21241807938 267.729759454728,1266.69981479645 PathPoint;PointKind.SMOOTHPOINT 275.096156835557,1247.48401880264 279.8333671093,1242.65758752823 270.358946561814,1252.31045007706 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,1236.01180315018 263.827756881715,1228.23659420013 274.680854320527,1243.78677606583 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,1221.09749794006 275.05968952179,1213.03125858307 263.448921680451,1229.16420936585 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,1206.18366479874 267.469885587693,1190.56621313095 271.038725614549,1221.80111646652 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,1186.68085098267 278.907168149949,1179.25072431564 264.274924039842,1194.1107416153 PathPoint;PointKind.SMOOTHPOINT 269.253951549531,1170.61965465546 272.987425565721,1164.3727684021 265.520831584931,1176.86654090881 PathPoint;PointKind.SMOOTHPOINT 268.085935354234,1158.00007581711 266.283104658128,1147.53596305847 269.88876605034,1168.46418857575 PathPoint;PointKind.SMOOTHPOINT 276.264527082444,1132.76115417481 277.168066740037,1129.47177886963 273.393522739411,1143.21157693863 PathPoint;PointKind.SMOOTHPOINT 276.138838768006,1122.30577468872 282.671444654466,1117.46518135071 273.068503379823,1124.58114624023 PathPoint;PointKind.SMOOTHPOINT 276.264527082444,1108.66935968399 272.674798011781,1105.71420907974 283.716604948045,1114.80412960053 PathPoint;PointKind.SMOOTHPOINT 272.759416341783,1093.75529050827 275.58439397812,1077.36246585846 271.838528156281,1099.09910917282 PathPoint;PointKind.SMOOTHPOINT 273.92778658867,1068.51636886597 274.356897115708,1053.9745259285 273.498676061631,1083.05821180344 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,1045.57170152664 271.111660242082,1030.18721580505 272.070077896119,1060.95642328262 PathPoint;PointKind.SMOOTHPOINT 271.591046094895,1020.33277988434 275.045881509782,1005.13192892075 268.135856628419,1035.53363084793 PathPoint;PointKind.SMOOTHPOINT 272.759416341783,995.093622207642 271.85127401352,982.035019397736 273.667558670045,1008.15246105194 PathPoint;PointKind.SMOOTHPOINT 272.759416341783,967.560210227967 273.40272808075,957.790982723237 272.115750551225,977.32967376709 PathPoint;PointKind.SMOOTHPOINT 273.92778658867,952.64637708664 275.182899475099,936.638760566712 272.672673702241,968.653757572175 PathPoint;PointKind.SMOOTHPOINT 275.251939535142,928.980152606965 270.939237117768,909.750666618348 279.564996004106,948.209638595582 PathPoint;PointKind.SMOOTHPOINT 275.096156835557,899.873807430268 276.360121011735,878.909232616425 274.378848314286,911.770412921906 PathPoint;PointKind.SMOOTHPOINT 283.25279736519,875.981698036194 283.240051507951,859.056615829468 283.266605377198,893.910162448884 PathPoint;PointKind.SMOOTHPOINT 277.76004099846,852.837345600128 277.119207620622,849.002022743225 281.17805504799,873.308136463165 PathPoint;PointKind.SMOOTHPOINT 277.76004099846,835.629022121429 279.404256582261,832.231779098511 275.717871427537,839.847428798676 PathPoint;PointKind.SMOOTHPOINT 279.769637823106,829.892914295197 279.958347320558,827.23304271698 279.485688447953,833.891100883484 PathPoint;PointKind.SMOOTHPOINT 279.992690324784,821.816761493683 279.963304042817,819.162790775299 280.022430658341,824.521479606628 PathPoint;PointKind.SMOOTHPOINT 277.76004099846,813.831717967987 276.917398214341,801.685388088226 277.939191102982,816.416058540344 PathPoint;PointKind.SMOOTHPOINT 280.938008069993,793.181540966034 280.098197698594,785.45117855072 281.326402664185,796.760058403015 PathPoint;PointKind.SMOOTHPOINT 278.928411245347,782.856452465057 277.494502305985,777.014129161835 281.3788022995,792.84542798996 PathPoint;PointKind.SMOOTHPOINT 278.601267576219,765.648128986359 278.156224727632,761.048762798309 279.228292942048,772.1284532547 PathPoint;PointKind.SMOOTHPOINT 276.591316699983,749.586932659149 281.506968975068,736.021800041199 274.5512714386,755.217769145966 PathPoint;PointKind.SMOOTHPOINT 278.928411245347,717.46454000473 270.92295074463,707.681622505188 286.933517694474,727.247221469879 PathPoint;PointKind.SMOOTHPOINT 281.264797687531,696.814363002777 281.209919691087,689.724833965302 281.319675683976,703.904128074646 PathPoint;PointKind.SMOOTHPOINT 284.252639055253,668.986852169037 284.266447067262,668.757898807526 282.812357187272,693.287301063538 PathPoint;PointKind.SMOOTHPOINT 284.443118810655,614.213891029358 285.049963235856,598.502261638641 283.835920333863,629.925756454468 PathPoint;PointKind.SMOOTHPOINT 281.928644418717,580.94437122345 279.664838552476,572.537298202515 284.192096233369,589.351444244385 PathPoint;PointKind.SMOOTHPOINT 285.433755159379,520.141439437866 283.156141281129,507.239327430725 287.711014986039,533.043079376221 PathPoint;PointKind.SMOOTHPOINT 279.591549873353,483.430066108704 281.568219900132,466.969735622406 277.615587949754,499.890160560608 PathPoint;PointKind.SMOOTHPOINT 280.75992012024,439.835221767426 279.682895183564,425.80415725708 281.837299108506,453.866522312164 PathPoint;PointKind.SMOOTHPOINT 284.252639055253,407.993710041046 285.074392795564,390.404427051544 283.431239366532,425.582993030548 PathPoint;PointKind.SMOOTHPOINT 286.25303053856,358.994858264923 287.777222633363,332.052948474884 284.728484392167,385.936768054962 PathPoint;PointKind.SMOOTHPOINT 286.25303053856,314.995923042297 286.828010320664,292.239611148834 285.678050756455,337.752470970154 PathPoint;PointKind.SMOOTHPOINT 285.252834796906,278.996901512146 286.905193567277,255.371038913727 283.600830078126,302.622528076172 PathPoint;PointKind.SMOOTHPOINT 285.252834796906,245.044770240784 283.532144069673,233.384199142456 286.97352552414,256.705105304718 PathPoint;PointKind.SMOOTHPOINT 288.253067970277,227.998130321503 288.42549109459,212.529380321503 288.060463905335,245.289301872253 PathPoint;PointKind.SMOOTHPOINT 295.253730058671,199.998786449432 301.355101108552,192.819564342499 290.369588375092,205.746695995331 PathPoint;PointKind.SMOOTHPOINT 312.25564146042,189.999189376831 309.002969503404,191.730501651764 305.646914482118,193.517045974731 PathPoint;PointKind.SMOOTHPOINT 332.257431983949,185.046007633209 337.780990839005,182.324295043945 320.888835430146,190.647811889648 PathPoint;PointKind.SMOOTHPOINT 353.863076210023,181.941683292389 359.025148391725,183.080077171326 348.701358079911,180.803761482239 PathPoint;PointKind.SMOOTHPOINT 377.230481147767,184.236409664154 383.556320905686,183.913750648499 370.904995441438,184.55906867981 PathPoint;PointKind.SMOOTHPOINT 392.419294357301,183.089046478271 401.54284977913,183.196678161621 383.296092987061,182.981414794922 PathPoint;PointKind.SMOOTHPOINT 413.45031285286,188.825390338898 429.004507303239,190.138449668884 397.896472454072,187.512331008911 PathPoint;PointKind.SMOOTHPOINT 443.828293323518,188.825390338898 455.479777097703,188.598561286926 426.329647541047,189.165987968445 PathPoint;PointKind.SMOOTHPOINT 461.269228696824,188.030426502228 465.747627258302,188.270709514618 452.368371725083,187.552692890167 PathPoint;PointKind.SMOOTHPOINT 481.82510995865,181.679921150208 490.040169000627,182.022879123688 475.109459400178,181.399984359741 PathPoint;PointKind.SMOOTHPOINT 502.273005485536,181.999275684357 513.526181221009,182.366309165955 494.206648111344,181.736333370209 PathPoint;PointKind.SMOOTHPOINT 527.275066614152,180.999433994293 536.211682796479,180.95930814743 522.070154190064,181.023037433624 PathPoint;PointKind.SMOOTHPOINT 562.278731107713,183.999195098877 583.984571933747,185.236251354218 540.572182178498,182.76237487793 PathPoint;PointKind.SMOOTHPOINT 604.578336715699,178.267335891724 611.241941690446,177.429413795471 597.915439844132,179.105494022369 PathPoint;PointKind.SMOOTHPOINT 629.284764766694,176.999595165253 631.70718574524,175.545859336853 614.172780752183,186.067800521851 PathPoint;PointKind.SMOOTHPOINT 644.285930633546,177.03075170517 647.436281681062,177.875046730042 640.160521507264,175.925402641296 PathPoint;PointKind.SMOOTHPOINT 659.15609741211,181.23664855957 661.382727861405,180.924611091614 654.959877967835,181.82413816452 PathPoint;PointKind.SMOOTHPOINT 664.997594594956,175.500304698944 674.424926280976,174.448063373566 661.85397052765,175.851051807404 PathPoint;PointKind.SMOOTHPOINT 682.523502349854,178.941922187805 685.919211149217,179.359467029572 678.195221662522,178.409900665283 PathPoint;PointKind.SMOOTHPOINT 695.375575065614,176.647431850433 707.720999956132,177.642316818237 689.947964191438,176.210060119629 PathPoint;PointKind.SMOOTHPOINT 715.237869262696,183.530902862549 733.767867326737,187.815163135529 696.708225250245,179.246878623962 PathPoint;PointKind.SMOOTHPOINT 777.298156261445,186.030507087708 816.39819765091,186.030507087708 738.19882297516,186.030507087708 PathPoint;PointKind.SMOOTHPOINT 848.769488573075,186.297934055328 883.232162237168,185.558438301086 814.307168960572,187.03742980957 PathPoint;PointKind.SMOOTHPOINT 960.933740377427,187.445061206818 1008.67795133591,186.051514148712 913.190237522126,188.838844299316 PathPoint;PointKind.SMOOTHPOINT 1201.33724832535,186.030507087708 1245.31541252136,185.904936790466 1157.35837602615,186.156077384949 PathPoint;PointKind.SMOOTHPOINT 1376.87638068199,186.297934055328 1399.36750793457,186.042544841766 1354.38489937782,186.55332326889 PathPoint;PointKind.SMOOTHPOINT 1475.0201895237,184.003443717957 1493.11151766777,181.744830608368 1456.92850732803,186.262056827545 PathPoint;PointKind.SMOOTHPOINT 1514.3659427166,177.03075170517 1531.17949867249,175.699753761292 1497.55238676071,178.361749649048 PathPoint;PointKind.SMOOTHPOINT 1539.28090715408,180.561826229095 1555.75244927406,182.394633293152 1522.8093650341,178.729019165039 PathPoint;PointKind.SMOOTHPOINT 1579.37193894386,178.030593395233 1591.96980261803,173.414468765259 1566.63953566551,182.695577144623 PathPoint;PointKind.SMOOTHPOINT 1602.37325453758,173.67835521698 1602.37325453758,173.67835521698 1591.31905579567,175.674262046814 PathPoint;PointKind.SMOOTHPOINT 1621.06753253937,177.119972705841 1644.87325334549,181.090779304504 1597.26181173325,173.149402141571 PathPoint;PointKind.SMOOTHPOINT 1668.97071266174,179.414699077606 1689.62289595604,180.077955722809 1648.31888341904,178.751442432404 PathPoint;PointKind.SMOOTHPOINT 1700.38323187828,176.030673980713 1711.21791863442,170.81006526947 1689.54854512215,181.251518726349 PathPoint;PointKind.SMOOTHPOINT 1736.73689508438,174.825482368469 1747.19310069084,175.860729217529 1726.28068947792,173.790235519409 PathPoint;PointKind.SMOOTHPOINT 1760.10430002213,180.561826229095 1771.68780589104,180.382676124573 1748.5211482048,180.741212368011 PathPoint;PointKind.SMOOTHPOINT 1782.30368876457,179.414699077606 1797.1044614315,178.504786491394 1767.50256204605,180.324375629425 PathPoint;PointKind.CORNERPOINT 1816.1864259243,178.267335891724 1816.1864259243,178.267335891724 1816.1864259243,178.267335891724 PathPoint;PointKind.SMOOTHPOINT 1825.53374195099,172.530992031097 1831.59899973869,166.436583995819 1819.46777606011,178.625872135162 PathPoint;PointKind.CORNERPOINT 1838.38546061516,173.67835521698 1838.38546061516,173.67835521698 1838.38546061516,173.67835521698 PathPoint;PointKind.SMOOTHPOINT 1845.39603614807,174.825482368469 1853.20960068703,168.959555625916 1837.58247160912,180.69188117981 PathPoint;PointKind.SMOOTHPOINT 1861.75321960449,172.530992031097 1870.53440713883,172.620685100555 1852.97203207016,172.441534996033 PathPoint;PointKind.SMOOTHPOINT 1878.39966320992,179.030671119689 1881.22393274307,179.204156398773 1860.44924759865,177.92839050293 PathPoint;PointKind.SMOOTHPOINT 1897.40161204338,183.03050994873 1914.25446772575,185.474646091461 1894.25444746018,182.574255466461 PathPoint;PointKind.SMOOTHPOINT 1924.84592103958,177.119972705841 1925.13341093063,169.627296924591 1924.60339570046,183.433892726898 PathPoint;PointKind.SMOOTHPOINT 1935.40480160713,175.030596256256 1939.530564785,179.68236207962 1931.27903842926,170.379066467285 PathPoint;PointKind.SMOOTHPOINT 1950.54971241951,177.119972705841 1960.38526558876,177.250027656555 1940.71451330185,176.99015378952 PathPoint;PointKind.SMOOTHPOINT 1971.58073091507,177.119972705841 1978.73717570305,169.999287128448 1964.42428612709,184.240894317626 PathPoint;PointKind.SMOOTHPOINT 1992.61139535904,172.530992031097 2001.28778362274,176.084961891174 1983.93536114693,168.977494239807 PathPoint;PointKind.SMOOTHPOINT 2010.13730311394,175.972845554351 2015.73698306084,171.805186271667 2004.53691506386,180.140504837036 PathPoint;PointKind.SMOOTHPOINT 2021.82100558281,173.67835521698 2038.82610344887,173.149402141571 2004.81555366516,174.207072257995 PathPoint;PointKind.SMOOTHPOINT 2044.02039432526,174.825482368469 2051.78368353844,173.929259777069 2036.25710511208,175.721940994262 PathPoint;PointKind.SMOOTHPOINT 2060.37757778168,177.119972705841 2072.04747223854,178.71556520462 2048.70732927322,175.524616241455 PathPoint;PointKind.SMOOTHPOINT 2079.07150173187,177.119972705841 2096.23202824593,172.719347476959 2061.91097521782,181.520833969116 PathPoint;PointKind.SMOOTHPOINT 2102.43926072121,173.67835521698 2119.91914176941,170.191891193389 2084.95902562142,177.16481924057 PathPoint;PointKind.SMOOTHPOINT 2121.1331846714,173.67835521698 2132.73014450073,176.761672496795 2109.53622484207,170.595273971557 PathPoint;PointKind.SMOOTHPOINT 2144.50058960915,175.972845554351 2156.60879993439,175.520131587982 2132.3927333355,176.425559520721 PathPoint;PointKind.CORNERPOINT 2158.52103257179,178.267335891723 2158.52103257179,178.267335891723 2158.52103257179,178.267335891723 PathPoint;PointKind.SMOOTHPOINT 2172.54182958603,171.384100914001 2189.50585746765,170.469703674316 2155.57744765282,172.298262119293 PathPoint;PointKind.SMOOTHPOINT 2186.56227254868,177.119972705841 2194.62792181969,175.805261135101 2167.31177949905,180.258285999298 PathPoint;PointKind.SMOOTHPOINT 2201.42960691452,173.030676841735 2206.48156905174,178.489208221435 2196.37693667412,167.572617530822 PathPoint;PointKind.SMOOTHPOINT 2229.79232573509,174.825482368469 2250.20233774185,173.140432834625 2209.38231372833,176.510531902313 PathPoint;PointKind.SMOOTHPOINT 2266.0118033886,177.119972705841 2277.8920044899,176.927368640899 2254.13195633888,177.312812805175 PathPoint;PointKind.SMOOTHPOINT 2284.70608139038,175.972845554351 2292.52389454842,176.075992584228 2276.88791418076,175.869698524475 PathPoint;PointKind.SMOOTHPOINT 2302.23163509369,175.972845554351 2323.07996296883,174.803059101104 2281.38330721855,177.142395973205 PathPoint;PointKind.CORNERPOINT 2354.8086502552,174.825482368469 2354.8086502552,174.825482368469 2354.8086502552,174.825482368469 PathPoint;PointKind.CORNERPOINT 2369.99746346474,171.384100914001 2369.99746346474,171.384100914001 2369.99746346474,171.384100914001 PathPoint;PointKind.SMOOTHPOINT 2380.51279568672,174.825482368469 2378.63738441467,168.798108100891 2382.38891506195,180.85309267044 PathPoint;PointKind.CORNERPOINT 2388.69138741493,171.384100914001 2388.69138741493,171.384100914001 2388.69138741493,171.384100914001 PathPoint;PointKind.SMOOTHPOINT 2399.20707368851,175.972845554351 2405.14487290382,174.435789585113 2393.26927447319,177.50990152359 PathPoint;PointKind.CORNERPOINT 2412.05914640427,178.267335891723 2412.05914640427,178.267335891723 2412.05914640427,178.267335891723 PathPoint;PointKind.SMOOTHPOINT 2422.57447862625,177.119972705841 2428.34374928475,168.753497600555 2416.80591607094,185.48668384552 PathPoint;PointKind.SMOOTHPOINT 2433.09016489983,174.825482368469 2438.16053771973,176.340351104736 2428.01943802834,173.310849666595 PathPoint;PointKind.CORNERPOINT 2448.27897810936,174.825482368469 2448.27897810936,174.825482368469 2448.27897810936,174.825482368469 PathPoint;PointKind.SMOOTHPOINT 2456.45756983757,174.825482368469 2463.92416381836,174.973475933074 2448.99097585678,174.677724838256 PathPoint;PointKind.SMOOTHPOINT 2471.6463830471,175.972845554351 2478.78016853333,174.233980178833 2464.51295161247,177.71171092987 PathPoint;PointKind.CORNERPOINT 2488.00392055512,178.267335891723 2488.00392055512,178.267335891723 2488.00392055512,178.267335891723 PathPoint;PointKind.SMOOTHPOINT 2500.85563921928,175.972845554351 2509.72392344475,175.869698524475 2491.988063097,176.075992584228 PathPoint;PointKind.SMOOTHPOINT 2513.70806598663,178.267335891723 2527.35427641869,181.310291290283 2500.06185555458,175.224380493164 PathPoint;PointKind.SMOOTHPOINT 2535.90745472908,179.414699077606 2548.38529491425,178.079216480255 2523.42926049233,180.750181674957 PathPoint;PointKind.SMOOTHPOINT 2553.43300843239,181.708953380584 2562.51513981819,185.150570869445 2544.35087704659,178.267335891723 PathPoint;PointKind.SMOOTHPOINT 2570.9585621357,181.708953380584 2576.93282866478,173.310849666595 2564.98429560661,190.107057094574 PathPoint;PointKind.SMOOTHPOINT 2586.14772939682,178.267335891723 2591.49638676643,183.03546667099 2580.79836392403,173.498969078064 PathPoint;PointKind.SMOOTHPOINT 2596.66270756722,178.267335891723 2606.96383857727,175.977330207824 2586.36228466034,180.557341575622 PathPoint;PointKind.CORNERPOINT 2611.85187482834,182.856080532074 2611.85187482834,182.856080532074 2611.85187482834,182.856080532074 PathPoint;PointKind.CORNERPOINT 2625.87231779099,187.445061206817 2625.87231779099,187.445061206817 2625.87231779099,187.445061206817 PathPoint;PointKind.SMOOTHPOINT 2631.71416902542,177.119972705841 2639.84744215012,177.182757854461 2623.58124995232,177.057423591613 PathPoint;PointKind.CORNERPOINT 2646.90298223496,184.003443717956 2646.90298223496,184.003443717956 2646.90298223496,184.003443717956 PathPoint;PointKind.SMOOTHPOINT 2656.25029826164,180.561826229095 2662.90930056572,177.155849933624 2649.59129595757,183.967566490173 PathPoint;PointKind.CORNERPOINT 2667.93400073052,179.414699077606 2667.93400073052,179.414699077606 2667.93400073052,179.414699077606 PathPoint;PointKind.SMOOTHPOINT 2676.11259245873,182.856080532074 2688.99652981758,184.895181655883 2663.22865509987,180.817215442657 PathPoint;PointKind.SMOOTHPOINT 2692.46977591515,179.414699077606 2699.76748728752,171.056957244873 2685.17206454277,187.772204875946 PathPoint;PointKind.SMOOTHPOINT 2730.47792220116,173.030676841735 2750.89713954926,174.303610324859 2710.05905890465,171.758215427398 PathPoint;PointKind.SMOOTHPOINT 2771.91966080666,177.119972705841 2784.34262299538,176.241688728332 2759.49669861794,177.998492717742 PathPoint;PointKind.SMOOTHPOINT 2790.61358475685,177.119972705841 2795.63403630257,179.015800952911 2785.59313321114,175.224380493164 PathPoint;PointKind.SMOOTHPOINT 2802.29764127731,182.856080532074 2812.95459413529,181.762769222259 2791.64068841934,183.949627876281 PathPoint;PointKind.SMOOTHPOINT 2825.66504621506,178.267335891723 2837.4308886528,179.410214424133 2813.89920377731,177.124457359314 PathPoint;PointKind.SMOOTHPOINT 2843.19059991837,179.414699077606 2849.3429543972,179.661118984222 2837.03859949112,179.168043136596 PathPoint;PointKind.SMOOTHPOINT 2853.70593214035,178.267335891723 2863.33153271675,181.48047208786 2844.08068561554,175.054199695587 PathPoint;PointKind.SMOOTHPOINT 2864.22161841393,184.003443717956 2870.10418558121,184.357495307922 2858.33834314346,183.64939212799 PathPoint;PointKind.SMOOTHPOINT 2877.07369112968,178.267335891723 2887.01404356957,175.972845554351 2867.1333386898,180.561826229095 PathPoint;PointKind.CORNERPOINT 2889.92576384544,179.414699077606 2889.92576384544,179.414699077606 2889.92576384544,179.414699077606 PathPoint;PointKind.SMOOTHPOINT 2899.27272582054,178.267335891723 2910.19911193848,175.479769706726 2888.3466937542,181.054902076721 PathPoint;PointKind.CORNERPOINT 2919.13502001762,180.561826229095 2919.13502001762,180.561826229095 2919.13502001762,180.561826229095 PathPoint;PointKind.SMOOTHPOINT 2927.31361174583,177.119972705841 2936.55612850189,174.475915431976 2918.07180309296,179.764266014099 PathPoint;PointKind.SMOOTHPOINT 2947.17625999451,179.414699077606 2955.47841572762,180.436491966247 2938.87445831299,178.392906188964 PathPoint;PointKind.SMOOTHPOINT 2963.53379750252,180.561826229095 2981.05899715424,181.623744964599 2946.00788974762,179.499671459198 PathPoint;PointKind.SMOOTHPOINT 2981.05899715424,180.561826229095 2995.16653680801,173.01958322525 2966.95216560364,188.103833198547 PathPoint;PointKind.CORNERPOINT 3000.92164540291,178.267335891723 3000.92164540291,178.267335891723 3000.92164540291,178.267335891723 PathPoint;PointKind.SMOOTHPOINT 3006.50362277031,182.030432224273 3015.52875185013,178.391962051391 3002.54638814926,183.625788688659 PathPoint;PointKind.SMOOTHPOINT 3018.44719910622,179.414699077606 3023.67760324478,178.007462024688 3013.21714901924,180.82170009613 PathPoint;PointKind.CORNERPOINT 3025.45777463913,180.561826229095 3025.45777463913,180.561826229095 3025.45777463913,180.561826229095 PathPoint;PointKind.SMOOTHPOINT 3031.29927182198,184.003443717956 3039.29092431068,181.265444755554 3023.30797338486,186.741678714752 PathPoint;PointKind.SMOOTHPOINT 3042.98297429085,178.267335891723 3047.57573151588,176.978588104248 3035.35210037231,180.409111976623 PathPoint;PointKind.SMOOTHPOINT 3055.8354010582,177.119972705841 3068.9399125576,180.411472320556 3051.40409135819,176.007070541381 PathPoint;PointKind.SMOOTHPOINT 3067.51945757866,184.003443717956 3077.59647393227,184.375433921814 3067.51945757866,184.003443717956 PathPoint;PointKind.CORNERPOINT 3085.04465723038,178.267335891723 3085.04465723038,178.267335891723 3085.04465723038,178.267335891723 PathPoint;PointKind.SMOOTHPOINT 3093.22324895859,177.119972705841 3115.80430531502,183.817920684814 3085.76586031914,174.908094406127 PathPoint;PointKind.CORNERPOINT 3117.75937819481,184.003443717956 3117.75937819481,184.003443717956 3117.75937819481,184.003443717956 PathPoint;PointKind.SMOOTHPOINT 3127.10634016991,175.972845554351 3131.87116646767,171.800701618194 3122.34151387215,180.144989490509 PathPoint;PointKind.SMOOTHPOINT 3135.28493189812,179.414699077606 3149.17331361771,177.424929141998 3135.28493189812,179.414699077606 PathPoint;PointKind.CORNERPOINT 3169.16802310944,179.414699077606 3169.16802310944,179.414699077606 3169.16802310944,179.414699077606 PathPoint;PointKind.CORNERPOINT 3180.85172557831,174.825482368469 3180.85172557831,174.825482368469 3180.85172557831,174.825482368469 PathPoint;PointKind.SMOOTHPOINT 3194.87252259255,177.119972705841 3208.27195906639,180.723273754119 3181.47237801552,173.516907691955 PathPoint;PointKind.CORNERPOINT 3218.23992753029,182.856080532074 3218.23992753029,182.856080532074 3218.23992753029,182.856080532074 PathPoint;PointKind.CORNERPOINT 3233.42874073982,178.267335891723 3233.42874073982,178.267335891723 3233.42874073982,178.267335891723 PathPoint;PointKind.SMOOTHPOINT 3247.44918370247,177.119972705841 3259.45294880867,174.534215927124 3235.44612669945,179.705965518951 PathPoint;PointKind.SMOOTHPOINT 3262.637996912,178.267335891723 3274.91084122658,180.516979694366 3250.36550664902,176.01769208908 PathPoint;PointKind.CORNERPOINT 3289.510866642,179.414699077606 3289.510866642,179.414699077606 3289.510866642,179.414699077606 PathPoint;PointKind.SMOOTHPOINT 3296.52108812332,174.825482368469 3302.11687350273,174.749479293823 3290.92601084709,174.901721477508 PathPoint;PointKind.SMOOTHPOINT 3324.5623281002,175.972845554351 3343.94559049606,173.875443935394 3305.17906570435,178.070247173309 PathPoint;PointKind.SMOOTHPOINT 3353.77158427239,177.119972705841 3363.99978065491,178.348059654235 3343.54374194145,175.892121791839 PathPoint;PointKind.SMOOTHPOINT 3375.97097301483,174.825482368469 3382.85798454285,172.956798076629 3369.08396148682,176.694402694702 PathPoint;PointKind.CORNERPOINT 3387.6546754837,177.119972705841 3387.6546754837,177.119972705841 3387.6546754837,177.119972705841 PathPoint;PointKind.CORNERPOINT 3405.18022918701,177.119972705841 3405.18022918701,177.119972705841 3405.18022918701,177.119972705841 PathPoint;PointKind.SMOOTHPOINT 3413.35917496681,172.530992031097 3436.46812224388,171.495037078857 3404.79077243805,172.915256023407 PathPoint;PointKind.SMOOTHPOINT 3444.90517163277,174.825482368469 3451.42680191994,180.010685920715 3438.38318729401,169.640750885009 PathPoint;PointKind.SMOOTHPOINT 3457.75724434853,179.414699077606 3467.52446556091,175.47080039978 3447.99073123932,183.358125686645 PathPoint;PointKind.SMOOTHPOINT 3472.94641160965,174.825482368469 3488.83801722527,176.981184482574 3457.05445194244,172.670016288757 PathPoint;PointKind.SMOOTHPOINT 3491.64033555985,175.972845554351 3507.67816448212,169.622812271118 3475.60250663757,182.322878837585 PathPoint;PointKind.CORNERPOINT 3507.99751901627,172.530992031097 3507.99751901627,172.530992031097 3507.99751901627,172.530992031097 PathPoint;PointKind.SMOOTHPOINT 3516.17611074448,178.267335891723 3520.87720775604,179.764266014099 3511.4753677845,176.770641803741 PathPoint;PointKind.SMOOTHPOINT 3529.02853751183,174.825482368469 3540.292334795,164.442329406738 3517.76474022865,185.208871364593 PathPoint;PointKind.CORNERPOINT 3546.55409121513,171.384100914001 3546.55409121513,171.384100914001 3546.55409121513,171.384100914001 PathPoint;PointKind.SMOOTHPOINT 3555.90140724182,170.236737728118 3562.66025209427,166.915969848632 3549.14185428619,173.557269573211 PathPoint;PointKind.SMOOTHPOINT 3569.92149615288,169.089610576629 3578.17762517929,170.528004169464 3561.66536712647,167.650980949401 PathPoint;PointKind.SMOOTHPOINT 3587.44740390778,170.236737728118 3598.56072926521,171.334769725799 3576.33407855034,169.138705730438 PathPoint;PointKind.SMOOTHPOINT 3602.63621711731,172.530992031097 3611.2531247139,167.933278083801 3594.01966357231,177.128942012786 PathPoint;PointKind.SMOOTHPOINT 3620.16177082062,165.647757053375 3630.11593127251,166.45452260971 3610.20796442032,164.840991497039 PathPoint;PointKind.SMOOTHPOINT 3635.35058403015,170.236737728118 3647.23078513145,172.01148033142 3623.47073698044,168.46223115921 PathPoint;PointKind.CORNERPOINT 3671.56475090981,166.030840873718 3671.56475090981,166.030840873718 3671.56475090981,166.030840873718 PathPoint;PointKind.SMOOTHPOINT 3703.11676645279,169.089610576629 3721.11710333824,168.63689661026 3685.11642956734,169.542088508606 PathPoint;PointKind.SMOOTHPOINT 3728.8212659359,171.384100914001 3733.24832701683,169.972379207611 3724.39385080338,172.795350551605 PathPoint;PointKind.SMOOTHPOINT 3763.87237334251,164.500393867492 3793.16376948357,163.985130786895 3734.58062314987,165.015892982482 PathPoint;PointKind.SMOOTHPOINT 3809.43916702271,170.236737728118 3817.98313999176,170.971748828887 3800.89519405365,169.501726627349 PathPoint;PointKind.CORNERPOINT 3831.63820171356,162.206139564514 3831.63820171356,162.206139564514 3831.63820171356,162.206139564514 PathPoint;PointKind.CORNERPOINT 3843.32190418243,166.795120239257 3843.32190418243,166.795120239257 3843.32190418243,166.795120239257 PathPoint;PointKind.SMOOTHPOINT 3860.84781193733,166.795120239257 3876.69374489784,170.80581665039 3845.00152492523,162.784423828125 PathPoint;PointKind.SMOOTHPOINT 3878.37336564064,165.647757053375 3884.90455532074,162.896304130554 3871.84253001213,168.399446010589 PathPoint;PointKind.SMOOTHPOINT 3894.73090314865,171.384100914001 3903.77196455002,173.207702636718 3885.68948769569,169.560027122497 PathPoint;PointKind.SMOOTHPOINT 3913.42482709885,166.795120239257 3927.646017313,163.595201969146 3899.2032828331,169.994802474975 PathPoint;PointKind.CORNERPOINT 3933.28712129593,167.942247390747 3933.28712129593,167.942247390747 3933.28712129593,167.942247390747 PathPoint;PointKind.SMOOTHPOINT 3940.29769682884,167.942247390747 3945.34080767632,164.379544258117 3935.25423192978,171.504950523376 PathPoint;PointKind.SMOOTHPOINT 3978.85391497612,166.795120239257 4005.21978282929,169.416754245758 3952.48804712296,164.173250198364 PathPoint;PointKind.CORNERPOINT 4008.0631711483,174.825482368469 4008.0631711483,174.825482368469 4008.0631711483,174.825482368469 PathPoint;PointKind.SMOOTHPOINT 4016.24176287651,169.089610576629 4024.49364328384,162.264440059661 4007.99023652077,175.914545059204 PathPoint;PointKind.SMOOTHPOINT 4032.59930038452,165.647757053375 4037.33686470985,166.459007263183 4027.86173605919,164.836506843566 PathPoint;PointKind.CORNERPOINT 4047.78846764565,166.795120239257 4047.78846764565,166.795120239257 4047.78846764565,166.795120239257 PathPoint;PointKind.SMOOTHPOINT 4053.62996482849,162.206139564514 4072.48144173622,162.526438236236 4052.36564660072,162.184660434722 PathPoint;PointKind.SMOOTHPOINT 4075.82935357094,171.384100914001 4087.22556614876,170.49212694168 4064.43314099312,172.275838851928 PathPoint;PointKind.SMOOTHPOINT 4088.6814262867,167.942247390747 4094.60116887093,161.507005691528 4082.76203775406,174.377489089965 PathPoint;PointKind.SMOOTHPOINT 4108.54372048378,163.353266716003 4121.37773656845,166.4231300354 4095.7100584507,160.283639430999 PathPoint;PointKind.SMOOTHPOINT 4133.07984972,165.647757053375 4139.98952054977,163.254604339599 4126.16982483864,168.04090976715 PathPoint;PointKind.SMOOTHPOINT 4150.60540342331,159.911649227142 4160.11239671707,160.624237060546 4141.09876418114,159.199061393737 PathPoint;PointKind.SMOOTHPOINT 4172.80479216576,163.353266716003 4186.09022402763,165.517702102661 4159.51900625229,161.188831329345 PathPoint;PointKind.CORNERPOINT 4196.61299133301,165.030999183654 4196.61299133301,165.030999183654 4196.61299133301,165.030999183654 PathPoint;PointKind.SMOOTHPOINT 4209.61411976814,162.031238079071 4221.22949028015,162.76624917984 4197.99910330772,161.296226978302 PathPoint;PointKind.SMOOTHPOINT 4225.38180732727,171.384100914001 4224.80824375153,175.442476272583 4226.51795887947,163.344297409057 PathPoint;PointKind.SMOOTHPOINT 4238.23388004303,172.530992031097 4244.16247391701,173.789055347442 4232.18986535072,171.248853206634 PathPoint;PointKind.CORNERPOINT 4248.74921226501,180.561826229095 4248.74921226501,180.561826229095 4248.74921226501,180.561826229095 PathPoint;PointKind.SMOOTHPOINT 4256.92780399323,167.942247390747 4259.81686496735,159.140996932983 4254.0387430191,176.743733882904 PathPoint;PointKind.SMOOTHPOINT 4270.94860100746,162.206139564514 4282.54556083679,167.059478759765 4259.35164117813,157.352800369262 PathPoint;PointKind.SMOOTHPOINT 4287.30578446388,163.353266716003 4300.16706252098,160.597329139709 4274.44415235519,166.10944032669 PathPoint;PointKind.CORNERPOINT 4323.52526211739,161.059012413024 4323.52526211739,161.059012413024 4323.52526211739,161.059012413024 PathPoint;PointKind.SMOOTHPOINT 4336.37768888474,156.470031738281 4351.3607981205,157.460432052612 4321.39422559738,155.47963142395 PathPoint;PointKind.SMOOTHPOINT 4353.90324258804,161.059012413024 4359.97345709801,164.307789802551 4347.83302807808,157.809998989105 PathPoint;PointKind.SMOOTHPOINT 4370.26042604446,159.911649227142 4390.82126402855,154.354691505432 4349.69994211197,165.468606948852 PathPoint;PointKind.CORNERPOINT 4387.78633379936,162.206139564514 4387.78633379936,162.206139564514 4387.78633379936,162.206139564514 PathPoint;PointKind.SMOOTHPOINT 4399.47003626823,156.470031738281 4412.40885162354,154.256029129028 4386.53122091293,158.68379831314 PathPoint;PointKind.SMOOTHPOINT 4414.65884947777,162.206139564514 4425.78138017654,165.110070705413 4403.53631877899,159.302208423614 PathPoint;PointKind.SMOOTHPOINT 4434.52114367485,162.206139564514 4456.56545782089,160.45405626297 4412.4771835804,163.958222866058 PathPoint;PointKind.SMOOTHPOINT 4464.89912414551,156.470031738281 4483.36503887177,155.506303310394 4446.43320941925,157.433524131774 PathPoint;PointKind.SMOOTHPOINT 4494.10873436928,157.61715888977 4513.79294061661,162.089774608612 4474.42382001877,153.145015239715 PathPoint;PointKind.SMOOTHPOINT 4535.00169301033,159.911649227142 4560.50544524193,160.924472808837 4509.49829483032,158.898825645446 PathPoint;PointKind.SMOOTHPOINT 4577.06337594986,159.911649227142 4582.75015258789,157.912909984588 4571.37695336342,161.910388469696 PathPoint;PointKind.SMOOTHPOINT 4586.41069197655,162.206139564513 4592.13818454742,164.885838031768 4580.68249130249,159.526205062866 PathPoint;PointKind.SMOOTHPOINT 4599.26276469231,163.353266716003 4619.36227345467,163.675925731658 4579.16290187836,163.030843734741 PathPoint;PointKind.SMOOTHPOINT 4624.96691012383,158.764522075652 4642.30552458763,156.214406490325 4607.62829566002,161.314401626586 PathPoint;PointKind.SMOOTHPOINT 4651.83977985382,157.61715888977 4662.72899055481,161.063497066497 4640.94986104965,154.170820713042 PathPoint;PointKind.SMOOTHPOINT 4678.71229553223,157.61715888977 4688.94013786316,158.638951778411 4668.48445320129,156.595366001128 PathPoint;PointKind.SMOOTHPOINT 4693.90110874176,163.353266716003 4706.84452676773,166.745789051055 4680.95769071579,159.960980415343 PathPoint;PointKind.SMOOTHPOINT 4712.59503269196,162.206139564513 4738.2630648613,159.768376350402 4686.9273545742,164.643902778625 PathPoint;PointKind.SMOOTHPOINT 4740.63627266884,164.500393867492 4748.3861079216,165.894176959991 4732.88679146767,163.10708284378 PathPoint;PointKind.SMOOTHPOINT 4764.00403165817,167.942247390746 4777.47215414047,176.264111995696 4750.53555512428,159.620382785796 PathPoint;PointKind.SMOOTHPOINT 4782.69795560837,163.353266716003 4794.19011616707,158.943672180175 4771.20579504967,167.763097286223 PathPoint;PointKind.SMOOTHPOINT 4802.56024980545,163.353266716003 4826.98202037811,167.552318572997 4778.13847923279,159.154214859008 PathPoint;PointKind.SMOOTHPOINT 4836.44334101677,166.795120239257 4849.49616098404,169.457116127013 4823.39016699791,164.133124351501 PathPoint;PointKind.CORNERPOINT 4860.9791162014,169.089610576629 4860.9791162014,169.089610576629 4860.9791162014,169.089610576629 PathPoint;PointKind.SMOOTHPOINT 4877.33629965782,162.206139564513 4892.95882606506,160.987257957458 4861.71412730217,163.425021171569 PathPoint;PointKind.SMOOTHPOINT 4903.04079914093,165.647757053374 4912.9216709137,169.394330978393 4893.15957331657,161.901419162749 PathPoint;PointKind.SMOOTHPOINT 4917.06124210358,165.647757053374 4922.82095336914,161.605668067931 4911.30153083801,169.690082073211 PathPoint;PointKind.SMOOTHPOINT 4931.08168506622,166.795120239257 4937.95524263382,166.803853511809 4924.20848155022,166.786150932311 PathPoint;PointKind.SMOOTHPOINT 4939.26027679443,166.795120239257 4952.62855672836,168.878831863402 4925.89270496368,164.711172580718 PathPoint;PointKind.SMOOTHPOINT 4963.79640603065,169.089610576629 4989.30440688133,168.394961357116 4938.28840517998,169.784259796142 PathPoint;PointKind.SMOOTHPOINT 5002.35297822952,166.795120239257 5013.12818431854,170.097949504851 4991.57741808891,163.492054939269 PathPoint;PointKind.SMOOTHPOINT 5023.38364267349,170.236737728118 5028.47702884674,173.077883720397 5018.29025650024,167.395591735839 PathPoint;PointKind.CORNERPOINT 5039.74082612991,178.267335891723 5039.74082612991,178.267335891723 5039.74082612991,178.267335891723 PathPoint;PointKind.SMOOTHPOINT 5042.07792067528,170.236737728118 5043.75577116013,167.979068756103 5038.28709030151,175.336732864379 PathPoint;PointKind.SMOOTHPOINT 5051.42452859879,166.795120239257 5068.22392249107,164.983084201812 5049.75588345528,166.975214481353 PathPoint;PointKind.SMOOTHPOINT 5063.10823106766,175.972845554351 5071.43800282478,178.679687976836 5054.77916741371,173.266003131866 PathPoint;PointKind.SMOOTHPOINT 5078.29739832878,172.530992031097 5082.15833091736,164.720141887664 5074.43611168861,180.342314243316 PathPoint;PointKind.SMOOTHPOINT 5096.99132227898,164.500393867492 5113.67741966248,166.319983005523 5080.30557894707,162.681276798247 PathPoint;PointKind.SMOOTHPOINT 5116.85397052765,166.795120239257 5123.51261878014,168.444292545318 5110.19532227516,165.145711898803 PathPoint;PointKind.SMOOTHPOINT 5133.21150803566,171.384100914001 5155.48312330246,163.980646133422 5110.93918466568,178.787083625793 PathPoint;PointKind.SMOOTHPOINT 5168.26261544228,167.942247390746 5180.74045562744,165.275766849517 5155.78477525711,170.608727931975 PathPoint;PointKind.SMOOTHPOINT 5181.11468815804,164.500393867492 5190.46200418472,163.371205329894 5171.76772618294,165.629818439483 PathPoint;PointKind.SMOOTHPOINT 5192.79839062691,169.089610576629 5200.63921713829,172.526507377624 5184.95756411552,165.652241706847 PathPoint;PointKind.SMOOTHPOINT 5209.15557408333,173.678355216979 5218.16972756386,168.928163051604 5200.14177465439,178.428783416747 PathPoint;PointKind.SMOOTHPOINT 5233.69170331955,169.089610576629 5245.99605822563,166.911485195159 5221.38734841347,171.267499923705 PathPoint;PointKind.SMOOTHPOINT 5248.88087058067,165.647757053374 5253.47646021843,160.664598941802 5244.28492689133,170.63115119934 PathPoint;PointKind.SMOOTHPOINT 5262.90095949173,165.647757053374 5269.60103178024,164.948623180388 5256.20124125481,166.34689092636 PathPoint;PointKind.SMOOTHPOINT 5279.25849699974,165.647757053374 5296.04018831253,168.264906406402 5262.47680568695,163.03084373474 PathPoint;PointKind.SMOOTHPOINT 5313.14123415947,170.236737728118 5319.29819130898,168.439807891845 5306.98463106155,172.033903598784 PathPoint;PointKind.SMOOTHPOINT 5333.00388240814,167.942247390746 5353.68793034554,166.03320121765 5312.31983447075,169.851293563842 PathPoint;PointKind.SMOOTHPOINT 5355.202917099,162.206139564513 5370.23205304146,157.567827701568 5340.17378115654,166.844215393065 PathPoint;PointKind.SMOOTHPOINT 5391.42274880409,159.911649227141 5403.81384634972,161.507005691527 5379.03165125847,158.316292762755 PathPoint;PointKind.CORNERPOINT 5411.28504300117,166.795120239257 5411.28504300117,166.795120239257 5411.28504300117,166.795120239257 PathPoint;PointKind.SMOOTHPOINT 5418.29561853409,161.059012413024 5440.74425959587,165.581431388854 5410.47178649902,159.482774734496 PathPoint;PointKind.SMOOTHPOINT 5452.17870974541,157.61715888977 5464.75214385986,155.121095180511 5439.60456752777,160.113458633422 PathPoint;PointKind.SMOOTHPOINT 5470.87227964401,162.206139564513 5479.27498602867,167.691342830657 5462.46992731094,156.720936298369 PathPoint;PointKind.SMOOTHPOINT 5486.06109285355,164.500393867492 5495.33441209793,164.527301788329 5471.37751126289,164.457907676696 PathPoint;PointKind.CORNERPOINT 5502.41863036156,163.353266716003 5502.41863036156,163.353266716003 5502.41863036156,163.353266716003 PathPoint;PointKind.CORNERPOINT 5507.09211134911,175.972845554351 5507.09211134911,175.972845554351 5507.09211134911,175.972845554351 PathPoint;PointKind.SMOOTHPOINT 5533.9649810791,174.825482368468 5546.25092530251,173.230125904082 5521.67868280411,176.421074867248 PathPoint;PointKind.CORNERPOINT 5546.81705379486,174.825482368468 5546.81705379486,174.825482368468 5546.81705379486,174.825482368468 PathPoint;PointKind.SMOOTHPOINT 5560.83749675751,172.530992031097 5572.6263525486,168.538234233855 5549.04899501801,176.523985862731 PathPoint;PointKind.SMOOTHPOINT 5579.53177475929,174.825482368468 5598.21649336815,177.783229351043 5560.84670209885,171.867971420287 PathPoint;PointKind.SMOOTHPOINT 5607.57266068459,172.530992031097 5622.1730401516,172.132329940795 5592.97228121758,172.929890155791 PathPoint;PointKind.SMOOTHPOINT 5628.60332512856,171.384100914001 5638.63502287865,167.135481834411 5618.57198143005,175.632247924804 PathPoint;PointKind.SMOOTHPOINT 5651.9707300663,172.530992031097 5664.17524242401,171.240592002868 5639.76692581177,173.821628093719 PathPoint;PointKind.CORNERPOINT 5660.1496758461,186.297934055327 5660.1496758461,186.297934055327 5660.1496758461,186.297934055327 PathPoint;PointKind.SMOOTHPOINT 5669.74836850166,195.030262470244 5680.58765792847,201.452050209045 5658.90872502327,188.608710765838 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,217.273199558257 5673.43546175957,223.69947195053 5674.90477585793,210.846691131591 PathPoint;PointKind.CORNERPOINT 5675.33884310722,244.806611537932 5675.33884310722,244.806611537932 5675.33884310722,244.806611537932 PathPoint;PointKind.CORNERPOINT 5675.33884310722,265.456552505492 5675.33884310722,265.456552505492 5675.33884310722,265.456552505492 PathPoint;PointKind.SMOOTHPOINT 5673.00174856186,284.959366321563 5673.48219656944,309.2973446846 5672.77727985382,273.591005802154 PathPoint;PointKind.SMOOTHPOINT 5671.83337831497,353.793368339538 5671.4548971653,364.741351604461 5673.76720809937,297.9039645195 PathPoint;PointKind.SMOOTHPOINT 5681.18034029007,384.768397808074 5680.81071043015,403.854374885558 5681.54997014999,365.682184696197 PathPoint;PointKind.SMOOTHPOINT 5684.68545103073,457.043781280517 5680.21307134628,473.732357025146 5689.15818476677,440.354969501494 PathPoint;PointKind.SMOOTHPOINT 5684.68545103073,479.988212585448 5684.09241461754,490.250751972198 5685.27884149551,469.725909233092 PathPoint;PointKind.SMOOTHPOINT 5677.67522954941,502.932879924773 5673.18904185295,514.73672389984 5682.16141724586,491.129035949706 PathPoint;PointKind.SMOOTHPOINT 5675.33884310722,539.644253253936 5671.67830371857,574.0656208992 5678.99902844429,505.222885608672 PathPoint;PointKind.SMOOTHPOINT 5673.00174856186,577.502517700194 5670.66040539742,586.035161018371 5675.34344577789,568.970110416411 PathPoint;PointKind.SMOOTHPOINT 5668.32826757431,611.919636726378 5666.72158145905,622.262663841247 5669.93459963799,601.57660961151 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,645.189156532287 5673.32287335396,681.395416259765 5674.67959904671,623.403418064117 PathPoint;PointKind.SMOOTHPOINT 5669.4966378212,708.286578655242 5671.01622724533,723.384518623351 5667.33196640015,686.781957149505 PathPoint;PointKind.SMOOTHPOINT 5669.4966378212,744.997951984405 5668.79384541512,760.781335830688 5670.19943022728,729.214568138122 PathPoint;PointKind.SMOOTHPOINT 5670.66500806808,777.120344638824 5670.04435563087,795.771782398223 5671.28601455688,758.469142913817 PathPoint;PointKind.SMOOTHPOINT 5668.32826757431,818.420462608336 5668.08645033836,830.412662029265 5668.57008481026,806.428499221801 PathPoint;PointKind.SMOOTHPOINT 5670.66500806808,847.101237773894 5671.47755646706,867.03434228897 5669.85245966911,827.168133258819 PathPoint;PointKind.SMOOTHPOINT 5668.32826757431,878.076503276824 5668.89864468575,886.380429267882 5667.75789046288,869.772577285766 PathPoint;PointKind.SMOOTHPOINT 5671.83337831497,901.020934581756 5671.60536909103,909.575765132904 5672.0617415905,892.466104030609 PathPoint;PointKind.SMOOTHPOINT 5668.32826757431,917.082130908966 5671.39081382751,925.357024669647 5665.48204684258,909.391894340515 PathPoint;PointKind.SMOOTHPOINT 5673.00174856186,934.290690422058 5672.43137145042,942.688794136047 5673.57212567329,925.892586708068 PathPoint;PointKind.SMOOTHPOINT 5667.15989732742,958.382484912872 5669.35961985588,992.126905918121 5667.15989732742,958.382484912872 PathPoint;PointKind.SMOOTHPOINT 5667.15989732742,999.682602882385 5666.03011870384,1007.40305185318 5668.11902308464,993.130524158477 PathPoint;PointKind.SMOOTHPOINT 5668.32826757431,1014.59667205811 5668.22346830368,1019.31547164917 5668.43342089653,1009.87763643265 PathPoint;PointKind.SMOOTHPOINT 5671.83337831497,1029.51050519943 5671.04809188843,1039.48602676392 5672.61831068993,1019.53498363495 PathPoint;PointKind.SMOOTHPOINT 5668.32826757431,1044.42457437515 5665.05612277985,1054.29270029068 5671.60076642036,1034.55668449402 PathPoint;PointKind.SMOOTHPOINT 5669.4966378212,1065.07451534271 5669.10434865952,1075.87025642395 5669.88928103447,1054.27924633026 PathPoint;PointKind.SMOOTHPOINT 5665.99152708054,1085.72469234467 5664.87803483009,1091.90454483032 5667.10501933098,1079.5450758934 PathPoint;PointKind.SMOOTHPOINT 5671.83337831497,1102.93301582336 5669.37803053856,1112.08855390549 5674.28872609138,1093.77771377563 PathPoint;PointKind.CORNERPOINT 5668.32826757431,1116.69995784759 5668.32826757431,1116.69995784759 5668.32826757431,1116.69995784759 PathPoint;PointKind.SMOOTHPOINT 5671.83337831497,1127.02504634857 5672.93801927567,1132.84636259079 5670.72873735428,1121.20373010635 PathPoint;PointKind.SMOOTHPOINT 5669.4966378212,1138.49726200104 5666.68511414528,1152.50590324402 5672.30816149712,1124.48862075806 PathPoint;PointKind.SMOOTHPOINT 5668.32826757431,1162.58905649185 5668.07264232635,1171.83405160904 5668.58389282227,1153.34406137466 PathPoint;PointKind.SMOOTHPOINT 5668.7485268116,1206.00427865982 5663.03873682022,1216.93904399872 5674.4576086998,1195.06974935532 PathPoint;PointKind.SMOOTHPOINT 5667.15989732742,1232.56994962692 5667.47960591316,1243.88543844223 5666.84018874168,1221.25446081161 PathPoint;PointKind.SMOOTHPOINT 5675.33884310722,1256.66174411774 5674.65835595131,1263.90375137329 5676.01862215996,1249.41973686218 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,1269.28132295608 5675.49391770363,1279.58847284317 5672.84667396545,1258.974173069 PathPoint;PointKind.SMOOTHPOINT 5673.00174856186,1288.78413677216 5673.14797186852,1309.29080486298 5672.85587930679,1268.27746868133 PathPoint;PointKind.SMOOTHPOINT 5671.83337831497,1316.31754875183 5667.5982131958,1326.19912862778 5676.06889748573,1306.43620491028 PathPoint;PointKind.SMOOTHPOINT 5670.66500806808,1344.99832391739 5667.75328779221,1361.10436677933 5673.57672834396,1328.89228105545 PathPoint;PointKind.SMOOTHPOINT 5670.66500806808,1372.53173589706 5670.47311210632,1380.17240524292 5670.85654997826,1364.89106655121 PathPoint;PointKind.CORNERPOINT 5670.66500806808,1398.91802072525 5670.66500806808,1398.91802072525 5670.66500806808,1398.91802072525 PathPoint;PointKind.SMOOTHPOINT 5667.15989732742,1409.24310922623 5666.53464221954,1418.38944196701 5667.7851524353,1400.09654045105 PathPoint;PointKind.SMOOTHPOINT 5668.32826757431,1427.59879589081 5670.44124746323,1439.12034273148 5666.2149336338,1416.07701301575 PathPoint;PointKind.SMOOTHPOINT 5673.00174856186,1445.95448255539 5673.96476888657,1452.81977891922 5672.03872823715,1439.08895015717 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,1470.04604101181 5673.88723158836,1481.90842151642 5674.45300602913,1458.18413257599 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,1492.99070835113 5672.86473059654,1509.65237617493 5675.47550702095,1476.32904052734 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,1518.22962999344 5675.63978695869,1530.76872110367 5672.7004506588,1505.6907749176 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,1541.17453336716 5672.22141885757,1548.64927053451 5676.11917281151,1533.69932413101 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,1559.52998399734 5675.20642781258,1574.14358139038 5673.13416385651,1544.91615056992 PathPoint;PointKind.SMOOTHPOINT 5670.66500806808,1593.94686698914 5667.98165106773,1606.15834236145 5673.34871912003,1581.73515558243 PathPoint;PointKind.SMOOTHPOINT 5676.50685930252,1615.74393510818 5676.96323180199,1627.47626066208 5676.05048680305,1604.01208162308 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,1636.39411211014 5676.83541917801,1650.00409126282 5671.50481843948,1622.78436899185 PathPoint;PointKind.SMOOTHPOINT 5676.50685930252,1663.92776012421 5675.04179382324,1680.23089170456 5677.9719247818,1647.62462854385 PathPoint;PointKind.SMOOTHPOINT 5669.4966378212,1690.313808918 5667.32417726517,1699.12874937057 5671.66909837723,1681.49910449982 PathPoint;PointKind.SMOOTHPOINT 5677.67522954941,1723.5835647583 5674.35705804825,1738.152551651 5680.99340105057,1709.0145778656 PathPoint;PointKind.SMOOTHPOINT 5676.50685930252,1749.96984958649 5676.05048680305,1761.15079879761 5676.96323180199,1738.78890037537 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,1777.50326156616 5676.45233535767,1792.51575708389 5671.88825631142,1762.49053001404 PathPoint;PointKind.CORNERPOINT 5677.67522954941,1799.3005657196 5677.67522954941,1799.3005657196 5677.67522954941,1799.3005657196 PathPoint;PointKind.CORNERPOINT 5674.17011880875,1808.4782910347 5674.17011880875,1808.4782910347 5674.17011880875,1808.4782910347 PathPoint;PointKind.CORNERPOINT 5678.8435997963,1815.36199808121 5678.8435997963,1815.36199808121 5678.8435997963,1815.36199808121 PathPoint;PointKind.SMOOTHPOINT 5675.33884310722,1849.7786450386 5671.99765825272,1864.39224243164 5678.67931985855,1835.16504764557 PathPoint;PointKind.SMOOTHPOINT 5676.50685930252,1872.72307634354 5681.08474636078,1890.97113132477 5671.92932629585,1854.4750213623 PathPoint;PointKind.SMOOTHPOINT 5673.00174856186,1904.84570503235 5670.84274196625,1913.50368261337 5675.16075515747,1896.18772745132 PathPoint;PointKind.CORNERPOINT 5671.83337831497,1923.20139169693 5671.83337831497,1923.20139169693 5671.83337831497,1923.20139169693 PathPoint;PointKind.SMOOTHPOINT 5669.4966378212,1930.08462667465 5670.44124746323,1946.79114103317 5668.55202817917,1913.37811231613 PathPoint;PointKind.CORNERPOINT 5669.4966378212,1955.32354831696 5669.4966378212,1955.32354831696 5669.4966378212,1955.32354831696 PathPoint;PointKind.SMOOTHPOINT 5675.33884310722,1964.50127363205 5677.18238973618,1972.75634050369 5673.49458837509,1956.24667882919 PathPoint;PointKind.SMOOTHPOINT 5671.83337831497,1977.12108850479 5669.25021791458,1995.47653913498 5674.41653871536,1958.76540184021 PathPoint;PointKind.CORNERPOINT 5673.00174856186,2005.80162763596 5673.00174856186,2005.80162763596 5673.00174856186,2005.80162763596 PathPoint;PointKind.SMOOTHPOINT 5673.00174856186,2017.27407932281 5676.10996747017,2032.89601564407 5669.89352965355,2001.65190696716 PathPoint;PointKind.CORNERPOINT 5676.50685930252,2044.80749130249 5676.50685930252,2044.80749130249 5676.50685930252,2044.80749130249 PathPoint;PointKind.SMOOTHPOINT 5673.00174856186,2051.69072628021 5671.03322172165,2062.00967788696 5674.36874175072,2044.52448606491 PathPoint;PointKind.SMOOTHPOINT 5670.66500806808,2073.48826646805 5668.74250793457,2103.33339929581 5671.01622724533,2068.02973508835 PathPoint;PointKind.SMOOTHPOINT 5680.01197004318,2109.05227661133 5682.92970919609,2110.4788684845 5672.54891657829,2105.40224075317 PathPoint;PointKind.CORNERPOINT 5674.17011880875,2133.14407110214 5674.17011880875,2133.14407110214 5674.17011880875,2133.14407110214 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,2149.20503139496 5672.0298769474,2163.6666226387 5676.31071472168,2134.74391222 PathPoint;PointKind.CORNERPOINT 5675.33884310722,2168.70808124542 5675.33884310722,2168.70808124542 5675.33884310722,2168.70808124542 PathPoint;PointKind.CORNERPOINT 5680.01197004318,2187.06376791 5680.01197004318,2187.06376791 5680.01197004318,2187.06376791 PathPoint;PointKind.SMOOTHPOINT 5675.33884310722,2199.68334674835 5673.98282551765,2215.6055188179 5676.69415259361,2183.7611746788 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,2230.65861225128 5669.1224052906,2247.85796642303 5679.21818637848,2213.45878601074 PathPoint;PointKind.CORNERPOINT 5670.66500806808,2255.89753389358 5670.66500806808,2255.89753389358 5670.66500806808,2255.89753389358 PathPoint;PointKind.SMOOTHPOINT 5668.7485268116,2276.97658538818 5671.74238705635,2301.64666414261 5665.75431251526,2252.30674266815 PathPoint;PointKind.SMOOTHPOINT 5671.83337831497,2309.81723070145 5667.79435777664,2318.42587709427 5675.87275290489,2301.20858430862 PathPoint;PointKind.SMOOTHPOINT 5669.74836850166,2325.97543716431 5671.74734377861,2334.83522415161 5667.74939322472,2317.11588621139 PathPoint;PointKind.SMOOTHPOINT 5669.4966378212,2338.498005867 5671.03463792801,2364.61521148682 5667.95863771439,2312.3805642128 PathPoint;PointKind.SMOOTHPOINT 5669.4966378212,2372.9146528244 5667.5663485527,2384.44092035294 5671.42728114128,2361.38862133026 PathPoint;PointKind.SMOOTHPOINT 5673.00174856186,2397.00644731522 5674.58931589127,2406.72351121902 5671.42090821266,2387.33139753342 PathPoint;PointKind.SMOOTHPOINT 5668.32826757431,2419.95111465454 5670.76414251328,2428.59351396561 5666.02657818794,2411.78385257721 PathPoint;PointKind.SMOOTHPOINT 5668.32826757431,2445.19003629684 5662.00242781639,2463.5008764267 5674.65375328064,2426.87919616699 PathPoint;PointKind.SMOOTHPOINT 5671.83337831497,2483.0485367775 5667.55714321136,2498.1641793251 5676.10996747017,2467.93313026428 PathPoint;PointKind.SMOOTHPOINT 5673.00174856186,2515.17116546631 5673.03361320496,2521.60168647766 5672.96988391876,2508.74017238617 PathPoint;PointKind.SMOOTHPOINT 5673.00174856186,2538.11559677124 5675.25210046768,2550.75311422348 5670.75175070763,2525.478079319 PathPoint;PointKind.SMOOTHPOINT 5678.8435997963,2561.06026411057 5680.20386600494,2572.11564302444 5677.48368763924,2550.00464916229 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,2585.15182256699 5671.3773598671,2605.73048114777 5676.96323180199,2564.5734000206 PathPoint;PointKind.SMOOTHPOINT 5671.83337831497,2627.59930372238 5671.40001916885,2642.16829061508 5672.26709151268,2613.03055286407 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,2653.98558855057 5679.33679366112,2671.56165361404 5669.00379800797,2636.40952348709 PathPoint;PointKind.SMOOTHPOINT 5676.50685930252,2694.13857936859 5673.29738163948,2704.67727899551 5678.97176647186,2686.04614019394 PathPoint;PointKind.SMOOTHPOINT 5671.83337831497,2718.23013782501 5671.15784788132,2730.40172338486 5672.50890874863,2706.05902433395 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,2740.02767801285 5674.12444615364,2746.58376932144 5674.21579146385,2733.47158670425 PathPoint;PointKind.SMOOTHPOINT 5675.33884310722,2757.23600149155 5661.4586045742,2785.76642274857 5676.37479805946,2755.1064991951 PathPoint;PointKind.SMOOTHPOINT 5677.67522954941,2806.56695365906 5679.35945296288,2820.27984380722 5675.99136018753,2792.8538274765 PathPoint;PointKind.SMOOTHPOINT 5678.8435997963,2839.83647346497 5678.90732908249,2849.968957901 5678.77951645851,2829.70422506332 PathPoint;PointKind.SMOOTHPOINT 5677.67522954941,2865.07539510727 5677.88057947159,2871.03125095367 5677.46987962723,2859.11977529526 PathPoint;PointKind.SMOOTHPOINT 5676.50685930252,2888.02006244659 5675.88620686531,2905.44813394547 5677.12751173973,2870.59222698212 PathPoint;PointKind.SMOOTHPOINT 5680.01197004318,2925.87879896164 5679.02629041672,2935.96171617508 5680.99800372124,2915.79564571381 PathPoint;PointKind.SMOOTHPOINT 5675.33884310722,2952.26484775543 5673.25277113914,2961.94910287857 5677.42420697212,2942.58059263229 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,2975.20951509476 5674.54895401001,2988.28605651855 5673.79128360748,2962.13297367096 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,3005.0374174118 5676.34257936478,3023.18681001663 5671.99765825272,2986.88778877258 PathPoint;PointKind.SMOOTHPOINT 5669.4966378212,3040.60142755508 5667.74691486359,3046.73832178116 5673.88192081451,3025.22213459015 PathPoint;PointKind.CORNERPOINT 5675.33884310722,3058.95711421967 5675.33884310722,3058.95711421967 5675.33884310722,3058.95711421967 PathPoint;PointKind.SMOOTHPOINT 5675.33884310722,3079.60729122162 5680.01657271385,3102.79531002045 5671.91941285133,3062.65789747238 PathPoint;PointKind.SMOOTHPOINT 5671.83337831497,3122.05477237701 5672.94262194633,3140.67906618118 5670.72413468361,3103.43024253845 PathPoint;PointKind.CORNERPOINT 5674.17011880875,3153.02980184555 5674.17011880875,3153.02980184555 5674.17011880875,3153.02980184555 PathPoint;PointKind.SMOOTHPOINT 5671.83337831497,3164.50201749802 5670.78361535072,3172.62230873108 5672.88314127922,3156.38196229935 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,3177.12183237076 5674.64065337181,3182.24684715271 5673.41705107689,3168.91609668732 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,3223.01093101501 5674.80882787704,3229.04703855515 5673.20462012291,3213.89197826385 PathPoint;PointKind.CORNERPOINT 5670.66500806808,3237.92476415634 5670.66500806808,3237.92476415634 5670.66500806808,3237.92476415634 PathPoint;PointKind.SMOOTHPOINT 5665.99152708054,3265.45817613602 5666.90887475014,3292.46287107468 5665.07417941093,3238.45348119736 PathPoint;PointKind.SMOOTHPOINT 5669.4966378212,3306.75829410553 5670.45505547523,3316.5367269516 5668.53822016716,3296.97986125946 PathPoint;PointKind.SMOOTHPOINT 5670.66500806808,3334.29170608521 5669.86626768112,3340.01459598541 5671.46374845505,3328.56905221939 PathPoint;PointKind.SMOOTHPOINT 5673.00174856186,3365.26697158813 5673.10690188408,3371.6125202179 5672.89694929123,3358.92142295837 PathPoint;PointKind.SMOOTHPOINT 5680.01197004318,3383.62265825272 5683.03344631195,3399.04302120209 5676.990847826,3368.20229530334 PathPoint;PointKind.SMOOTHPOINT 5678.8435997963,3405.41996240616 5678.53769922256,3414.19005632401 5679.14950037003,3396.65010452271 PathPoint;PointKind.SMOOTHPOINT 5677.67522954941,3437.54235506058 5674.22499680519,3446.85910463333 5681.12581634521,3428.22560548782 PathPoint;PointKind.SMOOTHPOINT 5681.18034029007,3455.89804172516 5680.78344845772,3467.29873895645 5681.57758617401,3444.49734449387 PathPoint;PointKind.CORNERPOINT 5677.67522954941,3476.54821872711 5677.67522954941,3476.54821872711 5677.67522954941,3476.54821872711 PathPoint;PointKind.SMOOTHPOINT 5677.67522954941,3501.78714036942 5672.7461233139,3515.70632457733 5682.60433578491,3487.86819219589 PathPoint;PointKind.SMOOTHPOINT 5670.66500806808,3530.46791553497 5672.5273194313,3538.42675924301 5668.80305075645,3522.50907182693 PathPoint;PointKind.SMOOTHPOINT 5674.17011880875,3554.55947399139 5672.89234662056,3561.08464479446 5675.44824504852,3548.03477525711 PathPoint;PointKind.SMOOTHPOINT 5675.33884310722,3568.32641601562 5685.96959614754,3574.42719697952 5661.1059691906,3560.1589179039 PathPoint;PointKind.SMOOTHPOINT 5684.68545103073,3587.8292298317 5682.62487077713,3596.76124334335 5685.65590643883,3583.6230969429 PathPoint;PointKind.SMOOTHPOINT 5680.01197004318,3601.59593582153 5677.35587501526,3614.42157268524 5682.66806507111,3588.77053499222 PathPoint;PointKind.CORNERPOINT 5678.8435997963,3636.01305484772 5678.8435997963,3636.01305484772 5678.8435997963,3636.01305484772 PathPoint;PointKind.SMOOTHPOINT 5675.74918889999,3650.91036558151 5675.04250192642,3651.7574930191 5680.55968785286,3645.14286518097 PathPoint;PointKind.SMOOTHPOINT 5672.74895572662,3670.94095230103 5671.47578620911,3695.92000007629 5672.33436131477,3679.07540559769 PathPoint;PointKind.SMOOTHPOINT 5677.74922633171,3697.90906190872 5670.78892612457,3708.17160129547 5684.70917248726,3687.64675855637 PathPoint;PointKind.SMOOTHPOINT 5678.74906802177,3717.90872812271 5680.82947516441,3726.62665843964 5676.73593068123,3709.47026252747 PathPoint;PointKind.SMOOTHPOINT 5677.74922633171,3731.90816402435 5677.14096570015,3736.35646820068 5679.05036592484,3722.4006986618 PathPoint;PointKind.SMOOTHPOINT 5676.50685930252,3741.55772209167 5686.82144427299,3751.44614696503 5673.12495851517,3738.31531763077 PathPoint;PointKind.SMOOTHPOINT 5679.4996573925,3759.90750789642 5679.51771402359,3763.78390073776 5679.48124670982,3756.03135108948 PathPoint;PointKind.SMOOTHPOINT 5670.66500806808,3777.12196826935 5661.45966672897,3779.66287851334 5679.87070345879,3774.58105802536 PathPoint;PointKind.SMOOTHPOINT 5655.47584080696,3775.97460508347 5649.42439103127,3776.12708330154 5661.52799868584,3775.82212686539 PathPoint;PointKind.SMOOTHPOINT 5648.46597337723,3780.56358575821 5639.99033236504,3781.59883260727 5656.94126033783,3779.52833890915 PathPoint;PointKind.SMOOTHPOINT 5634.44517636299,3777.12196826935 5627.61304283142,3776.90670490265 5641.27766394615,3777.33699560165 PathPoint;PointKind.SMOOTHPOINT 5625.09856843948,3781.71094894409 5616.59566545486,3782.31142044067 5633.60111737251,3781.11047744751 PathPoint;PointKind.SMOOTHPOINT 5607.57266068459,3774.82724189758 5603.05885696411,3774.99317407608 5612.08646440506,3774.66178178787 PathPoint;PointKind.SMOOTHPOINT 5595.88895821571,3779.41645860672 5585.04931473732,3780.0841999054 5606.72824764252,3778.74871730804 PathPoint;PointKind.CORNERPOINT 5576.02666401863,3780.56358575821 5576.02666401863,3780.56358575821 5576.02666401863,3780.56358575821 PathPoint;PointKind.SMOOTHPOINT 5559.66912651062,3777.12196826935 5549.72877407074,3777.12196826935 5569.6094789505,3777.12196826935 PathPoint;PointKind.SMOOTHPOINT 5533.9649810791,3780.56358575821 5522.21259260178,3780.20504951477 5545.71701550484,3780.92212200165 PathPoint;PointKind.SMOOTHPOINT 5502.73338222504,3776.93809747696 5499.90415596962,3776.37137889862 5510.13553881645,3778.42039346695 PathPoint;PointKind.SMOOTHPOINT 5484.73162913322,3775.9382557869 5466.55178809166,3777.79797077179 5491.19767332077,3775.27665138245 PathPoint;PointKind.CORNERPOINT 5454.51509618759,3778.26909542084 5454.51509618759,3778.26909542084 5454.51509618759,3778.26909542084 PathPoint;PointKind.SMOOTHPOINT 5438.15791273117,3777.12196826935 5426.57440686226,3779.8689365387 5449.74141860008,3774.375 PathPoint;PointKind.CORNERPOINT 5420.63200497627,3781.71094894409 5420.63200497627,3781.71094894409 5420.63200497627,3781.71094894409 PathPoint;PointKind.SMOOTHPOINT 5412.72461676598,3774.93817806244 5399.45263886452,3775.10411024094 5425.99694871902,3774.77248191833 PathPoint;PointKind.CORNERPOINT 5396.09622979164,3775.97460508347 5396.09622979164,3775.97460508347 5396.09622979164,3775.97460508347 PathPoint;PointKind.SMOOTHPOINT 5386.74926781654,3780.56358575821 5377.27449321747,3781.13714933395 5396.22404241562,3779.99002218246 PathPoint;PointKind.SMOOTHPOINT 5366.88661956787,3775.97460508347 5349.25626659393,3776.01945161819 5384.5173265934,3775.92975854874 PathPoint;PointKind.SMOOTHPOINT 5342.35084438324,3781.71094894409 5333.5700109005,3783.49890947342 5351.13167786598,3779.92275238037 PathPoint;PointKind.SMOOTHPOINT 5310.80484771729,3782.85807609558 5305.35953426361,3782.8221988678 5316.24945306778,3782.89395332336 PathPoint;PointKind.CORNERPOINT 5297.95242094994,3784.00520324707 5297.95242094994,3784.00520324707 5297.95242094994,3784.00520324707 PathPoint;PointKind.SMOOTHPOINT 5283.93197798729,3786.29969358444 5275.20106577873,3783.8843536377 5292.66289019585,3788.71526956558 PathPoint;PointKind.SMOOTHPOINT 5261.73294329643,3784.00520324707 5249.62013030052,3785.15681505203 5273.84540224075,3782.85359144211 PathPoint;PointKind.SMOOTHPOINT 5247.7121462822,3790.88867425919 5236.39347100258,3790.9693980217 5259.03082156181,3790.80795049667 PathPoint;PointKind.SMOOTHPOINT 5224.34474134445,3786.29969358444 5215.55682682991,3784.94721651077 5233.53981518745,3787.71471977234 PathPoint;PointKind.SMOOTHPOINT 5212.66068482399,3792.03603744507 5206.49523043633,3792.41699695587 5218.82684731483,3791.65507793427 PathPoint;PointKind.SMOOTHPOINT 5192.79839062691,3786.29969358444 5182.1956076622,3788.1431221962 5206.0339012146,3783.99859428406 PathPoint;PointKind.SMOOTHPOINT 5183.45142865181,3793.18292856216 5177.65064740181,3795.997402668 5189.25220990181,3790.36892652512 PathPoint;PointKind.CORNERPOINT 5163.58913445473,3793.18292856216 5163.58913445473,3793.18292856216 5163.58913445473,3793.18292856216 PathPoint;PointKind.SMOOTHPOINT 5151.90543198586,3790.88867425919 5141.78238892555,3790.42274236679 5162.02812099457,3791.35484218597 PathPoint;PointKind.CORNERPOINT 5132.04278373718,3793.18292856216 5132.04278373718,3793.18292856216 5132.04278373718,3793.18292856216 PathPoint;PointKind.SMOOTHPOINT 5115.68560028076,3795.47741889954 5108.15492296219,3795.54020404816 5123.21627759933,3795.41486978531 PathPoint;PointKind.SMOOTHPOINT 5099.32841682434,3793.18292856216 5082.81580471992,3791.73580169678 5115.84067487717,3794.63052749634 PathPoint;PointKind.CORNERPOINT 5073.62391734123,3793.18292856216 5073.62391734123,3793.18292856216 5073.62391734123,3793.18292856216 PathPoint;PointKind.SMOOTHPOINT 5059.60347437859,3793.18292856216 5053.28223729134,3792.35421180725 5065.92435741425,3794.01211738586 PathPoint;PointKind.CORNERPOINT 5046.75104761124,3792.03603744507 5046.75104761124,3792.03603744507 5046.75104761124,3792.03603744507 PathPoint;PointKind.CORNERPOINT 5038.57245588303,3793.18292856216 5038.57245588303,3793.18292856216 5038.57245588303,3793.18292856216 PathPoint;PointKind.SMOOTHPOINT 5026.88875341415,3797.77190923691 5020.23435378075,3796.76380634308 5033.54315304756,3798.78024816513 PathPoint;PointKind.SMOOTHPOINT 5017.54214549065,3792.03603744507 5005.82622432709,3790.57498455048 5029.25771260262,3793.49661827087 PathPoint;PointKind.SMOOTHPOINT 4990.66927576065,3793.18292856216 4972.23522567749,3793.52801084518 5009.10297179222,3792.83808231354 PathPoint;PointKind.SMOOTHPOINT 4957.95455479622,3793.18292856216 4951.94382095337,3793.11589479446 4963.96528863907,3793.25019836426 PathPoint;PointKind.SMOOTHPOINT 4946.27085232735,3789.7415471077 4937.65854740143,3789.42337274551 4954.88280320168,3790.05972146988 PathPoint;PointKind.SMOOTHPOINT 4929.91366887093,3795.47741889954 4907.70047211647,3793.7744307518 4952.12651157379,3797.18040704727 PathPoint;PointKind.SMOOTHPOINT 4897.19894790649,3787.44705677032 4889.30182719231,3787.08686828613 4906.44252681732,3787.86837816238 PathPoint;PointKind.SMOOTHPOINT 4870.3260781765,3792.03603744507 4864.29268503189,3791.60574674606 4876.3598253727,3792.46609210968 PathPoint;PointKind.SMOOTHPOINT 4862.14748644829,3787.44705677032 4851.80068278313,3786.08018159866 4872.49429011345,3788.81369590759 PathPoint;PointKind.SMOOTHPOINT 4825.92800879478,3794.33029174805 4801.93534874916,3788.32534074783 4849.92066884041,3800.33547878265 PathPoint;PointKind.SMOOTHPOINT 4781.52958536148,3786.29969358444 4776.49532580376,3786.21448516846 4786.5638449192,3786.38490200043 PathPoint;PointKind.SMOOTHPOINT 4756.99345612526,3787.44705677032 4734.82770228386,3787.42085695267 4775.90228939056,3787.4692440033 PathPoint;PointKind.SMOOTHPOINT 4692.73273849487,3790.88867425919 4672.97772192955,3789.86688137054 4714.2378320694,3792.00086832047 PathPoint;PointKind.SMOOTHPOINT 4661.18674182892,3787.44705677032 4633.72508430481,3784.67294454575 4688.64804530144,3790.22093296051 PathPoint;PointKind.SMOOTHPOINT 4630.80876135826,3787.44705677032 4619.58143138885,3786.80598735809 4642.03609132767,3788.08789014816 PathPoint;PointKind.SMOOTHPOINT 4602.76787543297,3788.59418392181 4589.56847810745,3793.61770391464 4615.9665646553,3783.57066392899 PathPoint;PointKind.SMOOTHPOINT 4574.7262814045,3793.18292856216 4557.83058547974,3792.54681587219 4591.62233138084,3793.81927728653 PathPoint;PointKind.SMOOTHPOINT 4539.67517399788,3789.7415471077 4529.22852778435,3787.56342172623 4550.122174263,3791.91943645477 PathPoint;PointKind.SMOOTHPOINT 4497.61349105835,3785.15233039856 4455.83965206146,3785.39001703262 4539.38768410683,3784.91487979889 PathPoint;PointKind.SMOOTHPOINT 4434.52114367485,3782.85807609558 4418.91702795029,3782.61614084244 4450.125613451,3783.10024738312 PathPoint;PointKind.SMOOTHPOINT 4413.49047923088,3784.00520324707 4403.25803422928,3786.56405210495 4423.72292423248,3781.44659042358 PathPoint;PointKind.SMOOTHPOINT 4374.9342610836,3785.15233039856 4361.15528130531,3785.62298297882 4388.71253275871,3784.68191385269 PathPoint;PointKind.SMOOTHPOINT 4353.90324258804,3781.71094894409 4338.02509093285,3780.12007713318 4369.78104019165,3783.301820755 PathPoint;PointKind.CORNERPOINT 4330.53548359871,3780.56358575821 4330.53548359871,3780.56358575821 4330.53548359871,3780.56358575821 PathPoint;PointKind.CORNERPOINT 4322.3568918705,3787.44705677033 4322.3568918705,3787.44705677033 4322.3568918705,3787.44705677033 PathPoint;PointKind.CORNERPOINT 4311.84155964851,3784.00520324707 4311.84155964851,3784.00520324707 4311.84155964851,3784.00520324707 PathPoint;PointKind.SMOOTHPOINT 4298.98948693275,3781.71094894409 4294.83646178246,3788.26255559921 4303.14286613464,3775.15887022018 PathPoint;PointKind.SMOOTHPOINT 4286.13706016541,3780.56358575821 4274.14320850372,3782.95225381851 4298.13161993027,3778.17491769791 PathPoint;PointKind.SMOOTHPOINT 4270.61968708038,3775.90709924698 4267.86941432953,3777.64478445053 4279.15870332718,3770.51276922226 PathPoint;PointKind.SMOOTHPOINT 4252.25432300568,3775.97460508347 4245.20763421059,3781.01629972458 4259.30101180077,3770.93314647675 PathPoint;PointKind.SMOOTHPOINT 4233.56039905548,3778.26909542084 4216.06635594368,3775.62503814697 4251.0537340641,3780.9131526947 PathPoint;PointKind.SMOOTHPOINT 4205.51951313019,3780.56358575821 4195.12243413925,3784.51149702072 4215.91588401794,3776.6154384613 PathPoint;PointKind.SMOOTHPOINT 4189.16197562218,3780.56358575821 4170.49495959282,3775.35171031952 4207.82863759995,3785.7754611969 PathPoint;PointKind.SMOOTHPOINT 4162.28910589218,3779.41645860672 4153.80036497116,3780.19608020783 4170.77820086479,3778.63660097122 PathPoint;PointKind.SMOOTHPOINT 4135.41659021378,3781.71094894409 4116.61751294136,3783.79914522171 4154.21566748619,3779.62251663208 PathPoint;PointKind.SMOOTHPOINT 4110.88081502914,3782.85807609558 4105.97897076607,3782.04257726669 4115.78230524063,3783.67381095886 PathPoint;PointKind.SMOOTHPOINT 4085.17631554604,3781.71094894409 4058.27158117294,3778.03612947464 4112.08069586754,3785.38553237915 PathPoint;PointKind.SMOOTHPOINT 4047.78846764565,3780.56358575821 4032.47609043121,3780.76539516449 4063.1001367569,3780.36201238632 PathPoint;PointKind.SMOOTHPOINT 4013.90537643433,3781.71094894409 4005.68111205101,3784.61912870407 4022.12964081764,3778.80229711533 PathPoint;PointKind.SMOOTHPOINT 3985.86413645744,3784.00520324707 3978.64254617691,3783.82746934891 4000.41388654709,3784.36373949051 PathPoint;PointKind.SMOOTHPOINT 3880.71010613442,3782.85807609558 3821.73006796837,3782.36523628235 3926.67095923424,3783.24234008789 PathPoint;PointKind.SMOOTHPOINT 3816.44938850403,3787.44705677033 3807.63173365593,3787.15106964111 3825.26704335213,3787.74280786514 PathPoint;PointKind.SMOOTHPOINT 3794.25035381317,3787.44705677033 3786.59186387062,3785.19269227982 3801.90884375572,3789.70118522644 PathPoint;PointKind.SMOOTHPOINT 3779.06154060364,3790.88867425919 3770.38975501061,3794.15090560913 3787.73297214508,3787.62620687485 PathPoint;PointKind.SMOOTHPOINT 3768.54585433006,3787.44705677033 3756.98996448517,3787.92195796967 3780.10174417496,3786.97191953659 PathPoint;PointKind.SMOOTHPOINT 3755.6937816143,3793.18292856216 3749.44370889664,3794.60385560989 3765.37001156807,3790.9833240509 PathPoint;PointKind.SMOOTHPOINT 3741.67333865166,3786.29969358444 3732.46764326096,3788.71951818466 3751.37045764923,3783.75075817108 PathPoint;PointKind.SMOOTHPOINT 3725.31615519524,3789.7415471077 3718.83807325363,3788.80236625671 3732.27185273171,3790.74988603592 PathPoint;PointKind.SMOOTHPOINT 3698.44328546524,3788.59418392181 3683.56001877785,3788.48206758499 3713.32655215263,3788.70630025864 PathPoint;PointKind.SMOOTHPOINT 3662.22345376015,3785.15233039856 3649.71197867394,3786.56310796738 3676.20530509949,3783.57609272003 PathPoint;PointKind.SMOOTHPOINT 3636.51930832863,3789.7415471077 3613.64615941048,3792.4724650383 3647.90879392624,3788.38151693344 PathPoint;PointKind.SMOOTHPOINT 3566.41638541222,3787.44705677033 3558.47500824928,3787.43808746338 3575.74493670464,3787.45720624924 PathPoint;PointKind.SMOOTHPOINT 3531.36492395401,3788.59418392181 3517.80120754242,3792.5288772583 3544.92934846878,3784.65949058533 PathPoint;PointKind.SMOOTHPOINT 3510.33461356163,3790.88867425919 3503.68021392822,3790.48529148102 3516.98865914345,3791.29205703735 PathPoint;PointKind.SMOOTHPOINT 3481.12500333786,3787.44705677033 3471.1134865284,3785.48348665237 3492.39163303375,3789.65633869171 PathPoint;PointKind.SMOOTHPOINT 3455.42085790634,3789.7415471077 3442.99470925331,3788.63076925278 3467.74114513397,3790.84264755249 PathPoint;PointKind.SMOOTHPOINT 3426.21124768257,3788.59418392181 3412.04918408394,3788.5134601593 3440.3733112812,3788.67490768433 PathPoint;PointKind.SMOOTHPOINT 3402.84384274483,3787.44705677033 3393.52378869057,3786.25933170319 3412.16318869591,3788.63454580307 PathPoint;PointKind.SMOOTHPOINT 3378.30735945702,3788.59418392181 3358.43161129952,3789.77742433548 3398.1838157177,3787.41117954254 PathPoint;PointKind.SMOOTHPOINT 3339.75114130974,3796.62478208542 3320.05454325676,3793.25680732727 3357.26005458832,3799.61864233017 PathPoint;PointKind.SMOOTHPOINT 3303.53166365624,3787.44705677033 3283.36984181404,3783.45099449158 3322.86500477791,3791.27883911133 PathPoint;PointKind.SMOOTHPOINT 3278.99553442001,3790.88867425919 3263.33760285378,3791.09567642212 3287.81779193878,3790.77230930328 PathPoint;PointKind.SMOOTHPOINT 3243.9444270134,3789.7415471077 3226.27087974548,3790.79614877701 3261.13717222214,3788.71526956558 PathPoint;PointKind.SMOOTHPOINT 3196.04053878784,3794.33029174805 3161.73789644241,3793.08473825455 3230.34353518486,3795.57608127594 PathPoint;PointKind.SMOOTHPOINT 3128.27471041679,3788.59418392181 3092.79059791565,3787.3915886879 3152.38774800301,3789.41133499146 PathPoint;PointKind.SMOOTHPOINT 3032.46799612045,3789.7415471077 2998.0672814846,3789.31196451187 3057.08060050011,3790.04862785339 PathPoint;PointKind.SMOOTHPOINT 2914.46153903008,3789.7415471077 2900.14900350571,3791.050593853 2954.49981713295,3786.0790014267 PathPoint;PointKind.SMOOTHPOINT 2884.08391261101,3790.88867425919 2885.21723175049,3790.90826511383 2897.85793566704,3791.12612485886 PathPoint;PointKind.SMOOTHPOINT 2794.1190495491,3788.59418392181 2781.35124111176,3788.96711826325 2834.06633639336,3787.42722988129 PathPoint;PointKind.SMOOTHPOINT 2760.23595833778,3792.03603744507 2755.34331941605,3793.05783033371 2765.12824320793,3791.01424455643 PathPoint;PointKind.SMOOTHPOINT 2721.67938613892,3792.03603744507 2690.97744846344,3789.76397037506 2752.38132381439,3794.30786848068 PathPoint;PointKind.SMOOTHPOINT 2652.74518752098,3789.7415471077 2628.29155230522,3788.84060382843 2677.19882273674,3790.64225435257 PathPoint;PointKind.SMOOTHPOINT 2596.66270756722,3788.59418392181 2584.29922604561,3788.69733095169 2609.026897192,3788.49103689194 PathPoint;PointKind.SMOOTHPOINT 2567.45345139504,3790.88867425919 2550.95464730263,3792.49300003052 2583.95225548744,3789.28434848785 PathPoint;PointKind.SMOOTHPOINT 2528.89723324776,3790.88867425919 2517.87065052986,3790.19850969315 2539.92381596565,3791.57883882523 PathPoint;PointKind.SMOOTHPOINT 2502.02436351776,3789.7415471077 2490.94290280342,3789.36955690384 2513.1058242321,3790.11330127716 PathPoint;PointKind.SMOOTHPOINT 2482.16206932068,3792.03603744507 2486.1695792675,3792.19984531403 2489.39569735527,3792.33178853989 PathPoint;PointKind.SMOOTHPOINT 2415.56425714493,3788.59418392181 2408.64077830315,3788.83611917496 2433.70054984093,3787.96043157578 PathPoint;PointKind.SMOOTHPOINT 2396.87033319473,3789.7415471077 2383.52542066574,3790.68261623383 2410.21524572373,3788.80024194717 PathPoint;PointKind.SMOOTHPOINT 2364.1556122303,3790.88867425919 2347.19123029709,3791.2023639679 2381.11999416351,3790.57498455048 PathPoint;PointKind.SMOOTHPOINT 2336.11472630501,3789.7415471077 2323.54093813896,3787.29906320572 2348.68851447105,3792.18379497528 PathPoint;PointKind.SMOOTHPOINT 2318.58881855011,3793.18292856216 2312.60074400902,3793.86860847473 2324.5768930912,3792.49748468399 PathPoint;PointKind.SMOOTHPOINT 2301.0632648468,3793.18292856216 2284.58287143707,3792.3631811142 2317.54401230812,3794.00314807892 PathPoint;PointKind.SMOOTHPOINT 2268.34889793396,3789.7415471077 2246.37326979637,3787.39324092865 2290.32452607155,3792.08985328674 PathPoint;PointKind.SMOOTHPOINT 2233.29743647575,3789.7415471077 2226.15019702911,3791.13060951233 2240.44467592239,3788.35224866867 PathPoint;PointKind.SMOOTHPOINT 2212.2664179802,3796.62478208542 2198.63153719902,3796.42627716064 2224.96624851227,3796.80959701538 PathPoint;PointKind.SMOOTHPOINT 2170.20473504067,3794.33029174805 2160.62976384163,3794.61258888245 2177.75948786736,3794.10747528076 PathPoint;PointKind.SMOOTHPOINT 2126.97503590584,3794.33029174805 2120.5900695324,3792.64099359512 2133.36000227928,3796.01982593536 PathPoint;PointKind.SMOOTHPOINT 2110.61785244942,3796.62478208542 2097.70169639587,3796.41872406006 2123.53365445137,3796.83084011078 PathPoint;PointKind.SMOOTHPOINT 2089.58718800545,3794.33029174805 2077.09978842735,3793.9896941185 2102.07387948036,3794.67088937759 PathPoint;PointKind.SMOOTHPOINT 2066.21907496452,3801.21376276016 2053.26220297814,3799.40786361694 2079.17665505409,3803.01966190338 PathPoint;PointKind.SMOOTHPOINT 2026.49448657036,3793.18292856216 2017.45342516899,3793.46971035004 2035.53554797173,3792.89638280869 PathPoint;PointKind.SMOOTHPOINT 2007.80020856857,3797.77190923691 1992.65706801415,3798.72218370438 2022.94370317459,3796.82187080383 PathPoint;PointKind.SMOOTHPOINT 1977.42258214951,3796.62478208542 1959.85525035858,3796.84901475906 1996.73255586624,3796.3783621788 PathPoint;PointKind.SMOOTHPOINT 1899.14142155647,3797.77190923691 1889.20992040634,3798.25153112412 1910.82476997376,3797.20802307129 PathPoint;PointKind.SMOOTHPOINT 1855.91136837006,3798.91927242279 1841.32479691506,3798.73115301132 1870.49793982506,3799.10739183426 PathPoint;PointKind.SMOOTHPOINT 1823.19664740563,3798.91927242279 1816.95330166817,3798.31880092621 1829.44034719467,3799.51974391937 PathPoint;PointKind.SMOOTHPOINT 1806.8394639492,3790.88867425919 1795.10088348389,3790.34650325775 1818.57804441452,3791.43108129501 PathPoint;PointKind.CORNERPOINT 1797.49250197411,3797.77190923691 1797.49250197411,3797.77190923691 1797.49250197411,3797.77190923691 PathPoint;PointKind.SMOOTHPOINT 1777.62985372543,3792.03603744507 1767.41121673584,3789.92518186569 1787.84884476662,3794.14642095566 PathPoint;PointKind.SMOOTHPOINT 1733.23178434372,3788.59418392181 1725.82891964913,3789.38301086426 1740.63464903832,3787.80535697937 PathPoint;PointKind.SMOOTHPOINT 1708.6956551075,3792.03603744507 1699.71832299233,3792.65893220902 1717.67298722267,3791.41314268112 PathPoint;PointKind.SMOOTHPOINT 1684.15987992287,3793.18292856217 1663.174888134,3791.83422803879 1705.14522576332,3794.53186511993 PathPoint;PointKind.SMOOTHPOINT 1653.78189945221,3792.03603744507 1646.82620191574,3791.10393762589 1660.73759698868,3792.96813726425 PathPoint;PointKind.SMOOTHPOINT 1638.59308624268,3792.03603744507 1633.64132070541,3792.26451873779 1643.54520583153,3791.80732011795 PathPoint;PointKind.CORNERPOINT 1628.07775402069,3795.47741889954 1628.07775402069,3795.47741889954 1628.07775402069,3795.47741889954 PathPoint;PointKind.SMOOTHPOINT 1621.06753253937,3790.88867425919 1610.86234951019,3791.06357574463 1631.27236151695,3790.71400880814 PathPoint;PointKind.SMOOTHPOINT 1607.04673552513,3793.18292856217 1599.61660885811,3794.46459531784 1614.47686219215,3791.90149784088 PathPoint;PointKind.SMOOTHPOINT 1594.19466280937,3793.18292856217 1587.0063533783,3791.54296159744 1601.38297224045,3794.82313156128 PathPoint;PointKind.SMOOTHPOINT 1581.34259009361,3792.03603744507 1572.93563508988,3792.40802764893 1589.74954509735,3791.66404724121 PathPoint;PointKind.SMOOTHPOINT 1564.9850525856,3789.7415471077 1554.28278112412,3789.2933177948 1575.68767809868,3790.1895403862 PathPoint;PointKind.SMOOTHPOINT 1547.45985293388,3789.7415471077 1536.81175136566,3790.61086177826 1558.10724639893,3788.87199640274 PathPoint;PointKind.SMOOTHPOINT 1531.10231542587,3785.15233039856 1510.39560818672,3784.32337760925 1551.80902266502,3785.98151922226 PathPoint;PointKind.SMOOTHPOINT 1505.39816999436,3792.03603744507 1499.80238461495,3793.14256668091 1510.99324727059,3790.92903614044 PathPoint;PointKind.SMOOTHPOINT 1484.3671514988,3792.03603744507 1462.07216882706,3792.39905834198 1506.66213417053,3791.67301654816 PathPoint;PointKind.SMOOTHPOINT 1448.14767384529,3792.03603744507 1414.53366184235,3788.59866857529 1481.76133179665,3795.47293424606 PathPoint;PointKind.SMOOTHPOINT 1401.41250991821,3793.18292856217 1389.15347361565,3792.26003408432 1413.67119216919,3794.1060590744 PathPoint;PointKind.SMOOTHPOINT 1367.52941870689,3793.18292856217 1346.76323080063,3792.95916795731 1388.29525256157,3793.40716123581 PathPoint;PointKind.SMOOTHPOINT 1327.80447626114,3794.33029174805 1317.25267672539,3794.20920610428 1338.35627579689,3794.45114135742 PathPoint;PointKind.SMOOTHPOINT 1306.77381181717,3793.18292856217 1282.37045192719,3791.61471605301 1331.17717170715,3794.75161314011 PathPoint;PointKind.SMOOTHPOINT 1256.53353714943,3788.59418392181 1244.53048014641,3786.04878902435 1268.53659415245,3791.13957881928 PathPoint;PointKind.SMOOTHPOINT 1231.9977619648,3787.44705677033 1225.24281167984,3788.43297243118 1238.75200414658,3786.46090507507 PathPoint;PointKind.SMOOTHPOINT 1200.45141124725,3788.59418392181 1191.35547184944,3788.41951847077 1209.54735064507,3788.76908540726 PathPoint;PointKind.SMOOTHPOINT 1165.39994978905,3793.18292856217 1148.84662175179,3793.76569747925 1181.9536318779,3792.60063171387 PathPoint;PointKind.CORNERPOINT 1140.86417460442,3790.88867425919 1140.86417460442,3790.88867425919 1140.86417460442,3790.88867425919 PathPoint;PointKind.CORNERPOINT 1131.51685857773,3794.33029174805 1131.51685857773,3794.33029174805 1131.51685857773,3794.33029174805 PathPoint;PointKind.CORNERPOINT 1126.84337759018,3789.7415471077 1126.84337759018,3789.7415471077 1126.84337759018,3789.7415471077 PathPoint;PointKind.SMOOTHPOINT 1110.48619413376,3789.7415471077 1097.31016421318,3787.06609725952 1123.66222405434,3792.41699695587 PathPoint;PointKind.SMOOTHPOINT 1085.95041894913,3790.88867425919 1069.89878201485,3785.77097654343 1102.00205588341,3796.00637197495 PathPoint;PointKind.SMOOTHPOINT 1047.39384675026,3790.88867425919 1042.75683307648,3784.896941185 1052.03086042404,3796.88017129898 PathPoint;PointKind.SMOOTHPOINT 1021.68970131874,3789.7415471077 1012.57535123825,3787.60826826096 1030.80369734764,3791.87458992004 PathPoint;PointKind.SMOOTHPOINT 993.648461341859,3794.33029174805 982.535135984422,3791.76270961762 1004.7617866993,3796.89810991287 PathPoint;PointKind.SMOOTHPOINT 965.607221364976,3793.18292856217 957.679652214051,3790.85728168488 973.534790515901,3795.50881147385 PathPoint;PointKind.SMOOTHPOINT 944.576556921006,3793.18292856217 934.90103507042,3788.8450884819 954.252078771592,3797.52100467682 PathPoint;PointKind.SMOOTHPOINT 925.882632970811,3793.18292856217 916.380596399308,3789.23950195313 935.384669542314,3797.1265912056 PathPoint;PointKind.SMOOTHPOINT 900.178133487702,3792.03603744507 881.484209537507,3791.94634437561 918.872411489488,3792.12549448013 PathPoint;PointKind.CORNERPOINT 870.968877315522,3794.33029174805 870.968877315522,3794.33029174805 870.968877315522,3794.33029174805 PathPoint;PointKind.SMOOTHPOINT 844.096361637116,3793.18292856217 831.823871374131,3791.99567556381 856.368851900102,3794.3706536293 PathPoint;PointKind.SMOOTHPOINT 816.054767608643,3790.88867425919 796.174416780473,3791.31448030472 835.935826539994,3790.46286821365 PathPoint;PointKind.SMOOTHPOINT 785.677495241166,3793.18292856217 764.167090892793,3792.77978181839 807.18719148636,3793.58631134033 PathPoint;PointKind.SMOOTHPOINT 759.972995758058,3794.33029174805 754.139995813371,3794.29441452026 765.805641651154,3794.36616897583 PathPoint;PointKind.SMOOTHPOINT 734.268496274949,3794.33029174805 726.998046875001,3792.67238616943 741.538945674897,3795.98843336105 PathPoint;PointKind.SMOOTHPOINT 714.406202077867,3794.33029174805 704.360696315766,3794.45114135742 724.451707839967,3794.20920610428 PathPoint;PointKind.SMOOTHPOINT 671.17614889145,3794.33029174805 664.558570623399,3793.70291233063 677.794081211091,3794.95767116547 PathPoint;PointKind.CORNERPOINT 632.619930744172,3794.33029174805 632.619930744172,3794.33029174805 632.619930744172,3794.33029174805 PathPoint;PointKind.SMOOTHPOINT 604.578336715699,3793.18292856217 583.985988140107,3793.92242431641 625.171393394471,3792.44366884232 PathPoint;PointKind.SMOOTHPOINT 554.338416099549,3790.88867425919 548.605966806413,3787.44257211685 560.070865392686,3794.33477640152 PathPoint;PointKind.SMOOTHPOINT 525.129159927369,3796.62478208542 516.156430482865,3802.89857625961 534.101535320283,3790.35098791123 PathPoint;PointKind.SMOOTHPOINT 513.445103406907,3792.03603744507 498.625920057298,3790.81691980362 528.264640808106,3793.25468301773 PathPoint";
	
	mask35mm[2] = "PointKind.CORNERPOINT 445.243241786957,3793.245241642 445.243241786957,3793.245241642 445.243241786957,3793.245241642 PathPoint;PointKind.SMOOTHPOINT 387.998056411743,3793.245241642 381.284884214401,3788.16342115402 385.926854610443,3791.67702913284 PathPoint;PointKind.SMOOTHPOINT 360.9998524189,3794.96876478195 353.383140563965,3793.18056821823 368.616210222244,3796.75672531128 PathPoint;PointKind.SMOOTHPOINT 338.93075466156,3795.53973197937 333.64618062973,3792.2324180603 344.21532869339,3798.84704589844 PathPoint;PointKind.SMOOTHPOINT 324.999886751175,3797.96876192093 319.923849105835,3796.59338951111 330.672147274017,3799.50605392456 PathPoint;PointKind.SMOOTHPOINT 299.999949932098,3801.96883678436 294.295470714569,3799.50865030289 306.364735364914,3804.71391677856 PathPoint;PointKind.SMOOTHPOINT 288.69508266449,3804.71792936325 279.759528636932,3804.30557727814 297.630636692047,3805.13028144836 PathPoint;PointKind.SMOOTHPOINT 272.999975681305,3800.96875905991 267.048368453979,3796.18929862976 278.083802461624,3805.05120992661 PathPoint;PointKind.SMOOTHPOINT 259.815094470978,3780.77271223068 256.346805095673,3775.20230054855 262.601480484009,3785.24792432785 PathPoint;PointKind.SMOOTHPOINT 258.319934606552,3763.41663122177 258.397471904755,3756.84236526489 258.24239730835,3769.99089717865 PathPoint;PointKind.SMOOTHPOINT 254.000151157379,3744.96865510941 255.487875938416,3732.90446519852 252.512426376343,3757.03284502029 PathPoint;PointKind.SMOOTHPOINT 257.805497646332,3716.37898921967 264.806159734726,3708.55444908142 250.805189609528,3724.2037653923 PathPoint;PointKind.SMOOTHPOINT 256.637481451035,3695.72834014893 256.421509981155,3690.17067432404 256.774145364761,3699.25563812256 PathPoint;PointKind.SMOOTHPOINT 261.310254335403,3687.69750595093 266.024451255798,3681.99279069901 256.596411466599,3693.40245723724 PathPoint;PointKind.SMOOTHPOINT 257.478708028793,3672.93048620224 257.323633432388,3667.70067214966 257.633782625198,3678.16030025482 PathPoint;PointKind.SMOOTHPOINT 262.151834964752,3659.16330814362 262.37984418869,3650.55891036987 261.923471689224,3667.76794195175 PathPoint;PointKind.SMOOTHPOINT 259.815094470978,3644.2490029335 263.507144451141,3638.07363510132 256.123398542404,3650.42460680008 PathPoint;PointKind.SMOOTHPOINT 259.488304853439,3626.89292192459 258.643891811371,3620.00048160553 260.332717895508,3633.78536224365 PathPoint;PointKind.SMOOTHPOINT 261.824691295624,3617.7149605751 263.508914709091,3612.22952127457 260.140821933746,3623.20016384125 PathPoint;PointKind.SMOOTHPOINT 260.656675100327,3606.24227285385 259.876345396042,3601.80128574371 261.437004804611,3610.68349599838 PathPoint;PointKind.SMOOTHPOINT 261.000105142593,3595.01553297043 259.412183761597,3585.34898042679 262.58838057518,3604.68208551407 PathPoint;PointKind.SMOOTHPOINT 264.161431789398,3578.708152771 264.900691509247,3573.55882644653 263.42217206955,3583.85724306107 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,3567.23546504974 266.963396072388,3559.78739976883 263.695853948593,3574.68376636505 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,3547.73217916489 265.115246772766,3540.64241409302 265.544003248215,3554.82194423676 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,3533.96500110626 267.205213308334,3528.37216615677 268.127163648605,3539.55807209015 PathPoint;PointKind.SMOOTHPOINT 263.00014257431,3516.01552963257 262.301952838898,3511.31891727448 263.698332309723,3520.71214199066 PathPoint;PointKind.SMOOTHPOINT 264.161431789398,3493.81106615067 262.030041217804,3486.74820899963 266.292468309402,3500.8739233017 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,3482.33861446381 266.903915405273,3476.13610267639 266.091721057892,3488.54089021683 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,3457.09874868393 272.63601064682,3443.83810043335 265.033106803894,3470.3596329689 PathPoint;PointKind.SMOOTHPOINT 263.999984264374,3436.99994802475 267.209107875824,3427.5595164299 261.481261253357,3444.41048383713 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,3403.17763566971 261.359467506409,3396.90360546112 271.636523008347,3409.45190191269 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,3392.85231113434 266.903915405273,3384.8618388176 266.091721057892,3400.84278345108 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,3369.90717172623 268.620003461838,3360.46485185623 266.712373495102,3379.34972763062 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,3342.37305164337 266.333538293839,3329.4754242897 266.662098169327,3355.27067899704 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,3322.86976575851 271.992344856262,3313.84853124619 272.685931921005,3331.89100027084 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,3309.10258769989 263.253289461136,3300.55200576782 272.079087495804,3317.65316963196 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,3299.9246263504 272.197694778442,3294.16585922241 272.480581998825,3305.683157444 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,3289.59930181503 266.233341693878,3284.32464122772 266.762648820877,3294.87396240234 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,3279.27397727966 271.280347108841,3268.32575798035 271.061543226242,3290.22219657898 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,3260.9178185463 269.473267793655,3254.67069625854 268.195495605469,3267.16494083405 PathPoint;PointKind.SMOOTHPOINT 262.993061542511,3252.8869843483 261.811237335205,3247.51366138458 264.175239801407,3258.26030731201 PathPoint;PointKind.SMOOTHPOINT 264.161431789398,3228.7944817543 263.540779352188,3223.1209230423 264.782084226608,3234.46804046631 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,3217.32203006744 269.811033010483,3211.71574115753 265.521343946457,3222.92831897736 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,3206.99670553207 267.789398431778,3200.0728726387 269.879364967346,3213.92053842545 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,3196.6713809967 270.888057947159,3190.42425870895 271.453832387924,3202.91850328445 PathPoint;PointKind.SMOOTHPOINT 262.993061542511,3186.34605646133 262.062259912491,3180.39916992188 263.924217224121,3192.29294300079 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,3165.69540739059 267.113867998123,3157.79911279678 270.554895401001,3173.59170198441 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,3150.78110218048 266.662098169327,3143.7272143364 263.997151851654,3157.83499002457 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,3135.86679697037 265.343255996704,3130.82061767578 272.32550740242,3140.91274023056 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,3126.68859958649 272.216105461121,3118.84612083435 267.789398431778,3134.53131437302 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,3116.36327505112 267.679996490479,3110.14754533768 265.315994024277,3122.57924079895 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,3101.448969841 270.728380680084,3093.52576732635 269.277123212814,3109.37217235565 PathPoint;PointKind.SMOOTHPOINT 266.000021696091,3085.01554727554 264.370676279068,3076.00776672363 267.629013061523,3094.02332782745 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,3056.70605421066 264.599393606186,3049.72368478775 266.059856414795,3063.68818759918 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,3046.38072967529 266.967998743057,3038.25123310089 270.701118707657,3054.5099902153 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,3034.90804195404 270.545690059662,3027.62567281723 271.796200275421,3042.19041109085 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,3018.84637355804 267.346833944321,3011.3534617424 279.668183326721,3026.33952140808 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2992.45961666107 266.967998743057,2982.17890262604 266.027991771698,3002.74009466171 PathPoint;PointKind.SMOOTHPOINT 266.000021696091,2955.00001430511 264.434759616852,2946.54361009598 267.56528377533,2963.45665454865 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2927.0658159256 269.870513677597,2920.63482284546 265.461863279343,2933.49680900574 PathPoint;PointKind.CORNERPOINT 265.329802036285,2915.59336423874 265.329802036285,2915.59336423874 265.329802036285,2915.59336423874 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2908.70965719223 267.451633214951,2903.27378511429 270.217130184174,2914.14576530457 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,2897.23720550537 266.612176895142,2890.80621242523 264.047427177429,2903.66796255112 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2889.20637130737 271.202809810638,2883.48348140717 266.465953588486,2894.92926120758 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2876.58655643463 262.710174322128,2870.47373771667 272.622202634811,2882.69913911819 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2865.11386871338 269.044511318207,2858.28421354294 268.624606132507,2871.94375991821 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,2853.64141702652 264.293847084045,2847.30908632278 266.365402936935,2859.97374773026 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2841.02160215378 270.290064811707,2833.8017821312 267.378698587418,2848.24118614197 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2813.48724603653 267.675393819809,2801.78182840347 269.993723630905,2825.19289970398 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,2780.21678209305 270.285816192627,2771.0657286644 269.719687700272,2789.36807155609 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2758.41900587082 262.261590957642,2749.45087909698 270.683770179749,2767.28020906448 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,2738.91548395157 269.2176425457,2728.36616277695 270.787507295609,2749.46504116058 PathPoint;PointKind.SMOOTHPOINT 263.00014257431,2726.99999570847 260.654904842377,2717.95586585999 265.242351293564,2735.64782381058 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,2704.4978928566 269.902378320694,2696.81662559509 270.103125572205,2712.1791601181 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2695.31969547272 264.594790935516,2689.52528715134 268.400845527649,2701.11433982849 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,2668.93293857574 271.81000828743,2658.71052503586 270.532236099243,2679.15511608124 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,2633.36798429489 272.768071889877,2625.31472682953 267.237077951431,2641.42100572586 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2625.33715009689 266.73538684845,2620.17885446548 266.260603666306,2630.49520969391 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,2617.3063158989 272.571927309036,2610.14031171799 267.433576583862,2624.47208404541 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2603.53913784027 270.507452487946,2597.72136211395 266.771500110626,2610.71269512177 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2584.03585195541 269.036722183228,2577.11154699326 268.572560548782,2593.00869941711 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,2569.1215467453 269.103637933731,2559.7148680687 273.238252401352,2578.52798938751 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,2547.32353448868 272.64061331749,2538.07381868362 272.038017511368,2556.57325029373 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,2504.87510919571 272.307450771332,2492.30438947678 272.371180057526,2517.44559288025 PathPoint;PointKind.SMOOTHPOINT 268.000059127808,2476.00007772446 268.556628227234,2467.98269748688 267.443135976791,2484.01745796204 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2461.27932071686 266.534285545349,2454.70481872559 266.461350917816,2467.85358667374 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,2452.10112333298 274.055049419403,2442.33614444733 268.28684091568,2461.86633825302 PathPoint;PointKind.SMOOTHPOINT 272.000133991241,2434.99995946884 270.343526601791,2427.17990398407 273.656741380692,2442.82025098801 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,2417.68353223801 268.90289068222,2406.61422729492 273.438999652863,2428.7526011467 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2400.47450065613 269.496281147003,2391.87010288239 265.836095809937,2409.07913446426 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,2384.41306829453 272.576529979706,2376.91992044449 272.102100849152,2391.90598011017 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2367.20403671265 267.031728029251,2361.25266551971 268.300648927689,2373.15564393997 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,2354.5842218399 268.510601520538,2345.00736236572 271.49490237236,2364.16131734848 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,2339.66991662979 263.358088731766,2330.23633003235 267.301161289215,2349.10350322723 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2325.90273857117 266.671303510666,2319.23004627228 266.324332952499,2332.57566690445 PathPoint;PointKind.SMOOTHPOINT 260.656675100327,2316.72477722168 260.784487724304,2311.14091157913 260.528862476349,2322.30864286423 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2307.54681587219 272.01535820961,2302.61700153351 265.653759241104,2312.47639417648 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2290.33778429031 262.080316543579,2282.68790960312 270.915319919586,2297.98765897751 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2281.15982294083 272.923500537872,2273.05723428726 264.745616912842,2289.26241159439 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,2266.24551773071 268.432710170746,2256.29666805267 273.909180164337,2276.19436740875 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,2254.77283000946 272.544665336609,2246.66599273682 272.133965492249,2262.8799033165 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2234.12218093872 269.386525154114,2227.54343032837 268.28223824501,2240.70116758347 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,2219.20787572861 275.757329463959,2210.09694814682 271.257687807083,2228.31880331039 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2201.99908018112 265.411942005157,2195.47390937805 269.920434951782,2208.5240149498 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2187.08477497101 268.980427980423,2180.89123249054 266.351948976517,2193.27808141708 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,2176.75945043564 267.949075698853,2171.12176895142 265.046560764313,2182.39713191986 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,2167.58125305176 270.97940325737,2158.61831903458 266.689714193344,2176.54418706894 PathPoint;PointKind.SMOOTHPOINT 262.993061542511,2154.96143817902 262.372409105301,2146.38394832611 263.613713979721,2163.53892803192 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2143.48898649216 272.266380786896,2138.79685878754 263.065996170044,2148.18111419678 PathPoint;PointKind.SMOOTHPOINT 264.161431789398,2130.86917161942 264.010605812073,2121.6640663147 264.311903715134,2140.07404088974 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2099.89319801331 269.537351131439,2088.16960573196 265.7950258255,2111.61655426025 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,2060.8863902092 264.804743528366,2053.03470611572 265.854506492615,2068.73783826828 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2041.38286828995 270.413274765015,2032.69349813461 264.919102191925,2050.07247447968 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,2009.25976753235 272.047222852707,1996.63995265961 263.285154104233,2021.87958240509 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,1996.63995265961 266.497818231583,1985.55270910263 266.497818231583,2007.72719621658 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,1980.57828426361 268.264181613922,1967.46562957764 267.068195343018,1993.69117498398 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,1951.89680099487 269.071773290634,1940.39744138718 268.59699010849,1963.39639663696 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,1932.39351511002 275.278297662735,1917.16552019119 267.063946723938,1947.62151002884 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1886.50323629379 272.936954498291,1879.86618518829 271.741322278976,1893.14028739929 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1875.03054857254 269.153913259506,1866.82953357697 270.851590633392,1883.23179960251 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1861.26360654831 273.470864295959,1853.27313423157 273.544152975082,1869.25407886505 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,1847.49642848969 268.487588167191,1840.61744213104 269.181175231934,1854.37541484833 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,1833.72925043106 272.261778116226,1824.39007759094 270.080466270447,1843.06865930557 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1817.66781806946 267.520319223404,1808.07301998138 272.485184669495,1827.26261615753 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1790.13346195221 276.893835067749,1783.66234302521 270.121536254883,1796.6048169136 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1770.63017606735 276.177234649658,1760.6992650032 268.501396179199,1780.5610871315 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1741.94869279861 275.048518180847,1732.1400475502 266.471618413925,1748.81351709366 PathPoint;PointKind.SMOOTHPOINT 274.675701856613,1723.59253406525 274.849187135696,1717.17523097992 274.50257062912,1730.01007318497 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,1713.26720952988 268.761270046234,1703.28696727753 268.90749335289,1723.24745178223 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,1693.76392364502 269.021497964859,1685.87211370468 266.310878992081,1701.65573358536 PathPoint;PointKind.SMOOTHPOINT 272.999975681305,1680.0000500679 273.853240013123,1672.6327085495 272.146711349487,1687.3676276207 PathPoint;PointKind.SMOOTHPOINT 274.675701856613,1663.93531322479 273.827040195465,1656.29440784454 275.524717569351,1671.57621860504 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,1654.75711584091 268.28684091568,1646.84288263321 269.381922483444,1662.67134904861 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1642.13730096817 272.571927309036,1632.98624753952 272.106703519821,1651.28859043121 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1614.60318088531 269.003441333771,1606.97124481201 275.675189495087,1622.23511695862 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1600.83600282669 275.264489650726,1593.50430250168 271.750527620316,1608.1677031517 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1583.62720727921 277.021647691727,1576.37174606323 267.656983137131,1590.88266849518 PathPoint;PointKind.SMOOTHPOINT 274.675701856613,1567.56553888321 273.146907091141,1561.3946557045 276.204496622086,1573.73665809631 PathPoint;PointKind.SMOOTHPOINT 266.497818231583,1557.24021434784 268.259578943253,1547.5736618042 264.736411571503,1566.90676689148 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1528.5587310791 276.861616373062,1514.46464538574 270.15340089798,1542.65305280685 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,1511.34993553162 267.967486381531,1499.2231965065 269.701631069183,1523.47691059113 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1466.60701990128 274.141792058945,1452.99232006073 270.536838769913,1480.22171974182 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1445.95637083054 270.742188692093,1435.8909201622 269.263315200806,1456.02158546448 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1423.01123142242 269.769963026047,1407.84578561783 270.235540866852,1438.17644119263 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1393.1823849678 271.399308443069,1384.64525699615 268.606195449829,1401.71974897385 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1377.1209526062 273.831642866135,1361.87029838562 266.173861026764,1392.37137079239 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1357.61743068695 271.946672201157,1345.98353147507 275.068345069885,1369.25132989883 PathPoint;PointKind.SMOOTHPOINT 265.329802036285,1335.81965446472 260.510451793671,1322.80991077423 270.14879822731,1348.82939815521 PathPoint;PointKind.SMOOTHPOINT 262.993061542511,1323.19983959198 262.79691696167,1318.19850683212 263.189206123352,1328.20117235184 PathPoint;PointKind.SMOOTHPOINT 271.170945167542,1319.75798606873 277.733291387558,1315.16900539398 264.608598947525,1324.34696674347 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1310.57978868484 273.05591583252,1301.56775951385 273.959455490112,1319.59205389023 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1302.54919052124 277.217084169388,1302.01292037964 267.027125358582,1303.4857749939 PathPoint;PointKind.SMOOTHPOINT 282.411020994186,1300.56720972061 282.47899889946,1300.53156852722 280.642887353897,1301.49270057678 PathPoint;PointKind.SMOOTHPOINT 282.327818870544,1286.75164461136 280.206695795059,1284.11301612854 282.172390222549,1286.55833244324 PathPoint;PointKind.SMOOTHPOINT 274.675701856613,1276.16219758987 271.764335632324,1262.93742656708 276.803905963898,1285.82756996155 PathPoint;PointKind.SMOOTHPOINT 267.66618847847,1258.95340204239 266.853994131088,1251.20934963226 268.478382825851,1266.69721841812 PathPoint;PointKind.SMOOTHPOINT 279.999929666519,1249.00006771088 284.736785888672,1244.17363643646 275.263073444366,1253.82673501968 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1236.00826263428 264.576734304428,1228.23281764984 275.42876958847,1243.78347158432 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1221.09372138977 275.807604789734,1213.02724599838 264.197899103165,1229.16043281555 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1206.17941617966 268.218508958817,1190.56149244308 271.786994934082,1221.79733991623 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1186.6761302948 279.654729366302,1179.24576759338 265.023901462555,1194.10625696182 PathPoint;PointKind.SMOOTHPOINT 270.002574920654,1170.6144618988 273.735694885254,1164.36733961105 266.269809007645,1176.86158418655 PathPoint;PointKind.SMOOTHPOINT 268.834558725357,1157.99464702606 267.031728029251,1147.53029823303 270.637035369873,1168.45899581909 PathPoint;PointKind.SMOOTHPOINT 277.012442350388,1132.75501728058 277.91598200798,1129.4656419754 274.141792058945,1143.2056760788 PathPoint;PointKind.SMOOTHPOINT 276.88675403595,1122.2994017601 283.418651819229,1117.4585723877 273.816772699356,1124.57477331161 PathPoint;PointKind.SMOOTHPOINT 277.012442350388,1108.66251468658 273.423067331314,1105.70736408234 284.463812112808,1114.79752063751 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,1093.74820947647 276.332309246063,1077.35491275787 272.586797475815,1099.09202814102 PathPoint;PointKind.SMOOTHPOINT 274.675701856613,1068.50857973099 275.104812383652,1053.96626472473 274.246945381165,1083.05089473724 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1045.56344032288 271.859929561615,1030.1784825325 272.818347215652,1060.94839811325 PathPoint;PointKind.SMOOTHPOINT 272.339315414429,1020.32381057739 275.793796777725,1005.12248754501 268.884479999542,1035.52489757538 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,995.083944797516 272.599543333054,982.025105953217 274.415827989578,1008.14301967621 PathPoint;PointKind.SMOOTHPOINT 273.507685661316,967.549824714661 274.150997400284,957.780361175537 272.864019870758,977.319524288177 PathPoint;PointKind.SMOOTHPOINT 274.675701856613,952.635519504547 275.930814743042,936.627666950226 273.420943021774,968.643372058868 PathPoint;PointKind.SMOOTHPOINT 275.999854803085,928.968822956085 271.687506437302,909.738864898682 280.312557220459,948.198781013489 PathPoint;PointKind.SMOOTHPOINT 275.8440721035,899.861769676208 277.108036279678,878.896486759186 275.12676358223,911.75861120224 PathPoint;PointKind.SMOOTHPOINT 284.000004529953,875.968952178955 283.987258672714,859.043397903442 284.013812541962,893.897888660431 PathPoint;PointKind.SMOOTHPOINT 278.507602214813,852.824127674103 277.867122888565,848.988568782806 281.925616264343,873.295390605927 PathPoint;PointKind.SMOOTHPOINT 278.507602214813,835.615332126617 280.151817798615,832.217853069305 276.46578669548,839.833738803864 PathPoint;PointKind.SMOOTHPOINT 280.517199039459,829.878988265991 280.705908536911,827.219116687775 280.233249664307,833.877174854279 PathPoint;PointKind.SMOOTHPOINT 280.740251541138,821.802599430084 280.710865259171,819.1486287117 280.769991874695,824.50731754303 PathPoint;PointKind.SMOOTHPOINT 278.507602214813,813.817319869995 277.665313482285,801.670753955841 278.686752319336,816.401896476746 PathPoint;PointKind.SMOOTHPOINT 281.685569286346,793.166670799255 280.845758914948,785.436072349548 282.073963880539,796.745188236237 PathPoint;PointKind.SMOOTHPOINT 279.6759724617,782.841346263885 278.242417573929,776.99878692627 282.126363515854,792.830557823181 PathPoint;PointKind.SMOOTHPOINT 279.348828792572,765.6325507164 278.903785943985,761.033184528351 279.975854158401,772.113111019135 PathPoint;PointKind.SMOOTHPOINT 277.339231967926,749.570882320404 282.254176139832,736.00551366806 275.299186706543,755.201954841614 PathPoint;PointKind.SMOOTHPOINT 279.6759724617,717.447781562805 271.671220064163,707.66462802887 287.680370807648,727.230699062347 PathPoint;PointKind.SMOOTHPOINT 282.012358903885,696.797132492065 281.95748090744,689.707367420197 282.06723690033,703.886897563934 PathPoint;PointKind.SMOOTHPOINT 283.00016283989,669.000070095062 283.013970851898,668.771116733551 281.559880971909,693.30099105835 PathPoint;PointKind.SMOOTHPOINT 284.000004529953,614.000043869019 284.606848955154,598.287942409515 283.392806053162,629.712145328522 PathPoint;PointKind.SMOOTHPOINT 282.675851583481,580.924072265625 280.412399768829,572.516763210297 284.939303398132,589.331381320953 PathPoint;PointKind.SMOOTHPOINT 286.180608272552,520.119488239288 283.903348445892,507.217140197754 288.457868099213,533.021600246429 PathPoint;PointKind.SMOOTHPOINT 280.339111089706,483.407170772552 282.315427064896,466.946604251862 278.363149166107,499.867737293243 PathPoint;PointKind.SMOOTHPOINT 281.507481336594,439.811382293701 280.430456399918,425.779845714569 282.58450627327,453.842918872833 PathPoint;PointKind.SMOOTHPOINT 284.999846220016,407.968926429749 285.821599960327,390.37917137146 284.178446531296,425.558681488037 PathPoint;PointKind.SMOOTHPOINT 286.999883651733,358.968894481659 288.524075746536,332.02627658844 285.475691556931,385.911512374878 PathPoint;PointKind.SMOOTHPOINT 286.999883651733,314.968779087067 287.574863433838,292.211995124817 286.424903869629,337.72579908371 PathPoint;PointKind.SMOOTHPOINT 286.00004196167,278.968813419342 287.65204668045,255.342478752136 284.348037242889,302.595148086548 PathPoint;PointKind.SMOOTHPOINT 286.00004196167,250.999917984009 284.279351234436,239.339110851288 287.720378637314,262.66072511673 PathPoint;PointKind.SMOOTHPOINT 288.99992108345,227.968862056732 289.172344207764,212.499639987946 288.807317018509,245.260269641876 PathPoint;PointKind.SMOOTHPOINT 295.999875068665,199.968810081482 302.100538015366,192.789351940155 291.116087436676,205.71671962738 PathPoint;PointKind.SMOOTHPOINT 313.000016212463,189.968740940094 309.747698307037,191.70028924942 306.391997337341,193.486833572388 PathPoint;PointKind.SMOOTHPOINT 333.000036478043,185.015559196472 338.523241281509,182.293846607208 321.63250207901,190.617363452911 PathPoint;PointKind.SMOOTHPOINT 354.603910446167,181.911234855652 359.765274524689,183.049628734589 349.442546367645,180.773077011108 PathPoint;PointKind.SMOOTHPOINT 377.969191074371,184.205961227417 384.294322729111,183.883302211761 371.644059419632,184.528620243073 PathPoint;PointKind.SMOOTHPOINT 393.156588077545,183.058598041534 402.279081344604,183.166229724884 384.034094810486,182.950966358185 PathPoint;PointKind.SMOOTHPOINT 414.185482263565,188.794941902161 429.738260507584,190.108001232147 398.633058071136,187.481882572174 PathPoint;PointKind.SMOOTHPOINT 436.999858617783,187.999978065491 448.650280237198,187.773149013519 419.502983093262,188.340575695038 PathPoint;PointKind.SMOOTHPOINT 462.000149488449,187.999978065491 466.478193998337,188.240261077881 453.100000619888,187.52224445343 PathPoint;PointKind.SMOOTHPOINT 482.553906440735,181.64947271347 490.768257379532,181.992430686951 475.838963985443,181.369299888611 PathPoint;PointKind.SMOOTHPOINT 503.000031709671,181.96882724762 514.252145290375,182.335860729218 494.93438243866,181.705884933472 PathPoint;PointKind.SMOOTHPOINT 527.999968528748,180.968749523163 536.935522556305,180.9286236763 522.79541015625,180.992352962494 PathPoint;PointKind.SMOOTHPOINT 563.000092506409,183.96874666214 584.704163074493,185.20580291748 541.295667886734,182.731926441193 PathPoint;PointKind.SMOOTHPOINT 605.296157598495,178.236651420593 611.959054470062,177.398729324341 598.633614778519,179.074809551239 PathPoint;PointKind.SMOOTHPOINT 630.000107288361,176.968910694122 632.422174215317,175.515174865723 614.889539480209,186.037352085114 PathPoint;PointKind.SMOOTHPOINT 644.999856948853,177.000067234039 648.149853944778,177.844362258911 640.874801874161,175.894718170166 PathPoint;PointKind.SMOOTHPOINT 659.868607521057,181.20596408844 662.095237970352,180.893926620483 655.672742128372,181.793689727783 PathPoint;PointKind.SMOOTHPOINT 665.709750652313,175.469620227814 675.136020183563,174.417378902435 662.566480636597,175.820367336273 PathPoint;PointKind.SMOOTHPOINT 683.233888149261,178.911237716675 686.629242897034,179.328782558441 678.905961513519,178.379216194153 PathPoint;PointKind.SMOOTHPOINT 696.084898710251,176.616747379303 708.429261445999,177.611632347107 690.657641887665,176.179375648499 PathPoint;PointKind.SMOOTHPOINT 715.945422649384,183.500454425812 734.473650455475,187.784714698792 697.417548894882,179.216194152832 PathPoint;PointKind.SMOOTHPOINT 778.000044822693,186.00005865097 817.096191644669,186.00005865097 738.904252052307,186.00005865097 PathPoint;PointKind.SMOOTHPOINT 849.464650154114,186.267485618591 883.924137353897,185.527989864349 815.00551700592,187.006981372833 PathPoint;PointKind.SMOOTHPOINT 961.618634462357,187.414612770081 1009.35824275017,186.021065711975 913.879380226135,188.808395862579 PathPoint;PointKind.SMOOTHPOINT 1201.99983716011,186.00005865097 1245.97410678864,185.874488353729 1158.02521348,186.125628948212 PathPoint;PointKind.SMOOTHPOINT 1377.52303719521,186.267485618591 1400.01204013824,186.012096405029 1355.03368020058,186.522874832153 PathPoint;PointKind.SMOOTHPOINT 1475.65764069557,183.972995281219 1493.74755263329,181.714382171631 1457.56772875786,186.231608390808 PathPoint;PointKind.SMOOTHPOINT 1514.99985337257,177.000067234039 1531.8119931221,175.669069290161 1498.18771362305,178.331065177917 PathPoint;PointKind.SMOOTHPOINT 1539.91269350052,180.531141757965 1556.38246536255,182.364184856415 1523.4425675869,178.698334693909 PathPoint;PointKind.SMOOTHPOINT 1579.99983072281,177.999908924103 1592.5966322422,173.383784294128 1567.26848959923,182.665128707886 PathPoint;PointKind.SMOOTHPOINT 1602.99902200699,173.64767074585 1602.99902200699,173.64767074585 1591.94588541985,175.643577575684 PathPoint;PointKind.SMOOTHPOINT 1621.69152975082,177.089288234711 1645.49512624741,181.060094833374 1597.88793325424,173.118717670441 PathPoint;PointKind.SMOOTHPOINT 1664.99982833862,180.99990606308 1685.64988732338,181.663162708282 1644.34976935387,180.336649417877 PathPoint;PointKind.SMOOTHPOINT 1701.00014805794,175.999989509583 1711.8337726593,170.779144763947 1690.16616940498,181.220834255219 PathPoint;PointKind.SMOOTHPOINT 1737.35027074814,174.794797897339 1747.80541419983,175.830044746399 1726.89512729645,173.759551048279 PathPoint;PointKind.SMOOTHPOINT 1760.71555137634,180.531141757965 1772.29799509048,180.351991653442 1749.13346171379,180.710527896881 PathPoint;PointKind.SMOOTHPOINT 1782.91281580925,179.384014606476 1797.71252632141,178.474102020264 1768.11310529709,180.293691158295 PathPoint;PointKind.CORNERPOINT 1816.79272055626,178.236651420593 1816.79272055626,178.236651420593 1816.79272055626,178.236651420593 PathPoint;PointKind.SMOOTHPOINT 1826.13897442818,172.500307559967 1832.20387816429,166.405663490295 1820.07371664047,178.595187664032 PathPoint;PointKind.CORNERPOINT 1838.98963093758,173.64767074585 1838.98963093758,173.64767074585 1838.98963093758,173.64767074585 PathPoint;PointKind.SMOOTHPOINT 1845.99949836731,174.794797897339 1853.81235480309,168.928635120392 1838.18664193153,180.661196708679 PathPoint;PointKind.SMOOTHPOINT 1862.35526561737,172.500307559967 1871.13539099693,172.590000629425 1853.57478618622,172.410850524902 PathPoint;PointKind.SMOOTHPOINT 1878.99993896484,178.99998664856 1881.824208498,179.173471927643 1861.05129361153,177.897706031799 PathPoint;PointKind.SMOOTHPOINT 1898.00011754036,183.000061511993 1914.85155701637,185.444197654724 1894.85330700874,182.543807029724 PathPoint;PointKind.SMOOTHPOINT 1925.44194817543,177.089288234711 1925.72943806648,169.596376419067 1925.1994228363,183.403444290161 PathPoint;PointKind.SMOOTHPOINT 1936.0001206398,174.999911785126 1940.12552976608,179.65167760849 1931.87471151352,170.348145961761 PathPoint;PointKind.SMOOTHPOINT 1951.14361524582,177.089288234711 1960.9781062603,177.219343185425 1941.30912423134,176.95946931839 PathPoint;PointKind.SMOOTHPOINT 1972.17250943184,177.089288234711 1979.32824611664,169.968366622925 1965.01677274704,184.21044588089 PathPoint;PointKind.SMOOTHPOINT 1993.20140361786,172.500307559967 2001.87672972679,176.054277420044 1984.52607750893,168.946573734283 PathPoint;PointKind.SMOOTHPOINT 2010.72554111481,175.942161083221 2016.32486701012,171.774265766144 2005.12586116791,180.109820365906 PathPoint;PointKind.SMOOTHPOINT 2022.40818142891,173.64767074585 2039.41186308861,173.118717670441 2005.40449976921,174.176387786865 PathPoint;PointKind.SMOOTHPOINT 2044.60544586182,174.794797897339 2052.36802697182,173.898575305939 2036.84286475182,175.691256523132 PathPoint;PointKind.SMOOTHPOINT 2060.96121311188,177.089288234711 2072.63004541397,178.68488073349 2049.29202675819,175.493931770325 PathPoint;PointKind.SMOOTHPOINT 2079.65336680412,177.089288234711 2096.81247711182,172.688663005829 2062.49461054802,181.490149497986 PathPoint;PointKind.SMOOTHPOINT 2103.01900148392,173.64767074585 2120.49746632576,170.160970687866 2085.54053664207,177.13413476944 PathPoint;PointKind.SMOOTHPOINT 2121.71115517616,173.64767074585 2133.30705285072,176.730988025665 2110.1152575016,170.564353466034 PathPoint;PointKind.SMOOTHPOINT 2145.07643580437,175.942161083221 2157.18358397484,175.489447116852 2132.96964168549,176.394875049591 PathPoint;PointKind.CORNERPOINT 2159.09581661224,178.236651420593 2159.09581661224,178.236651420593 2159.09581661224,178.236651420593 PathPoint;PointKind.SMOOTHPOINT 2173.11519742012,171.353180408478 2190.07780909538,170.438783168793 2156.15223169327,172.26734161377 PathPoint;PointKind.SMOOTHPOINT 2187.13422417641,177.089288234711 2195.19916534424,175.774576663971 2167.88550138474,180.227601528168 PathPoint;PointKind.SMOOTHPOINT 2202.00014233589,172.999992370605 2207.05175042152,178.458523750305 2196.94818019867,167.541697025299 PathPoint;PointKind.SMOOTHPOINT 2230.36038279533,174.794797897339 2250.76862454414,173.109748363495 2209.95214104652,176.479847431183 PathPoint;PointKind.SMOOTHPOINT 2266.57667398453,177.089288234711 2278.45581293106,176.896684169769 2254.69788908958,177.282128334045 PathPoint;PointKind.SMOOTHPOINT 2285.26918172836,175.942161083221 2293.08628678322,176.045308113098 2277.45172262192,175.839014053345 PathPoint;PointKind.SMOOTHPOINT 2317.99983501434,178.99998664856 2338.84639263153,177.830200195312 2297.15363144875,180.169537067413 PathPoint;PointKind.CORNERPOINT 2355.36537766457,174.794797897339 2355.36537766457,174.794797897339 2355.36537766457,174.794797897339 PathPoint;PointKind.CORNERPOINT 2370.55277466774,171.353180408478 2370.55277466774,171.353180408478 2370.55277466774,171.353180408478 PathPoint;PointKind.SMOOTHPOINT 2381.06704473495,174.794797897339 2379.19163346291,168.767187595367 2382.94281005859,180.82240819931 PathPoint;PointKind.CORNERPOINT 2389.24492835999,171.353180408478 2389.24492835999,171.353180408478 2389.24492835999,171.353180408478 PathPoint;PointKind.SMOOTHPOINT 2399.75955247879,175.942161083221 2405.69664359093,174.405105113983 2393.82246136665,177.47921705246 PathPoint;PointKind.CORNERPOINT 2412.61056303978,178.236651420593 2412.61056303978,178.236651420593 2412.61056303978,178.236651420593 PathPoint;PointKind.SMOOTHPOINT 2423.12483310699,177.089288234711 2428.89339566231,168.722577095032 2417.35662460327,185.456235408783 PathPoint;PointKind.SMOOTHPOINT 2433.6394572258,174.794797897339 2438.70947599411,176.309666633606 2428.56943845749,173.280165195465 PathPoint;PointKind.CORNERPOINT 2448.82685422897,174.794797897339 2448.82685422897,174.794797897339 2448.82685422897,174.794797897339 PathPoint;PointKind.SMOOTHPOINT 2457.004737854,174.794797897339 2464.47062373161,174.942791461945 2449.53885197639,174.647040367126 PathPoint;PointKind.SMOOTHPOINT 2472.19213485718,175.942161083221 2479.32521224022,174.203295707703 2465.05941152573,177.68102645874 PathPoint;PointKind.CORNERPOINT 2488.54825615883,178.236651420593 2488.54825615883,178.236651420593 2488.54825615883,178.236651420593 PathPoint;PointKind.SMOOTHPOINT 2501.39891266823,175.942161083221 2510.26613473892,175.839014053345 2492.53204464912,176.045308113098 PathPoint;PointKind.SMOOTHPOINT 2514.24992322922,178.236651420593 2527.8950715065,181.279606819153 2500.60512900352,175.193696022034 PathPoint;PointKind.SMOOTHPOINT 2536.44718766212,179.384014606476 2548.92396569252,178.048532009125 2523.97040963173,180.719497203827 PathPoint;PointKind.SMOOTHPOINT 2553.97132515907,181.678504943848 2563.0527484417,185.120122432709 2544.88990187645,178.236651420593 PathPoint;PointKind.SMOOTHPOINT 2571.49510860443,181.678504943848 2577.46902108192,173.280165195465 2565.52155017853,190.076608657837 PathPoint;PointKind.SMOOTHPOINT 2586.68285965919,178.236651420593 2592.03116297722,183.005018234253 2581.33420228958,173.468284606934 PathPoint;PointKind.SMOOTHPOINT 2597.19712972641,178.236651420593 2607.4971985817,175.946645736694 2586.89741492271,180.526657104492 PathPoint;PointKind.CORNERPOINT 2612.38488078117,182.825632095337 2612.38488078117,182.825632095337 2612.38488078117,182.825632095337 PathPoint;PointKind.CORNERPOINT 2626.40390753746,187.414612770081 2626.40390753746,187.414612770081 2626.40390753746,187.414612770081 PathPoint;PointKind.SMOOTHPOINT 2632.24540472031,177.089288234711 2640.37761569023,177.152073383331 2624.11319375038,177.026739120483 PathPoint;PointKind.CORNERPOINT 2647.43280172348,183.972995281219 2647.43280172348,183.972995281219 2647.43280172348,183.972995281219 PathPoint;PointKind.SMOOTHPOINT 2656.7790555954,180.531141757965 2663.4373497963,177.125165462494 2650.1207613945,183.937118053436 PathPoint;PointKind.CORNERPOINT 2668.4616959095,179.384014606476 2668.4616959095,179.384014606476 2668.4616959095,179.384014606476 PathPoint;PointKind.SMOOTHPOINT 2676.63957953453,182.825632095337 2689.52245473862,184.864733219147 2663.75670433044,180.786530971527 PathPoint;PointKind.SMOOTHPOINT 2692.99534678459,179.384014606476 2700.29235005379,171.026036739349 2685.6983435154,187.741756439209 PathPoint;PointKind.SMOOTHPOINT 2730.9999525547,172.999992370605 2751.41739964485,174.272925853729 2710.58285951614,171.727294921875 PathPoint;PointKind.SMOOTHPOINT 2772.43779659271,177.089288234711 2784.85969662666,176.211004257202 2760.01589655876,177.967808246613 PathPoint;PointKind.SMOOTHPOINT 2791.12995028496,177.089288234711 2796.15004777908,178.985116481781 2786.11020684242,175.193696022034 PathPoint;PointKind.SMOOTHPOINT 2802.81294465065,182.825632095337 2813.46883535385,181.732320785522 2792.15705394745,183.919179439545 PathPoint;PointKind.SMOOTHPOINT 2826.17822527885,178.236651420593 2837.94300556183,179.379529953003 2814.41344499588,177.093772888184 PathPoint;PointKind.SMOOTHPOINT 2843.7023627758,179.384014606476 2849.85400915146,179.630434513092 2837.55071640015,179.137358665466 PathPoint;PointKind.SMOOTHPOINT 2854.21663284302,178.236651420593 2863.84117126465,181.44978761673 2844.59209442139,175.023515224457 PathPoint;PointKind.SMOOTHPOINT 2864.73125696182,183.972995281219 2870.61347007751,184.327046871185 2858.84868979454,183.618943691254 PathPoint;PointKind.SMOOTHPOINT 2877.58226752281,178.236651420593 2887.52155780792,175.942161083221 2867.64262318611,180.531141757965 PathPoint;PointKind.CORNERPOINT 2890.43292403221,179.384014606476 2890.43292403221,179.384014606476 2890.43292403221,179.384014606476 PathPoint;PointKind.SMOOTHPOINT 2899.77917790413,178.236651420593 2910.70450186729,175.449085235596 2888.85420799255,181.024217605591 PathPoint;PointKind.CORNERPOINT 2919.63970184326,180.531141757965 2919.63970184326,180.531141757965 2919.63970184326,180.531141757965 PathPoint;PointKind.SMOOTHPOINT 2927.81758546829,177.089288234711 2937.05904006958,174.445230960846 2918.57648491859,179.733581542969 PathPoint;PointKind.SMOOTHPOINT 2947.67846345901,179.384014606476 2955.97955703735,180.405807495117 2939.37736988068,178.362221717834 PathPoint;PointKind.SMOOTHPOINT 2964.03423070908,180.531141757965 2981.55801415443,181.593296527863 2946.51009321213,179.468986988068 PathPoint;PointKind.SMOOTHPOINT 2981.55801415443,180.531141757965 2995.66413760185,172.98889875412 2967.45224475861,188.07338476181 PathPoint;PointKind.CORNERPOINT 3001.41889214516,178.236651420593 3001.41889214516,178.236651420593 3001.41889214516,178.236651420593 PathPoint;PointKind.SMOOTHPOINT 3007.00016140938,181.999983787537 3016.02458238602,178.361277580261 3003.04328083992,183.595340251923 PathPoint;PointKind.SMOOTHPOINT 3018.94267559052,179.384014606476 3024.17272567749,177.976777553558 3013.71297955513,180.791015625 PathPoint;PointKind.CORNERPOINT 3025.95254302025,180.531141757965 3025.95254302025,180.531141757965 3025.95254302025,180.531141757965 PathPoint;PointKind.SMOOTHPOINT 3031.7936861515,183.972995281219 3039.78463053703,181.234760284424 3023.80309581757,186.711230278015 PathPoint;PointKind.SMOOTHPOINT 3043.47632646561,178.236651420593 3048.06837558746,176.947903633118 3035.84616065025,180.378427505493 PathPoint;PointKind.SMOOTHPOINT 3056.3273370266,177.089288234711 3069.43078637123,180.380787849426 3051.89638137817,175.976386070251 PathPoint;PointKind.SMOOTHPOINT 3068.01033139229,183.972995281219 3078.08663964272,184.344985485077 3068.01033139229,183.972995281219 PathPoint;PointKind.CORNERPOINT 3085.53411483765,178.236651420593 3085.53411483765,178.236651420593 3085.53411483765,178.236651420593 PathPoint;PointKind.SMOOTHPOINT 3093.71199846268,177.089288234711 3116.29093050957,183.787472248077 3086.25531792641,174.877409934998 PathPoint;PointKind.CORNERPOINT 3118.24564933777,183.972995281219 3118.24564933777,183.972995281219 3118.24564933777,183.972995281219 PathPoint;PointKind.SMOOTHPOINT 3127.59190320969,175.942161083221 3132.35637545586,171.769781112671 3122.82743096352,180.114305019379 PathPoint;PointKind.SMOOTHPOINT 3135.76978683472,179.384014606476 3149.65675234795,177.394244670868 3135.76978683472,179.384014606476 PathPoint;PointKind.CORNERPOINT 3169.64969158173,179.384014606476 3169.64969158173,179.384014606476 3169.64969158173,179.384014606476 PathPoint;PointKind.CORNERPOINT 3181.33233189583,174.794797897339 3181.33233189583,174.794797897339 3181.33233189583,174.794797897339 PathPoint;PointKind.SMOOTHPOINT 3195.3517127037,177.089288234711 3208.75008702278,180.69258928299 3181.95298433304,173.486223220825 PathPoint;PointKind.CORNERPOINT 3218.71699333191,182.825632095337 3218.71699333191,182.825632095337 3218.71699333191,182.825632095337 PathPoint;PointKind.CORNERPOINT 3233.90439033508,178.236651420593 3233.90439033508,178.236651420593 3233.90439033508,178.236651420593 PathPoint;PointKind.SMOOTHPOINT 3247.92377114296,177.089288234711 3259.9261200428,174.503531455994 3235.92177629471,179.675281047821 PathPoint;PointKind.SMOOTHPOINT 3263.11116814613,178.236651420593 3275.38259625435,180.486295223236 3250.83974003792,175.98700761795 PathPoint;PointKind.CORNERPOINT 3289.981559515,179.384014606476 3289.981559515,179.384014606476 3289.981559515,179.384014606476 PathPoint;PointKind.SMOOTHPOINT 3296.99107289314,174.794797897339 3302.58615016937,174.718794822693 3291.3963496685,174.871037006378 PathPoint;PointKind.SMOOTHPOINT 3325.02948045731,175.942161083221 3344.41097259521,173.844759464264 3305.64834237099,178.039562702179 PathPoint;PointKind.SMOOTHPOINT 3354.23625826836,177.089288234711 3364.46339249611,178.317375183105 3344.00947809219,175.861437320709 PathPoint;PointKind.SMOOTHPOINT 3376.43352270126,174.794797897339 3383.3198261261,172.926113605499 3369.54721927643,176.663718223572 PathPoint;PointKind.CORNERPOINT 3388.11616301537,177.089288234711 3388.11616301537,177.089288234711 3388.11616301537,177.089288234711 PathPoint;PointKind.CORNERPOINT 3405.64030051231,177.089288234711 3405.64030051231,177.089288234711 3405.64030051231,177.089288234711 PathPoint;PointKind.SMOOTHPOINT 3413.81818413734,172.500307559967 3436.92500710487,171.464116573334 3405.25084376335,172.884571552277 PathPoint;PointKind.SMOOTHPOINT 3445.36134839058,174.794797897339 3451.88262462616,179.980001449585 3438.840072155,169.609830379486 PathPoint;PointKind.SMOOTHPOINT 3458.21235895157,179.384014606476 3467.97851800919,175.44011592865 3448.44655394554,183.327677249908 PathPoint;PointKind.SMOOTHPOINT 3473.40011000633,174.794797897339 3489.29029941559,176.950500011444 3457.50956654549,172.639331817627 PathPoint;PointKind.SMOOTHPOINT 3492.09226369858,175.942161083221 3508.12867641449,169.591891765594 3476.05585098267,182.292430400848 PathPoint;PointKind.CORNERPOINT 3508.44803094864,172.500307559967 3508.44803094864,172.500307559967 3508.44803094864,172.500307559967 PathPoint;PointKind.SMOOTHPOINT 3516.62591457367,178.236651420593 3521.32630348206,179.733581542969 3511.92552566528,176.739957332611 PathPoint;PointKind.SMOOTHPOINT 3529.47692513466,174.794797897339 3540.73966026306,164.411408901215 3518.21419000626,185.178422927856 PathPoint;PointKind.CORNERPOINT 3547.00106263161,171.353180408478 3547.00106263161,171.353180408478 3547.00106263161,171.353180408478 PathPoint;PointKind.SMOOTHPOINT 3556.34731650352,170.205817222595 3563.10580730438,166.885049343109 3549.58847165108,173.526585102081 PathPoint;PointKind.SMOOTHPOINT 3570.36634325981,169.058690071106 3578.62176418304,170.49708366394 3562.11092233658,167.620060443878 PathPoint;PointKind.SMOOTHPOINT 3587.89048075676,170.205817222595 3599.00274395943,171.303849220276 3576.77821755409,169.107785224915 PathPoint;PointKind.SMOOTHPOINT 3603.07787775993,172.500307559967 3611.69407725334,167.902357578278 3594.46203231812,177.098257541656 PathPoint;PointKind.SMOOTHPOINT 3620.60201525688,165.616836547852 3630.555113554,166.423602104187 3610.64891695976,164.810070991516 PathPoint;PointKind.SMOOTHPOINT 3635.78941226006,170.205817222595 3647.66855120659,171.980559825897 3623.91062736511,168.431310653687 PathPoint;PointKind.CORNERPOINT 3672.00003862381,165.999920368195 3672.00003862381,165.999920368195 3672.00003862381,165.999920368195 PathPoint;PointKind.SMOOTHPOINT 3703.54922175407,169.058690071106 3721.54778838158,168.605976104736 3685.55065512657,169.511168003082 PathPoint;PointKind.SMOOTHPOINT 3730.99990367889,174.999911785126 3735.42661070824,173.588190078735 3726.57319664955,176.411397457123 PathPoint;PointKind.SMOOTHPOINT 3764.29916381836,164.469473361969 3793.58808159828,163.954210281372 3735.01024603844,164.984972476959 PathPoint;PointKind.SMOOTHPOINT 3809.86170887947,170.205817222595 3818.40497374535,170.940828323364 3801.31879806519,169.470806121826 PathPoint;PointKind.CORNERPOINT 3832.05897331238,162.174983024597 3832.05897331238,162.174983024597 3832.05897331238,162.174983024597 PathPoint;PointKind.CORNERPOINT 3843.74161362648,166.764199733734 3843.74161362648,166.764199733734 3843.74161362648,166.764199733734 PathPoint;PointKind.SMOOTHPOINT 3861.26575112343,166.764199733734 3877.11026787758,170.774896144867 3845.42088031769,162.753267288208 PathPoint;PointKind.SMOOTHPOINT 3878.78988862038,165.616836547852 3885.3203701973,162.865147590637 3872.25940704346,168.368525505066 PathPoint;PointKind.SMOOTHPOINT 3895.14565587044,171.353180408478 3904.18600916862,173.177018165588 3886.10530257225,169.529106616974 PathPoint;PointKind.SMOOTHPOINT 3913.83780956268,166.764199733734 3928.05793762207,163.564281463623 3899.6176815033,169.963881969452 PathPoint;PointKind.CORNERPOINT 3933.69833350182,167.911326885223 3933.69833350182,167.911326885223 3933.69833350182,167.911326885223 PathPoint;PointKind.SMOOTHPOINT 3940.70820093155,167.911326885223 3945.75095772743,164.348623752594 3935.66544413567,171.474030017853 PathPoint;PointKind.SMOOTHPOINT 3979.26087856293,166.764199733734 4005.62462210655,169.385833740234 3952.89748907089,164.142329692841 PathPoint;PointKind.CORNERPOINT 4008.46765637398,174.794797897339 4008.46765637398,174.794797897339 4008.46765637398,174.794797897339 PathPoint;PointKind.SMOOTHPOINT 4016.64553999901,169.058690071106 4024.89671230316,162.233283519745 4008.39472174644,175.883860588074 PathPoint;PointKind.SMOOTHPOINT 4033.00130724907,165.616836547852 4037.73851752281,166.42808675766 4028.26445102692,164.805586338043 PathPoint;PointKind.CORNERPOINT 4048.18905830383,166.764199733734 4048.18905830383,166.764199733734 4048.18905830383,166.764199733734 PathPoint;PointKind.SMOOTHPOINT 4054.03020143509,162.174983024597 4072.87990808487,162.49528169632 4052.76588320732,162.153503894806 PathPoint;PointKind.SMOOTHPOINT 4076.227465868,171.353180408478 4087.62261629105,170.461206436157 4064.83231544495,172.244918346405 PathPoint;PointKind.SMOOTHPOINT 4089.07847642899,167.911326885223 4094.99751091003,161.475849151611 4083.15944194794,174.346804618835 PathPoint;PointKind.SMOOTHPOINT 4108.93900036812,163.32234621048 4121.77160024643,166.392209529877 4096.10640048981,160.252482891083 PathPoint;PointKind.SMOOTHPOINT 4133.47265124321,165.616836547852 4140.38196802139,163.223683834076 4126.56333446503,168.009989261627 PathPoint;PointKind.SMOOTHPOINT 4150.99678874016,159.880492687225 4160.50271987915,160.59308052063 4141.49085760117,159.167904853821 PathPoint;PointKind.SMOOTHPOINT 4173.19405317307,163.32234621048 4186.47842288017,165.486781597137 4159.90932941437,161.157674789429 PathPoint;PointKind.CORNERPOINT 4197.00012803078,165.000078678131 4197.00012803078,165.000078678131 4197.00012803078,165.000078678131 PathPoint;PointKind.SMOOTHPOINT 4209.99984025955,162.000081539154 4221.61414861679,162.735092639923 4198.3858859539,161.265070438385 PathPoint;PointKind.SMOOTHPOINT 4225.76611161232,171.353180408478 4225.19254803658,175.411791801453 4226.90226316452,163.313376903534 PathPoint;PointKind.SMOOTHPOINT 4238.61712217331,172.500307559967 4244.54500794411,173.758370876312 4232.57381558418,171.217932701111 PathPoint;PointKind.CORNERPOINT 4249.13139224052,180.531141757965 4249.13139224052,180.531141757965 4249.13139224052,180.531141757965 PathPoint;PointKind.SMOOTHPOINT 4257.30927586555,167.911326885223 4260.19798278809,159.109840393066 4254.42056894302,176.713049411774 PathPoint;PointKind.SMOOTHPOINT 4271.32865667343,162.174983024597 4282.92455434799,167.028558254242 4259.73275899887,157.321643829346 PathPoint;PointKind.SMOOTHPOINT 4287.68442392349,163.32234621048 4300.54463982582,160.566172599792 4274.82420802116,166.078519821167 PathPoint;PointKind.CORNERPOINT 4323.90071511269,161.027855873108 4323.90071511269,161.027855873108 4323.90071511269,161.027855873108 PathPoint;PointKind.SMOOTHPOINT 4336.75172567368,156.438875198364 4351.73377275467,157.429275512695 4321.76967859268,155.448474884033 PathPoint;PointKind.SMOOTHPOINT 4354.27586317062,161.027855873108 4360.34536957741,164.276869297028 4348.20635676384,157.778842449188 PathPoint;PointKind.SMOOTHPOINT 4370.63163042068,159.880492687225 4391.19034409523,154.323534965515 4350.07291674614,165.437686443329 PathPoint;PointKind.CORNERPOINT 4390.00002264977,165.999920368195 4390.00002264977,165.999920368195 4390.00002264977,165.999920368195 PathPoint;PointKind.SMOOTHPOINT 4399.83840823174,156.438875198364 4412.77616143227,154.224872589111 4386.9006550312,158.652641773224 PathPoint;PointKind.SMOOTHPOINT 4415.02580523491,162.174983024597 4426.14727377892,165.07915019989 4403.9043366909,159.271051883698 PathPoint;PointKind.SMOOTHPOINT 4434.88632917404,162.174983024597 4456.92851901054,160.422899723053 4412.84449338913,163.927302360535 PathPoint;PointKind.SMOOTHPOINT 4465.26147723198,156.438875198364 4483.72562170029,155.475146770477 4446.79733276367,157.402367591858 PathPoint;PointKind.SMOOTHPOINT 4494.46825504303,157.586002349854 4514.15069103241,162.058618068695 4474.78546500206,153.113622665405 PathPoint;PointKind.SMOOTHPOINT 4535.35767316818,159.880492687225 4560.85894703865,160.893316268921 4509.85639929771,158.86766910553 PathPoint;PointKind.SMOOTHPOINT 4577.41546154022,159.880492687225 4583.10153007507,157.881753444672 4571.72939300537,161.879231929779 PathPoint;PointKind.SMOOTHPOINT 4586.76171541214,162.174983024597 4592.48885393143,164.854917526245 4581.03422284126,159.495048522949 PathPoint;PointKind.SMOOTHPOINT 4599.61272597313,163.32234621048 4619.71046447754,163.645005226135 4579.51463341713,162.999687194824 PathPoint;PointKind.SMOOTHPOINT 4625.31439304352,158.733365535736 4642.65159130096,156.183249950409 4607.97754883766,161.28324508667 PathPoint;PointKind.SMOOTHPOINT 4652.18478441238,157.586002349854 4663.07328701019,161.032340526581 4641.29592776299,154.139664173126 PathPoint;PointKind.SMOOTHPOINT 4679.05482172966,157.586002349854 4689.28195595741,158.607795238495 4668.8280415535,156.564209461212 PathPoint;PointKind.SMOOTHPOINT 4694.24257278442,163.32234621048 4707.18457460403,166.714868545532 4681.30021691322,159.929823875427 PathPoint;PointKind.SMOOTHPOINT 4712.93472647667,162.174983024597 4738.60028028488,159.737219810486 4687.26917266846,164.612982273102 PathPoint;PointKind.SMOOTHPOINT 4740.97313404083,164.469473361969 4748.72226119041,165.863256454468 4733.22436094284,163.075926303864 PathPoint;PointKind.SMOOTHPOINT 4764.33876872063,167.911326885223 4777.80582904816,176.233427524567 4750.8717083931,159.58922624588 PathPoint;PointKind.SMOOTHPOINT 4783.03092241287,163.32234621048 4794.5220208168,158.912515640259 4771.53982400894,167.732176780701 PathPoint;PointKind.SMOOTHPOINT 4802.89144635201,163.32234621048 4827.31109261513,167.521398067474 4778.47215414047,159.123058319092 PathPoint;PointKind.SMOOTHPOINT 4836.77135109901,166.764199733734 4849.82310891151,169.42619562149 4823.71959328651,164.102203845978 PathPoint;PointKind.CORNERPOINT 4861.30500197411,169.058690071106 4861.30500197411,169.058690071106 4861.30500197411,169.058690071106 PathPoint;PointKind.SMOOTHPOINT 4877.66076922417,162.174983024597 4893.28187942505,160.956101417542 4862.04001307487,163.394100666046 PathPoint;PointKind.SMOOTHPOINT 4903.36279034615,165.616836547852 4913.24295401573,169.36341047287 4893.48262667656,161.870262622833 PathPoint;PointKind.SMOOTHPOINT 4917.38217115402,165.616836547852 4923.14117431641,161.574511528015 4911.62281394005,169.659161567688 PathPoint;PointKind.SMOOTHPOINT 4931.40119791031,166.764199733734 4938.27404737473,166.772933006287 4924.52870249748,166.755230426788 PathPoint;PointKind.SMOOTHPOINT 4939.57908153534,166.764199733734 4952.94594526291,168.84791135788 4926.21257185936,164.680252075195 PathPoint;PointKind.SMOOTHPOINT 4964.11273241043,169.058690071106 4989.61860895157,168.364040851593 4938.60720992088,169.753339290619 PathPoint;PointKind.SMOOTHPOINT 5002.6657640934,166.764199733734 5013.44026207924,170.067028999329 4991.89126610756,163.461134433746 PathPoint;PointKind.SMOOTHPOINT 5023.69465827942,170.205817222595 5028.78769040108,173.047199249268 5018.60162615776,167.364671230316 PathPoint;PointKind.CORNERPOINT 5040.05042552948,178.236651420593 5040.05042552948,178.236651420593 5040.05042552948,178.236651420593 PathPoint;PointKind.SMOOTHPOINT 5042.38716602325,170.205817222595 5044.0650165081,167.94814825058 5038.59668970108,175.30604839325 PathPoint;PointKind.SMOOTHPOINT 5051.73306584358,166.764199733734 5068.53068947792,164.952163696289 5050.06442070007,166.94429397583 PathPoint;PointKind.SMOOTHPOINT 5063.41570615768,175.942161083221 5071.74441576004,178.649003505707 5055.08735060692,173.235318660736 PathPoint;PointKind.SMOOTHPOINT 5078.60345721245,172.500307559967 5082.46403574944,164.689221382141 5074.74252462387,180.311629772186 PathPoint;PointKind.SMOOTHPOINT 5097.29561090469,164.469473361969 5113.97993803024,166.2890625 5080.61128377914,162.650120258331 PathPoint;PointKind.SMOOTHPOINT 5117.15648889542,166.764199733734 5123.81442904472,168.413372039795 5110.49819469452,165.11479139328 PathPoint;PointKind.SMOOTHPOINT 5133.51225614548,171.353180408478 5155.78210115433,163.949725627899 5111.24205708504,178.756399154663 PathPoint;PointKind.SMOOTHPOINT 5168.56017708778,167.911326885223 5181.03695511818,165.244846343994 5156.08339905739,170.577807426453 PathPoint;PointKind.SMOOTHPOINT 5181.41118764877,164.469473361969 5190.75744152069,163.340284824371 5172.06493377686,165.59889793396 PathPoint;PointKind.SMOOTHPOINT 5193.09382796288,169.058690071106 5200.93394637108,172.495822906494 5185.25370955467,165.621321201324 PathPoint;PointKind.SMOOTHPOINT 5209.44959521294,173.64767074585 5218.4626865387,168.897242546082 5200.43650388718,178.398098945618 PathPoint;PointKind.SMOOTHPOINT 5233.98324608803,169.058690071106 5246.28653883934,166.880564689636 5221.67995333672,171.236579418182 PathPoint;PointKind.SMOOTHPOINT 5249.17099714279,165.616836547852 5253.76623272896,160.633442401886 5244.57540750504,170.600230693817 PathPoint;PointKind.SMOOTHPOINT 5263.19002389908,165.616836547852 5269.88938808441,164.917702674866 5256.49065971375,166.315970420837 PathPoint;PointKind.SMOOTHPOINT 5279.54579114914,165.616836547852 5296.32606625557,168.233985900879 5262.7658700943,162.999687194824 PathPoint;PointKind.SMOOTHPOINT 5313.42569589615,170.205817222595 5319.58194494247,168.408887386322 5307.26944684982,172.002983093262 PathPoint;PointKind.SMOOTHPOINT 5333.28621983528,167.911326885223 5353.96849751472,166.002280712128 5312.60429620743,169.820373058319 PathPoint;PointKind.SMOOTHPOINT 5355.48348426819,162.174983024597 5370.51120400429,157.536671161652 5340.45576453209,166.813294887543 PathPoint;PointKind.SMOOTHPOINT 5391.69977545738,159.880492687225 5404.08981084824,161.475849151611 5379.30974006653,158.285136222839 PathPoint;PointKind.CORNERPOINT 5411.56029939651,166.764199733734 5411.56029939651,166.764199733734 5411.56029939651,166.764199733734 PathPoint;PointKind.SMOOTHPOINT 5418.57016682625,161.027855873108 5441.01668357849,165.550510883331 5410.74704289436,159.45161819458 PathPoint;PointKind.SMOOTHPOINT 5452.45007157326,157.586002349854 5465.02244353294,155.089938640594 5439.87734556198,160.082302093506 PathPoint;PointKind.SMOOTHPOINT 5471.1422252655,162.174983024597 5479.54386949539,167.660422325134 5462.74058103561,156.689779758453 PathPoint;PointKind.SMOOTHPOINT 5486.32962226868,164.469473361969 5495.60187935829,164.496381282806 5471.64710283279,164.426987171173 PathPoint;PointKind.CORNERPOINT 5502.68538951874,163.32234621048 5502.68538951874,163.32234621048 5502.68538951874,163.32234621048 PathPoint;PointKind.CORNERPOINT 5507.3585164547,175.942161083221 5507.3585164547,175.942161083221 5507.3585164547,175.942161083221 PathPoint;PointKind.SMOOTHPOINT 5534.22890782356,174.794797897339 5546.5137898922,173.199441432953 5521.94367170334,176.390390396118 PathPoint;PointKind.CORNERPOINT 5547.07991838455,174.794797897339 5547.07991838455,174.794797897339 5547.07991838455,174.794797897339 PathPoint;PointKind.SMOOTHPOINT 5561.09894514084,172.500307559967 5572.88673877716,168.507313728333 5549.31150555611,176.493301391602 PathPoint;PointKind.SMOOTHPOINT 5579.79145288467,174.794797897339 5598.47440123558,177.752544879913 5561.10815048218,171.837050914764 PathPoint;PointKind.SMOOTHPOINT 5607.82986044884,172.500307559967 5622.42882370949,172.101409435272 5593.23089718819,172.899205684662 PathPoint;PointKind.SMOOTHPOINT 5628.85875463486,171.353180408478 5638.88939023018,167.104561328888 5618.82811903954,175.601563453674 PathPoint;PointKind.SMOOTHPOINT 5652.22403526306,172.500307559967 5664.42713141441,171.209671497345 5640.0212931633,173.790943622589 PathPoint;PointKind.CORNERPOINT 5660.40191888809,186.267485618591 5660.40191888809,186.267485618591 5660.40191888809,186.267485618591 PathPoint;PointKind.SMOOTHPOINT 5667.99986600876,198.999888896942 5678.83809328079,205.421912670135 5657.16128468513,192.578101158142 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,217.243459224701 5673.68664264679,223.669967651367 5675.15595674515,210.816950798035 PathPoint;PointKind.CORNERPOINT 5675.58966994286,244.777579307556 5675.58966994286,244.777579307556 5675.58966994286,244.777579307556 PathPoint;PointKind.CORNERPOINT 5675.58966994286,265.428228378296 5675.58966994286,265.428228378296 5675.58966994286,265.428228378296 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,284.931514263153 5673.73337745667,309.269964694977 5673.02846074104,273.562917709351 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,353.767168521881 5671.70607805252,364.715387821198 5674.01838898659,297.876348495483 PathPoint;PointKind.SMOOTHPOINT 5681.43081307411,384.743142127991 5681.06118321419,403.829591274261 5681.80044293404,365.656456947327 PathPoint;PointKind.SMOOTHPOINT 5684.93556976318,457.020177841187 5680.46354413033,473.709225654602 5689.40794944763,440.331130027771 PathPoint;PointKind.SMOOTHPOINT 5684.93556976318,479.965317249298 5684.34253334999,490.228092670441 5685.52896022797,469.702777862549 PathPoint;PointKind.SMOOTHPOINT 5677.92605638504,502.91045665741 5673.44022274017,514.714772701263 5682.41189002991,491.106376647949 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,539.622774124146 5671.92948460579,574.045085906982 5679.24950122833,505.200698375702 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,577.482218742371 5670.91194033623,586.01509809494 5675.59427261353,568.949575424194 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,611.900045871735 5666.97347044945,622.243309020996 5670.1861345768,601.556782722473 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,645.170509815216 5673.57405424118,681.377713680267 5674.93077993393,623.384299278259 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,708.269584178925 5671.26776218414,723.367760181427 5667.58385539055,686.764254570007 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,744.98190164566 5669.04538035393,760.76575756073 5670.45096516609,729.198045730591 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,777.105002403259 5670.29589056969,795.756912231445 5671.53719544411,758.453328609467 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,818.406300544739 5668.33798527718,830.398736000061 5668.82161974907,806.413865089417 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,847.087783813477 5671.72873735428,867.021360397339 5670.10399460793,827.154207229614 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,878.063757419586 5669.15017962456,886.367919445038 5668.00942540169,869.759595394135 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,901.008896827698 5671.85654997826,909.563963413239 5672.31292247772,892.453830242157 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,917.070565223694 5671.64199471474,925.345458984375 5665.73393583298,909.38009262085 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,934.279360771179 5672.68255233765,942.677700519562 5673.82330656052,925.881021022797 PathPoint;PointKind.SMOOTHPOINT 5667.41178631783,958.371863365173 5669.61115479469,992.117228507996 5667.41178631783,958.371863365173 PathPoint;PointKind.SMOOTHPOINT 5667.41178631783,999.673161506653 5666.28200769424,1007.39361047745 5668.37055802345,993.120846748352 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,1014.58746671677 5668.47500324249,1019.30650234222 5668.68495583534,1009.86843109131 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,1029.50177192688 5671.29962682724,1039.47752952576 5672.86949157715,1019.526014328 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,1044.41607713699 5665.30801177025,1054.28443908691 5671.85194730759,1034.54795122147 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,1065.06672620773 5669.35588359833,1075.86270332336 5670.14081597328,1054.2709851265 PathPoint;PointKind.SMOOTHPOINT 5666.24341607094,1085.71737527847 5665.1299238205,1091.89746379852 5667.35690832138,1079.53752279282 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,1102.92617082596 5669.62956547737,1112.08194494247 5674.53990697861,1093.77063274384 PathPoint;PointKind.CORNERPOINT 5668.57980251312,1116.69334888458 5668.57980251312,1116.69334888458 5668.57980251312,1116.69334888458 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,1127.01867341995 5673.18920016289,1132.84022569656 5670.98027229309,1121.19735717773 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,1138.4913611412 5666.93700313568,1152.50023841858 5672.55934238434,1124.48224782944 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,1162.58362770081 5668.32417726517,1171.82885885239 5668.83542776108,1153.33839654922 PathPoint;PointKind.SMOOTHPOINT 5669.00006175041,1206.00003004074 5663.29097986221,1216.93503141403 5674.70878958702,1195.06526470184 PathPoint;PointKind.SMOOTHPOINT 5667.41178631783,1232.56640911102 5667.73114085197,1243.88213396072 5667.09207773209,1221.25068426132 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,1256.65867567062 5674.90953683853,1263.90091896057 5676.26944899559,1249.41666841507 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1269.27872657776 5675.74474453926,1279.58611249924 5673.09785485268,1258.97134065628 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,1288.78201246262 5673.39915275574,1309.28915262222 5673.10706019402,1268.27487230301 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,1316.31613254547 5667.84974813461,1326.19794845581 5676.31972432137,1306.43455266953 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,1344.99761581421 5668.00482273102,1361.10413074493 5673.82790923119,1328.89110088348 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,1372.53173589706 5670.72464704514,1380.17264127731 5671.10808491707,1364.89083051682 PathPoint;PointKind.CORNERPOINT 5670.9165430069,1398.91872882843 5670.9165430069,1398.91872882843 5670.9165430069,1398.91872882843 PathPoint;PointKind.SMOOTHPOINT 5667.41178631783,1409.2440533638 5666.78653120995,1418.39062213898 5668.03668737411,1400.09724855423 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,1427.60021209717 5670.69278240204,1439.12199497223 5666.46682262421,1416.07819318771 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,1445.95637083054 5674.21594977379,1452.82190322876 5672.28990912437,1439.09060239792 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1470.04863739014 5674.13841247559,1481.91125392914 5674.70418691635,1458.18625688553 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1492.99377679825 5673.11591148376,1509.65591669083 5675.72633385658,1476.33163690567 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1518.23340654373 5675.89061379433,1530.77273368835 5672.95163154602,1505.6943154335 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1541.17878198624 5672.4725997448,1548.65375518799 5676.36999964714,1533.70357275009 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1559.53470468521 5675.45725464821,1574.14877414703 5673.38534474373,1544.92063522339 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,1593.95253181458 5668.23318600655,1606.16447925568 5673.59990000725,1581.74058437347 PathPoint;PointKind.SMOOTHPOINT 5676.75768613815,1615.7503080368 5677.21405863762,1627.48286962509 5676.30131363869,1604.01798248291 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1636.40095710754 5677.08624601364,1650.01117229462 5671.75599932671,1622.79074192047 PathPoint;PointKind.SMOOTHPOINT 5676.75768613815,1663.93531322479 5675.29297471046,1680.23891687393 5678.22275161743,1647.63170957565 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,1690.32207012177 5667.57606625557,1699.13724660873 5671.92027926445,1681.50712966919 PathPoint;PointKind.SMOOTHPOINT 5677.92605638504,1723.59253406525 5674.60823893547,1738.16199302673 5681.24387383461,1709.02331113815 PathPoint;PointKind.SMOOTHPOINT 5676.75768613815,1749.97952699661 5676.30131363869,1761.16071224213 5677.21405863762,1738.7983417511 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,1777.51364707947 5676.7031621933,1792.52661466599 5672.13943719864,1762.50067949295 PathPoint;PointKind.CORNERPOINT 5677.92605638504,1799.31165933609 5677.92605638504,1799.31165933609 5677.92605638504,1799.31165933609 PathPoint;PointKind.CORNERPOINT 5671.99994087219,1807.00000762939 5671.99994087219,1807.00000762939 5671.99994087219,1807.00000762939 PathPoint;PointKind.CORNERPOINT 5679.09442663193,1815.37332773209 5679.09442663193,1815.37332773209 5679.09442663193,1815.37332773209 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,1849.79091882706 5672.24883913994,1864.40498828888 5678.93014669418,1835.17684936523 PathPoint;PointKind.SMOOTHPOINT 5676.75768613815,1872.73605823517 5681.33521914482,1890.98458528519 5672.18050718307,1854.48753118515 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,1904.85939502716 5671.09427690506,1913.51760864258 5675.4115819931,1896.20118141174 PathPoint;PointKind.CORNERPOINT 5672.08455920219,1923.21555376053 5672.08455920219,1923.21555376053 5672.08455920219,1923.21555376053 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,1930.09902477264 5670.69278240204,1946.80601119995 5668.80356311798,1913.39203834534 PathPoint;PointKind.CORNERPOINT 5669.74817276001,1955.33865451813 5669.74817276001,1955.33865451813 5669.74817276001,1955.33865451813 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,1964.51661586761 5677.43321657181,1972.77168273926 5673.74576926231,1956.26178503036 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,1977.13666677475 5669.50175285339,1995.49258947372 5674.66771960258,1958.78050804138 PathPoint;PointKind.CORNERPOINT 5673.25292944908,2005.81791400909 5673.25292944908,2005.81791400909 5673.25292944908,2005.81791400909 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,2017.29060173035 5676.3607943058,2032.91301012039 5670.14506459236,2001.6681933403 PathPoint;PointKind.CORNERPOINT 5676.75768613815,2044.8247218132 5676.75768613815,2044.8247218132 5676.75768613815,2044.8247218132 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,2051.70819282532 5671.28475666046,2062.02738046646 5674.61992263794,2044.54171657562 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,2073.50620508194 5668.99404287338,2103.35228204727 5671.26776218414,2068.04767370224 PathPoint;PointKind.SMOOTHPOINT 5680.26244282722,2109.07115936279 5683.17982792854,2110.49775123596 5672.80009746552,2105.42112350464 PathPoint;PointKind.CORNERPOINT 5674.42129969597,2133.16366195679 5674.42129969597,2133.16366195679 5674.42129969597,2133.16366195679 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,2149.22509431839 5672.28105783463,2163.68692159653 5676.56154155731,2134.76350307465 PathPoint;PointKind.CORNERPOINT 5675.58966994286,2168.72861623764 5675.58966994286,2168.72861623764 5675.58966994286,2168.72861623764 PathPoint;PointKind.CORNERPOINT 5680.26244282722,2187.08477497101 5680.26244282722,2187.08477497101 5680.26244282722,2187.08477497101 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,2199.70458984375 5674.23400640488,2215.62723398209 5676.94497942924,2183.78194570541 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,2230.68056344986 5669.37394022942,2247.8803896904 5679.46865916252,2213.48050117493 PathPoint;PointKind.CORNERPOINT 5670.9165430069,2255.92019319534 5670.9165430069,2255.92019319534 5670.9165430069,2255.92019319534 PathPoint;PointKind.SMOOTHPOINT 5669.00006175041,2276.99995279312 5671.99356794357,2301.67050361633 5666.00620150566,2252.32940196991 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,2309.84130620956 5668.04589271545,2318.45018863678 5676.12357974052,2301.23242378235 PathPoint;PointKind.SMOOTHPOINT 5669.99990344048,2325.99998474121 5671.99852466583,2334.86000776291 5668.00092816353,2317.14019775391 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,2338.5227894783 5671.28617286682,2364.64070320129 5668.2101726532,2312.40463972092 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,2372.94038057327 5667.81788349152,2384.4668841362 5671.6784620285,2361.41411304474 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,2397.03288316727 5674.84049677849,2406.75018310547 5671.67208909988,2387.35759735107 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,2419.97802257538 5671.01567745209,2428.62065792084 5666.27846717834,2411.81052446365 PathPoint;PointKind.SMOOTHPOINT 5668.57980251312,2445.21765232086 5662.25467085838,2463.5289645195 5674.90493416786,2426.90634012222 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,2483.07709693909 5667.80867815018,2498.19321155548 5676.3607943058,2467.96121835709 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,2515.20043373108 5673.28479409218,2521.63119077682 5673.22106480598,2508.76944065094 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,2538.14557313919 5675.50292730331,2550.78332662582 5671.00328564644,2525.50781965256 PathPoint;PointKind.SMOOTHPOINT 5679.09442663193,2561.0907125473 5680.45433878899,2572.14656352997 5677.73451447487,2550.03486156464 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,2585.1829791069 5671.62854075432,2605.76210975647 5677.21405863762,2564.60408449173 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,2627.63164043427 5671.65120005608,2642.20086336136 5672.5182723999,2613.06241750717 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,2654.01863336563 5679.58726644516,2671.5949344635 5669.25533294678,2636.44209623337 PathPoint;PointKind.SMOOTHPOINT 5676.75768613815,2694.17256832123 5673.5485625267,2704.71150398254 5679.22223925591,2686.07989311218 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,2718.26483488083 5671.40938282013,2730.43665647507 5672.76008963585,2706.09324932098 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,2740.06284713745 5674.37562704086,2746.61917448044 5674.46697235107,2733.50651979446 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,2757.27164268494 5661.7108476162,2785.80277204514 5676.6256248951,2755.14214038849 PathPoint;PointKind.SMOOTHPOINT 5677.92605638504,2806.60377502441 5679.60992574692,2820.31713724136 5676.24218702316,2792.89041280746 PathPoint;PointKind.SMOOTHPOINT 5679.09442663193,2839.8742389679 5679.15815591812,2850.00695943832 5679.03034329414,2829.74175453186 PathPoint;PointKind.SMOOTHPOINT 5677.92605638504,2865.11386871338 5678.13140630722,2871.06972455978 5677.72070646286,2859.15801286697 PathPoint;PointKind.SMOOTHPOINT 5675.00017404556,2887.99999952316 5674.37952160835,2905.42854309082 5675.62082648277,2870.5716919899 PathPoint;PointKind.SMOOTHPOINT 5680.26244282722,2925.91868877411 5679.27676320076,2936.00184202194 5681.24847650528,2915.83529949188 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,2952.30544567108 5673.50395202637,2961.98993682861 5677.67503380775,2942.62095451355 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,2975.25058507919 5674.80013489723,2988.32759857178 5674.04246449471,2962.173807621 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,3005.07943153381 5676.59340620041,3023.22929620743 5672.24883913994,2986.92933082581 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,3040.64438581467 5667.9984498024,3046.78128004074 5674.13310170174,3025.26462078094 PathPoint;PointKind.CORNERPOINT 5675.58966994286,3059.00054454803 5675.58966994286,3059.00054454803 5675.58966994286,3059.00054454803 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,3079.65119361877 5680.26704549789,3102.83968448639 5672.17059373856,3062.70132780075 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,3122.09961891174 5673.19380283356,3140.72462081909 5670.97566962242,3103.47461700439 PathPoint;PointKind.CORNERPOINT 5674.42129969597,3153.07559251785 5674.42129969597,3153.07559251785 5674.42129969597,3153.07559251785 PathPoint;PointKind.SMOOTHPOINT 5672.08455920219,3164.54804420471 5671.03515028954,3172.66857147217 5673.13432216644,3156.42775297165 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,3177.16809511185 5674.89183425903,3182.29334592819 5673.66823196411,3168.96235942841 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,3223.05837392807 5675.06000876427,3229.09471750259 5673.45580101013,3213.93918514252 PathPoint;PointKind.CORNERPOINT 5670.9165430069,3237.97267913818 5670.9165430069,3237.97267913818 5670.9165430069,3237.97267913818 PathPoint;PointKind.SMOOTHPOINT 5666.24341607094,3265.50679922104 5667.16076374054,3292.51220226288 5665.32606840134,3238.5013961792 PathPoint;PointKind.SMOOTHPOINT 5669.74817276001,3306.80809736252 5670.70659041405,3316.58676624298 5668.78975510597,3297.02942848206 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,3334.34221744537 5670.11780261993,3340.06510734558 5671.71492934227,3328.61932754517 PathPoint;PointKind.SMOOTHPOINT 5673.25292944908,3365.31819105148 5673.3580827713,3371.66397571564 5673.14813017845,3358.97240638733 PathPoint;PointKind.SMOOTHPOINT 5680.26244282722,3383.67434978485 5683.2835650444,3399.09518480301 5677.24167466164,3368.25351476669 PathPoint;PointKind.SMOOTHPOINT 5679.09442663193,3405.47212600708 5678.7885260582,3414.24245595932 5679.39997315407,3396.70203208923 PathPoint;PointKind.SMOOTHPOINT 5677.92605638504,3437.59546279907 5674.47617769241,3446.91244840622 5681.37628912926,3428.27847719193 PathPoint;PointKind.SMOOTHPOINT 5681.43081307411,3455.95162153244 5681.03392124176,3467.35255479813 5681.82805895805,3444.55068826675 PathPoint;PointKind.CORNERPOINT 5677.92605638504,3476.60227060318 5677.92605638504,3476.60227060318 5677.92605638504,3476.60227060318 PathPoint;PointKind.SMOOTHPOINT 5677.92605638504,3501.84190034866 5672.99730420113,3515.76132059097 5682.85480856895,3487.92248010635 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,3530.5233836174 5672.77850031853,3538.48246335983 5669.05458569527,3522.56430387497 PathPoint;PointKind.SMOOTHPOINT 5674.42129969597,3554.615650177 5673.14352750778,3561.14082098007 5675.69907188416,3548.09071540833 PathPoint;PointKind.SMOOTHPOINT 5675.58966994286,3568.38282823563 5686.21971487999,3574.48384523392 5661.35821223259,3560.21509408951 PathPoint;PointKind.SMOOTHPOINT 5684.93556976318,3587.88611412048 5682.87534356117,3596.81836366653 5685.90602517128,3583.67998123169 PathPoint;PointKind.SMOOTHPOINT 5680.26244282722,3601.65329217911 5677.60670185089,3614.47916507721 5682.91853785515,3588.82741928101 PathPoint;PointKind.CORNERPOINT 5679.09442663193,3636.07111930847 5679.09442663193,3636.07111930847 5679.09442663193,3636.07111930847 PathPoint;PointKind.SMOOTHPOINT 5676.00001573563,3650.96890211105 5675.29368281364,3651.81602954865 5680.8101606369,3645.20116567612 PathPoint;PointKind.SMOOTHPOINT 5673.00013661385,3670.99996089935 5671.72696709633,3695.9797167778 5672.585542202,3679.13465023041 PathPoint;PointKind.SMOOTHPOINT 5678.00005316734,3697.96877861023 5671.04046106339,3708.23155403137 5684.95929121971,3687.70623922348 PathPoint;PointKind.SMOOTHPOINT 5678.99989485741,3717.96891689301 5681.07994794846,3726.68708324432 5676.98675751686,3709.53021526337 PathPoint;PointKind.SMOOTHPOINT 5678.00005316734,3731.96882486343 5677.39179253578,3736.41712903976 5679.30083870888,3722.46112346649 PathPoint;PointKind.SMOOTHPOINT 5676.75768613815,3741.61861896515 5687.07120895386,3751.50727987289 5673.37613940239,3738.37621450424 PathPoint;PointKind.SMOOTHPOINT 5679.75013017654,3759.96887683868 5679.76818680763,3763.84526968002 5679.73171949387,3756.09248399734 PathPoint;PointKind.SMOOTHPOINT 5670.9165430069,3777.1838092804 5661.71190977097,3779.72471952438 5680.12117624283,3774.64266300201 PathPoint;PointKind.SMOOTHPOINT 5655.72879195213,3776.03644609451 5649.67769622803,3776.18892431259 5661.78024172783,3775.88396787643 PathPoint;PointKind.SMOOTHPOINT 5648.71927857399,3780.62542676926 5640.24469971657,3781.66067361832 5657.19385743141,3779.5901799202 PathPoint;PointKind.SMOOTHPOINT 5634.69989776611,3777.1838092804 5627.86847233772,3776.9685459137 5641.53167724609,3777.3988366127 PathPoint;PointKind.SMOOTHPOINT 5625.35399794579,3781.77278995514 5616.85215711594,3782.37326145172 5633.85583877563,3781.17231845856 PathPoint;PointKind.SMOOTHPOINT 5607.82986044884,3774.88908290863 5603.31641077995,3775.05501508713 5612.34331011772,3774.72338676453 PathPoint;PointKind.SMOOTHPOINT 5599.14722013474,3781.47829961777 5588.30863881111,3782.14604091644 5609.98544740677,3780.81055831909 PathPoint;PointKind.CORNERPOINT 5579.2866961956,3782.62542676926 5579.2866961956,3782.62542676926 5579.2866961956,3782.62542676926 PathPoint;PointKind.SMOOTHPOINT 5562.93092894554,3779.1838092804 5552.99128460884,3779.1838092804 5572.87021923065,3779.1838092804 PathPoint;PointKind.SMOOTHPOINT 5535.22890782356,3785.62542676926 5523.47758150101,3785.26689052582 5546.97988009453,3785.9839630127 PathPoint;PointKind.SMOOTHPOINT 5504.00014138222,3781.99993848801 5501.17126917839,3781.43321990967 5511.40158987045,3783.482234478 PathPoint;PointKind.SMOOTHPOINT 5486.00015854836,3781.00009679794 5467.82208776474,3782.85981178284 5492.46549463272,3780.33849239349 PathPoint;PointKind.CORNERPOINT 5455.78645801544,3783.33093643188 5455.78645801544,3783.33093643188 5455.78645801544,3783.33093643188 PathPoint;PointKind.SMOOTHPOINT 5439.43069076538,3782.1838092804 5421.34532445311,3786.47305329707 5451.01313447952,3779.43660497665 PathPoint;PointKind.SMOOTHPOINT 5413.99987316132,3780.00001907349 5400.72895741463,3780.16595125198 5423.05292088273,3779.88698579617 PathPoint;PointKind.CORNERPOINT 5397.37290239334,3781.03644609451 5397.37290239334,3781.03644609451 5397.37290239334,3781.03644609451 PathPoint;PointKind.SMOOTHPOINT 5388.02664852142,3785.62542676926 5378.55293607712,3786.198990345 5397.50071501732,3785.05186319351 PathPoint;PointKind.SMOOTHPOINT 5368.16612458229,3781.03644609451 5350.53718781471,3781.08129262924 5385.79506134987,3780.99159955978 PathPoint;PointKind.SMOOTHPOINT 5342.6324737072,3781.77278995514 5333.85234832764,3783.56075048447 5351.41259908676,3779.98459339142 PathPoint;PointKind.SMOOTHPOINT 5311.08930945396,3782.91991710663 5305.64470410347,3782.88403987885 5316.53356075287,3782.95579433441 PathPoint;PointKind.CORNERPOINT 5298.23829889297,3784.06728029251 5298.23829889297,3784.06728029251 5298.23829889297,3784.06728029251 PathPoint;PointKind.SMOOTHPOINT 5284.2189180851,3786.36177062988 5275.48871397972,3783.94619464874 5292.94912219048,3788.77734661102 PathPoint;PointKind.SMOOTHPOINT 5262.02200770378,3784.06728029251 5249.91025686264,3785.21889209747 5274.13340449333,3782.91543245316 PathPoint;PointKind.SMOOTHPOINT 5248.0026268959,3790.95075130463 5236.68501377106,3791.03147506714 5259.32024002075,3790.87002754211 PathPoint;PointKind.SMOOTHPOINT 5224.6373462677,3786.36177062988 5215.85013985634,3785.00929355621 5233.83135795593,3787.77679681778 PathPoint;PointKind.SMOOTHPOINT 5212.95435190201,3792.09811449051 5206.78925156593,3792.47907400131 5219.11980628967,3791.71715497971 PathPoint;PointKind.SMOOTHPOINT 5193.09382796288,3786.36177062988 5182.49210715294,3788.20519924164 5206.32792234421,3784.0606713295 PathPoint;PointKind.SMOOTHPOINT 5183.74757409096,3793.245241642 5177.94750094414,3796.05971574783 5189.54800128937,3790.43100357056 PathPoint;PointKind.CORNERPOINT 5163.88705015182,3793.245241642 5163.88705015182,3793.245241642 5163.88705015182,3793.245241642 PathPoint;PointKind.SMOOTHPOINT 5152.20440983772,3790.95075130463 5142.08242893219,3790.48481941223 5162.32639074326,3791.41691923141 PathPoint;PointKind.CORNERPOINT 5132.34388589859,3793.245241642 5132.34388589859,3793.245241642 5132.34388589859,3793.245241642 PathPoint;PointKind.SMOOTHPOINT 5115.98811864853,3795.53973197937 5108.45814943314,3795.60251712799 5123.51808786392,3795.47718286514 PathPoint;PointKind.SMOOTHPOINT 5099.63235139847,3793.245241642 5083.12115550041,3791.79787874222 5116.14319324493,3794.69284057617 PathPoint;PointKind.CORNERPOINT 5073.93033027649,3793.245241642 5073.93033027649,3793.245241642 5073.93033027649,3793.245241642 PathPoint;PointKind.SMOOTHPOINT 5059.91094946861,3793.245241642 5053.59042048454,3792.41628885269 5066.23147845268,3794.0744304657 PathPoint;PointKind.CORNERPOINT 5047.05993890762,3792.09811449051 5047.05993890762,3792.09811449051 5047.05993890762,3792.09811449051 PathPoint;PointKind.CORNERPOINT 5038.88205528259,3793.245241642 5038.88205528259,3793.245241642 5038.88205528259,3793.245241642 PathPoint;PointKind.SMOOTHPOINT 5031.00015878677,3797.99991846085 5024.34646725655,3796.99181556702 5037.653850317,3799.00825738907 PathPoint;PointKind.SMOOTHPOINT 5017.85351514816,3792.09811449051 5006.13865613937,3790.63706159592 5029.56802010536,3793.55893135071 PathPoint;PointKind.SMOOTHPOINT 4990.9831237793,3793.245241642 4972.55084395409,3793.59032392502 5009.41540360451,3792.90015935898 PathPoint;PointKind.SMOOTHPOINT 4958.27158927917,3793.245241642 4952.26120948792,3793.1779718399 4964.28161501884,3793.31251144409 PathPoint;PointKind.SMOOTHPOINT 4946.58894896507,3789.80362415314 4937.97735214233,3789.48544979095 4955.20019173622,3790.12179851532 PathPoint;PointKind.SMOOTHPOINT 4930.23318171501,3795.53973197937 4908.0221092701,3793.83674383163 4952.44390010834,3797.24272012711 PathPoint;PointKind.SMOOTHPOINT 4897.52164721489,3787.50913381577 4889.62523460388,3787.14894533157 4906.76416397095,3787.93045520782 PathPoint;PointKind.SMOOTHPOINT 4870.65125584602,3792.09811449051 4864.61821675301,3791.6678237915 4876.68429493904,3792.52816915512 PathPoint;PointKind.SMOOTHPOINT 4862.47337222099,3787.50913381577 4852.1276307106,3786.1422586441 4872.81911373138,3788.87577295303 PathPoint;PointKind.SMOOTHPOINT 4826.2570810318,3794.39260482788 4802.26654529572,3788.38741779327 4850.24761676788,3800.39779186249 PathPoint;PointKind.SMOOTHPOINT 4781.86290621758,3786.36177062988 4776.82900071144,3786.2765622139 4786.89645767212,3786.44697904587 PathPoint;PointKind.SMOOTHPOINT 4757.32890129089,3787.50913381577 4735.16527175903,3787.48293399811 4776.23596429825,3787.53132104874 PathPoint;PointKind.SMOOTHPOINT 4693.07420253754,3790.95075130463 4673.32095623016,3789.92895841599 4714.57717180252,3792.06294536591 PathPoint;PointKind.SMOOTHPOINT 4661.5310382843,3787.50913381577 4634.07185912132,3784.73502159119 4688.98986339569,3790.28301000595 PathPoint;PointKind.SMOOTHPOINT 4631.15589022636,3787.50913381577 4619.92962241173,3786.86806440353 4642.382158041,3788.1499671936 PathPoint;PointKind.SMOOTHPOINT 4603.1174826622,3788.65626096725 4589.91950154305,3793.68001699448 4616.31510972977,3783.63250494003 PathPoint;PointKind.SMOOTHPOINT 4575.07872104645,3793.245241642 4558.18444132805,3792.60889291763 4591.97300076485,3793.88159036636 PathPoint;PointKind.SMOOTHPOINT 4540.03080010414,3789.80362415314 4529.58486199379,3787.62549877167 4550.47673821449,3791.98151350021 PathPoint;PointKind.SMOOTHPOINT 4497.9730117321,3785.214407444 4456.20271325111,3785.45209407806 4539.74331021309,3784.97695684433 PathPoint;PointKind.SMOOTHPOINT 4434.88632917404,3782.91991710663 4419.28362965584,3782.67798185349 4450.48938274384,3783.16208839417 PathPoint;PointKind.SMOOTHPOINT 4413.85743498802,3784.06728029251 4403.62605214119,3786.62612915039 4424.08917188644,3781.50843143463 PathPoint;PointKind.SMOOTHPOINT 4375.30475735664,3785.214407444 4361.52719378471,3785.68506002426 4389.08196687698,3784.74399089813 PathPoint;PointKind.SMOOTHPOINT 4354.27586317062,3781.77278995514 4338.39912772179,3780.18191814423 4370.15224456787,3783.36366176605 PathPoint;PointKind.CORNERPOINT 4330.91022849083,3780.62542676926 4330.91022849083,3780.62542676926 4330.91022849083,3780.62542676926 PathPoint;PointKind.CORNERPOINT 4322.7323448658,3787.50913381577 4322.7323448658,3787.50913381577 4322.7323448658,3787.50913381577 PathPoint;PointKind.CORNERPOINT 4312.21807479858,3784.06728029251 4312.21807479858,3784.06728029251 4312.21807479858,3784.06728029251 PathPoint;PointKind.SMOOTHPOINT 4299.36706423759,3781.77278995514 4295.21439313889,3788.32463264465 4303.52008938789,3775.22071123123 PathPoint;PointKind.SMOOTHPOINT 4286.51605367661,3780.62542676926 4274.52326416969,3783.01409482956 4298.50919723511,3778.23675870895 PathPoint;PointKind.SMOOTHPOINT 4264.99998450279,3778.00001621246 4262.24971175194,3779.73770141602 4273.53793859482,3772.60545015335 PathPoint;PointKind.SMOOTHPOINT 4252.6361489296,3776.03644609451 4245.59016823769,3781.07814073563 4259.6824836731,3770.9947514534 PathPoint;PointKind.SMOOTHPOINT 4233.94399523735,3778.33093643188 4216.4517223835,3775.68687915802 4251.43591403961,3780.97499370575 PathPoint;PointKind.SMOOTHPOINT 4205.90558767319,3780.62542676926 4195.50957083702,3784.57357406616 4216.30125045776,3776.67727947235 PathPoint;PointKind.SMOOTHPOINT 4189.54982042313,3780.62542676926 4170.88457465172,3775.41355133057 4208.21471214294,3785.83753824234 PathPoint;PointKind.SMOOTHPOINT 4162.67942905426,3779.47829961777 4154.19139623642,3780.25792121887 4171.16781592369,3778.69844198227 PathPoint;PointKind.SMOOTHPOINT 4135.80939173698,3781.77278995514 4117.01208472252,3783.86098623276 4154.60669875145,3779.68435764313 PathPoint;PointKind.SMOOTHPOINT 4111.27574086189,3782.91991710663 4106.37425065041,3782.10441827774 4116.17687702179,3783.73565196991 PathPoint;PointKind.SMOOTHPOINT 4085.57371973991,3781.77278995514 4058.67146372795,3778.09797048569 4112.47562170029,3785.44760942459 PathPoint;PointKind.SMOOTHPOINT 4048.18905830383,3780.62542676926 4032.87809729576,3780.82723617554 4063.49966526031,3780.42385339737 PathPoint;PointKind.SMOOTHPOINT 4014.30915355682,3781.77278995514 4006.08559727669,3784.68120574951 4022.53270983696,3778.86413812637 PathPoint;PointKind.SMOOTHPOINT 3986.27074599266,3784.06728029251 3979.04950976372,3783.88931035995 4000.81907987595,3784.42581653595 PathPoint;PointKind.SMOOTHPOINT 3881.12627506256,3782.91991710663 3822.15154767036,3782.4270772934 3927.0828795433,3783.30418109894 PathPoint;PointKind.SMOOTHPOINT 3816.8715763092,3787.50913381577 3808.05462956429,3787.21314668655 3825.68816900253,3787.80488491058 PathPoint;PointKind.SMOOTHPOINT 3794.6743118763,3787.50913381577 3787.01653003693,3785.25476932526 3802.33209371567,3789.76326227188 PathPoint;PointKind.SMOOTHPOINT 3779.48691487312,3790.95075130463 3770.81619143486,3794.21321868896 3788.15763831139,3787.68828392029 PathPoint;PointKind.SMOOTHPOINT 3768.97229075432,3787.50913381577 3757.41746306419,3787.98403501511 3780.52711844444,3787.03399658203 PathPoint;PointKind.SMOOTHPOINT 3756.12128019333,3793.245241642 3749.87191557884,3794.66616868973 3765.79680204391,3791.04540109634 PathPoint;PointKind.SMOOTHPOINT 3742.10225343704,3786.36177062988 3732.89726614952,3788.7815952301 3751.79866433144,3783.81259918213 PathPoint;PointKind.SMOOTHPOINT 3725.74648618698,3789.80362415314 3719.26911234856,3788.86444330215 3732.70182967186,3790.81196308136 PathPoint;PointKind.SMOOTHPOINT 3698.87609481812,3788.65626096725 3683.99424433708,3788.54414463043 3713.75794529915,3788.76837730408 PathPoint;PointKind.SMOOTHPOINT 3662.65980362892,3785.214407444 3650.14939069748,3786.62518501282 3676.6402387619,3783.63793373108 PathPoint;PointKind.SMOOTHPOINT 3636.95778250694,3789.80362415314 3614.08675789833,3792.53454208374 3648.34620594978,3788.44359397888 PathPoint;PointKind.SMOOTHPOINT 3566.86158657074,3787.50913381577 3558.92091751099,3787.50016450882 3576.18907570839,3787.51928329468 PathPoint;PointKind.SMOOTHPOINT 3531.81331157684,3788.65626096725 3518.25065732002,3792.59095430374 3545.37631988525,3784.72156763077 PathPoint;PointKind.SMOOTHPOINT 3510.78477144241,3790.95075130463 3504.13107991219,3790.54736852646 3517.43810892105,3791.35413408279 PathPoint;PointKind.SMOOTHPOINT 3481.57799363136,3787.50913381577 3471.56718492508,3785.54556369781 3492.84356117249,3789.71841573715 PathPoint;PointKind.SMOOTHPOINT 3455.87597250938,3789.80362415314 3443.45124006271,3788.69284629822 3468.19519758224,3790.90472459793 PathPoint;PointKind.SMOOTHPOINT 3426.66919469833,3788.65626096725 3412.50854730606,3788.57553720474 3440.82984209061,3788.73698472977 PathPoint;PointKind.SMOOTHPOINT 3403.30391407013,3787.50913381577 3393.98492217064,3786.32140874863 3412.62255191803,3788.69662284851 PathPoint;PointKind.SMOOTHPOINT 3378.76990914345,3788.65626096725 3358.8959312439,3789.83950138092 3398.64424109459,3787.47325658798 PathPoint;PointKind.SMOOTHPOINT 3340.21723151207,3796.68709516525 3320.52240371704,3793.3191204071 3357.7243745327,3799.68095541 PathPoint;PointKind.SMOOTHPOINT 3304.00094032288,3787.50913381577 3283.84088873863,3783.51283550262 3323.3325111866,3791.34091615677 PathPoint;PointKind.SMOOTHPOINT 3279.46693539619,3790.95075130463 3263.81042003632,3791.15775346756 3288.28848481178,3790.83438634872 PathPoint;PointKind.SMOOTHPOINT 3244.41901445389,3789.80362415314 3226.74723744392,3790.85822582245 3261.61034345627,3788.77734661102 PathPoint;PointKind.SMOOTHPOINT 3196.519728899,3794.39260482788 3162.22027301788,3793.14681529999 3230.81953883171,3795.63839435577 PathPoint;PointKind.SMOOTHPOINT 3128.76027345657,3788.65626096725 3093.27934741974,3787.45366573334 3152.87083268166,3789.4734120369 PathPoint;PointKind.SMOOTHPOINT 3032.96205639839,3789.80362415314 2998.56452822685,3789.37404155731 3057.57253646851,3790.11070489883 PathPoint;PointKind.SMOOTHPOINT 2914.9665749073,3789.80362415314 2900.65545558929,3791.11267089844 2955.00131249428,3786.14107847214 PathPoint;PointKind.SMOOTHPOINT 2884.59178090096,3790.95075130463 2885.72510004044,3790.97034215927 2898.36438775063,3791.1882019043 PathPoint;PointKind.SMOOTHPOINT 2794.63506102562,3788.65626096725 2781.86866879463,3789.02919530869 2834.57880735397,3787.48930692673 PathPoint;PointKind.SMOOTHPOINT 2760.75515627861,3792.09811449051 2755.86287140846,3793.11990737915 2765.64708709717,3791.07632160187 PathPoint;PointKind.SMOOTHPOINT 2722.20212459564,3792.09811449051 2691.50301933289,3789.8260474205 2752.9012298584,3794.37018156052 PathPoint;PointKind.SMOOTHPOINT 2653.27429890633,3789.80362415314 2628.82278800011,3788.90268087387 2677.72580981255,3790.70433139801 PathPoint;PointKind.SMOOTHPOINT 2597.19712972641,3788.65626096725 2584.83471035957,3788.75940799713 2609.55990314484,3788.55311393738 PathPoint;PointKind.SMOOTHPOINT 2567.99035191536,3790.95075130463 2551.4933180809,3792.55507707596 2584.48773980141,3789.34642553329 PathPoint;PointKind.SMOOTHPOINT 2529.43767428398,3790.95075130463 2518.41215372086,3790.26058673859 2540.46319484711,3791.64091587067 PathPoint;PointKind.SMOOTHPOINT 2502.56728291512,3789.80362415314 2491.48688435555,3789.43163394928 2513.64768147469,3790.1753783226 PathPoint;PointKind.SMOOTHPOINT 2482.70675897598,3792.09811449051 2486.71391487122,3792.26192235947 2489.94003295898,3792.39386558533 PathPoint;PointKind.SMOOTHPOINT 2416.11531972885,3788.65626096725 2409.19254899025,3788.8981962204 2434.2498421669,3788.02250862122 PathPoint;PointKind.SMOOTHPOINT 2397.42316603661,3789.80362415314 2384.07931566238,3790.74469327927 2410.76666235924,3788.86231899261 PathPoint;PointKind.SMOOTHPOINT 2364.71127748489,3790.95075130463 2347.74866580963,3791.26444101334 2381.67424321175,3790.63706159592 PathPoint;PointKind.SMOOTHPOINT 2336.67286992073,3789.80362415314 2324.10049796104,3787.36114025116 2349.24559593201,3792.24587202072 PathPoint;PointKind.SMOOTHPOINT 2319.14873242378,3793.245241642 2313.16136598587,3793.93092155457 2325.13609886169,3792.55956172943 PathPoint;PointKind.SMOOTHPOINT 2301.62494897842,3793.245241642 2285.14597177505,3792.42525815964 2318.10392618179,3794.06546115875 PathPoint;PointKind.SMOOTHPOINT 2268.9134144783,3789.80362415314 2246.93991065025,3787.45531797409 2290.88691830635,3792.15193033218 PathPoint;PointKind.SMOOTHPOINT 2233.86513948441,3789.80362415314 2226.71860814095,3791.19268655777 2241.01167082787,3788.41432571411 PathPoint;PointKind.SMOOTHPOINT 2212.83624529839,3796.68709516525 2199.20242667198,3796.48859024048 2225.5346596241,3796.87191009521 PathPoint;PointKind.SMOOTHPOINT 2170.77845692635,3794.39260482788 2161.20419383049,3794.67490196228 2178.33250164986,3794.1697883606 PathPoint;PointKind.SMOOTHPOINT 2127.55265235901,3794.39260482788 2121.16804003716,3792.70307064056 2133.93691062927,3796.0821390152 PathPoint;PointKind.SMOOTHPOINT 2111.19688510895,3796.68709516525 2098.28179121017,3796.48103713989 2124.11162495613,3796.89315319061 PathPoint;PointKind.SMOOTHPOINT 2090.16799092293,3794.39260482788 2077.68200755119,3794.05200719833 2102.65362024307,3794.73320245743 PathPoint;PointKind.SMOOTHPOINT 2066.80235624313,3801.27607584 2053.84654641151,3799.47017669678 2079.75852012634,3803.08221101761 PathPoint;PointKind.SMOOTHPOINT 2027.08130836487,3793.245241642 2018.04095506668,3793.53202342987 2036.12166166306,3792.95845985413 PathPoint;PointKind.SMOOTHPOINT 2008.38880062103,3797.83422231674 1993.24707627296,3798.78449678421 2023.53087902069,3796.88418388367 PathPoint;PointKind.SMOOTHPOINT 1978.01400661469,3796.68709516525 1960.44809103012,3796.9113278389 1997.32221007347,3796.44067525864 PathPoint;PointKind.SMOOTHPOINT 1899.73992705345,3797.83422231674 1889.80948805809,3798.31384420395 1911.42221331596,3797.27033615112 PathPoint;PointKind.SMOOTHPOINT 1856.51376843452,3798.98158550262 1841.92861318588,3798.79346609116 1871.09892368317,3799.16970491409 PathPoint;PointKind.SMOOTHPOINT 1823.8022339344,3798.98158550262 1817.55924224854,3798.38111400604 1830.04522562027,3799.58205699921 PathPoint;PointKind.SMOOTHPOINT 1807.44646668434,3790.95075130463 1795.70894837379,3790.40858030319 1819.18398499489,3791.49315834045 PathPoint;PointKind.CORNERPOINT 1798.10021281242,3797.83422231674 1798.10021281242,3797.83422231674 1798.10021281242,3797.83422231674 PathPoint;PointKind.SMOOTHPOINT 1778.23968887329,3792.09811449051 1768.02175998688,3789.98725891113 1788.4576177597,3794.20873403549 PathPoint;PointKind.SMOOTHPOINT 1733.84551405907,3788.65626096725 1726.44335746765,3789.4450879097 1741.24767065048,3787.86743402481 PathPoint;PointKind.SMOOTHPOINT 1709.31186318398,3792.09811449051 1700.33523917198,3792.72100925446 1718.28813314438,3791.47521972656 PathPoint;PointKind.SMOOTHPOINT 1684.77821230888,3793.245241642 1663.79499077797,3791.89630508423 1705.7614338398,3794.59417819977 PathPoint;PointKind.SMOOTHPOINT 1654.40306425095,3792.09811449051 1647.44807481766,3791.16601467133 1661.35805368423,3793.03021430969 PathPoint;PointKind.SMOOTHPOINT 1639.21566724777,3792.09811449051 1634.2642557621,3792.32659578323 1644.16707873344,3791.86939716339 PathPoint;PointKind.CORNERPOINT 1628.70104312897,3795.53973197937 1628.70104312897,3795.53973197937 1628.70104312897,3795.53973197937 PathPoint;PointKind.SMOOTHPOINT 1621.69152975082,3790.95075130463 1611.48740887642,3791.12565279007 1631.89565062523,3790.77608585358 PathPoint;PointKind.SMOOTHPOINT 1607.67214894295,3793.245241642 1600.2427303791,3794.52690839767 1615.10156750679,3791.96357488632 PathPoint;PointKind.SMOOTHPOINT 1594.82113838196,3793.245241642 1587.63353705406,3791.60503864288 1602.00873970985,3794.88544464111 PathPoint;PointKind.SMOOTHPOINT 1581.97048187256,3792.09811449051 1573.564234972,3792.47010469437 1590.37637472153,3791.72612428665 PathPoint;PointKind.SMOOTHPOINT 1565.61436057091,3789.80362415314 1554.91315126419,3789.35539484024 1576.31592392921,3790.25161743164 PathPoint;PointKind.SMOOTHPOINT 1548.09057712555,3789.80362415314 1537.4435377121,3790.6729388237 1558.73726248741,3788.93407344818 PathPoint;PointKind.SMOOTHPOINT 1531.73480987549,3785.214407444 1511.02987289429,3784.38545465469 1552.4393928051,3786.0435962677 PathPoint;PointKind.SMOOTHPOINT 1506.03278875351,3792.09811449051 1500.43771147728,3793.20487976074 1511.62751197815,3790.99111318588 PathPoint;PointKind.SMOOTHPOINT 1485.00389456749,3792.09811449051 1462.71103620529,3792.46113538742 1507.29675292969,3791.7350935936 PathPoint;PointKind.SMOOTHPOINT 1448.7876033783,3792.09811449051 1415.17677783966,3788.66074562073 1482.39807486534,3795.5352473259 PathPoint;PointKind.SMOOTHPOINT 1402.0566880703,3793.245241642 1389.79906797409,3792.32211112976 1414.3143081665,3794.16837215424 PathPoint;PointKind.SMOOTHPOINT 1368.17678332329,3793.245241642 1347.41271972656,3793.02124500275 1388.94084692001,3793.46947431564 PathPoint;PointKind.SMOOTHPOINT 1328.45573544502,3794.39260482788 1317.90464401245,3794.27151918411 1339.006472826,3794.51345443726 PathPoint;PointKind.SMOOTHPOINT 1307.426841259,3793.245241642 1283.02560567856,3791.67679309845 1331.82807683945,3794.81392621994 PathPoint;PointKind.SMOOTHPOINT 1257.19116926193,3788.65626096725 1245.18917441368,3786.11086606979 1269.19316411018,3791.20165586472 PathPoint;PointKind.SMOOTHPOINT 1232.65751838684,3787.50913381577 1225.90327620506,3788.49504947662 1239.41140651703,3786.52298212051 PathPoint;PointKind.SMOOTHPOINT 1201.11435413361,3788.65626096725 1192.01912283897,3788.4815955162 1210.20923137665,3788.8311624527 PathPoint;PointKind.SMOOTHPOINT 1166.06607913971,3793.245241642 1149.51416730881,3793.82801055908 1182.61799097061,3792.66270875931 PathPoint;PointKind.CORNERPOINT 1141.53242826462,3790.95075130463 1141.53242826462,3790.95075130463 1141.53242826462,3790.95075130463 PathPoint;PointKind.CORNERPOINT 1132.1861743927,3794.39260482788 1132.1861743927,3794.39260482788 1132.1861743927,3794.39260482788 PathPoint;PointKind.CORNERPOINT 1127.51304745674,3789.80362415314 1127.51304745674,3789.80362415314 1127.51304745674,3789.80362415314 PathPoint;PointKind.SMOOTHPOINT 1111.15728020668,3789.80362415314 1097.98231244087,3787.12817430496 1124.33224797249,3792.47907400131 PathPoint;PointKind.SMOOTHPOINT 1086.62362933159,3790.95075130463 1070.57376265526,3785.83305358887 1102.67385005951,3796.06868505478 PathPoint;PointKind.SMOOTHPOINT 1048.07059764862,3790.95075130463 1043.43429207802,3784.95901823044 1052.70725727081,3796.94248437881 PathPoint;PointKind.SMOOTHPOINT 1022.36893057823,3789.80362415314 1013.25528860092,3787.6703453064 1031.48221850395,3791.93666696548 PathPoint;PointKind.SMOOTHPOINT 994.330168962479,3794.39260482788 983.217905759811,3791.82478666306 1005.44243216515,3796.96042299271 PathPoint;PointKind.SMOOTHPOINT 966.291761398315,3793.245241642 958.364900350571,3790.91935873032 974.21862244606,3795.57112455368 PathPoint;PointKind.SMOOTHPOINT 945.262867212296,3793.245241642 935.588407516479,3788.90716552734 954.937680959702,3797.58331775665 PathPoint;PointKind.SMOOTHPOINT 926.57071352005,3793.245241642 917.069385051727,3789.30157899857 936.072041988373,3797.18890428543 PathPoint;PointKind.SMOOTHPOINT 900.868692398071,3792.09811449051 882.176538705826,3792.00842142105 919.561200141907,3792.18757152557 PathPoint;PointKind.CORNERPOINT 871.661914587021,3794.39260482788 871.661914587021,3794.39260482788 871.661914587021,3794.39260482788 PathPoint;PointKind.SMOOTHPOINT 844.791877269745,3793.245241642 832.52044916153,3792.05775260925 857.06330537796,3794.43296670914 PathPoint;PointKind.SMOOTHPOINT 816.753115653992,3790.95075130463 796.874535083771,3791.37655735016 836.632050275803,3790.52494525909 PathPoint;PointKind.SMOOTHPOINT 786.378321647644,3793.245241642 764.87004160881,3792.84185886383 807.886247634888,3793.64862442017 PathPoint;PointKind.SMOOTHPOINT 760.676300525665,3794.39260482788 754.844008684158,3794.3567276001 766.508592367172,3794.42848205566 PathPoint;PointKind.SMOOTHPOINT 734.974279403687,3794.39260482788 727.704538106918,3792.73446321487 742.244020700455,3796.05074644089 PathPoint;PointKind.SMOOTHPOINT 715.113755464554,3794.39260482788 705.069311857224,3794.51345443726 725.158199071884,3794.27151918411 PathPoint;PointKind.SMOOTHPOINT 671.887596845627,3794.39260482788 665.270726680756,3793.76522541046 678.504821062088,3795.0199842453 PathPoint;PointKind.CORNERPOINT 633.334919214249,3794.39260482788 633.334919214249,3794.39260482788 633.334919214249,3794.39260482788 PathPoint;PointKind.SMOOTHPOINT 605.296157598495,3793.245241642 584.705579280853,3793.98473739624 625.887089967728,3792.50574588776 PathPoint;PointKind.SMOOTHPOINT 555.060839653015,3790.95075130463 549.328744411469,3787.50464916229 560.792580842972,3794.39708948135 PathPoint;PointKind.SMOOTHPOINT 525.854061841965,3796.68709516525 516.882040500641,3802.96112537384 534.825729131699,3790.41306495667 PathPoint;PointKind.SMOOTHPOINT 500.999994277954,3791.99992418289 486.182227134705,3790.78080654144 515.818115472794,3793.21880578995 PathPoint";
	
	shadow35mm[0] = "PointKind.CORNERPOINT 279.885905265808,3803.41572761536 279.885905265808,3803.41572761536 279.885905265808,3803.41572761536 PathPoint;PointKind.SMOOTHPOINT 264.720459461212,3788.5170006752 250.265949249268,3765.04526853561 279.174969673157,3811.98873281479 PathPoint;PointKind.SMOOTHPOINT 251.888213634491,3754.13528680801 251.7926197052,3738.66795301437 251.983807563782,3769.60262060165 PathPoint;PointKind.SMOOTHPOINT 236.421469926834,3730.0680398941 234.661576242226,3720.49110739001 238.904787778854,3743.58336925507 PathPoint;PointKind.SMOOTHPOINT 237.875,3711 233.675097112087,3700.60764349764 242.782493163567,3723.14323755805 PathPoint;PointKind.SMOOTHPOINT 231.609375,3708 232.304292583466,3698.92187156677 231.257567884465,3712.59586899877 PathPoint;PointKind.SMOOTHPOINT 244.355057954788,3678.00003290176 249.786917448044,3656.13097429276 238.923198461533,3699.86909151077 PathPoint;PointKind.SMOOTHPOINT 256.55461359024,3628.06884527206 262.082067012787,3611.89411640167 251.027160167694,3644.24333810806 PathPoint;PointKind.SMOOTHPOINT 269.386859416962,3589.10263538361 266.620654344559,3575.54245948792 272.152710437775,3602.6628112793 PathPoint;PointKind.SMOOTHPOINT 264.720459461212,3523.77728462219 262.956928491592,3507.64740228653 266.483990430832,3539.90716695786 PathPoint;PointKind.SMOOTHPOINT 262.387259483337,3490.54175376892 252.10241484642,3475.31163454056 272.672458171844,3505.77163696289 PathPoint;PointKind.SMOOTHPOINT 265.88705945015,3460.74406385422 264.342332363129,3447.6047372818 267.43178653717,3473.88339042664 PathPoint;PointKind.SMOOTHPOINT 269.386859416962,3380.51998615265 264.857123374939,3355.5931019783 273.916241407394,3405.446870327 PathPoint;PointKind.SMOOTHPOINT 264.720459461212,3333.53143930435 266.771126270294,3316.07645988464 262.66979265213,3350.98665475845 PathPoint;PointKind.SMOOTHPOINT 268.220259428024,3308.31824541092 267.923918247223,3298.65287303925 268.516246557236,3317.98361778259 PathPoint;PointKind.SMOOTHPOINT 271.720059394836,3272.79034852982 270.694725990295,3259.13623094559 272.745038747787,3286.44470214844 PathPoint;PointKind.SMOOTHPOINT 265.88705945015,3256.74567461014 264.069004535675,3246.11326932907 267.705114364624,3267.3780798912 PathPoint;PointKind.SMOOTHPOINT 272.886305332184,3208.61118078232 271.861325979233,3195.27925014496 273.911638736725,3221.94311141968 PathPoint;PointKind.SMOOTHPOINT 269.386859416962,3192.56627082825 269.158850193024,3181.75920009613 269.61451458931,3203.37334156036 PathPoint;PointKind.SMOOTHPOINT 270.553459405899,3161.62263393402 270.85865187645,3148.5505771637 270.247912883759,3174.69492673874 PathPoint;PointKind.SMOOTHPOINT 265.88705945015,3132.97112703323 271.961522579193,3108.52339267731 259.812596321106,3157.41909742355 PathPoint;PointKind.SMOOTHPOINT 269.386859416962,3102.0277261734 266.547719717026,3087.93009996414 272.225645065308,3116.12511634827 PathPoint;PointKind.SMOOTHPOINT 265.88705945015,3056.18536233902 263.91853260994,3038.97656679153 267.855586290359,3073.39415788651 PathPoint;PointKind.SMOOTHPOINT 267.053659439087,3026.38767242432 270.011052370071,3006.57801389694 264.096266508102,3046.19756698608 PathPoint;PointKind.SMOOTHPOINT 271.720059394836,2969.08465862274 277.903570413589,2938.88877868652 265.536194324493,2999.28077459335 PathPoint;PointKind.SMOOTHPOINT 285.718551158905,2919.8042178154 285.386096715927,2894.1522359848 286.051359653473,2945.456199646 PathPoint;PointKind.SMOOTHPOINT 268.220259428024,2884.2763209343 269.058653593063,2857.45148420334 267.381865262985,2911.10139369965 PathPoint;PointKind.SMOOTHPOINT 270.553459405899,2853.33292007446 273.278240442276,2833.38423728943 267.828324317932,2873.2813668251 PathPoint;PointKind.SMOOTHPOINT 271.720059394836,2794.88372325897 273.925446748734,2771.85077905655 269.514317989349,2817.91690349579 PathPoint;PointKind.SMOOTHPOINT 268.220259428024,2755.91774940491 268.252124071121,2735.20360708237 268.188394784927,2776.63189172745 PathPoint;PointKind.SMOOTHPOINT 269.386859416962,2732.99668550491 269.705859899521,2722.40015745163 269.067858934402,2743.5932135582 PathPoint;PointKind.SMOOTHPOINT 267.053659439087,2689.44645166397 266.634462356567,2673.7015414238 267.472856521606,2705.19136190414 PathPoint;PointKind.SMOOTHPOINT 264.720459461212,2658.50281476974 269.468645334244,2625.11480569839 259.972273588181,2691.8905878067 PathPoint;PointKind.SMOOTHPOINT 265.88705945015,2590.88533401489 269.286662817001,2569.26245927811 262.487456083298,2612.50820875168 PathPoint;PointKind.SMOOTHPOINT 265.88705945015,2543.8967871666 274.968836784363,2510.23143768311 256.805282115936,2577.56237268448 PathPoint;PointKind.SMOOTHPOINT 270.553459405899,2488.88613939285 268.279386043549,2469.55515861511 272.82717871666,2508.2168841362 PathPoint;PointKind.SMOOTHPOINT 269.386859416962,2433.87525558472 274.809513568878,2412.16717243195 263.964205265045,2455.58310270309 PathPoint;PointKind.SMOOTHPOINT 263.553859472275,2400.63948869705 264.11892580986,2388.60149860382 262.988793134689,2412.67747879028 PathPoint;PointKind.SMOOTHPOINT 270.553459405899,2371.98798179626 265.964596748352,2361.14078521729 275.141968011856,2382.83517837524 PathPoint;PointKind.SMOOTHPOINT 265.88705945015,2335.31413793564 268.425255298615,2317.0309138298 263.348863601685,2353.59736204147 PathPoint;PointKind.SMOOTHPOINT 267.053659439087,2305.51668405533 274.773046255112,2290.52826404572 259.334272623062,2320.50486803055 PathPoint;PointKind.SMOOTHPOINT 262.387259483337,2259.67432022095 261.863263130188,2241.13145828247 262.911255836487,2278.21718215942 PathPoint;PointKind.SMOOTHPOINT 269.386859416962,2235.60707330704 271.37344288826,2217.38191366196 267.399921894073,2253.83199691772 PathPoint;PointKind.SMOOTHPOINT 274.052905321121,2205.80938339233 270.516992092133,2198.30183744431 277.5891726017,2213.31692934036 PathPoint;PointKind.SMOOTHPOINT 268.220259428024,2176.01192951202 269.026788949966,2157.81367778778 267.413729906082,2194.21018123627 PathPoint;PointKind.SMOOTHPOINT 268.220259428024,2145.0682926178 275.488584518433,2122.06650495529 260.951934337616,2168.0700802803 PathPoint;PointKind.SMOOTHPOINT 267.053659439087,2096.93379878998 271.401058912277,2079.76536512375 262.706259965897,2114.10223245621 PathPoint;PointKind.SMOOTHPOINT 268.220259428024,2045.3612279892 269.947323083878,2027.48539924622 266.493195772171,2063.23705673218 PathPoint;PointKind.SMOOTHPOINT 272.886305332184,2015.56353807449 268.940046310425,1997.51776456833 276.832564353943,2033.60954761505 PathPoint;PointKind.SMOOTHPOINT 262.387259483337,1985.76608419418 265.353857755661,1969.90929365158 259.420661211014,2001.62287473679 PathPoint;PointKind.SMOOTHPOINT 267.053659439087,1942.21585035324 271.104717731476,1917.80847787857 263.002601146698,1966.6234588623 PathPoint;PointKind.SMOOTHPOINT 272.886305332184,1906.68795347214 273.606446266174,1877.69183635712 272.166518449783,1935.68430662155 PathPoint;PointKind.SMOOTHPOINT 267.053659439087,1858.55345964432 269.555387973785,1830.73468208313 264.551930904388,1886.37223720551 PathPoint;PointKind.SMOOTHPOINT 268.220259428024,1824.17174577713 272.549248218536,1805.35579204559 263.891270637512,1842.98769950867 PathPoint;PointKind.SMOOTHPOINT 267.053659439087,1777.18343496323 268.343115329742,1756.4827466011 265.764203548431,1797.88412332535 PathPoint;PointKind.SMOOTHPOINT 271.720059394836,1742.80148506165 267.163061380386,1708.12874078751 276.276703357697,1777.47446537018 PathPoint;PointKind.SMOOTHPOINT 268.220259428024,1685.49870729446 270.685520648956,1670.91319799423 265.754998207092,1700.0839805603 PathPoint;PointKind.SMOOTHPOINT 268.220259428024,1651.11675739288 270.462114095688,1629.23872947693 265.978050708771,1672.99502134323 PathPoint;PointKind.SMOOTHPOINT 269.386859416962,1609.85865354538 271.154993057251,1586.01988792419 267.618725776672,1633.69765520096 PathPoint;PointKind.SMOOTHPOINT 270.553459405899,1570.89267969131 269.641776561737,1550.38011074066 271.464788198471,1591.40548467636 PathPoint;PointKind.SMOOTHPOINT 264.720459461212,1525.05031585693 270.995315790176,1500.68306922913 258.445603132248,1549.41756248474 PathPoint;PointKind.SMOOTHPOINT 269.386859416962,1495.25286197662 269.423326730728,1468.44124317169 269.350392103195,1522.06424474716 PathPoint;PointKind.SMOOTHPOINT 274.052905321121,1463.16327810287 273.150781869888,1451.86832427979 274.955382823944,1474.45823192596 PathPoint;PointKind.SMOOTHPOINT 268.220259428024,1419.61304426193 258.783014297485,1400.21054506302 277.657504558563,1439.01530742645 PathPoint;PointKind.SMOOTHPOINT 268.220259428024,1390.96153736115 269.391462087631,1372.66485929489 267.049056768417,1409.2582154274 PathPoint;PointKind.SMOOTHPOINT 270.553459405899,1358.871717453 263.677069425583,1343.27456474304 277.429849386215,1374.46887016296 PathPoint;PointKind.SMOOTHPOINT 267.053659439087,1303.86106967926 268.899330377579,1295.80734014511 265.207988500595,1311.91479921341 PathPoint;PointKind.SMOOTHPOINT 268.220259428024,1286.66997671127 270.352712154388,1267.47802019119 266.08745265007,1305.86216926575 PathPoint;PointKind.SMOOTHPOINT 267.053659439087,1258.01870584488 271.970373868942,1237.23280906677 262.136590957642,1278.80436658859 PathPoint;PointKind.SMOOTHPOINT 272.886305332184,1228.22101593018 265.294731140137,1213.43865394592 280.478233575821,1243.00337791443 PathPoint;PointKind.SMOOTHPOINT 265.88705945015,1204.15376901627 268.120062828064,1185.83490371704 263.654056072235,1222.47287034988 PathPoint;PointKind.SMOOTHPOINT 275.219505310059,1174.35631513596 272.480916261673,1160.8407497406 277.958448410034,1187.87164449692 PathPoint;PointKind.SMOOTHPOINT 267.053659439087,1138.82841825485 270.22985625267,1122.07634925842 263.877462625504,1155.58072328568 PathPoint;PointKind.SMOOTHPOINT 271.720059394836,1109.03096437454 275.903178930283,1098.63577365875 267.5365858078,1119.42615509033 PathPoint;PointKind.SMOOTHPOINT 277.552705287933,1081.52540445328 275.711637020111,1054.82590198517 279.393773555756,1108.22514295578 PathPoint;PointKind.SMOOTHPOINT 272.886305332184,1033.39114665985 271.505858182907,1014.82586145401 274.267106533051,1051.9561958313 PathPoint;PointKind.SMOOTHPOINT 272.886305332184,996.717066764832 275.224107980728,972.990181446075 270.548856735229,1020.44418811798 PathPoint;PointKind.SMOOTHPOINT 269.386859416962,952.020885944366 267.923918247223,921.569616794586 270.84944653511,982.471919059753 PathPoint;PointKind.SMOOTHPOINT 268.220259428024,915.34704208374 272.439846277237,897.739820480347 264.000672578812,932.954263687134 PathPoint;PointKind.SMOOTHPOINT 275.219505310059,884.403405189514 276.080912828445,852.927038669586 274.358451843262,915.879771709442 PathPoint;PointKind.SMOOTHPOINT 276.386105298996,819.078054428101 268.374979972839,795.445110797882 284.397230625153,842.710998058319 PathPoint;PointKind.CORNERPOINT 270.553459405899,775.527820587158 270.553459405899,775.527820587158 270.553459405899,775.527820587158 PathPoint;PointKind.SMOOTHPOINT 271.720059394836,744.584183692932 280.924692630768,708.461008071899 262.515072107315,780.707359313965 PathPoint;PointKind.SMOOTHPOINT 279.885905265808,698.741819858551 279.001838445663,683.516185283661 280.769972085953,713.967454433441 PathPoint;PointKind.SMOOTHPOINT 277.552705287933,660.921792984009 278.222570896149,620.250234603882 276.882839679718,701.593587398529 PathPoint;PointKind.SMOOTHPOINT 281.052505254745,602.472832202911 276.039842844009,581.59747838974 286.065167665482,623.348186016083 PathPoint;PointKind.SMOOTHPOINT 275.219505310059,553.192391395569 274.918915510178,536.825058460236 275.52044916153,569.559488296509 PathPoint;PointKind.SMOOTHPOINT 276.386105298996,524.540884494781 282.013755321503,506.517298221588 270.758455276489,542.564470767975 PathPoint;PointKind.SMOOTHPOINT 278.719305276871,466.091923713684 278.62831401825,445.888087749481 278.810296535492,486.295523643494 PathPoint;PointKind.SMOOTHPOINT 279.885905265808,412.226986885071 270.393782138824,382.487597465515 289.378028392792,441.966376304626 PathPoint;PointKind.SMOOTHPOINT 278.719305276871,374.407196044922 284.146562099457,354.704697132111 273.292048454285,394.10945892334 PathPoint;PointKind.SMOOTHPOINT 286.885151147842,341.171429157257 285.162690162659,325.704095363617 288.607612133026,356.638762950897 PathPoint;PointKind.SMOOTHPOINT 276.386105298996,299.913325309753 279.694363355637,261.00093126297 273.077847242355,338.825483322144 PathPoint;PointKind.SMOOTHPOINT 268.258142948151,256.000070571899 270.85475730896,251.631782054901 264.913417577744,261.627366542816 PathPoint;PointKind.SMOOTHPOINT 281.222804069519,225.000021457672 283.928466320038,220.792472362518 271.835480213165,239.597804546356 PathPoint;PointKind.SMOOTHPOINT 286.885151147842,208.228597640991 311.064396381378,183.89817237854 282.593337774277,212.547318935394 PathPoint;PointKind.SMOOTHPOINT 337.069839715958,178.99998664856 352.198818206787,175.973789691925 321.940861225128,182.026419639587 PathPoint;PointKind.SMOOTHPOINT 414.856744289398,180.99990606308 428.377266407013,178.971898555756 401.336576223373,183.027913570404 PathPoint;PointKind.SMOOTHPOINT 442.780439138412,178.99998664856 455.120553255081,181.010055541992 430.440325021744,176.989917755127 PathPoint;PointKind.SMOOTHPOINT 475.690242528915,178.99998664856 492.705607891083,176.036338806152 458.674877166748,181.963634490967 PathPoint;PointKind.SMOOTHPOINT 506.605673313141,178.99998664856 525.817574739456,180.89369058609 487.393771886826,177.106282711029 PathPoint;PointKind.SMOOTHPOINT 546.496311903,180.000064373016 556.052164316177,178.227210044861 536.940459489822,181.772918701172 PathPoint;PointKind.SMOOTHPOINT 571.427916765213,180.000064373016 581.006782531738,178.630120754242 561.849405050278,181.370007991791 PathPoint;PointKind.SMOOTHPOINT 594.858696937561,177.284960746765 608.173869132996,175.377802848816 581.543170690536,179.192118644714 PathPoint;PointKind.SMOOTHPOINT 634.521680355072,176.138777732849 662.833769798279,158.164522647858 606.209944963455,194.113268852234 PathPoint;PointKind.SMOOTHPOINT 685.850663661957,162.38623380661 693.178115367889,161.486234664917 678.523211956024,163.28599691391 PathPoint;PointKind.SMOOTHPOINT 705.682509422302,161.240050792694 729.624186038971,160.429744720459 681.740478754044,162.050356864929 PathPoint;PointKind.SMOOTHPOINT 736.013046979904,177.284960746765 744.616500616074,184.326810836792 727.409593343735,170.242874622345 PathPoint;PointKind.SMOOTHPOINT 747.678692817688,176.138777732849 752.93742108345,172.454516887665 742.419964551926,179.823274612427 PathPoint;PointKind.SMOOTHPOINT 762.844138622284,177.284960746765 787.259890317917,184.098565578461 738.428032875061,170.47135591507 PathPoint;PointKind.SMOOTHPOINT 792.008076190948,172.700700759888 802.808065891266,171.724698543549 781.208440542221,173.676702976227 PathPoint;PointKind.SMOOTHPOINT 820.005767822266,183.015167713165 827.059891700745,184.967172145844 812.951643943787,181.06339931488 PathPoint;PointKind.SMOOTHPOINT 842.170459508896,184.161350727081 859.996957063675,183.033106327057 824.343961954117,185.289359092712 PathPoint;PointKind.CORNERPOINT 863.168551206589,178.430907726288 863.168551206589,178.430907726288 863.168551206589,178.430907726288 PathPoint;PointKind.SMOOTHPOINT 881.833796977997,181.869220733643 892.551646709442,182.742075920105 871.115947246552,180.996129512787 PathPoint;PointKind.SMOOTHPOINT 964.659917831421,184.161350727081 982.445345401764,184.895417690277 946.874490261078,183.427047729492 PathPoint;PointKind.SMOOTHPOINT 1003.15665531158,185.307297706604 1019.60695433617,185.41469335556 986.706356287003,185.199902057648 PathPoint;PointKind.SMOOTHPOINT 1040.48679280281,184.161350727081 1062.37815666199,183.538928031921 1018.59542894363,184.783537387848 PathPoint;PointKind.CORNERPOINT 1088.31597614288,184.161350727081 1088.31597614288,184.161350727081 1088.31597614288,184.161350727081 PathPoint;PointKind.SMOOTHPOINT 1082.4829761982,171.554517745972 1095.23308205605,169.925172328949 1069.73287034035,173.184099197388 PathPoint;PointKind.CORNERPOINT 1105.81426787376,171.554517745972 1105.81426787376,171.554517745972 1105.81426787376,171.554517745972 PathPoint;PointKind.SMOOTHPOINT 1123.31291365623,174.992830753326 1134.24036192894,174.173555374146 1112.38546538353,175.812106132507 PathPoint;PointKind.SMOOTHPOINT 1145.47760534286,181.869220733643 1155.0561170578,180.978190898895 1135.89909362793,182.760014533997 PathPoint;PointKind.SMOOTHPOINT 1169.97549700737,178.430907726288 1190.77319550514,174.173555374146 1149.1777985096,182.688496112823 PathPoint;PointKind.SMOOTHPOINT 1204.97243452072,172.700700759888 1215.25727915764,174.106521606445 1194.6875898838,171.29487991333 PathPoint;PointKind.SMOOTHPOINT 1222.47108030319,180.723037719727 1234.41005396843,178.027997016907 1210.53175258636,183.418078422546 PathPoint;PointKind.SMOOTHPOINT 1242.30257201195,172.700700759888 1266.32638859749,171.478514671326 1218.27875542641,173.92288684845 PathPoint;PointKind.SMOOTHPOINT 1260.96746373177,181.869220733643 1281.27303051949,177.602663040161 1240.66189694405,186.135542392731 PathPoint;PointKind.SMOOTHPOINT 1290.13175535202,173.84664773941 1310.40545749664,172.655854225159 1269.8580532074,175.037677288055 PathPoint;PointKind.SMOOTHPOINT 1318.12944698334,177.284960746765 1331.34442257881,172.767734527588 1304.91447138786,181.801950931549 PathPoint;PointKind.SMOOTHPOINT 1354.29298448563,177.284960746765 1359.52869939804,179.460725784302 1349.05691552162,175.109195709229 PathPoint;PointKind.SMOOTHPOINT 1369.45807623863,183.015167713165 1389.73177838326,183.977715969086 1349.1847281456,182.052619457245 PathPoint;PointKind.SMOOTHPOINT 1389.28992199898,180.723037719727 1403.77629685402,172.732093334198 1374.80354714394,188.714218139648 PathPoint;PointKind.SMOOTHPOINT 1411.45461368561,173.84664773941 1412.33868050575,181.528859138489 1410.57054686546,166.164672374725 PathPoint;PointKind.SMOOTHPOINT 1420.78705954552,183.015167713165 1425.29378223419,169.374504089355 1416.28033685684,196.656067371368 PathPoint;PointKind.SMOOTHPOINT 1437.11910533905,169.262623786926 1443.46689629555,170.793542861938 1430.77131438255,167.731468677521 PathPoint;PointKind.SMOOTHPOINT 1460.45039701462,177.284960746765 1465.63619065285,180.011394023895 1455.26460337639,174.558527469635 PathPoint;PointKind.SMOOTHPOINT 1474.44924283028,177.284960746765 1492.00701522827,174.204947948456 1456.89147043228,180.364973545074 PathPoint;PointKind.SMOOTHPOINT 1491.94753456116,170.408570766449 1503.03005743027,167.637526988983 1480.86536574364,173.179614543915 PathPoint;PointKind.SMOOTHPOINT 1509.44618034363,174.992830753326 1528.89033961296,178.243024349213 1490.00166702271,171.74263715744 PathPoint;PointKind.SMOOTHPOINT 1537.44351792336,177.284960746765 1560.39668250084,176.398415565491 1514.49070739746,178.171269893646 PathPoint;PointKind.SMOOTHPOINT 1589.93910121918,172.700700759888 1604.77173852921,167.444922924042 1575.10646390915,177.956478595734 PathPoint;PointKind.SMOOTHPOINT 1613.27039289474,174.992830753326 1635.00668215752,170.84287405014 1591.53410363197,179.142787456512 PathPoint;PointKind.SMOOTHPOINT 1644.76788449287,172.700700759888 1665.74756550789,169.611718654633 1623.78784942627,175.789682865143 PathPoint;PointKind.SMOOTHPOINT 1672.7652220726,177.284960746765 1683.943338871,171.71124458313 1661.5871052742,182.858440876007 PathPoint;PointKind.SMOOTHPOINT 1689.09726786613,179.577090740204 1699.08152270317,176.170170307159 1679.1130130291,182.983775138855 PathPoint;PointKind.SMOOTHPOINT 1710.09535956383,172.700700759888 1733.09419679642,167.642011642456 1687.09687638283,177.759389877319 PathPoint;PointKind.SMOOTHPOINT 1746.25889706612,171.554517745972 1763.21513581276,172.36930847168 1729.30265831947,170.739963054657 PathPoint;PointKind.SMOOTHPOINT 1771.92338871956,179.577090740204 1785.54835605621,172.033667564392 1758.2984213829,187.120513916016 PathPoint;PointKind.SMOOTHPOINT 1801.08768033981,172.700700759888 1817.5379793644,172.266397476196 1784.63702726364,173.135004043579 PathPoint;PointKind.SMOOTHPOINT 1823.25237202644,173.84664773941 1841.91726374626,171.832094192505 1804.58712625504,175.861201286316 PathPoint;PointKind.SMOOTHPOINT 1851.24970960617,171.554517745972 1863.32570123672,171.563487052917 1839.17407202721,171.545784473419 PathPoint;PointKind.SMOOTHPOINT 1893.24624705315,180.723037719727 1921.59020113945,180.297703742981 1864.90229296684,181.148371696472 PathPoint;PointKind.CORNERPOINT 1927.07658457756,183.015167713165 1927.07658457756,183.015167713165 1927.07658457756,183.015167713165 PathPoint;PointKind.SMOOTHPOINT 1969.07312202454,173.84664773941 2010.04857468605,170.014629364014 1928.09731531143,177.6789021492 PathPoint;PointKind.SMOOTHPOINT 2032.06739711761,170.408570766449 2075.08926796913,174.397315979004 1989.04588031769,166.419825553894 PathPoint;PointKind.SMOOTHPOINT 2098.5618262291,186.45348072052 2104.80481791496,184.268746376038 2092.31883454323,188.637979030609 PathPoint;PointKind.SMOOTHPOINT 2135.89196372032,176.138777732849 2158.94532489777,172.315728664398 2112.83860254288,179.962062835693 PathPoint;PointKind.SMOOTHPOINT 2186.05434703827,166.970493793488 2203.77144265175,167.780799865723 2168.3368973732,166.160187721252 PathPoint;PointKind.SMOOTHPOINT 2222.21788454056,179.577090740204 2234.58065795898,178.023512363434 2209.85475707054,181.130433082581 PathPoint;PointKind.SMOOTHPOINT 2268.88046789169,174.992830753326 2289.13575935364,173.770644664764 2248.62482237816,176.215016841888 PathPoint;PointKind.SMOOTHPOINT 2301.54420542717,173.84664773941 2331.69276046753,176.174654960632 2271.39565038681,171.518876552582 PathPoint;PointKind.SMOOTHPOINT 2350.53998875618,174.992830753326 2378.56494235992,167.547833919525 2322.51503515244,182.437827587128 PathPoint;PointKind.SMOOTHPOINT 2384.37032628059,170.408570766449 2413.47513723373,170.677177906036 2355.26551532745,170.139963626862 PathPoint;PointKind.SMOOTHPOINT 2417.03406381607,179.577090740204 2432.71465468407,174.979376792908 2401.35382699966,184.1748046875 PathPoint;PointKind.SMOOTHPOINT 2436.86590957642,172.700700759888 2455.69047856331,169.866871833801 2418.04134058952,175.534529685974 PathPoint;PointKind.SMOOTHPOINT 2463.6970012188,177.284960746765 2479.46362662315,176.550657749176 2447.93002176285,178.019027709961 PathPoint;PointKind.SMOOTHPOINT 2533.6908762455,174.992830753326 2559.39183521271,174.867496490479 2507.98991727829,175.118165016174 PathPoint;PointKind.SMOOTHPOINT 2564.0214138031,178.430907726288 2573.20834445953,177.620601654053 2554.83483719826,179.241213798523 PathPoint;PointKind.SMOOTHPOINT 2583.85325956345,173.84664773941 2602.38609004021,173.53791475296 2565.3200750351,174.155616760254 PathPoint;PointKind.SMOOTHPOINT 2614.18379712105,178.430907726288 2621.42025756836,179.966547489166 2606.94733667374,176.895503997803 PathPoint;PointKind.SMOOTHPOINT 2643.3480887413,176.138777732849 2660.92391777039,173.900463581085 2625.77190566063,178.377327919006 PathPoint;PointKind.SMOOTHPOINT 2669.01258039474,179.577090740204 2684.87479972839,180.956003665924 2653.15000700951,178.198177814484 PathPoint;PointKind.SMOOTHPOINT 2691.17727208138,178.430907726288 2701.9769077301,173.045310974121 2680.37728238106,183.816504478455 PathPoint;PointKind.SMOOTHPOINT 2734.3400554657,171.554517745972 2775.47518539429,171.782999038696 2693.20492553711,171.32627248764 PathPoint;PointKind.SMOOTHPOINT 2793.83488464355,173.84664773941 2808.67212462425,174.580950737 2778.99764466286,173.112580776215 PathPoint;PointKind.SMOOTHPOINT 2827.66522216797,176.138777732849 2856.12318086624,170.556328296661 2799.20761752129,181.72146320343 PathPoint;PointKind.SMOOTHPOINT 2909.32509708405,173.84664773941 2922.72205519676,173.157427310944 2895.92778491974,174.536104202271 PathPoint;PointKind.SMOOTHPOINT 2948.98808050156,174.992830753326 2977.96083021164,170.498027801514 2920.01533079147,179.487397670746 PathPoint;PointKind.SMOOTHPOINT 3008.48290967941,172.700700759888 3018.33510327339,174.276466369629 2998.63107013702,171.124935150146 PathPoint;PointKind.SMOOTHPOINT 3035.31400132179,177.284960746765 3055.76543736458,173.260338306427 3014.86256527901,181.309583187103 PathPoint;PointKind.SMOOTHPOINT 3070.31093883514,173.84664773941 3089.90096735954,171.908333301544 3050.72091031075,175.78519821167 PathPoint;PointKind.SMOOTHPOINT 3104.14127635956,174.992830753326 3124.64298772812,175.78519821167 3083.63991904259,174.200463294983 PathPoint;PointKind.SMOOTHPOINT 3142.63801383972,177.284960746765 3160.74279594421,174.016828536987 3124.53358578682,180.553092956543 PathPoint;PointKind.SMOOTHPOINT 3182.30135130882,173.84664773941 3212.99656200409,171.496453285217 3151.60614061356,176.197078227997 PathPoint;PointKind.SMOOTHPOINT 3219.63148880005,176.138777732849 3242.32017683983,176.640350818634 3196.94280076027,175.637440681458 PathPoint;PointKind.SMOOTHPOINT 3259.29447221756,173.84664773941 3275.8909945488,170.542874336243 3242.69830393791,177.150657176971 PathPoint;PointKind.SMOOTHPOINT 3283.79236388206,172.700700759888 3313.01578211784,170.789058208466 3254.56929969788,174.61234331131 PathPoint;PointKind.SMOOTHPOINT 3323.45570135117,171.554517745972 3347.54820394516,174.02131319046 3299.36355280876,169.087958335876 PathPoint;PointKind.SMOOTHPOINT 3366.61883878708,172.700700759888 3385.93093681335,168.004560470581 3347.30638670921,177.396841049194 PathPoint;PointKind.SMOOTHPOINT 3396.94937634468,171.554517745972 3418.33940315247,167.6016497612 3375.5593495369,175.507621765137 PathPoint;PointKind.SMOOTHPOINT 3452.94440555573,169.262623786926 3471.5048520565,167.762861251831 3434.38431310654,170.762150287628 PathPoint;PointKind.SMOOTHPOINT 3491.44114303589,166.970493793488 3522.9428832531,162.618963718414 3459.93940281868,171.321787834167 PathPoint;PointKind.SMOOTHPOINT 3524.10523462296,169.262623786926 3543.78165173531,166.554129123688 3504.42846345901,171.970882415771 PathPoint;PointKind.SMOOTHPOINT 3581.26686382294,163.532180786133 3604.8806886673,163.675453662872 3557.65303897858,163.388907909393 PathPoint;PointKind.SMOOTHPOINT 3640.76169300079,165.824310779572 3655.05652594566,165.537765026093 3626.46650600433,166.110856533051 PathPoint;PointKind.SMOOTHPOINT 3720.08801388741,160.094103813171 3738.10605335236,158.428645133972 3702.06997442245,161.759326457977 PathPoint;PointKind.SMOOTHPOINT 3748.08570551872,162.38623380661 3787.87189888954,161.235566139221 3708.2995121479,163.536665439606 PathPoint;PointKind.SMOOTHPOINT 3800.58128881454,163.532180786133 3845.48034119606,161.996777057648 3755.68188238144,165.067820549011 PathPoint;PointKind.SMOOTHPOINT 3857.74291801453,162.38623380661 3866.25502634048,159.341862201691 3849.23045563698,165.430369377136 PathPoint;PointKind.SMOOTHPOINT 3885.74025559425,162.38623380661 3907.57709550858,157.546820640564 3863.90376973152,167.225646972656 PathPoint;PointKind.SMOOTHPOINT 3945.2354388237,164.678363800049 3963.95060586929,166.057040691376 3926.52027177811,163.299450874329 PathPoint;PointKind.SMOOTHPOINT 3974.39937639236,162.38623380661 3990.41702437401,160.675928592682 3958.38208246231,164.096302986145 PathPoint;PointKind.SMOOTHPOINT 4004.73026800156,164.678363800049 4032.05773997307,164.387333393097 3977.40244197845,164.969158172607 PathPoint;PointKind.SMOOTHPOINT 4043.22665143013,160.094103813171 4055.90877938271,154.950206279755 4030.54487752914,165.237765312195 PathPoint;PointKind.SMOOTHPOINT 4078.22394299507,156.655790805817 4102.01550173759,159.279313087463 4054.43238425255,154.032504558563 PathPoint;PointKind.SMOOTHPOINT 4110.88768053055,157.801973819733 4126.09844493866,157.761611938477 4095.67656207085,157.842099666595 PathPoint;PointKind.SMOOTHPOINT 4149.38441801071,157.801973819733 4164.75910830498,154.484510421753 4134.00937366486,161.119201183319 PathPoint;PointKind.SMOOTHPOINT 4178.54835557938,155.509843826294 4212.34222579002,154.71747636795 4144.75448536873,156.302211284637 PathPoint;PointKind.SMOOTHPOINT 4234.54373884201,161.240050792694 4248.50576329231,167.095828056335 4220.58136034012,155.384509563446 PathPoint;PointKind.SMOOTHPOINT 4267.20747637749,157.801973819733 4289.91882371902,150.710792541504 4244.49577498436,164.893155097961 PathPoint;PointKind.SMOOTHPOINT 4301.0378139019,156.655790805817 4325.16642975807,155.004022121429 4276.90919804573,158.307795524597 PathPoint;PointKind.SMOOTHPOINT 4423.52727222443,154.363660812378 4436.18638682365,155.630693435669 4410.8681576252,153.09686422348 PathPoint;PointKind.SMOOTHPOINT 4452.69120979309,157.801973819733 4471.42939019203,153.531167507172 4433.95338344574,162.072780132294 PathPoint;PointKind.SMOOTHPOINT 4488.85474729538,154.363660812378 4503.85626721382,155.644147396088 4473.85358142853,153.083410263062 PathPoint;PointKind.SMOOTHPOINT 4529.68468475342,155.509843826294 4575.58641123772,155.34414768219 4483.78295826912,155.675539970398 PathPoint;PointKind.SMOOTHPOINT 4600.84515976906,158.947920799255 4637.34610843658,156.951305866241 4564.34456515312,160.944535732269 PathPoint;PointKind.SMOOTHPOINT 4662.67318892479,154.363660812378 4673.23596405983,152.16570854187 4652.11041378975,156.561849117279 PathPoint;PointKind.SMOOTHPOINT 4703.50312638283,160.094103813171 4728.54307103157,162.3548412323 4678.4628276825,157.833366394043 PathPoint;PointKind.SMOOTHPOINT 4769.99720144272,161.240050792694 4802.14614796638,154.788994789124 4737.84825491905,167.691106796265 PathPoint;PointKind.SMOOTHPOINT 4822.49278473854,160.094103813171 4850.87745475769,162.086234092712 4794.1077606678,158.10197353363 PathPoint;PointKind.SMOOTHPOINT 4859.82292222977,162.38623380661 4885.2548019886,156.078450679779 4834.39068841934,168.694016933441 PathPoint;PointKind.SMOOTHPOINT 4984.64522647858,163.532180786133 5011.016051054,164.60212469101 4958.27440190315,162.462236881256 PathPoint;PointKind.SMOOTHPOINT 5028.97496390343,165.824310779572 5053.41797757149,171.330757141113 5004.53159618378,160.31786441803 PathPoint;PointKind.SMOOTHPOINT 5068.63794732094,169.262623786926 5093.68284869194,162.516052722931 5043.59340000153,176.008958816528 PathPoint;PointKind.SMOOTHPOINT 5112.96768474579,161.240050792694 5127.0210545063,161.334228515625 5098.91396093369,161.146109104156 PathPoint;PointKind.SMOOTHPOINT 5132.79917645454,163.532180786133 5165.4037873745,164.727458953857 5100.19456553459,162.336902618408 PathPoint;PointKind.SMOOTHPOINT 5213.29209733009,168.11644077301 5243.36771774292,160.904409885406 5183.21683096886,175.328471660614 PathPoint;PointKind.SMOOTHPOINT 5249.45563483238,160.094103813171 5259.26215577126,162.542960643768 5239.64911389351,157.645246982574 PathPoint;PointKind.SMOOTHPOINT 5287.95237231255,163.532180786133 5318.11898398399,164.04248714447 5257.7857606411,163.021874427795 PathPoint;PointKind.SMOOTHPOINT 5343.94740152359,163.532180786133 5366.58616828918,157.331793308258 5321.30898880959,169.732568264008 PathPoint;PointKind.SMOOTHPOINT 5394.10978484154,156.655790805817 5415.75968551636,150.930068492889 5372.45988416672,162.381749153137 PathPoint;PointKind.SMOOTHPOINT 5417.44107651711,155.509843826294 5437.92897987366,160.595440864563 5396.95352721214,150.424246788025 PathPoint;PointKind.SMOOTHPOINT 5447.7719681263,160.094103813171 5469.35778546333,154.730930328369 5426.18579673767,165.457277297974 PathPoint;PointKind.SMOOTHPOINT 5474.60305976868,156.655790805817 5490.91209220886,162.757751941681 5458.2936732769,150.554065704346 PathPoint;PointKind.SMOOTHPOINT 5514.26604318619,173.84664773941 5539.98966145515,172.597789764404 5488.54242491722,175.09574174881 PathPoint;PointKind.SMOOTHPOINT 5556.26258063316,170.408570766449 5573.47373652458,167.520925998688 5539.05107069016,173.29621553421 PathPoint;PointKind.SMOOTHPOINT 5584.25991821289,170.408570766449 5600.42803812027,174.939014911652 5568.0921523571,165.878126621246 PathPoint;PointKind.SMOOTHPOINT 5625.08985567093,168.11644077301 5651.03688049316,166.04807138443 5599.14283084869,170.184810161591 PathPoint;PointKind.SMOOTHPOINT 5651.92094731331,166.970493793488 5663.38619995117,174.500463008881 5640.45569467545,159.440524578094 PathPoint;PointKind.SMOOTHPOINT 5663.58659315109,184.161350727081 5673.857629776,193.240177631378 5653.31520247459,175.082287788391 PathPoint;PointKind.SMOOTHPOINT 5678.60121297836,220.542984008789 5689.42386198044,228.328106403351 5667.77856397629,212.757861614227 PathPoint;PointKind.SMOOTHPOINT 5687.44790005684,246.000001430511 5680.88590788841,255.566947460175 5694.00989222527,236.433055400848 PathPoint;PointKind.SMOOTHPOINT 5677.43461298943,261.801087856293 5667.80582594872,276.726722717285 5687.06340003014,246.8754529953 PathPoint;PointKind.SMOOTHPOINT 5675.10141301155,288.160464763641 5685.52752423286,300.001602172852 5664.67530179024,276.319327354431 PathPoint;PointKind.SMOOTHPOINT 5686.45053672791,305.999944210052 5683.50234913826,315.835497379303 5689.39907836914,296.164391040802 PathPoint;PointKind.SMOOTHPOINT 5678.60121297836,327.126438617706 5672.96896028519,333.676156997681 5684.23346567154,320.576956272125 PathPoint;PointKind.SMOOTHPOINT 5676.41883897781,351.485896110535 5676.49177360535,360.797688961029 5676.34590435028,342.17410326004 PathPoint;PointKind.SMOOTHPOINT 5682.25148487091,373.261013031006 5687.01808142662,391.526298522949 5677.48524236679,354.995727539062 PathPoint;PointKind.SMOOTHPOINT 5688.0844848156,399.620389938354 5681.5954272747,408.851459026337 5694.57354235649,390.389320850372 PathPoint;PointKind.SMOOTHPOINT 5689.25108480453,420.249559879303 5687.62882041931,443.282504081726 5690.87334918976,397.216379642487 PathPoint;PointKind.SMOOTHPOINT 5685.75128483772,480.990650653839 5679.4856338501,499.873638153076 5692.01693582535,462.107427120209 PathPoint;PointKind.SMOOTHPOINT 5683.41808485985,514.226181507111 5678.62882900238,534.349529743195 5688.20734071732,494.10306930542 PathPoint;PointKind.SMOOTHPOINT 5677.58543896675,564.652805328369 5672.74130511284,587.475678920746 5682.42921876907,541.830167770386 PathPoint;PointKind.SMOOTHPOINT 5671.75243902206,609.349222183228 5670.94130682945,623.536069393158 5672.56357121468,595.162138938904 PathPoint;PointKind.SMOOTHPOINT 5677.58543896675,635.708599090576 5678.09102463722,656.248075962067 5677.07949924469,615.169122219086 PathPoint;PointKind.SMOOTHPOINT 5676.41883897781,696.449689865112 5672.03497219086,728.749816417694 5680.80235171318,664.149563312531 PathPoint;PointKind.SMOOTHPOINT 5671.75243902206,748.022260665894 5672.2311167717,761.515402793884 5671.27411532402,734.529354572296 PathPoint;PointKind.SMOOTHPOINT 5672.919039011,778.96589756012 5672.90098237991,794.988384246826 5672.93744969368,762.943410873413 PathPoint;PointKind.SMOOTHPOINT 5668.25299310684,814.493794441223 5664.80771708488,828.251059055328 5671.69791507721,800.736529827118 PathPoint;PointKind.SMOOTHPOINT 5672.919039011,837.414858341217 5675.49370217323,852.022790908813 5670.34437584877,822.807161808014 PathPoint;PointKind.SMOOTHPOINT 5675.25223898888,867.21254825592 5660.09599852562,881.354548931122 5690.40847945213,853.070311546326 PathPoint;PointKind.SMOOTHPOINT 5668.25299310684,894.717872142792 5667.77431535721,904.58033323288 5668.73131680489,884.855411052704 PathPoint;PointKind.SMOOTHPOINT 5672.919039011,911.908729076385 5672.8096370697,924.009504318237 5673.0284409523,899.807953834534 PathPoint;PointKind.SMOOTHPOINT 5672.919039011,930.245769023895 5670.01617002487,942.180848121643 5675.82190799713,918.310689926147 PathPoint;PointKind.SMOOTHPOINT 5670.58583903313,1001.30132675171 5668.76778411865,1017.0103597641 5672.40424799919,985.592293739319 PathPoint;PointKind.SMOOTHPOINT 5670.58583903313,1023.07644367218 5671.4653031826,1033.42230319977 5669.70637488365,1012.73058414459 PathPoint;PointKind.SMOOTHPOINT 5675.25223898888,1048.28987360001 5673.09677290916,1055.6541466713 5677.40770506859,1040.92536449432 PathPoint;PointKind.SMOOTHPOINT 5668.25299310684,1071.2109375 5667.66951608658,1084.25632238388 5668.83611607552,1058.16555261612 PathPoint;PointKind.SMOOTHPOINT 5670.58583903313,1091.84010744095 5672.46797728539,1098.12546730042 5668.70405483246,1085.55474758148 PathPoint;PointKind.SMOOTHPOINT 5672.919039011,1106.7388343811 5671.5428404808,1115.45959711075 5674.2952375412,1098.01807165146 PathPoint;PointKind.SMOOTHPOINT 5672.919039011,1123.9296913147 5673.53438067436,1135.38137197495 5672.30405139923,1112.47801065445 PathPoint;PointKind.SMOOTHPOINT 5669.41923904419,1146.85099124908 5666.63072872162,1155.87151765823 5672.20810341835,1137.83022880554 PathPoint;PointKind.SMOOTHPOINT 5676.41883897781,1168.62610816956 5676.6556994915,1191.74426078796 5676.18197846413,1145.50795555115 PathPoint;PointKind.SMOOTHPOINT 5671.75243902206,1203.00782203674 5670.75472164154,1212.21646785736 5672.75051045418,1193.79894018173 PathPoint;PointKind.SMOOTHPOINT 5676.41883897781,1227.07506895065 5674.27257823944,1235.94358921051 5678.56509971619,1218.2065486908 PathPoint;PointKind.SMOOTHPOINT 5671.75243902206,1248.85018587112 5668.93171000481,1259.52271699905 5674.57316803932,1238.1774187088 PathPoint;PointKind.SMOOTHPOINT 5675.25223898888,1280.93976974487 5676.17737579346,1289.27107572556 5674.3271021843,1272.60846376419 PathPoint;PointKind.SMOOTHPOINT 5676.41883897781,1301.56893968582 5672.58658456802,1323.88127088547 5680.2510933876,1279.25660848618 PathPoint;PointKind.SMOOTHPOINT 5674.08563899994,1330.22044658661 5672.95550632477,1347.57676362991 5675.21577167511,1312.86389350891 PathPoint;PointKind.SMOOTHPOINT 5676.41883897781,1355.43364048004 5675.63496875763,1368.58642101288 5677.202709198,1342.2808599472 PathPoint;PointKind.SMOOTHPOINT 5676.41883897781,1378.35470438004 5676.24110507965,1393.95634174347 5676.59657287598,1362.75330305099 PathPoint;PointKind.SMOOTHPOINT 5676.41883897781,1404.71408128738 5674.95589780807,1425.30288934708 5677.88142609596,1384.12550926208 PathPoint;PointKind.SMOOTHPOINT 5676.41883897781,1440.24197816849 5677.31175708771,1458.30592632294 5675.52556681633,1422.17803001404 PathPoint;PointKind.SMOOTHPOINT 5678.75203895569,1474.62369203568 5677.69484090805,1497.58535385132 5679.80923700333,1451.66226625443 PathPoint;PointKind.SMOOTHPOINT 5677.58543896675,1518.17392587662 5679.43075585365,1533.98162126541 5675.73976802826,1502.36646652222 PathPoint;PointKind.SMOOTHPOINT 5679.91863894463,1565.16247272491 5676.03610920906,1580.48204898834 5683.8008146286,1549.84289646149 PathPoint;PointKind.SMOOTHPOINT 5675.25223898888,1596.10610961914 5675.11557507515,1606.88178777695 5675.3889029026,1585.33043146133 PathPoint;PointKind.SMOOTHPOINT 5678.75203895569,1617.88122653961 5679.82729363441,1636.33439540863 5677.67643022537,1599.4278216362 PathPoint;PointKind.SMOOTHPOINT 5681.08488488197,1652.2629404068 5676.30483436584,1668.63452196121 5685.86528944969,1635.89135885239 PathPoint;PointKind.SMOOTHPOINT 5677.58543896675,1682.06039428711 5677.40770506859,1697.26809024811 5677.76317286491,1666.85269832611 PathPoint;PointKind.SMOOTHPOINT 5684.58468484879,1706.12764120102 5683.86029529572,1721.0041809082 5685.30942845345,1691.25133752823 PathPoint;PointKind.SMOOTHPOINT 5684.58468484879,1732.48701810837 5682.9397611618,1746.54428243637 5686.22960853577,1718.42998981476 PathPoint;PointKind.SMOOTHPOINT 5685.75128483772,1754.26213502884 5686.25722455978,1773.65566492081 5685.24534511566,1734.86860513687 PathPoint;PointKind.SMOOTHPOINT 5683.41808485985,1790.93597888947 5683.18582701683,1803.11299324036 5683.65069675446,1778.75920057297 PathPoint;PointKind.SMOOTHPOINT 5686.91788482666,1812.71109580994 5684.44802093506,1827.82933473587 5689.38774871826,1797.5930929184 PathPoint;PointKind.SMOOTHPOINT 5684.58468484879,1837.92452573776 5685.06336259842,1853.47234725952 5684.10636115074,1822.376704216 PathPoint;PointKind.SMOOTHPOINT 5683.41808485985,1873.45242261887 5683.61422944069,1891.5026807785 5683.2222943306,1855.40192842484 PathPoint;PointKind.SMOOTHPOINT 5683.41808485985,1898.6656165123 5683.48641681671,1908.76529216766 5683.34975290298,1888.56594085693 PathPoint;PointKind.SMOOTHPOINT 5690.41768479347,1925.02499341965 5689.80694580078,1933.50854158401 5691.02806973457,1916.54144525528 PathPoint;PointKind.SMOOTHPOINT 5677.62226033211,1948.9461350441 5676.38732838631,1959.33684110641 5678.85719227791,1938.55542898178 PathPoint;PointKind.SMOOTHPOINT 5679.95546030998,1969.57530498505 5679.29019737244,1981.43862962723 5680.62072324753,1957.71174430847 PathPoint;PointKind.SMOOTHPOINT 5678.78886032104,1997.08062887192 5671.32014203072,2008.38455200195 5686.25757861137,1985.77670574188 PathPoint;PointKind.SMOOTHPOINT 5677.62226033211,2017.70979881287 5680.19692349434,2034.12599086761 5675.04759716988,2001.29337072372 PathPoint;PointKind.SMOOTHPOINT 5683.45526027679,2047.50725269318 5678.30593395233,2059.63493585587 5688.60458660126,2035.37956953049 PathPoint;PointKind.SMOOTHPOINT 5689.25108480453,2071.72060489655 5690.99160242081,2085.43302297592 5687.51021313667,2058.00818681717 PathPoint;PointKind.SMOOTHPOINT 5689.25108480453,2094.64166879654 5684.51635289192,2106.00389242172 5693.98546266556,2083.27968120575 PathPoint;PointKind.SMOOTHPOINT 5688.0844848156,2112.97870874405 5695.42574453354,2121.35486125946 5680.74322509766,2104.60255622864 PathPoint;PointKind.SMOOTHPOINT 5681.12206029892,2142.6300573349 5678.53358912468,2159.5032119751 5683.71053147316,2125.7571387291 PathPoint;PointKind.SMOOTHPOINT 5679.95546030998,2164.40517425537 5680.91246175766,2175.39587974548 5678.9984588623,2153.41470479965 PathPoint;PointKind.SMOOTHPOINT 5684.62186026573,2180.45008420944 5686.8318502903,2189.65896606445 5682.41151618958,2171.24143838882 PathPoint;PointKind.SMOOTHPOINT 5679.95546030998,2198.78712415695 5678.82993030548,2204.84423875809 5681.08099031448,2192.73000955582 PathPoint;PointKind.SMOOTHPOINT 5685.78846025467,2209.10159111023 5687.20112609863,2217.08380222321 5684.37579441071,2201.11937999725 PathPoint;PointKind.SMOOTHPOINT 5686.95506024361,2224.00031805038 5686.31705927849,2230.66191673279 5687.59270715714,2217.33895540237 PathPoint;PointKind.SMOOTHPOINT 5683.45526027679,2238.89904499054 5678.2011346817,2247.23932027817 5688.70938587189,2230.55876970291 PathPoint;PointKind.SMOOTHPOINT 5679.95546030998,2253.79777193069 5684.77658081055,2259.59524869919 5675.13433980942,2248.00053119659 PathPoint;PointKind.SMOOTHPOINT 5686.95506024361,2264.11247491837 5684.24337911606,2275.4163980484 5689.66638731956,2252.80855178833 PathPoint;PointKind.SMOOTHPOINT 5683.45526027679,2280.15714883804 5679.91439032555,2285.49813508987 5686.99577617645,2274.81639862061 PathPoint;PointKind.SMOOTHPOINT 5683.45526027679,2297.34800577164 5686.05718541145,2312.84673213959 5680.85333514214,2281.84951543808 PathPoint;PointKind.SMOOTHPOINT 5686.95506024361,2320.26930570602 5684.13433122635,2324.65647697449 5689.77578926086,2315.88213443756 PathPoint;PointKind.SMOOTHPOINT 5681.12206029892,2334.02208566666 5675.88634538651,2339.31798934937 5686.35777521133,2328.72594594955 PathPoint;PointKind.SMOOTHPOINT 5681.12206029892,2343.19036960602 5687.41072463989,2348.84905815125 5674.83339595795,2337.53191709518 PathPoint;PointKind.SMOOTHPOINT 5682.28866028786,2355.79720258713 5674.5282034874,2362.44062662125 5690.04911708832,2349.15354251862 PathPoint;PointKind.SMOOTHPOINT 5690.45450615883,2370.69592952728 5688.10324954987,2382.96240091324 5692.80611681938,2358.42945814133 PathPoint;PointKind.SMOOTHPOINT 5684.62186026573,2387.88678646088 5677.39000248909,2397.43579387665 5691.85371804237,2378.3377790451 PathPoint;PointKind.SMOOTHPOINT 5689.28790616989,2406.22382640839 5688.91438174248,2413.93719434738 5689.6617846489,2398.510222435 PathPoint;PointKind.SMOOTHPOINT 5686.95506024361,2426.85276031494 5686.66792440414,2435.32733917236 5687.24184203148,2418.37818145752 PathPoint;PointKind.SMOOTHPOINT 5688.12130618095,2447.48193025589 5689.56158804893,2456.61008834839 5686.68137836456,2438.35377216339 PathPoint;PointKind.SMOOTHPOINT 5682.28866028786,2460.08852720261 5677.99153614044,2466.65146350861 5686.58578443527,2453.52559089661 PathPoint;PointKind.CORNERPOINT 5681.12206029892,2472.69512414932 5681.12206029892,2472.69512414932 5681.12206029892,2472.69512414932 PathPoint;PointKind.SMOOTHPOINT 5686.95506024361,2474.98725414276 5695.41689324379,2486.10305786133 5678.49287319183,2463.87145042419 PathPoint;PointKind.SMOOTHPOINT 5695.12090611458,2496.76237106323 5693.89057683945,2501.33317708969 5696.35123538971,2492.19156503677 PathPoint;PointKind.SMOOTHPOINT 5678.78886032104,2493.32429409027 5678.81612229347,2509.96896743774 5678.76159834862,2476.6793847084 PathPoint;PointKind.SMOOTHPOINT 5685.78846025467,2510.51515102386 5692.14970517159,2509.88375902176 5679.42686128616,2511.14630699158 PathPoint;PointKind.SMOOTHPOINT 5693.95430612564,2517.39154100418 5692.68750953674,2529.78759527206 5695.22110271454,2504.9952507019 PathPoint;PointKind.SMOOTHPOINT 5679.95546030998,2524.2676949501 5679.33587002754,2542.06752061844 5680.57540464401,2506.46810531616 PathPoint;PointKind.SMOOTHPOINT 5682.28866028786,2551.77325487137 5686.57657909393,2555.82030057907 5678.00074148178,2547.72620916367 PathPoint;PointKind.SMOOTHPOINT 5691.62110614777,2540.31260490417 5694.18656396866,2548.6035490036 5689.05564832687,2532.02166080475 PathPoint;PointKind.SMOOTHPOINT 5689.28790616989,2559.79559183121 5689.47944808006,2571.66363716125 5689.09671831131,2547.92754650116 PathPoint;PointKind.SMOOTHPOINT 5683.45526027679,2578.13263177872 5678.10978937149,2585.96708536148 5688.80037713051,2570.29817819595 PathPoint;PointKind.SMOOTHPOINT 5681.12206029892,2587.30115175247 5685.00919270515,2593.51924180984 5677.23492789268,2581.08282566071 PathPoint;PointKind.SMOOTHPOINT 5691.62110614777,2589.59328174591 5692.46870565414,2599.88532543182 5690.77350664139,2579.3010020256 PathPoint;PointKind.SMOOTHPOINT 5691.62110614777,2606.7841386795 5691.19270372391,2613.71859312057 5692.04950857162,2599.84944820404 PathPoint;PointKind.SMOOTHPOINT 5679.95546030998,2601.05369567871 5681.24066758156,2611.32803678513 5678.67060709,2590.77959060669 PathPoint;PointKind.SMOOTHPOINT 5689.28790616989,2623.9749956131 5695.70863175392,2631.44217967987 5682.86753463745,2616.50757551193 PathPoint;PointKind.CORNERPOINT 5691.62110614777,2637.72753953934 5691.62110614777,2637.72753953934 5691.62110614777,2637.72753953934 PathPoint;PointKind.SMOOTHPOINT 5682.28866028786,2642.31179952621 5677.52206373215,2655.33051252365 5687.05525684357,2629.29332256317 PathPoint;PointKind.SMOOTHPOINT 5685.78846025467,2662.94096946716 5689.74817323685,2667.11783409119 5681.8283932209,2658.76410484314 PathPoint;PointKind.SMOOTHPOINT 5695.12090611458,2667.52522945404 5691.38424563408,2677.96054601669 5698.85756659508,2657.08967685699 PathPoint;PointKind.SMOOTHPOINT 5678.78886032104,2677.83969640732 5680.53893733025,2688.83913516998 5677.03913736343,2666.84025764465 PathPoint;PointKind.SMOOTHPOINT 5696.28750610352,2685.86203336716 5698.42456150055,2697.39443778992 5694.15009665489,2674.32986497879 PathPoint;PointKind.SMOOTHPOINT 5695.12090611458,2711.07546329498 5694.98884487152,2714.87184047699 5695.25296735764,2707.27908611298 PathPoint;PointKind.SMOOTHPOINT 5684.62186026573,2703.05312633514 5684.21151447296,2717.34736919403 5685.03185200691,2688.75864744186 PathPoint;PointKind.SMOOTHPOINT 5695.12090611458,2727.12037324905 5699.78695201874,2735.33956289291 5690.45450615883,2718.9009475708 PathPoint;PointKind.SMOOTHPOINT 5681.12206029892,2736.28865718842 5681.40919613838,2744.84844446182 5680.83492445946,2727.7291059494 PathPoint;PointKind.SMOOTHPOINT 5695.12090611458,2750.04143714905 5697.69556927681,2761.18414878845 5692.54624295235,2738.89872550964 PathPoint;PointKind.SMOOTHPOINT 5686.95506024361,2763.79421710968 5685.29172587395,2770.70176362991 5688.61804056168,2756.88643455505 PathPoint;PointKind.SMOOTHPOINT 5697.45410609245,2777.54676103592 5696.62916588783,2790.01032114029 5698.27869224548,2765.08343696594 PathPoint;PointKind.SMOOTHPOINT 5693.95430612564,2799.32187795639 5688.23531079292,2811.14082813263 5699.67330145836,2787.50316381454 PathPoint;PointKind.SMOOTHPOINT 5691.62110614777,2817.6589179039 5694.53742909431,2833.43073606491 5688.70478320122,2801.88709974289 PathPoint;PointKind.SMOOTHPOINT 5697.45410609245,2844.01829481125 5693.35277247429,2853.24039459229 5701.55508565903,2834.79619503021 PathPoint;PointKind.SMOOTHPOINT 5689.28790616989,2864.6472287178 5688.58157324791,2870.53439855576 5689.99423909187,2858.76029491425 PathPoint;PointKind.SMOOTHPOINT 5691.62110614777,2878.40000867844 5698.63876271248,2891.14090919495 5684.60344958305,2865.65910816193 PathPoint;PointKind.SMOOTHPOINT 5703.28675198555,2900.17512559891 5696.88903975487,2907.67818689346 5709.68481826782,2892.67206430435 PathPoint;PointKind.SMOOTHPOINT 5677.62226033211,2901.32130861282 5678.10093808174,2916.15725040436 5677.14393663406,2886.4851307869 PathPoint;PointKind.SMOOTHPOINT 5678.78886032104,2926.53450250626 5688.30364274979,2933.07076692581 5669.2740778923,2919.99847412109 PathPoint;PointKind.SMOOTHPOINT 5698.62070608139,2913.92790555954 5703.75162172318,2913.91893625259 5693.48943638802,2913.93687486649 PathPoint;PointKind.SMOOTHPOINT 5707.9531519413,2926.53450250626 5705.79768586159,2933.6391377449 5710.10861802101,2919.42986726761 PathPoint;PointKind.SMOOTHPOINT 5698.62070608139,2936.84896945953 5695.56736516953,2942.08680868149 5701.67369294167,2931.61113023758 PathPoint;PointKind.SMOOTHPOINT 5689.28790616989,2958.62408638 5681.04452300072,2975.1302075386 5697.53128933907,2942.1182012558 PathPoint;PointKind.SMOOTHPOINT 5689.28790616989,2974.66899633408 5691.83991003036,2982.84806013107 5686.73625636101,2966.48993253708 PathPoint;PointKind.SMOOTHPOINT 5698.62070608139,2989.56772327423 5704.64489388466,3010.38029193878 5692.59616422653,2968.75515460968 PathPoint;PointKind.SMOOTHPOINT 5702.12015199661,3035.41008710861 5696.9938390255,3062.0784330368 5707.24681901932,3008.74197721481 PathPoint;PointKind.SMOOTHPOINT 5703.28675198555,3113.34227085114 5698.42456150055,3148.71768951416 5708.14894247055,3077.96661615372 PathPoint;PointKind.CORNERPOINT 5699.78695201874,3245.13891935349 5699.78695201874,3245.13891935349 5699.78695201874,3245.13891935349 PathPoint;PointKind.SMOOTHPOINT 5702.12015199661,3279.52063322067 5702.25256729126,3297.40094661713 5701.98809075356,3261.64031982422 PathPoint;PointKind.SMOOTHPOINT 5691.62110614777,3312.75640010834 5689.64337396622,3324.74081039429 5693.59883832932,3300.77198982239 PathPoint;PointKind.CORNERPOINT 5686.95506024361,3350.57642698288 5686.95506024361,3350.57642698288 5686.95506024361,3350.57642698288 PathPoint;PointKind.SMOOTHPOINT 5693.91713070869,3365.62125921249 5692.70981478691,3385.90558290482 5695.12480068207,3345.33693552017 PathPoint;PointKind.SMOOTHPOINT 5698.58353066444,3389.6885061264 5698.98006844521,3397.9346036911 5698.18699288368,3381.44217252731 PathPoint;PointKind.SMOOTHPOINT 5689.25108480453,3418.34001302719 5685.1451485157,3423.54197502136 5693.35666704178,3413.13781499863 PathPoint;PointKind.SMOOTHPOINT 5685.75128483772,3433.23873996735 5689.38774871826,3443.44132661819 5682.11482095718,3423.0361533165 PathPoint;PointKind.SMOOTHPOINT 5689.25108480453,3456.15980386734 5686.55781435966,3466.76530122757 5691.94400119781,3445.55430650711 PathPoint;PointKind.SMOOTHPOINT 5686.91788482666,3482.51918077469 5684.26108169556,3493.9439535141 5689.57468795776,3471.09440803528 PathPoint;PointKind.SMOOTHPOINT 5689.25108480453,3502.00216770172 5697.6675992012,3506.07612133026 5680.83457040787,3497.92845010757 PathPoint;PointKind.SMOOTHPOINT 5693.91713070869,3514.60900068283 5685.90635943413,3528.30348014832 5701.92825603485,3500.91428518295 PathPoint;PointKind.SMOOTHPOINT 5685.75128483772,3550.13666152954 5687.21422600746,3560.23185253143 5684.28869771957,3540.04147052765 PathPoint;PointKind.SMOOTHPOINT 5689.25108480453,3569.61964845657 5692.3996655941,3583.98116111755 5686.10214996338,3555.25813579559 PathPoint;PointKind.SMOOTHPOINT 5690.41768479347,3597.12520837784 5688.18928408623,3603.64329814911 5692.64573144913,3590.60688257217 PathPoint;PointKind.SMOOTHPOINT 5686.91788482666,3618.90032529831 5678.93402147293,3627.05248117447 5694.9013941288,3610.74793338776 PathPoint;PointKind.SMOOTHPOINT 5681.08488488197,3641.8213891983 5681.77776384354,3657.08290100098 5680.392359972,3626.56011343002 PathPoint;PointKind.SMOOTHPOINT 5679.91863894463,3663.59650611877 5667.33245897293,3669.95362043381 5692.50446486473,3657.23962783813 PathPoint;PointKind.SMOOTHPOINT 5672.919039011,3679.64141607285 5670.91404485703,3695.68632602692 5674.92403316498,3663.59650611877 PathPoint;PointKind.SMOOTHPOINT 5674.08563899994,3709.43886995316 5685.27296113968,3728.04003238678 5662.8983168602,3690.83794355392 PathPoint;PointKind.SMOOTHPOINT 5691.58428478241,3732.36016988754 5691.63420605659,3748.69587421417 5691.53400945663,3716.02422952652 PathPoint;PointKind.SMOOTHPOINT 5686.45053672791,3751.99988365173 5682.36301112175,3761.37894630432 5690.53806233406,3742.62105703354 PathPoint;PointKind.SMOOTHPOINT 5678.75203895569,3767.88783073425 5656.22267413139,3768.61764907837 5701.28104972839,3767.15824842453 PathPoint;PointKind.SMOOTHPOINT 5654.25414729118,3780.49466371536 5640.79310584068,3781.47491455078 5667.71518874168,3779.51417684555 PathPoint;PointKind.SMOOTHPOINT 5629.75625562668,3778.20253372192 5619.89060807228,3777.15052843094 5639.62190318108,3779.25453901291 PathPoint;PointKind.SMOOTHPOINT 5600.59196400642,3777.05635070801 5589.91518425941,3778.88302087784 5611.26874375343,3775.22991657257 PathPoint;PointKind.SMOOTHPOINT 5569.09482645988,3778.20253372192 5561.35702896118,3778.29647541046 5576.832269907,3778.10835599899 PathPoint;PointKind.SMOOTHPOINT 5549.26298069954,3775.91040372849 5533.79234242439,3774.64785575867 5564.73361897469,3777.17271566391 PathPoint;PointKind.SMOOTHPOINT 5516.59924316406,3775.91040372849 5511.97851586342,3775.71779966354 5521.21997046471,3776.10277175903 PathPoint;PointKind.SMOOTHPOINT 5496.76775145531,3769.03401374817 5486.87448787689,3769.0788602829 5506.66066098213,3768.98916721344 PathPoint;PointKind.SMOOTHPOINT 5464.10365986824,3771.32614374161 5458.4349398613,3771.73353910446 5469.77273392677,3770.91874837875 PathPoint;PointKind.SMOOTHPOINT 5441.93896818161,3773.61827373505 5436.83071184158,3775.84761857986 5447.04722452164,3771.38869285583 PathPoint;PointKind.CORNERPOINT 5420.94087648392,3779.34848070145 5420.94087648392,3779.34848070145 5420.94087648392,3779.34848070145 PathPoint;PointKind.SMOOTHPOINT 5409.27523064613,3770.17996072769 5381.83375406265,3769.11001682281 5436.71670722961,3771.24990463257 PathPoint;PointKind.SMOOTHPOINT 5378.94469308853,3775.91040372849 5369.60304188728,3778.64108562469 5388.28599023819,3773.17948579788 PathPoint;PointKind.SMOOTHPOINT 5363.77924728394,3775.91040372849 5346.93701314926,3775.28798103333 5380.62148141861,3776.53259038925 PathPoint;PointKind.SMOOTHPOINT 5339.28135561943,3775.91040372849 5335.15736269951,3782.088367939 5343.40534853935,3769.73243951797 PathPoint;PointKind.SMOOTHPOINT 5307.7838640213,3791.95507764816 5286.60343575478,3800.21486520767 5328.96464633942,3783.69552612305 PathPoint;PointKind.SMOOTHPOINT 5265.78768062592,3788.5170006752 5249.16425037384,3785.51299095154 5282.41111087799,3791.52101039886 PathPoint;PointKind.SMOOTHPOINT 5242.45638895035,3789.66294765472 5217.58922147751,3786.79347753525 5267.3232023716,3792.53265380859 PathPoint;PointKind.SMOOTHPOINT 5212.12549734116,3787.37105369568 5206.01952362061,3791.6149520874 5218.2318251133,3783.12691926956 PathPoint;PointKind.SMOOTHPOINT 5189.96080565453,3794.2472076416 5180.25023269653,3796.48575782776 5199.67173266411,3792.00889348984 PathPoint;PointKind.SMOOTHPOINT 5140.96502232552,3787.37105369568 5116.11166286469,3787.47844934464 5165.81838178635,3787.26342201233 PathPoint;PointKind.SMOOTHPOINT 5111.80108475685,3796.53933763504 5100.22643017769,3802.51147985458 5123.37538528442,3790.56743144989 PathPoint;PointKind.SMOOTHPOINT 5058.13890147209,3789.66294765472 5040.54466176033,3788.04257154465 5075.73314118385,3791.28355979919 PathPoint;PointKind.SMOOTHPOINT 4999.81067228317,3804.56191062927 4982.43523645401,3793.52210998535 5017.18610811234,3815.60171127319 PathPoint;PointKind.SMOOTHPOINT 4963.64713478088,3793.10126066208 4937.98264312744,3791.60598278046 4989.31162643433,3794.5965385437 PathPoint;PointKind.SMOOTHPOINT 4922.81719732285,3798.83146762848 4912.62794661522,3798.37946176529 4933.00644803047,3799.28370952606 PathPoint;PointKind.SMOOTHPOINT 4892.48665976524,3795.39339065552 4872.31315422058,3798.21376562119 4912.66016530991,3792.57301568985 PathPoint;PointKind.SMOOTHPOINT 4850.49012231827,3798.83146762848 4833.72082281113,3796.87072992325 4867.259775877,3800.7924413681 PathPoint;PointKind.SMOOTHPOINT 4817.82638478279,3801.12359762192 4802.8160135746,3801.37875080109 4832.83675599098,3800.86844444275 PathPoint;PointKind.SMOOTHPOINT 4787.49584722519,3795.39339065552 4772.90007042885,3795.02635717392 4802.09162402153,3795.76042413712 PathPoint;PointKind.SMOOTHPOINT 4718.66821813583,3804.56191062927 4700.74152398109,3804.7901558876 4736.59526634216,3804.33342933655 PathPoint;PointKind.SMOOTHPOINT 4679.00523471832,3803.41572761536 4658.17567157745,3798.71510267258 4699.83479785919,3808.11635255814 PathPoint;PointKind.SMOOTHPOINT 4641.6750972271,3798.83146762848 4622.27625656128,3797.43036746979 4661.07358384132,3800.23280382156 PathPoint;PointKind.SMOOTHPOINT 4605.51155972481,3803.41572761536 4589.71731829643,3803.85003089905 4621.30580115318,3802.98142433167 PathPoint;PointKind.SMOOTHPOINT 4553.01597642899,3799.9776506424 4529.67087674141,3799.20747041702 4576.36107611656,3800.74759483337 PathPoint;PointKind.SMOOTHPOINT 4471.3564555645,3797.68552064896 4431.93918395042,3795.60818195343 4510.77372717857,3799.76262331009 PathPoint;PointKind.SMOOTHPOINT 4407.19522643089,3790.80913066864 4379.958745718,3787.43808746338 4434.43170714378,3794.1801738739 PathPoint;PointKind.SMOOTHPOINT 4352.36679720879,3787.37105369568 4343.12073993683,3787.76947975159 4361.61250042915,3786.97239160538 PathPoint;PointKind.SMOOTHPOINT 4327.86890554428,3793.10126066208 4318.63205361366,3791.55665159225 4337.1057574749,3794.64563369751 PathPoint;PointKind.SMOOTHPOINT 4310.37025976181,3787.37105369568 4287.33070659637,3781.94509506226 4333.41016697884,3792.79677629471 PathPoint;PointKind.SMOOTHPOINT 4273.04012227058,3778.20253372192 4260.95067667961,3774.84494447708 4285.12956786156,3781.56012296677 PathPoint;PointKind.SMOOTHPOINT 4247.37563061714,3783.93274068832 4231.34452867508,3785.235414505 4263.40708661079,3782.63006687164 PathPoint;PointKind.SMOOTHPOINT 4224.04433894157,3783.93274068832 4205.36103653908,3777.24447011948 4242.72764134407,3790.62101125717 PathPoint;PointKind.SMOOTHPOINT 4180.88155555725,3786.22487068176 4170.24584579468,3785.45044183731 4191.51726531982,3786.99929952621 PathPoint;PointKind.SMOOTHPOINT 4155.21706390381,3780.49466371536 4140.65775442123,3779.00387048721 4169.77637338638,3781.98545694351 PathPoint;PointKind.SMOOTHPOINT 4103.88808059692,3782.7867937088 4091.61665248871,3783.1538271904 4116.15986275673,3782.41952419281 PathPoint;PointKind.SMOOTHPOINT 4074.72414302826,3783.93274068832 4054.16330504417,3784.4699549675 4095.28462696075,3783.39552640915 PathPoint;PointKind.SMOOTHPOINT 4043.22665143013,3779.34848070145 4024.27002120018,3776.89513921738 4062.18363571167,3781.80182218552 PathPoint;PointKind.SMOOTHPOINT 4007.06311392784,3780.49466371536 3992.18055534363,3784.16098594666 4021.94602656364,3776.82810544968 PathPoint;PointKind.SMOOTHPOINT 3967.40013051033,3786.22487068176 3946.90762448311,3787.7515411377 3987.89228248596,3784.69820022583 PathPoint;PointKind.SMOOTHPOINT 3925.40359306335,3787.37105369568 3904.76096916199,3780.53478956223 3946.04657101631,3794.20708179474 PathPoint;PointKind.SMOOTHPOINT 3888.07345557213,3781.64061069489 3873.6008887291,3780.51260232925 3902.54637646675,3782.76885509491 PathPoint;PointKind.SMOOTHPOINT 3853.07651805878,3790.80913066864 3831.64081859589,3786.76656961441 3874.51221752167,3794.85169172287 PathPoint;PointKind.SMOOTHPOINT 3818.07958054543,3785.07892370224 3782.64963793755,3783.55225324631 3853.50952315331,3786.60535812378 PathPoint;PointKind.SMOOTHPOINT 3773.75019717216,3798.83146762848 3754.0461640358,3799.32407140732 3793.45423030853,3798.33909988403 PathPoint;PointKind.CORNERPOINT 3459.94400548935,3796.53933763504 3459.94400548935,3796.53933763504 3459.94400548935,3796.53933763504 PathPoint;PointKind.CORNERPOINT 3326.95550131798,3797.68552064896 3326.95550131798,3797.68552064896 3326.95550131798,3797.68552064896 PathPoint;PointKind.CORNERPOINT 3228.96393465996,3796.53933763504 3228.96393465996,3796.53933763504 3228.96393465996,3796.53933763504 PathPoint;PointKind.SMOOTHPOINT 3113.47407627106,3791.95507764816 3098.51822900772,3790.63894987106 3128.4295694828,3793.27144145966 PathPoint;PointKind.SMOOTHPOINT 3022.48175549507,3796.53933763504 2997.30479288101,3795.4292678833 3047.65871810913,3797.64964342117 PathPoint;PointKind.SMOOTHPOINT 2974.652572155,3786.22487068176 2946.48174929619,3787.85445213318 3002.82339501381,3784.59528923035 PathPoint;PointKind.SMOOTHPOINT 2943.15543460846,3796.53933763504 2917.87827539444,3795.63508987427 2968.43259382248,3797.44382143021 PathPoint;PointKind.SMOOTHPOINT 2882.49400544167,3789.66294765472 2854.82451963425,3788.38269710541 2910.16349124908,3790.94343423843 PathPoint;PointKind.SMOOTHPOINT 2832.33162212372,3793.10126066208 2818.56538820267,3792.85956144333 2846.09785604477,3793.34295988083 PathPoint;PointKind.SMOOTHPOINT 2795.00148463249,3791.95507764816 2769.22298836708,3788.7676692009 2820.7799808979,3795.14272212982 PathPoint;PointKind.SMOOTHPOINT 2742.50590133667,3796.53933763504 2714.3761484623,3795.04854440689 2770.63565421104,3798.03013086319 PathPoint;PointKind.CORNERPOINT 2665.51278042793,3793.10126066208 2665.51278042793,3793.10126066208 2665.51278042793,3793.10126066208 PathPoint;PointKind.SMOOTHPOINT 2625.84944295883,3794.2472076416 2587.9726498127,3794.93217945099 2663.72623610497,3793.56223583221 PathPoint;PointKind.SMOOTHPOINT 2558.18876791,3791.95507764816 2526.66861701012,3790.75979948044 2589.7085647583,3793.15059185028 PathPoint;PointKind.SMOOTHPOINT 2519.69203042984,3790.80913066864 2498.58913946152,3790.35240411758 2540.79492139816,3791.2658572197 PathPoint;PointKind.SMOOTHPOINT 2483.52849292755,3789.66294765472 2460.76687026024,3791.09567642212 2506.29011559486,3788.23045492172 PathPoint;PointKind.SMOOTHPOINT 2429.86630964279,3782.7867937088 2415.39834547043,3783.22983026505 2444.33462786674,3782.34352111816 PathPoint;PointKind.SMOOTHPOINT 2398.36917209625,3783.93274068832 2383.52732944489,3785.94280958176 2413.21101474762,3781.92267179489 PathPoint;PointKind.SMOOTHPOINT 2344.70698881149,3787.37105369568 2328.93576073647,3795.496301651 2360.47857093811,3779.24556970596 PathPoint;PointKind.SMOOTHPOINT 2307.37720537186,3795.39339065552 2280.25437521935,3793.98756980896 2334.49968147278,3796.79897546768 PathPoint;PointKind.SMOOTHPOINT 2251.38182210922,3789.66294765472 2222.12653923035,3787.39772558212 2280.6371049881,3791.92840576172 PathPoint;PointKind.CORNERPOINT 2212.88508462906,3787.37105369568 2212.88508462906,3787.37105369568 2212.88508462906,3787.37105369568 PathPoint;PointKind.SMOOTHPOINT 2112.56067204475,3797.68552064896 2095.44475603104,3799.51643943787 2129.67623400688,3795.85436582565 PathPoint;PointKind.SMOOTHPOINT 2083.3963804245,3797.68552064896 2066.02554726601,3794.23823833466 2100.76721358299,3801.13256692886 PathPoint;PointKind.SMOOTHPOINT 2044.89964294434,3794.2472076416 2030.68234729767,3795.82769393921 2059.11729264259,3792.66695737839 PathPoint;PointKind.SMOOTHPOINT 2015.73570537567,3796.53933763504 2010.7276456356,3796.35593891144 2020.74376511574,3796.72297239304 PathPoint;PointKind.SMOOTHPOINT 1834.91801786423,3793.10126066208 1819.53376817703,3794.82029914856 1850.30191349983,3791.3822221756 PathPoint;PointKind.CORNERPOINT 1813.91957211494,3796.53933763504 1813.91957211494,3796.53933763504 1813.91957211494,3796.53933763504 PathPoint;PointKind.SMOOTHPOINT 1802.25392627716,3793.10126066208 1792.89882111549,3791.93289041519 1811.60938549042,3794.26963090897 PathPoint;PointKind.SMOOTHPOINT 1764.92414283752,3789.66294765472 1731.9410507679,3787.5185751915 1797.90688085556,3791.80755615234 PathPoint;PointKind.SMOOTHPOINT 1719.42780542374,3790.80913066864 1700.94525027275,3789.58245992661 1737.91071462631,3792.03580141068 PathPoint;PointKind.SMOOTHPOINT 1679.76482200623,3789.66294765472 1655.81358599663,3789.96294736862 1703.71570396423,3789.36318397522 PathPoint;PointKind.SMOOTHPOINT 1629.60243868828,3791.95507764816 1619.65465116501,3793.13713788986 1639.55022621155,3790.77325344086 PathPoint;PointKind.SMOOTHPOINT 1599.27154707909,3793.10126066208 1580.81625390053,3791.59252882004 1617.72719430923,3794.60999250412 PathPoint;PointKind.SMOOTHPOINT 1554.94216370583,3789.66294765472 1523.11221766472,3786.60535812378 1586.77210974693,3792.72077322006 PathPoint;PointKind.SMOOTHPOINT 1466.28304290771,3794.2472076416 1446.26921463013,3798.04358482361 1486.29722523689,3790.45106649399 PathPoint;PointKind.CORNERPOINT 1383.45692205429,3791.95507764816 1383.45692205429,3791.95507764816 1383.45692205429,3791.95507764816 PathPoint;PointKind.CORNERPOINT 1183.97434282303,3796.53933763504 1183.97434282303,3796.53933763504 1183.97434282303,3796.53933763504 PathPoint;PointKind.SMOOTHPOINT 1166.47569704056,3782.7867937088 1154.66878461838,3783.33746194839 1178.28260946274,3782.23612546921 PathPoint;PointKind.SMOOTHPOINT 1157.14325118065,3796.53933763504 1131.88910531998,3798.40164899826 1182.39775109291,3794.67702627182 PathPoint;PointKind.CORNERPOINT 1106.9808678627,3796.53933763504 1106.9808678627,3796.53933763504 1106.9808678627,3796.53933763504 PathPoint;PointKind.SMOOTHPOINT 1106.9808678627,3779.34848070145 1094.12596273422,3779.74690675735 1119.83577299118,3778.95005464554 PathPoint;PointKind.SMOOTHPOINT 1066.15128445625,3799.9776506424 1061.297945261,3799.26577091217 1071.00426959991,3800.68929433823 PathPoint;PointKind.SMOOTHPOINT 1035.82039284706,3791.95507764816 1025.06147313118,3792.76089906693 1046.57931256294,3791.1492562294 PathPoint;PointKind.CORNERPOINT 990.324409484863,3794.2472076416 990.324409484863,3794.2472076416 990.324409484863,3794.2472076416 PathPoint;PointKind.SMOOTHPOINT 898.16584277153,3793.10126066208 883.387729406357,3793.56672048569 912.943602085114,3792.63556480408 PathPoint;PointKind.SMOOTHPOINT 845.670259475708,3794.2472076416 805.915930747986,3791.1315536499 885.42458820343,3797.36309766769 PathPoint;PointKind.SMOOTHPOINT 789.675230264664,3790.80913066864 763.946655273438,3791.98647022247 815.4034512043,3789.63179111481 PathPoint;PointKind.SMOOTHPOINT 738.346246957779,3794.2472076416 726.753535747528,3795.36199808121 749.93895816803,3793.13265323639 PathPoint;PointKind.SMOOTHPOINT 706.84875535965,3796.53933763504 634.184623241425,3796.35593891144 779.513241529465,3796.72297239304 PathPoint;PointKind.SMOOTHPOINT 627.522434473038,3795.39339065552 621.766971826553,3795.45145511627 633.277897119522,3795.33509016037 PathPoint;PointKind.SMOOTHPOINT 576.193451166153,3790.80913066864 561.606879711151,3790.89410305023 590.780022621155,3790.72415828705 PathPoint;PointKind.CORNERPOINT 548.196113586426,3790.80913066864 548.196113586426,3790.80913066864 548.196113586426,3790.80913066864 PathPoint;PointKind.SMOOTHPOINT 529.530867815018,3797.68552064896 523.543147325516,3797.94964313507 535.51858830452,3797.42139816284 PathPoint;PointKind.SMOOTHPOINT 473.535838603973,3798.83146762848 428.240248441696,3797.28709459305 518.831428766251,3800.3760766983 PathPoint;PointKind.CORNERPOINT 398.875563621521,3795.39339065552 398.875563621521,3795.39339065552 398.875563621521,3795.39339065552 PathPoint;PointKind.SMOOTHPOINT 390.709717750549,3788.5170006752 373.051748752594,3787.52305984497 408.367686748505,3789.51094150543 PathPoint;PointKind.SMOOTHPOINT 353.379580259323,3790.80913066864 347.314322471619,3791.74477100372 359.444838047028,3789.87349033356 PathPoint;PointKind.SMOOTHPOINT 318.382642745972,3794.2472076416 310.134656906128,3799.81195449829 326.630628585815,3788.68269681931 PathPoint;PointKind.CORNERPOINT 288.05175113678,3807.99998760223 288.05175113678,3807.99998760223 288.05175113678,3807.99998760223 PathPoint";

	shadow35mm[1] = "PointKind.CORNERPOINT 284.121023654938,3800.92202425003 284.121023654938,3800.92202425003 284.121023654938,3800.92202425003 PathPoint;PointKind.SMOOTHPOINT 261.906410694122,3791.00008249283 247.474913835526,3767.56045103073 276.337553501129,3814.43971395493 PathPoint;PointKind.SMOOTHPOINT 255.906298398972,3758.99995565414 255.810704469681,3743.5538649559 256.001538276672,3774.44628238678 PathPoint;PointKind.SMOOTHPOINT 240.726336479187,3727.67465114594 238.969178438187,3718.11077356339 243.205759763718,3741.17156982422 PathPoint;PointKind.SMOOTHPOINT 240.859375,3714 236.666342020035,3703.62203979492 245.759094953537,3726.12673902512 PathPoint;PointKind.SMOOTHPOINT 235.906278133392,3694.99993801117 236.440187931061,3691.60670757294 235.190739870071,3699.5469045639 PathPoint;PointKind.SMOOTHPOINT 248.647178649902,3675.67792654037 254.070186853409,3653.83860826492 243.223816394806,3697.51700878143 PathPoint;PointKind.SMOOTHPOINT 260.827261447906,3625.81495285034 266.345863580704,3609.66241121292 255.308659315109,3641.96725845337 PathPoint;PointKind.SMOOTHPOINT 273.63861823082,3586.90208673477 270.877015829086,3573.36032152176 276.400220632553,3600.44361591339 PathPoint;PointKind.SMOOTHPOINT 263.202593564987,3535.33470869064 262.849250078201,3515.89774847031 263.497518539429,3551.53587341309 PathPoint;PointKind.SMOOTHPOINT 259.890794992447,3488.99997711182 261.664947509766,3470.73492765427 258.419356584549,3504.14795637131 PathPoint;PointKind.SMOOTHPOINT 270.144483089447,3458.71888875961 268.602234363556,3445.59773683548 271.686731815338,3471.84027671814 PathPoint;PointKind.SMOOTHPOINT 273.63861823082,3378.60456705093 269.116317272186,3353.71190786362 278.160919189453,3403.49746227264 PathPoint;PointKind.SMOOTHPOINT 268.980007410049,3331.68022155762 271.027133703232,3314.24931764603 266.932527065277,3349.11159753799 PathPoint;PointKind.SMOOTHPOINT 272.474142551422,3306.50172472 272.178155422211,3296.84957027435 272.769421577454,3316.15387916565 PathPoint;PointKind.SMOOTHPOINT 275.968277692795,3271.02221488953 274.944714546204,3257.38698005676 276.991486787796,3284.65792179108 PathPoint;PointKind.SMOOTHPOINT 270.144483089447,3254.99949216843 268.329614639282,3244.38172101974 271.959705591202,3265.6174993515 PathPoint;PointKind.SMOOTHPOINT 277.132753372192,3206.93085193634 276.109190225601,3193.61733198166 278.156316518784,3220.24460792542 PathPoint;PointKind.SMOOTHPOINT 273.63861823082,3190.90789318085 273.410963058472,3180.11569261551 273.865919351578,3201.70032978058 PathPoint;PointKind.SMOOTHPOINT 274.803447961807,3160.00674247742 275.108286380768,3146.95238828659 274.498609542847,3173.06109666824 PathPoint;PointKind.SMOOTHPOINT 270.144483089447,3131.39441728592 276.209386825562,3106.97996377945 264.079933404922,3155.80887079239 PathPoint;PointKind.SMOOTHPOINT 273.63861823082,3100.49326658249 270.804081201553,3086.41499519348 276.473155260086,3114.5713019371 PathPoint;PointKind.SMOOTHPOINT 270.144483089447,3054.71345186234 268.179142713547,3037.52825975418 272.109823465347,3071.89888000488 PathPoint;PointKind.SMOOTHPOINT 271.309312820435,3024.95659589767 274.26210308075,3005.17408132553 268.35652256012,3044.73934650421 PathPoint;PointKind.SMOOTHPOINT 275.968277692795,2967.73194551468 282.141875267029,2937.57737159729 269.794326066971,2997.88675546646 PathPoint;PointKind.SMOOTHPOINT 289.944464206696,2918.51901054382 289.612363815308,2892.90196180344 290.276564598083,2944.13582324982 PathPoint;PointKind.SMOOTHPOINT 272.474142551422,2883.03973674774 273.311120510101,2856.25148534775 271.637164592743,2909.82798814774 PathPoint;PointKind.SMOOTHPOINT 274.803447961807,2852.13858604431 277.523980379105,2832.21704721451 272.08291554451,2872.05965280533 PathPoint;PointKind.SMOOTHPOINT 275.968277692795,2793.76916885376 278.170124530792,2770.76785326004 273.766076803207,2816.77095651627 PathPoint;PointKind.SMOOTHPOINT 272.474142551422,2754.85653877258 272.506007194519,2734.17072057724 272.442277908325,2775.54235696793 PathPoint;PointKind.SMOOTHPOINT 273.63861823082,2731.9668674469 273.957264661789,2721.38473749161 273.32032585144,2742.54899740219 PathPoint;PointKind.SMOOTHPOINT 271.309312820435,2688.47611427307 270.890823841095,2672.75291919708 271.727801799774,2704.19954538345 PathPoint;PointKind.SMOOTHPOINT 268.980007410049,2657.57496356964 273.720404148102,2624.2325091362 264.239256620407,2690.9169459343 PathPoint;PointKind.SMOOTHPOINT 270.144483089447,2590.04977226257 273.538775682449,2568.45663785934 266.750544548035,2611.6431427002 PathPoint;PointKind.SMOOTHPOINT 270.144483089447,2543.12566280365 279.211744308472,2509.50634002686 261.077221870422,2576.74522161484 PathPoint;PointKind.SMOOTHPOINT 274.803447961807,2488.19007396698 272.532915115356,2468.88552904129 277.073626756668,2507.49438285828 PathPoint;PointKind.SMOOTHPOINT 273.63861823082,2433.25448513031 279.052775144577,2411.5761423111 268.224815368652,2454.93259191513 PathPoint;PointKind.SMOOTHPOINT 267.815177679062,2400.06427288055 268.379181861877,2388.04280519485 267.250819444656,2412.08574056625 PathPoint;PointKind.SMOOTHPOINT 274.803447961807,2371.45194768906 270.22202038765,2360.61962127686 279.384521484375,2382.28427410126 PathPoint;PointKind.SMOOTHPOINT 270.144483089447,2334.82814311981 272.678784370422,2316.56993865967 267.610535860062,2353.08634757996 PathPoint;PointKind.SMOOTHPOINT 271.309312820435,2305.07152318954 279.016307830811,2290.10363817215 263.602317810059,2320.03917217255 PathPoint;PointKind.SMOOTHPOINT 266.650347948074,2259.29194450378 266.127413749695,2240.77433824539 267.173636198044,2277.80931472778 PathPoint;PointKind.SMOOTHPOINT 273.63861823082,2235.25750637054 275.622015237808,2217.05736637115 271.654867172241,2253.45741033554 PathPoint;PointKind.SMOOTHPOINT 278.29722905159,2205.50065040588 274.766980648041,2198.00325393677 281.827831506729,2212.99781084061 PathPoint;PointKind.SMOOTHPOINT 272.474142551422,2175.74379444122 273.279255867004,2157.57056236267 271.66867518425,2193.91726255417 PathPoint;PointKind.SMOOTHPOINT 272.474142551422,2144.84264373779 279.730783939362,2121.8722486496 265.217501163483,2167.8128027916 PathPoint;PointKind.SMOOTHPOINT 271.309312820435,2096.77376747131 275.649631261826,2079.62893724442 266.968994379044,2113.9188337326 PathPoint;PointKind.SMOOTHPOINT 272.474142551422,2045.27177095413 274.198373794556,2027.42048978806 270.749911308289,2063.1232881546 PathPoint;PointKind.SMOOTHPOINT 277.132753372192,2015.51491498947 273.192513227463,1997.49368906021 281.072639465332,2033.53614091873 PathPoint;PointKind.SMOOTHPOINT 266.650347948074,1985.7582950592 269.612343549728,1969.92298364639 263.68870639801,2001.59337043762 PathPoint;PointKind.SMOOTHPOINT 271.309312820435,1942.26754188538 275.353998184204,1917.89345026016 267.264627456665,1966.64186954498 PathPoint;PointKind.SMOOTHPOINT 277.132753372192,1906.78826808929 277.851478099823,1877.83180475235 276.414028644562,1935.74496746063 PathPoint;PointKind.SMOOTHPOINT 271.309312820435,1858.71962785721 273.807146787643,1830.93885183334 268.811478853226,1886.50016784668 PathPoint;PointKind.SMOOTHPOINT 272.474142551422,1824.38488483429 276.796050310135,1805.59465885162 268.151880741119,1843.17511081696 PathPoint;PointKind.SMOOTHPOINT 271.309312820435,1777.46077537537 272.59664440155,1756.78841114044 270.021981239319,1798.13313961029 PathPoint;PointKind.SMOOTHPOINT 275.968277692795,1743.12579631805 271.418714761734,1708.50049495697 280.517486572266,1777.75133371353 PathPoint;PointKind.SMOOTHPOINT 272.474142551422,1685.90138196945 274.935509204865,1671.33593559265 270.01277589798,1700.46682834625 PathPoint;PointKind.SMOOTHPOINT 272.474142551422,1651.56663894653 274.712456703186,1629.71835136414 270.235474348068,1673.41492652893 PathPoint;PointKind.SMOOTHPOINT 273.63861823082,1610.36494731903 275.403919458389,1586.55875444412 271.87331700325,1634.17137622833 PathPoint;PointKind.SMOOTHPOINT 274.803447961807,1571.45208120346 273.893181324005,1550.96760034561 275.713360548019,1591.9370341301 PathPoint;PointKind.SMOOTHPOINT 268.980007410049,1525.6725025177 275.244596242905,1501.33853673935 262.715064525604,1550.00646829605 PathPoint;PointKind.SMOOTHPOINT 273.63861823082,1495.91588258743 273.675085544586,1469.14084911346 273.602504968643,1522.69044399261 PathPoint;PointKind.SMOOTHPOINT 278.29722905159,1463.87020111084 277.396521806717,1452.59058952332 279.198290348053,1475.14957666397 PathPoint;PointKind.SMOOTHPOINT 272.474142551422,1420.37944793701 263.051767587662,1401.00338459015 281.896163463593,1439.75527524948 PathPoint;PointKind.SMOOTHPOINT 272.474142551422,1391.76712274551 273.643220901489,1373.49546432495 271.304710149765,1410.03878116608 PathPoint;PointKind.SMOOTHPOINT 274.803447961807,1359.72120523453 267.93803358078,1344.14529561996 281.668862342834,1375.29711484909 PathPoint;PointKind.SMOOTHPOINT 271.309312820435,1304.78585243225 273.152151346207,1296.74298048019 269.466474294662,1312.82848834991 PathPoint;PointKind.SMOOTHPOINT 272.474142551422,1287.6181268692 274.603054761887,1268.45237016678 270.344522237778,1306.78411960602 PathPoint;PointKind.SMOOTHPOINT 271.309312820435,1259.0060377121 276.218238115311,1238.24870109558 266.400033473969,1279.76337432861 PathPoint;PointKind.SMOOTHPOINT 277.132753372192,1229.24918174744 269.553216934204,1214.48711872101 284.712289810181,1244.01124477386 PathPoint;PointKind.SMOOTHPOINT 270.144483089447,1205.2147436142 272.373945951462,1186.92089796066 267.915020227432,1223.50882530212 PathPoint;PointKind.SMOOTHPOINT 279.462058782578,1175.45812368393 276.727718353271,1161.96096897125 282.196753263474,1188.95504236221 PathPoint;PointKind.SMOOTHPOINT 271.309312820435,1139.97884988785 274.480552911758,1123.24967622757 268.138072729111,1156.70825958252 PathPoint;PointKind.SMOOTHPOINT 275.968277692795,1110.22222995758 280.144670248032,1099.84120130539 271.791531085968,1120.60302257538 PathPoint;PointKind.SMOOTHPOINT 281.791364192963,1082.75419950485 279.95348238945,1056.09128236771 283.629600048065,1109.41735267639 PathPoint;PointKind.SMOOTHPOINT 277.132753372192,1034.68579530716 275.754430532455,1016.1457657814 278.511076211929,1053.22535276413 PathPoint;PointKind.SMOOTHPOINT 277.132753372192,998.061754703522 279.466661453247,974.367442131042 274.798845291138,1021.75653934479 PathPoint;PointKind.SMOOTHPOINT 273.63861823082,953.426706790924 272.178155422211,923.01721572876 275.099081039429,983.836197853088 PathPoint;PointKind.SMOOTHPOINT 272.474142551422,916.803138256073 276.687002420425,899.219992160797 268.261282682419,934.386284351349 PathPoint;PointKind.SMOOTHPOINT 279.462058782578,885.90175151825 280.322050094604,854.468343257904 278.602421522141,917.335159778595 PathPoint;PointKind.SMOOTHPOINT 280.626888513565,820.665857791901 272.628509044647,797.065014839172 288.624913930893,844.266464710236 PathPoint;PointKind.CORNERPOINT 274.803447961807,777.175104618073 274.803447961807,777.175104618073 274.803447961807,777.175104618073 PathPoint;PointKind.SMOOTHPOINT 275.968277692795,746.273717880249 285.158040761948,710.199873447418 266.778160572052,782.34756231308 PathPoint;PointKind.SMOOTHPOINT 284.121023654938,700.494139194489 283.238373041153,685.28927564621 285.003674268723,715.699002742767 PathPoint;PointKind.SMOOTHPOINT 281.791364192963,662.725803852081 282.460167646408,622.109949588776 281.122914791107,703.34189414978 PathPoint;PointKind.SMOOTHPOINT 279.890461206436,602.999897003174 274.885941982269,582.153103351593 284.895334482193,623.846690654755 PathPoint;PointKind.SMOOTHPOINT 279.462058782578,555.143687725067 279.161823034286,538.798778057098 279.762648582458,571.488361358643 PathPoint;PointKind.SMOOTHPOINT 280.626888513565,526.531362533569 286.245333194733,508.532559871674 275.008089780807,544.530401229858 PathPoint;PointKind.SMOOTHPOINT 278.859375,469 278.768737792969,448.823780059814 278.950366258621,489.175983905792 PathPoint;PointKind.SMOOTHPOINT 277.859375,414 280.457756771887,382.934291543824 276.969086408615,424.644104003906 PathPoint;PointKind.SMOOTHPOINT 282.95619392395,376.60302400589 288.374953508377,356.927433013916 277.537788391113,396.27837896347 PathPoint;PointKind.SMOOTHPOINT 284.890731811523,342.999987602234 283.170749187469,327.553896903992 286.610360383987,358.446078300476 PathPoint;PointKind.SMOOTHPOINT 278.890619516373,308.99994134903 282.193566799164,270.140891075134 275.587672233582,347.858991622925 PathPoint;PointKind.SMOOTHPOINT 271.890665531158,271.000056266785 274.483031272888,266.637668609619 268.551250934601,276.619563102722 PathPoint;PointKind.SMOOTHPOINT 285.455798149109,227.400255203247 288.157211780548,223.198370933533 276.083344459534,241.9779753685 PathPoint;PointKind.SMOOTHPOINT 291.108939886093,210.651726722717 315.249593496323,186.354582309723 286.824207544327,214.964547157288 PathPoint;PointKind.SMOOTHPOINT 341.213258743286,181.463005542755 356.317807674408,178.4410572052 326.108355760574,184.485425949097 PathPoint;PointKind.SMOOTHPOINT 418.875537157059,183.460328578949 432.374108076096,181.434917449951 405.376966238022,185.485503673553 PathPoint;PointKind.SMOOTHPOINT 446.754267454147,181.463005542755 459.074554681778,183.470478057861 434.433980226517,179.455769062042 PathPoint;PointKind.SMOOTHPOINT 479.611317157745,181.463005542755 496.599420547485,178.503370285034 462.623213768005,184.422640800476 PathPoint;PointKind.SMOOTHPOINT 510.477180719376,181.463005542755 529.658279657364,183.354113101959 491.296081781387,179.571897983551 PathPoint;PointKind.SMOOTHPOINT 550.304090023041,182.461667060852 559.84436416626,180.691409111023 540.763461828232,184.232161045074 PathPoint;PointKind.SMOOTHPOINT 575.195687055588,182.461667060852 584.758974552155,181.093611717224 565.632399559021,183.829958438873 PathPoint;PointKind.SMOOTHPOINT 598.588937759399,179.750339984894 611.882512807846,177.845778465271 585.294654607773,181.654901504517 PathPoint;PointKind.SMOOTHPOINT 638.188191890717,178.605809211731 666.454962730408,160.656101703644 609.921775102615,196.555752754211 PathPoint;PointKind.SMOOTHPOINT 681.890549898148,169.999995231628 689.206317901611,169.101176261902 674.574781894684,170.898578166962 PathPoint;PointKind.SMOOTHPOINT 709.235016345978,163.727381229401 733.13810133934,162.918255329132 685.331223249435,164.536507129669 PathPoint;PointKind.SMOOTHPOINT 739.516694784164,179.750339984894 736.270398268201,177.092661348396 730.927049160004,172.717931270599 PathPoint;PointKind.SMOOTHPOINT 766.304946184158,179.750339984894 790.681398153305,186.55473947525 764.891923776172,179.355936559624 PathPoint;PointKind.SMOOTHPOINT 795.422148942947,175.172452926636 806.204790115356,174.197630882263 784.639861822128,176.147038936615 PathPoint;PointKind.SMOOTHPOINT 823.374876022339,185.472757816315 830.417670249939,187.422165870667 816.332081794739,183.523585796356 PathPoint;PointKind.SMOOTHPOINT 845.504162549973,186.617288589478 863.301981925964,185.490696430206 827.705989122391,187.743880748749 PathPoint;PointKind.CORNERPOINT 866.468265295029,180.894870758057 866.468265295029,180.894870758057 866.468265295029,180.894870758057 PathPoint;PointKind.SMOOTHPOINT 966.859375,185 984.616124391556,185.733122825623 923.768820484786,183.220955957993 PathPoint;PointKind.SMOOTHPOINT 1031.859375,185 1085.45682456854,185.349705988677 1015.43527579308,184.892604351044 PathPoint;PointKind.SMOOTHPOINT 1085.4311170578,174.02768611908 1093.4606050398,167.496825560049 1083.0451795578,175.96831111908 PathPoint;PointKind.CORNERPOINT 1108.72523331642,174.02768611908 1108.72523331642,174.02768611908 1108.72523331642,174.02768611908 PathPoint;PointKind.SMOOTHPOINT 1126.19555497169,177.461278438568 1137.10565471649,176.643183231354 1115.28580927849,178.279609680176 PathPoint;PointKind.SMOOTHPOINT 1148.32484149933,184.328463077545 1157.8881289959,183.438613414764 1138.76155400276,185.217840671539 PathPoint;PointKind.SMOOTHPOINT 1172.78343343735,180.894870758057 1193.54785108566,176.643183231354 1152.01901578903,185.14655828476 PathPoint;PointKind.SMOOTHPOINT 1207.72443079948,175.172452926636 1217.99263501167,176.576385498047 1197.45587253571,173.768520355225 PathPoint;PointKind.SMOOTHPOINT 1225.19475245476,183.183696269989 1237.11460733414,180.492432117462 1213.27454352379,185.875196456909 PathPoint;PointKind.SMOOTHPOINT 1244.99473357201,175.172452926636 1263.81341462195,174.21482850457 1221.00915455818,176.392986774445 PathPoint;PointKind.SMOOTHPOINT 1292.74708771706,176.316747665405 1312.9882171154,175.127606391907 1264.18462631506,177.995089954539 PathPoint;PointKind.SMOOTHPOINT 1320.69981479645,179.750339984894 1333.89354729652,175.239250659943 1307.50608229637,184.261193275452 PathPoint;PointKind.SMOOTHPOINT 1356.80528783798,179.750339984894 1362.03285956383,181.923272609711 1351.57771611214,177.57764339447 PathPoint;PointKind.SMOOTHPOINT 1371.94630408287,185.472757816315 1392.18743348122,186.433889865875 1351.70517468452,184.511625766754 PathPoint;PointKind.SMOOTHPOINT 1391.74628520012,183.183696269989 1406.20929265022,175.203845500946 1377.28292369843,191.164019107819 PathPoint;PointKind.SMOOTHPOINT 1413.87521767616,176.316747665405 1414.75786828995,183.988573551178 1412.99256706238,168.645393848419 PathPoint;PointKind.SMOOTHPOINT 1428.89054560661,175.999989509583 1433.39018726349,162.377972602844 1424.39125800133,189.622242450714 PathPoint;PointKind.SMOOTHPOINT 1439.49863934517,171.739096641541 1445.83651685715,173.267891407013 1433.16111588478,170.210065841675 PathPoint;PointKind.SMOOTHPOINT 1462.79275560379,179.750339984894 1467.97005200386,182.472996711731 1457.61510515213,177.027683258057 PathPoint;PointKind.SMOOTHPOINT 1476.76894211769,179.750339984894 1494.29874444008,176.674575805664 1459.23949384689,182.826104164124 PathPoint;PointKind.SMOOTHPOINT 1494.23926377296,172.88339138031 1505.30408406258,170.116124153137 1483.17479753494,175.650658607483 PathPoint;PointKind.SMOOTHPOINT 1511.70993947983,177.461278438568 1531.12294220924,180.707223415375 1492.29658269882,174.215569496155 PathPoint;PointKind.SMOOTHPOINT 1539.66231250763,179.750339984894 1562.57865571976,178.864974975586 1516.74632334709,180.635468959808 PathPoint;PointKind.SMOOTHPOINT 1592.07363152504,175.172452926636 1606.88254737854,169.923756122589 1577.26471567154,180.420913696289 PathPoint;PointKind.SMOOTHPOINT 1615.36774778366,177.461278438568 1637.06898593903,173.316986560822 1593.66615557671,181.605570316315 PathPoint;PointKind.SMOOTHPOINT 1646.81461000443,175.172452926636 1667.76065611839,172.08771944046 1625.86820983887,178.257186412811 PathPoint;PointKind.SMOOTHPOINT 1674.76698303223,179.750339984894 1685.92704319954,174.184176921844 1663.60692286491,185.31626701355 PathPoint;PointKind.SMOOTHPOINT 1691.0728290081,182.039401531219 1701.04115152359,178.637201786041 1681.10450649261,185.441365242004 PathPoint;PointKind.SMOOTHPOINT 1712.03728580475,175.172452926636 1734.99930167198,170.12060880661 1689.07562398911,180.224061012268 PathPoint;PointKind.SMOOTHPOINT 1748.14275884628,174.02768611908 1765.07208967209,174.841532707214 1731.21378207207,173.214311599731 PathPoint;PointKind.SMOOTHPOINT 1773.76618051529,182.039401531219 1787.36919665337,174.506363868713 1760.16316437721,189.572439193726 PathPoint;PointKind.SMOOTHPOINT 1802.88373732567,175.172452926636 1819.30783653259,174.738621711731 1786.45928406715,175.606048107147 PathPoint;PointKind.SMOOTHPOINT 1825.0130238533,176.316747665405 1843.64782118797,174.305026531219 1806.37751841545,178.328468799591 PathPoint;PointKind.SMOOTHPOINT 1852.9653968811,174.02768611908 1865.02191567421,174.036655426025 1840.90923213959,174.018952846527 PathPoint;PointKind.SMOOTHPOINT 1894.89466452599,183.183696269989 1923.19294595718,182.759070396423 1866.5960290432,183.608558177948 PathPoint;PointKind.CORNERPOINT 1928.67047810555,185.472757816315 1928.67047810555,185.472757816315 1928.67047810555,185.472757816315 PathPoint;PointKind.SMOOTHPOINT 1970.59974575043,176.316747665405 2011.5096988678,172.489922046661 1929.68979263306,180.143809318542 PathPoint;PointKind.SMOOTHPOINT 2033.49311614037,172.88339138031 2076.44594693184,176.866707801819 1990.54063940048,168.900074958801 PathPoint;PointKind.SMOOTHPOINT 2099.88097572327,188.906350135803 2106.11405396461,186.724684238434 2093.64789748192,191.087779998779 PathPoint;PointKind.SMOOTHPOINT 2137.15127849579,178.605809211731 2160.16746425629,174.787952899933 2114.1347386837,182.423901557922 PathPoint;PointKind.SMOOTHPOINT 2187.23329210281,169.450035095215 2204.92170953751,170.259160995483 2169.54416656494,168.640909194946 PathPoint;PointKind.SMOOTHPOINT 2223.33876514435,182.039401531219 2235.68171167374,180.487947463989 2210.99546456337,183.590619564056 PathPoint;PointKind.SMOOTHPOINT 2269.92664361,177.461278438568 2290.14936232567,176.240980625153 2249.70321679115,178.681812286377 PathPoint;PointKind.SMOOTHPOINT 2302.53798151016,176.316747665405 2332.6380314827,178.641686439514 2272.43757748604,173.992280960083 PathPoint;PointKind.SMOOTHPOINT 2351.4551653862,177.461278438568 2379.43515443802,170.026667118073 2323.47517633438,184.896125793457 PathPoint;PointKind.SMOOTHPOINT 2385.23133301735,172.88339138031 2414.28940916061,173.151526451111 2356.17290282249,172.615256309509 PathPoint;PointKind.SMOOTHPOINT 2417.84267091751,182.039401531219 2433.49812412262,177.448060512543 2402.18757176399,186.630742549896 PathPoint;PointKind.SMOOTHPOINT 2437.64265203476,175.172452926636 2456.43712663651,172.342400550842 2418.84817743301,178.002269268036 PathPoint;PointKind.SMOOTHPOINT 2464.43054938316,179.750339984894 2480.17203712463,179.016981124878 2448.68906164169,180.483462810516 PathPoint;PointKind.SMOOTHPOINT 2534.31219005585,177.461278438568 2559.97207903862,177.336180210114 2508.65265512466,177.586612701416 PathPoint;PointKind.SMOOTHPOINT 2564.59422254562,180.894870758057 2573.76628303528,180.085508823395 2555.42251610756,181.703996658325 PathPoint;PointKind.SMOOTHPOINT 2584.39420366287,176.316747665405 2602.89729380608,176.008486747742 2565.89075946808,176.625244617462 PathPoint;PointKind.SMOOTHPOINT 2614.67623615265,180.894870758057 2621.90101289749,182.428386211395 2607.45145940781,179.361355304718 PathPoint;PointKind.SMOOTHPOINT 2643.79379296303,178.605809211731 2661.34129786491,176.37056350708 2626.24557995796,180.841290950775 PathPoint;PointKind.SMOOTHPOINT 2669.41721463203,182.039401531219 2685.25394225121,183.416426181793 2653.57977890968,180.662376880646 PathPoint;PointKind.SMOOTHPOINT 2691.54614710808,180.894870758057 2702.3284342289,175.516591072083 2680.76350593567,186.272914409637 PathPoint;PointKind.SMOOTHPOINT 2734.63989043236,174.02768611908 2775.70881271362,174.255931377411 2693.5706140995,173.799912929535 PathPoint;PointKind.SMOOTHPOINT 2794.03912568092,176.316747665405 2808.85264420509,177.050106525421 2779.22560715675,175.583624839783 PathPoint;PointKind.SMOOTHPOINT 2827.81529331207,178.605809211731 2856.22757935524,173.030912876129 2799.4033613205,184.180705547333 PathPoint;PointKind.SMOOTHPOINT 2909.34416913986,176.316747665405 2922.71988415718,175.628471374512 2895.96845412254,177.005259990692 PathPoint;PointKind.SMOOTHPOINT 2948.94377732277,177.461278438568 2977.86979222298,172.972612380981 2920.01740837097,181.949708461761 PathPoint;PointKind.SMOOTHPOINT 2997.89070153236,171.000072956085 3007.72696280479,172.573714256287 2988.05444025993,169.426431655884 PathPoint;PointKind.SMOOTHPOINT 3035.13126397133,179.750339984894 3055.54977321625,175.731146335602 3014.71240067482,183.769533634186 PathPoint;PointKind.SMOOTHPOINT 3070.07190728188,176.316747665405 3089.63042521477,174.381029605865 3050.51338934898,178.252701759338 PathPoint;PointKind.SMOOTHPOINT 3103.84807491302,177.461278438568 3124.31685948372,178.252701759338 3083.37964439392,176.670091152191 PathPoint;PointKind.SMOOTHPOINT 3142.28320741653,179.750339984894 3160.35895729065,176.486692428589 3124.20781159401,183.013987541199 PathPoint;PointKind.SMOOTHPOINT 3181.88281559944,176.316747665405 3212.5288131237,173.969857692719 3151.23681807518,178.663873672485 PathPoint;PointKind.SMOOTHPOINT 3219.15311837196,178.605809211731 3241.80533909798,179.106674194336 3196.50089764595,178.105180263519 PathPoint;PointKind.SMOOTHPOINT 3258.75237250328,176.316747665405 3275.32234096527,173.01745891571 3242.18311214447,179.616272449493 PathPoint;PointKind.SMOOTHPOINT 3283.2109644413,175.172452926636 3312.3876478672,173.26340675354 3254.03498911858,177.081499099731 PathPoint;PointKind.SMOOTHPOINT 3322.8109266758,174.02768611908 3346.86483764648,176.491177082062 3298.7573697567,171.564667224884 PathPoint;PointKind.SMOOTHPOINT 3365.90467000008,175.172452926636 3385.18596553802,170.482685565948 3346.62337446213,179.862220287323 PathPoint;PointKind.SMOOTHPOINT 3396.18670248985,174.02768611908 3417.54238629341,170.080246925354 3374.83101868629,177.975361347198 PathPoint;PointKind.SMOOTHPOINT 3452.09180259705,171.739096641541 3470.62250876427,170.241222381592 3433.56145048141,173.236498832703 PathPoint;PointKind.SMOOTHPOINT 3490.52693510056,169.450035095215 3521.9780459404,165.104405879974 3459.07582426071,173.795428276062 PathPoint;PointKind.SMOOTHPOINT 3523.13862705231,171.739096641541 3542.78353357315,169.034142494202 3503.49336647987,174.443578720093 PathPoint;PointKind.SMOOTHPOINT 3580.20855689049,166.016442775726 3603.78449821472,166.159479618073 3556.63261556625,165.87340593338 PathPoint;PointKind.SMOOTHPOINT 3639.60814619064,168.305504322052 3653.87996578217,168.019194602966 3625.33597254753,168.591578006744 PathPoint;PointKind.SMOOTHPOINT 3702.89061927795,162.000081539154 3720.87962651253,160.336747169495 3684.90161204338,163.662943840027 PathPoint;PointKind.SMOOTHPOINT 3746.76008963585,164.871912002563 3786.48255372047,163.722896575928 3707.03762555122,166.020927429199 PathPoint;PointKind.SMOOTHPOINT 3799.17140865326,166.016442775726 3843.99858856201,164.483163356781 3754.34387469292,167.549958229065 PathPoint;PointKind.SMOOTHPOINT 3856.24133849144,164.871912002563 3864.73999285698,161.831789016724 3847.7426841259,167.912034988403 PathPoint;PointKind.SMOOTHPOINT 3884.19371151924,164.871912002563 3905.99585437775,160.039343833923 3862.39227676392,169.704716205597 PathPoint;PointKind.SMOOTHPOINT 3943.59365487099,167.160973548889 3962.27872753143,168.53776216507 3924.90858221054,165.783948898315 PathPoint;PointKind.SMOOTHPOINT 3972.71085762978,164.871912002563 3988.70265984535,163.163967132568 3956.7190554142,166.579856872559 PathPoint;PointKind.SMOOTHPOINT 4002.99324417114,167.160973548889 4030.2768137455,166.870415210724 3975.70896649361,167.451531887054 PathPoint;PointKind.SMOOTHPOINT 4041.42766857147,162.583086490631 4054.08961558342,157.446269989014 4028.7664296627,167.719666957855 PathPoint;PointKind.SMOOTHPOINT 4076.3690199852,159.149494171143 4100.12234115601,161.769239902496 4052.6153447628,156.529748439789 PathPoint;PointKind.SMOOTHPOINT 4108.98035788536,160.294024944305 4124.16669273376,160.253663063049 4093.79366898537,160.334150791168 PathPoint;PointKind.SMOOTHPOINT 4147.41513633728,160.294024944305 4162.76539707184,156.981046199799 4132.06487560272,163.606767654419 PathPoint;PointKind.SMOOTHPOINT 4176.53233909607,158.00496339798 4210.27203941345,157.213776111603 4142.79263877869,158.79638671875 PathPoint;PointKind.SMOOTHPOINT 4212.89060497284,159.99992609024 4226.83032417297,165.847678184509 4198.95053172112,154.152410030365 PathPoint;PointKind.SMOOTHPOINT 4265.0494852066,160.294024944305 4287.72436523438,153.212521076202 4242.37425112724,167.375528812408 PathPoint;PointKind.SMOOTHPOINT 4298.82565283775,159.149494171143 4322.91532301903,157.499849796295 4274.73562860489,160.79913854599 PathPoint;PointKind.SMOOTHPOINT 4421.11861252785,156.860432624817 4433.75754618645,158.125813007355 4408.47967886925,155.595288276672 PathPoint;PointKind.SMOOTHPOINT 4450.23581528664,160.294024944305 4468.94390130043,156.029119491577 4431.52808332443,164.558930397034 PathPoint;PointKind.SMOOTHPOINT 4486.34128832817,156.860432624817 4501.31873273849,158.139266967773 4471.36419796944,155.581834316254 PathPoint;PointKind.SMOOTHPOINT 4527.10572624207,158.00496339798 4572.93380999565,157.839503288269 4481.27764248848,158.17042350769 PathPoint;PointKind.SMOOTHPOINT 4598.15219664574,161.438319683075 4634.59472680092,159.444537162781 4561.71002054214,163.432338237762 PathPoint;PointKind.SMOOTHPOINT 4659.88109135628,156.860432624817 4670.426872015,154.665548801422 4649.33531069756,159.055552482605 PathPoint;PointKind.SMOOTHPOINT 4700.64552927017,162.583086490631 4725.64546608925,164.840755462646 4675.6455924511,160.325417518616 PathPoint;PointKind.SMOOTHPOINT 4767.03303480148,163.727381229401 4799.13028979301,157.285294532776 4734.93577980995,170.169703960419 PathPoint;PointKind.SMOOTHPOINT 4819.44435381889,162.583086490631 4847.78370523453,164.572384357452 4791.10500240326,160.593552589417 PathPoint;PointKind.SMOOTHPOINT 4856.71465659142,164.871912002563 4882.1058204174,158.572862148285 4831.32313871384,171.171197891235 PathPoint;PointKind.SMOOTHPOINT 4981.33692169189,166.016442775726 5007.66561412811,167.084970474243 4955.00822925568,164.947915077209 PathPoint;PointKind.SMOOTHPOINT 5025.59549474716,168.305504322052 5049.99920868874,173.804397583008 5001.191426754,162.806375026703 PathPoint;PointKind.SMOOTHPOINT 5065.19510293007,171.739096641541 5090.19964241982,165.001730918884 5040.19056344032,178.476226329803 PathPoint;PointKind.SMOOTHPOINT 5109.45367598534,163.727381229401 5123.48438644409,163.821558952332 5095.4222574234,163.633675575256 PathPoint;PointKind.SMOOTHPOINT 5129.25330305099,166.016442775726 5161.80551433563,167.210068702698 5096.70109176636,164.822816848755 PathPoint;PointKind.SMOOTHPOINT 5209.61699509621,170.594329833984 5239.6444644928,163.3922123909 5179.5902338028,177.796683311462 PathPoint;PointKind.SMOOTHPOINT 5245.72282218933,162.583086490631 5255.51341080666,165.028638839722 5235.93187952042,160.137534141541 PathPoint;PointKind.SMOOTHPOINT 5284.15760064125,166.016442775726 5314.27606129646,166.526041030884 5254.03949403763,165.506844520569 PathPoint;PointKind.SMOOTHPOINT 5340.06305480003,166.016442775726 5362.66535425186,159.824552536011 5317.46075534821,172.208333015442 PathPoint;PointKind.SMOOTHPOINT 5390.14506840706,159.149494171143 5411.76027202606,153.431560993195 5368.52986478806,164.867663383484 PathPoint;PointKind.SMOOTHPOINT 5413.43883061409,158.00496339798 5433.89380717278,163.083715438843 5392.98420810699,152.92644739151 PathPoint;PointKind.SMOOTHPOINT 5443.72121715546,162.583086490631 5465.27233743668,157.227230072021 5422.16938877106,167.938942909241 PathPoint;PointKind.SMOOTHPOINT 5470.50911450386,159.149494171143 5486.79194712639,165.242958068848 5454.22592782974,153.056030273438 PathPoint;PointKind.SMOOTHPOINT 5510.10836863518,176.316747665405 5535.79091691971,175.069541931152 5484.42617440224,177.564189434052 PathPoint;PointKind.SMOOTHPOINT 5552.03763628006,172.88339138031 5569.22117614746,169.999759197235 5534.85374236107,175.767023563385 PathPoint;PointKind.SMOOTHPOINT 5579.99036335945,172.88339138031 5596.13228344917,177.407698631287 5563.84844326973,168.359084129333 PathPoint;PointKind.SMOOTHPOINT 5620.75480127335,170.594329833984 5646.66004800797,168.528792858124 5594.84920048714,172.659866809845 PathPoint;PointKind.SMOOTHPOINT 5647.54269862175,169.450035095215 5658.98954057693,176.969618797302 5636.09585666656,161.930451393127 PathPoint;PointKind.SMOOTHPOINT 5659.18957972527,186.617288589478 5669.44432997704,195.683841705322 5648.9348294735,177.550735473633 PathPoint;PointKind.SMOOTHPOINT 5674.18012404442,222.94935464859 5673.61126532185,230.004743356687 5675.25012110574,209.680877417059 PathPoint;PointKind.SMOOTHPOINT 5673.01564836502,264.150810241699 5663.40208554268,279.056146144867 5675.30929136646,260.59455979349 PathPoint;PointKind.SMOOTHPOINT 5670.68598890305,290.474309921265 5681.09545969963,302.299160957336 5660.27651810646,278.6492228508 PathPoint;PointKind.SMOOTHPOINT 5682.01705598831,308.289241790771 5679.07347106934,318.111340999603 5684.96064090729,298.46714258194 PathPoint;PointKind.SMOOTHPOINT 5674.18012404442,329.386940002441 5668.55707669258,335.92768907547 5679.80352544785,322.846426963806 PathPoint;PointKind.SMOOTHPOINT 5672.00129055977,353.713116645813 5672.0742251873,363.012163639069 5671.92835593224,344.414069652557 PathPoint;PointKind.SMOOTHPOINT 5677.82473111153,375.458493232727 5682.58353853226,393.698759078979 5673.0659236908,357.217991352081 PathPoint;PointKind.SMOOTHPOINT 5683.64817166328,401.781756877899 5677.16973567009,411.000080108643 5690.12696170807,392.563197612762 PathPoint;PointKind.SMOOTHPOINT 5684.81300139427,422.38260269165 5683.19321537018,445.384154319763 5686.43278741837,399.381051063538 PathPoint;PointKind.SMOOTHPOINT 5681.3188662529,483.040609359741 5675.06312870979,501.897869110107 5687.57460379601,464.183349609375 PathPoint;PointKind.SMOOTHPOINT 5678.98920679092,516.230821609497 5674.20774006844,536.326553821564 5683.771027565,496.13508939743 PathPoint;PointKind.SMOOTHPOINT 5673.16612029076,566.588523387909 5668.32977557182,589.380004405975 5678.0021109581,543.797042369843 PathPoint;PointKind.SMOOTHPOINT 5667.34232568741,611.2238073349 5666.53260970116,625.391299724579 5668.15239572525,597.056078910828 PathPoint;PointKind.SMOOTHPOINT 5673.16612029076,637.547070980072 5673.67099785805,658.058459758759 5672.66088867188,617.035682201385 PathPoint;PointKind.SMOOTHPOINT 5672.00129055977,698.205077648163 5667.62450480461,730.461065769196 5676.37772226334,665.94908952713 PathPoint;PointKind.SMOOTHPOINT 5667.34232568741,749.707074165344 5667.82029533386,763.181805610657 5666.86471009254,736.232578754425 PathPoint;PointKind.SMOOTHPOINT 5668.5071554184,780.608460903168 5668.48909878731,796.608996391296 5668.52556610107,764.607925415039 PathPoint;PointKind.SMOOTHPOINT 5663.84854459763,816.087734699249 5660.40893340111,829.82611656189 5667.28815579414,802.349352836609 PathPoint;PointKind.SMOOTHPOINT 5668.5071554184,838.977406024933 5671.07756996155,853.565511703491 5665.93674087524,824.389772415161 PathPoint;PointKind.SMOOTHPOINT 5670.83646082878,868.734498023987 5672.73272651596,883.262404823804 5668.15746603448,848.209849525609 PathPoint;PointKind.SMOOTHPOINT 5668.5071554184,931.68133020401 5665.60888910294,943.600122928619 5663.50514918404,952.251108264422 PathPoint;PointKind.SMOOTHPOINT 5666.17785000801,1002.63987779617 5664.36262750626,1018.32743167877 5667.99307250977,986.952323913574 PathPoint;PointKind.SMOOTHPOINT 5666.17785000801,1024.38525438309 5667.05589795113,1034.71695184708 5665.2998020649,1014.0533208847 PathPoint;PointKind.SMOOTHPOINT 5670.83646082878,1049.5639872551 5668.68453526497,1056.91834688187 5672.98874044418,1042.20962762833 PathPoint;PointKind.SMOOTHPOINT 5663.84854459763,1072.45389461517 5663.26612973213,1085.48134088516 5664.43060541153,1059.42621231079 PathPoint;PointKind.SMOOTHPOINT 5666.17785000801,1093.05474042892 5668.05680179596,1099.33160305023 5664.29889822006,1086.77811384201 PathPoint;PointKind.SMOOTHPOINT 5668.5071554184,1107.93316841125 5667.13308119774,1116.64189338684 5669.88122963905,1099.22420740128 PathPoint;PointKind.SMOOTHPOINT 5668.5071554184,1125.10042190552 5669.12143492699,1136.53652429581 5667.8932299614,1113.66455554962 PathPoint;PointKind.SMOOTHPOINT 5665.01302027702,1147.99032926559 5662.22875857353,1156.99858188629 5667.79728198051,1138.9820766449 PathPoint;PointKind.SMOOTHPOINT 5672.00129055977,1169.73570585251 5672.23779702187,1192.82222986221 5671.76478409767,1146.6491818428 PathPoint;PointKind.SMOOTHPOINT 5667.34232568741,1204.07044887543 5666.34637856483,1213.2665848732 5668.33898091316,1194.87407684326 PathPoint;PointKind.SMOOTHPOINT 5672.00129055977,1228.10488700867 5669.8585703373,1236.96113348007 5674.14401078224,1219.24840450287 PathPoint;PointKind.SMOOTHPOINT 5667.34232568741,1249.85002756119 5664.52619934082,1260.50816059113 5670.15880608559,1239.19189453125 PathPoint;PointKind.SMOOTHPOINT 5670.83646082878,1281.89570903778 5671.760181427,1290.21568536758 5669.91309428215,1273.57596874237 PathPoint;PointKind.SMOOTHPOINT 5672.00129055977,1302.49679088593 5668.1754090786,1324.77867364883 5675.82752609253,1280.21490812302 PathPoint;PointKind.SMOOTHPOINT 5669.67198514938,1331.10911607742 5668.54362273216,1348.441593647 5670.8003475666,1313.77616643906 PathPoint;PointKind.SMOOTHPOINT 5672.00129055977,1356.28784894943 5671.21883654594,1369.42269086838 5672.78409862518,1343.15300703049 PathPoint;PointKind.SMOOTHPOINT 5672.00129055977,1379.17752027512 5671.8239107132,1394.75791454315 5672.17867040634,1363.59736204147 PathPoint;PointKind.SMOOTHPOINT 5672.00129055977,1405.50078392029 5670.54082775116,1426.06150388718 5673.46175336838,1384.94053602219 PathPoint;PointKind.SMOOTHPOINT 5672.00129055977,1440.98005771637 5672.8927924633,1459.01945829391 5671.10943460464,1422.94089317322 PathPoint;PointKind.SMOOTHPOINT 5674.33095002174,1475.31480073929 5673.27516818047,1498.24506998062 5675.38637781143,1452.38476753235 PathPoint;PointKind.SMOOTHPOINT 5673.16612029076,1518.80555391312 5675.00860476494,1534.59153413773 5671.32328176498,1503.01957368851 PathPoint;PointKind.SMOOTHPOINT 5675.49542570114,1565.72989940643 5671.6192688942,1581.02846860886 5679.37158250809,1550.43109416962 PathPoint;PointKind.SMOOTHPOINT 5670.83646082878,1596.63105010986 5670.70015096664,1607.39209413528 5670.97312474251,1585.87024211884 PathPoint;PointKind.SMOOTHPOINT 5674.33095002174,1618.37642669678 5675.40443444252,1636.80433988571 5673.25675749779,1599.94827747345 PathPoint;PointKind.SMOOTHPOINT 5676.65990138054,1652.7111697197 5671.88763999939,1669.06032800674 5681.43251681328,1636.36201143265 PathPoint;PointKind.SMOOTHPOINT 5673.16612029076,1682.46778964996 5672.98874044418,1697.65471458435 5673.34350013733,1667.28086471558 PathPoint;PointKind.SMOOTHPOINT 5680.15403652191,1706.5022277832 5679.43070912361,1721.35846853256 5680.8777179718,1691.64622306824 PathPoint;PointKind.SMOOTHPOINT 5680.15403652191,1732.82549142838 5678.51194524765,1746.86363697052 5681.79648184776,1718.78781795502 PathPoint;PointKind.SMOOTHPOINT 5681.3188662529,1754.57086801529 5681.82409787178,1773.93796205521 5680.81363463402,1735.20377397537 PathPoint;PointKind.SMOOTHPOINT 5678.98920679092,1791.19443655014 5678.75765705109,1803.3549284935 5679.22146463394,1779.03441667557 PathPoint;PointKind.SMOOTHPOINT 5682.48369598389,1812.93981313705 5680.01772665977,1828.03751707077 5684.94931125641,1797.84258127213 PathPoint;PointKind.SMOOTHPOINT 5680.15403652191,1838.11878204346 5680.63200616837,1853.64536046982 5679.67642092705,1822.5922036171 PathPoint;PointKind.SMOOTHPOINT 5678.98920679092,1873.59805583954 5679.18535137177,1891.62376642227 5678.79377031326,1855.57234525681 PathPoint;PointKind.SMOOTHPOINT 5678.98920679092,1898.77678871155 5679.05753874779,1908.8627743721 5678.92122888565,1888.69103908539 PathPoint;PointKind.SMOOTHPOINT 5685.97783112526,1925.10028839111 5685.36815428734,1933.57203483582 5686.58715391159,1916.62830591202 PathPoint;PointKind.SMOOTHPOINT 5673.20294165611,1948.98862123489 5671.96977996826,1959.36516523361 5674.43574929237,1938.61207723618 PathPoint;PointKind.SMOOTHPOINT 5675.5322470665,1969.58946704865 5674.12262853537,1994.73267349252 5676.19644784927,1957.74219274521 PathPoint;PointKind.SMOOTHPOINT 5679.02638220787,2047.41496324539 5673.88555312157,2059.52612400055 5680.90318383269,2042.99375404626 PathPoint;PointKind.SMOOTHPOINT 5684.81300139427,2071.5952706337 5686.55068659782,2085.28880596161 5683.07496213913,2057.90149927139 PathPoint;PointKind.SMOOTHPOINT 5684.81300139427,2094.48494195938 5696.71393499958,2065.9198490757 5689.53994417191,2083.13853263855 PathPoint;PointKind.SMOOTHPOINT 5680.19121193886,2180.17604827881 5682.39766144753,2189.37218427658 5671.34645165814,2143.31838687477 PathPoint;PointKind.SMOOTHPOINT 5675.5322470665,2198.48783254623 5674.40848731995,2204.5366859436 5676.65600681305,2192.43897914886 PathPoint;PointKind.SMOOTHPOINT 5681.35604166985,2208.78837347031 5682.76622915268,2216.7594909668 5679.94550013542,2200.81701993942 PathPoint;PointKind.SMOOTHPOINT 5682.52051734924,2223.66656541824 5682.0449986401,2228.63321163548 5683.15745615959,2217.01440811157 PathPoint;PointKind.SMOOTHPOINT 5682.52051734924,2263.72396230698 5679.81343889236,2275.01230716705 5685.48382998751,2251.36687884394 PathPoint;PointKind.SMOOTHPOINT 5679.02638220787,2279.74668502808 5675.49117708206,2285.08035421371 5682.56123328209,2274.41325187683 PathPoint;PointKind.SMOOTHPOINT 5679.02638220787,2296.91393852234 5681.62441277504,2312.39142179489 5676.42870569229,2281.43669128418 PathPoint;PointKind.SMOOTHPOINT 5682.52051734924,2319.80384588242 5679.70439100266,2324.18511629105 5685.33699774742,2315.42281150818 PathPoint;PointKind.SMOOTHPOINT 5676.69707679749,2333.53797912598 5671.46985912323,2338.82656574249 5681.92429447174,2328.24892044067 PathPoint;PointKind.SMOOTHPOINT 5676.69707679749,2342.69375324249 5682.97547364235,2348.34465265274 5670.41832590103,2337.04285383224 PathPoint;PointKind.SMOOTHPOINT 5677.86190652847,2355.28335571289 5670.11384153366,2361.91757440567 5685.60961747169,2348.64866495132 PathPoint;PointKind.SMOOTHPOINT 5686.01465249062,2370.16154766083 5683.66693639755,2382.41126060486 5688.36236858368,2357.9118347168 PathPoint;PointKind.SMOOTHPOINT 5680.19121193886,2387.32903718948 5672.97103786469,2396.86482667923 5687.41138601303,2377.79301166534 PathPoint;PointKind.SMOOTHPOINT 5684.84982275963,2405.64082145691 5684.47700643539,2413.3438038826 5685.22299313545,2397.93783903122 PathPoint;PointKind.SMOOTHPOINT 5682.52051734924,2426.24166727066 5682.23408961296,2434.70468044281 5682.80694508553,2417.77865409851 PathPoint;PointKind.SMOOTHPOINT 5683.68499302864,2446.84251308441 5685.12315058708,2455.95816135406 5682.24754357338,2437.72686481476 PathPoint;PointKind.SMOOTHPOINT 5677.86190652847,2459.43187952042 5673.57150936127,2465.98584651947 5682.15194964409,2452.87791252136 PathPoint;PointKind.CORNERPOINT 5676.69707679749,2472.02124595642 5676.69707679749,2472.02124595642 5676.69707679749,2472.02124595642 PathPoint;PointKind.SMOOTHPOINT 5682.52051734924,2474.31030750275 5690.96889638901,2485.41100502014 5674.07213830948,2463.20960998535 PathPoint;PointKind.SMOOTHPOINT 5690.67326331139,2496.05568408966 5689.44505834579,2500.6201171875 5691.90182232857,2491.49101495743 PathPoint;PointKind.SMOOTHPOINT 5674.36741733551,2492.62232780457 5674.39467930794,2509.24410581589 5674.34050941467,2476.00007772446 PathPoint;PointKind.SMOOTHPOINT 5681.35604166985,2509.78958129883 5687.70701909065,2509.1591334343 5675.00471019745,2510.41979312897 PathPoint;PointKind.SMOOTHPOINT 5689.50878763199,2516.65652990341 5688.24376130104,2529.03558969498 5690.77345991135,2504.27723407745 PathPoint;PointKind.SMOOTHPOINT 5675.5322470665,2523.5232424736 5674.67457166451,2548.17146870851 5676.15112924576,2505.74820041656 PathPoint;PointKind.SMOOTHPOINT 5684.84982275963,2559.00275230408 5685.04101061821,2570.85451126099 5684.47979674149,2536.02177957805 PathPoint;PointKind.SMOOTHPOINT 5679.02638220787,2577.3145365715 5673.68940854073,2585.13836860657 5684.36300182343,2569.49094057083 PathPoint;PointKind.SMOOTHPOINT 5676.69707679749,2586.47054672241 5680.5778362751,2592.68013954163 5672.81596326828,2580.2607178688 PathPoint;PointKind.SMOOTHPOINT 5687.17912817001,2588.75960826874 5688.02531147003,2599.03748989105 5686.33294487,2578.48149061203 PathPoint;PointKind.SMOOTHPOINT 5687.17912817001,2605.926861763 5686.75143384933,2612.85187482834 5687.60682249069,2599.00184869766 PathPoint;PointKind.SMOOTHPOINT 5675.5322470665,2600.20444393158 5676.81533002853,2610.4646229744 5674.24951815605,2589.94426488876 PathPoint;PointKind.SMOOTHPOINT 5684.84982275963,2623.09435129166 5691.26028084755,2630.55114984512 5678.4397187233,2615.6370806694 PathPoint;PointKind.CORNERPOINT 5687.17912817001,2636.82801246643 5687.17912817001,2636.82801246643 5687.17912817001,2636.82801246643 PathPoint;PointKind.SMOOTHPOINT 5677.86190652847,2641.40589952469 5673.10274505615,2654.40690994263 5682.6207139492,2628.40536117554 PathPoint;PointKind.SMOOTHPOINT 5681.35604166985,2662.00698137283 5688.00992804527,2669.03786709893 5677.40540717825,2657.83288363194 PathPoint;PointKind.SMOOTHPOINT 5691.83809304237,2684.89665269852 5694.4095095842,2696.32350972685 5689.44625004769,2674.26796652686 PathPoint;PointKind.SMOOTHPOINT 5690.67326331139,2710.07562160492 5690.54155611992,2713.86680603027 5690.80532455444,2706.28443717957 PathPoint;PointKind.SMOOTHPOINT 5682.90607953072,2712.00001001358 5682.49644184113,2726.27466201782 5683.31571722031,2697.72512197495 PathPoint;PointKind.SMOOTHPOINT 5690.67326331139,2726.09858036041 5696.37529561019,2736.76736731726 5686.22456528094,2717.7748443598 PathPoint;PointKind.SMOOTHPOINT 5689.93749796861,2748.93704026706 5699.17611162037,2759.61600400975 5671.17210713157,2727.24602298678 PathPoint;PointKind.SMOOTHPOINT 5693.00292277336,2776.45604610443 5692.1793987751,2788.90261173248 5694.02152589751,2761.05476686732 PathPoint;PointKind.SMOOTHPOINT 5689.50878763199,2798.20142269135 5683.79899764061,2810.00408649445 5695.21857762337,2786.39875888824 PathPoint;PointKind.SMOOTHPOINT 5687.17912817001,2816.51320695877 5690.09084844589,2832.26354598999 5684.26776194572,2800.76310396194 PathPoint;PointKind.SMOOTHPOINT 5693.00292277336,2842.83670663834 5688.90796208382,2852.04606056213 5697.09717535973,2833.62711668015 PathPoint;PointKind.SMOOTHPOINT 5684.84982275963,2863.43731641769 5684.14455199242,2869.31646108627 5685.55509352684,2857.55840778351 PathPoint;PointKind.SMOOTHPOINT 5687.17912817001,2877.17144966125 5691.99285051741,2885.91268945026 5680.17280125618,2864.44777965546 PathPoint;PointKind.SMOOTHPOINT 5703.48497414589,2925.24008989334 5701.33304858208,2932.33481168747 5707.98847344003,2910.39437126828 PathPoint;PointKind.SMOOTHPOINT 5694.16775250435,2935.54039478302 5679.92494727871,2959.97695318548 5697.21578264236,2930.30963659286 PathPoint;PointKind.SMOOTHPOINT 5694.16775250435,2988.18692207336 5700.1820268631,3008.97116661072 5683.5627450774,2951.54266484889 PathPoint;PointKind.SMOOTHPOINT 5697.66153359413,3033.96673679352 5692.54336380959,3060.59849739075 5702.78005743027,3007.33497619629 PathPoint;PointKind.SMOOTHPOINT 5698.82600927353,3111.79223299026 5693.9719619751,3147.11926460266 5703.68041062355,3076.46496534348 PathPoint;PointKind.CORNERPOINT 5695.33187413216,3243.40878725052 5695.33187413216,3243.40878725052 5695.33187413216,3243.40878725052 PathPoint;PointKind.SMOOTHPOINT 5697.66153359413,3277.74329423904 5697.79359483719,3295.59929609299 5697.52947235107,3259.88752841949 PathPoint;PointKind.SMOOTHPOINT 5687.17912817001,3310.93374252319 5685.20458245277,3322.90163040161 5689.15367388725,3298.96561861038 PathPoint;PointKind.CORNERPOINT 5682.52051734924,3348.7020778656 5682.52051734924,3348.7020778656 5682.52051734924,3348.7020778656 PathPoint;PointKind.SMOOTHPOINT 5689.47161221504,3363.726375103 5688.26606655121,3383.98284673691 5690.67715787888,3343.46966743469 PathPoint;PointKind.SMOOTHPOINT 5694.1305770874,3387.76057720184 5694.52640676498,3395.99534511566 5693.73474740982,3379.52557325363 PathPoint;PointKind.SMOOTHPOINT 5684.81300139427,3416.37290239334 5680.71379208565,3421.56778335571 5688.91185665131,3411.17778539658 PathPoint;PointKind.SMOOTHPOINT 5681.3188662529,3431.25133037567 5684.94931125641,3441.43999099731 5677.6880671978,3421.06266975403 PathPoint;PointKind.SMOOTHPOINT 5684.81300139427,3454.14100170135 5682.12397956848,3464.7318649292 5687.50166916847,3443.54990243912 PathPoint;PointKind.SMOOTHPOINT 5682.48369598389,3480.46426534653 5679.83114147186,3491.87345981598 5685.13625049591,3469.05507087708 PathPoint;PointKind.SMOOTHPOINT 5684.81300139427,3499.92058038712 5693.21606183052,3503.98910522461 5676.40994095802,3495.85252761841 PathPoint;PointKind.SMOOTHPOINT 5689.47161221504,3512.51018285751 5681.47358679771,3526.18601560593 5697.46999168396,3498.8343501091 PathPoint;PointKind.SMOOTHPOINT 5681.3188662529,3547.9892206192 5682.77932906151,3558.07072162628 5679.85875749588,3537.90795564651 PathPoint;PointKind.SMOOTHPOINT 5684.81300139427,3567.44577169418 5687.95662546158,3581.78745746613 5681.66902327538,3553.10384988785 PathPoint;PointKind.SMOOTHPOINT 5685.97783112526,3594.91356611252 5683.75297093391,3601.42268657684 5688.20233726501,3588.4042096138 PathPoint;PointKind.SMOOTHPOINT 5682.48369598389,3616.65894269943 5674.5125784874,3624.80000495911 5690.4541053772,3608.51764440536 PathPoint;PointKind.SMOOTHPOINT 5676.65990138054,3639.54861402512 5677.35171818733,3654.78935480118 5675.96843862534,3624.30834531784 PathPoint;PointKind.SMOOTHPOINT 5675.49542570114,3661.29399061203 5662.92942667007,3667.64237165451 5688.06107068062,3654.94584560394 PathPoint;PointKind.SMOOTHPOINT 5668.5071554184,3677.31694936752 5666.50534772873,3693.33990812302 5670.50896310806,3661.29399061203 PathPoint;PointKind.SMOOTHPOINT 5669.67198514938,3707.07356929779 5680.84125065804,3725.64947605133 5658.50236558914,3688.49813461304 PathPoint;PointKind.SMOOTHPOINT 5687.14230680466,3729.96371269226 5687.19222807884,3746.27699375153 5687.09238553047,3713.64995956421 PathPoint;PointKind.SMOOTHPOINT 5685.90631270409,3751.00004196167 5681.82516002655,3760.36612272263 5689.98711133003,3741.63396120071 PathPoint;PointKind.SMOOTHPOINT 5672.90624642372,3773.00009965897 5650.4129948616,3773.72873783112 5695.39914393425,3772.27146148682 PathPoint;PointKind.SMOOTHPOINT 5649.87235808372,3778.03235292435 5636.43255972862,3779.01118755341 5663.31180238724,3777.0530462265 PathPoint;PointKind.SMOOTHPOINT 5625.41341209412,3775.74329137802 5615.56369686127,3774.6927022934 5635.26348137856,3776.79388046265 PathPoint;PointKind.SMOOTHPOINT 5596.29620933533,3774.59876060486 5585.63642406464,3776.42283439636 5606.95564055443,3772.77468681335 PathPoint;PointKind.SMOOTHPOINT 5564.84934711456,3775.74329137802 5557.12394142151,3775.83699703217 5572.57439875603,3775.64934968948 PathPoint;PointKind.SMOOTHPOINT 5545.04936599731,3773.4542298317 5529.60351133347,3772.19357013702 5560.49522066116,3774.71488952637 PathPoint;PointKind.SMOOTHPOINT 5519,3777 5514.38670778275,3776.80763196945 5523.61329221725,3777.19213199615 PathPoint;PointKind.SMOOTHPOINT 5493,3777 5483.12231469154,3777.04484653473 5502.87697720528,3776.95538949966 PathPoint;PointKind.SMOOTHPOINT 5459.90633153915,3779.00009393692 5454.24646282196,3779.40678119659 5465.56620025635,3778.59317064285 PathPoint;PointKind.SMOOTHPOINT 5429.90612411499,3781.00001335144 5424.80601096153,3783.22628974915 5435.00623726845,3778.77350091934 PathPoint;PointKind.CORNERPOINT 5413.90617871284,3776.00009679794 5413.90617871284,3776.00009679794 5413.90617871284,3776.00009679794 PathPoint;PointKind.SMOOTHPOINT 5380.9060921669,3776.99993848801 5380.65152907372,3777.07452535629 5396.06233263016,3772.56815671921 PathPoint;PointKind.SMOOTHPOINT 5332.90625596046,3779.00009393692 5327.54060411453,3784.12109613419 5337.88528347015,3774.24754142761 PathPoint;PointKind.SMOOTHPOINT 5303.9575817585,3789.4769525528 5295.76305770874,3795.78969240189 5321.93915390968,3775.62503814697 PathPoint;PointKind.SMOOTHPOINT 5262.02866816521,3786.0435962677 5245.43179178238,3783.04383516312 5278.62519049644,3789.04359340668 PathPoint;PointKind.SMOOTHPOINT 5238.73455190659,3787.18812704086 5213.90739226341,3784.32243347168 5263.56171154976,3790.05382061005 PathPoint;PointKind.SMOOTHPOINT 5208.45251941681,3784.89930152893 5202.35610508919,3789.13729906082 5214.54893374443,3780.66083192825 PathPoint;PointKind.SMOOTHPOINT 5186.32323288918,3791.76601409912 5176.62823820114,3794.00149583817 5196.0185816288,3789.53076839447 PathPoint;PointKind.SMOOTHPOINT 5137.40604901314,3784.89930152893 5112.59269738197,3785.00646114349 5162.2194006443,3784.79166984558 PathPoint;PointKind.SMOOTHPOINT 5108.28884625435,3794.05507564545 5096.73295640945,3800.01895666122 5119.84473609924,3788.09119462967 PathPoint;PointKind.SMOOTHPOINT 5054.71269750595,3787.18812704086 5037.14678192139,3785.56987524033 5072.27861309052,3788.8063788414 PathPoint;PointKind.SMOOTHPOINT 4983.90627408028,3800.99991559982 4963.66939330101,3797.40109920502 5009.11651754379,3805.48338890076 PathPoint;PointKind.SMOOTHPOINT 4960.37246489525,3790.62171936035 4934.74904322624,3789.12832975388 4985.99588656425,3792.11487293243 PathPoint;PointKind.SMOOTHPOINT 4919.60802698135,3796.34390115738 4909.43506264687,3795.89260339737 4929.78099131584,3796.79567098618 PathPoint;PointKind.SMOOTHPOINT 4889.32599449158,3792.91054487228 4869.18506169319,3795.72714328766 4909.46728134155,3790.0941824913 PathPoint;PointKind.SMOOTHPOINT 4847.39672684669,3796.34390115738 4830.65433526039,3794.38599586487 4864.13982653618,3798.30227851868 PathPoint;PointKind.SMOOTHPOINT 4814.78538894653,3798.6329627037 4799.79909324646,3798.88787984848 4829.77168464661,3798.37828159332 PathPoint;PointKind.SMOOTHPOINT 4784.50371050835,3792.91054487228 4769.93130111694,3792.54398345947 4799.07611989975,3793.2771062851 PathPoint;PointKind.SMOOTHPOINT 4722,3798 4704.10233807564,3798.22800922394 4739.89837002754,3797.77199077606 PathPoint;PointKind.SMOOTHPOINT 4676.18693733215,3800.92202425003 4655.39065504074,3796.22777223587 4696.98321962357,3805.61627626419 PathPoint;PointKind.SMOOTHPOINT 4652.90627503395,3794.99992132187 4633.53859090805,3793.60070943832 4672.27360510826,3796.39936923981 PathPoint;PointKind.SMOOTHPOINT 4585,3798 4569.23089623451,3798.43359518051 4600.7687497139,3797.5661687851 PathPoint;PointKind.SMOOTHPOINT 4535.90638661385,3794.00007963181 4512.59846234322,3793.23084354401 4559.21395683289,3794.76884365082 PathPoint;PointKind.SMOOTHPOINT 4451.9062306881,3800.00007390976 4412.55233430862,3797.92556762695 4491.26048111916,3802.07434415817 PathPoint;PointKind.SMOOTHPOINT 4404.81276655197,3788.33265781403 4377.61983418465,3784.96609926224 4432.0056989193,3791.69898033142 PathPoint;PointKind.SMOOTHPOINT 4350.07214212418,3784.89930152893 4340.840955019,3785.29725551605 4359.30297517776,3784.50111150742 PathPoint;PointKind.SMOOTHPOINT 4325.61355018616,3790.62171936035 4316.39156842232,3789.07923460007 4334.83553195,3792.16396808624 PathPoint;PointKind.SMOOTHPOINT 4308.14287447929,3784.89930152893 4285.1404967308,3779.4806599617 4331.14596033096,3790.31747102737 PathPoint;PointKind.SMOOTHPOINT 4270.87292575836,3775.74329137802 4258.80259895325,3772.39018678665 4282.94289851189,3779.09639596939 PathPoint;PointKind.SMOOTHPOINT 4245.24950408936,3781.46570920944 4229.24389386177,3782.76649475098 4261.25511431694,3780.16468763351 PathPoint;PointKind.SMOOTHPOINT 4204,3787 4185.34679198265,3780.32093477249 4222.65356206894,3793.67906522751 PathPoint;PointKind.SMOOTHPOINT 4178.86199855804,3783.75453472137 4168.24328327179,3782.98128604889 4189.4807138443,3784.52801942825 PathPoint;PointKind.SMOOTHPOINT 4153.23857688904,3778.03235292435 4138.7026348114,3776.54344797134 4167.77451896667,3779.52102184296 PathPoint;PointKind.SMOOTHPOINT 4101.99208760262,3780.32117843628 4089.74013233185,3780.68773984909 4114.24404287338,3779.95461702347 PathPoint;PointKind.SMOOTHPOINT 4072.87488484383,3781.46570920944 4052.34697365761,3782.00221538544 4093.40208792686,3780.92920303345 PathPoint;PointKind.SMOOTHPOINT 4041.42766857147,3776.88758611679 4022.50148677826,3774.43778514862 4060.35420441628,3779.33762311935 PathPoint;PointKind.SMOOTHPOINT 3996.18130001201,3785.74511934206 3988.2165847898,3783.58923101928 4010.9533957005,3789.7436287312 PathPoint;PointKind.SMOOTHPOINT 3970,3786 3949.53688716473,3787.48150047272 3990.40305583745,3784.52284756912 PathPoint;PointKind.SMOOTHPOINT 3923.79367375374,3784.89930152893 3903.18397665024,3778.07224273682 3944.40337085724,3791.72588825226 PathPoint;PointKind.SMOOTHPOINT 3886.52337098122,3779.17664766312 3872.07381749153,3778.05029153824 3900.9729244709,3780.30347585678 PathPoint;PointKind.SMOOTHPOINT 3851.58237361908,3788.33265781403 3830.18101716042,3784.29552555084 3872.98373007774,3792.36979007721 PathPoint;PointKind.SMOOTHPOINT 3816.64173030853,3782.6102399826 3781.26843595505,3781.08569383621 3852.01467061043,3784.1345500946 PathPoint;PointKind.SMOOTHPOINT 3772.38351130486,3796.34390115738 3752.71098875999,3796.83603286743 3792.05567979813,3795.85224151611 PathPoint;PointKind.CORNERPOINT 3459.08042693138,3794.05507564545 3459.08042693138,3794.05507564545 3459.08042693138,3794.05507564545 PathPoint;PointKind.CORNERPOINT 3303.90634202957,3797.99991846085 3303.90634202957,3797.99991846085 3303.90634202957,3797.99991846085 PathPoint;PointKind.CORNERPOINT 3228.47069406509,3794.05507564545 3228.47069406509,3794.05507564545 3228.47069406509,3794.05507564545 PathPoint;PointKind.SMOOTHPOINT 3113.16600465775,3789.4769525528 3098.23387885094,3788.16271305084 3128.09742236137,3790.79166412354 PathPoint;PointKind.SMOOTHPOINT 3022.31955313683,3794.05507564545 2997.18295240402,3792.94642210007 3047.45615386963,3795.16372919083 PathPoint;PointKind.SMOOTHPOINT 2974.56684494019,3783.75453472137 2946.44134068489,3785.38199186325 3002.69270324707,3782.12731361389 PathPoint;PointKind.SMOOTHPOINT 2943.12033677101,3794.05507564545 2917.88353943825,3793.15200805664 2968.35713410378,3794.95814323425 PathPoint;PointKind.SMOOTHPOINT 2882.55627179146,3787.18812704086 2854.93104243279,3785.9095287323 2910.18114709854,3788.46672534943 PathPoint;PointKind.SMOOTHPOINT 2832.47425818443,3790.62171936035 2818.72997546196,3790.38025617599 2846.21854090691,3790.86294651031 PathPoint;PointKind.SMOOTHPOINT 2795.20395541191,3789.4769525528 2769.46688318253,3786.294028759 2820.9410276413,3792.66034841537 PathPoint;PointKind.SMOOTHPOINT 2742.7926363945,3794.05507564545 2714.70784807205,3792.56617069244 2770.87707066536,3795.54374456406 PathPoint;PointKind.CORNERPOINT 2665.92272543907,3790.62171936035 2665.92272543907,3790.62171936035 2665.92272543907,3790.62171936035 PathPoint;PointKind.SMOOTHPOINT 2626.32311725616,3791.76601409912 2588.50722098351,3792.45004177094 2664.13901352882,3791.08198642731 PathPoint;PointKind.SMOOTHPOINT 2558.77078199387,3789.4769525528 2527.30126047134,3788.28332662582 2590.24030351639,3790.67081451416 PathPoint;PointKind.SMOOTHPOINT 2520.33600354195,3788.33265781403 2499.26674747467,3787.87663936615 2541.40490555763,3788.7886762619 PathPoint;PointKind.SMOOTHPOINT 2484.23017644882,3787.18812704086 2461.50537514687,3788.61873149872 2506.95533180237,3785.75752258301 PathPoint;PointKind.SMOOTHPOINT 2430.65438175201,3780.32117843628 2416.209430933,3780.76374292374 2445.09933257103,3779.87861394882 PathPoint;PointKind.SMOOTHPOINT 2399.20751953125,3781.46570920944 2384.38939833641,3783.47294569016 2414.02564072609,3779.45823669434 PathPoint;PointKind.SMOOTHPOINT 2345.63137078285,3784.89930152893 2329.8856344223,3793.01345586777 2361.37781524658,3776.7849111557 PathPoint;PointKind.SMOOTHPOINT 2308.36142206192,3792.91054487228 2281.28214025497,3791.50684833527 2335.44034981728,3794.3142414093 PathPoint;PointKind.SMOOTHPOINT 2252.45596790314,3787.18812704086 2223.24741983414,3784.92597341537 2281.66416192055,3789.45028066635 PathPoint;PointKind.CORNERPOINT 2214.02083539963,3784.89930152893 2214.02083539963,3784.89930152893 2214.02083539963,3784.89930152893 PathPoint;PointKind.SMOOTHPOINT 2113.85716223717,3795.19960641861 2096.76886224747,3797.02792882919 2130.94546222687,3793.37104797363 PathPoint;PointKind.SMOOTHPOINT 2084.73995947838,3795.19960641861 2067.3967423439,3791.75704479218 2102.08282256126,3798.64193201065 PathPoint;PointKind.SMOOTHPOINT 2046.30482697487,3791.76601409912 2032.11019062996,3793.34437608719 2060.49946331978,3790.18788814545 PathPoint;PointKind.SMOOTHPOINT 2012.90607833862,3800.99991559982 2007.90616178513,3800.81675291061 2017.90634894371,3801.18331432343 PathPoint;PointKind.SMOOTHPOINT 1836.65990495682,3790.62171936035 1821.30008482933,3792.3383975029 1852.01901698112,3788.9050412178 PathPoint;PointKind.CORNERPOINT 1815.69509410858,3794.05507564545 1815.69509410858,3794.05507564545 1815.69509410858,3794.05507564545 PathPoint;PointKind.SMOOTHPOINT 1804.04821300507,3790.62171936035 1794.70797801018,3789.45476531982 1813.38844799995,3791.78843736649 PathPoint;PointKind.SMOOTHPOINT 1766.77826428413,3787.18812704086 1733.84792590141,3785.04658699036 1799.70789456367,3789.32966709137 PathPoint;PointKind.SMOOTHPOINT 1721.35486149788,3788.33265781403 1702.90204668045,3787.10763931274 1739.8080303669,3789.55767631531 PathPoint;PointKind.SMOOTHPOINT 1681.75525331497,3787.18812704086 1657.84260892868,3787.48765468597 1705.66789770126,3786.88859939575 PathPoint;PointKind.SMOOTHPOINT 1631.67359375954,3789.4769525528 1621.74173855782,3790.65736055374 1641.60544896126,3788.29678058624 PathPoint;PointKind.SMOOTHPOINT 1601.39120721817,3790.62171936035 1582.96565437317,3789.11487579346 1619.81711411476,3792.12832689285 PathPoint;PointKind.SMOOTHPOINT 1557.13298821449,3787.18812704086 1525.35402560234,3784.1345500946 1588.91195082664,3790.24170398712 PathPoint;PointKind.SMOOTHPOINT 1468.61584210396,3791.76601409912 1448.63423252106,3795.55719852448 1488.59815979004,3787.97506570816 PathPoint;PointKind.CORNERPOINT 1385.92249059677,3789.4769525528 1385.92249059677,3789.4769525528 1385.92249059677,3789.4769525528 PathPoint;PointKind.CORNERPOINT 1186.75997400284,3794.05507564545 1186.75997400284,3794.05507564545 1186.75997400284,3794.05507564545 PathPoint;PointKind.SMOOTHPOINT 1169.28929829597,3780.32117843628 1157.50115060806,3780.87113857269 1181.0770919323,3779.77145433426 PathPoint;PointKind.SMOOTHPOINT 1159.97172260284,3794.05507564545 1134.75829267502,3795.91479063034 1185.18586063385,3792.19536066055 PathPoint;PointKind.CORNERPOINT 1109.88970899582,3794.05507564545 1109.88970899582,3794.05507564545 1109.88970899582,3794.05507564545 PathPoint;PointKind.SMOOTHPOINT 1091.90636658669,3794.00007963181 1079.07199645042,3794.39779758453 1104.74038267136,3793.60212564468 PathPoint;PointKind.SMOOTHPOINT 1069.12562513351,3797.48866796494 1064.28007507324,3796.77773237228 1073.9708211422,3798.19936752319 PathPoint;PointKind.SMOOTHPOINT 1038.84359264374,3789.4769525528 1028.10166740417,3790.28182983398 1049.58516383171,3788.672311306 PathPoint;PointKind.CORNERPOINT 993.420543909073,3791.76601409912 993.420543909073,3791.76601409912 993.420543909073,3791.76601409912 PathPoint;PointKind.SMOOTHPOINT 901.409616708755,3790.62171936035 886.65522480011,3791.08647108078 916.163654565811,3790.15649557114 PathPoint;PointKind.SMOOTHPOINT 848.998297691345,3791.76601409912 809.307698249817,3788.6546087265 888.688897132874,3794.87765550613 PathPoint;PointKind.SMOOTHPOINT 793.092843532562,3788.33265781403 767.405692577362,3789.50834512711 818.779994487762,3787.15697050095 PathPoint;PointKind.SMOOTHPOINT 741.84635424614,3791.76601409912 730.272053718567,3792.87938833237 753.420300722122,3790.65287590027 PathPoint;PointKind.SMOOTHPOINT 710.399137973785,3794.05507564545 637.851488828659,3793.87191295624 782.947141170502,3794.23847436905 PathPoint;PointKind.SMOOTHPOINT 631.200275659561,3792.91054487228 625.454018354416,3792.96860933304 636.946532964706,3792.85248041153 PathPoint;PointKind.SMOOTHPOINT 579.953432321548,3788.33265781403 565.390228271484,3788.41739416122 594.516636371613,3788.24768543243 PathPoint;PointKind.CORNERPOINT 552.001059293747,3788.33265781403 552.001059293747,3788.33265781403 552.001059293747,3788.33265781403 PathPoint;PointKind.SMOOTHPOINT 533.365553855896,3795.19960641861 527.387392759323,3795.46349287033 539.343714952469,3794.93595600128 PathPoint;PointKind.SMOOTHPOINT 477.460453748703,3796.34390115738 432.237444162369,3794.80165243149 522.683463335037,3797.88638591766 PathPoint;PointKind.CORNERPOINT 402.919848203659,3792.91054487228 402.919848203659,3792.91054487228 402.919848203659,3792.91054487228 PathPoint;PointKind.SMOOTHPOINT 373,3793 355.370355129242,3792.00723934174 390.629644870758,3793.99252462387 PathPoint;PointKind.SMOOTHPOINT 348,3793 341.944655656815,3793.93446016312 354.055698394775,3792.06553983688 PathPoint;PointKind.SMOOTHPOINT 322.556156158447,3791.76601409912 314.321270227432,3797.32320785522 330.790688037872,3786.20905637741 PathPoint;PointKind.CORNERPOINT 292.273769617081,3805.49991130829 292.273769617081,3805.49991130829 292.273769617081,3805.49991130829 PathPoint";
	
	shadow35mm[2] = "PointKind.CORNERPOINT 284.261620330258,3800.92199713448 284.261620330258,3800.92199713448 284.261620330258,3800.92199713448 PathPoint;PointKind.SMOOTHPOINT 262.046875,3791 247.61554056631,3767.56036815054 276.47820943369,3814.43963184946 PathPoint;PointKind.SMOOTHPOINT 256.046875,3759 255.951434342157,3743.5538195622 256.142315657843,3774.4461804378 PathPoint;PointKind.SMOOTHPOINT 240.866874112576,3727.67462080234 239.109705556511,3718.11085878368 243.346210312985,3741.17146639777 PathPoint;PointKind.SMOOTHPOINT 242.317925595706,3708.63266007188 238.124899361139,3698.25451451266 247.217566182229,3720.75931419951 PathPoint;PointKind.SMOOTHPOINT 236.046875,3695 236.580944191387,3691.60677183117 235.331485363837,3699.54701066712 PathPoint;PointKind.SMOOTHPOINT 248.787741745705,3675.67782279112 254.210892014692,3653.83867263207 243.364591476717,3697.51697295017 PathPoint;PointKind.SMOOTHPOINT 260.967737106055,3625.81492179658 266.486328032885,3609.66231372607 255.449146179225,3641.96729415551 PathPoint;PointKind.SMOOTHPOINT 273.779408227758,3586.90200267657 271.017638376917,3573.36037187921 276.540824594681,3600.44363347394 PathPoint;PointKind.SMOOTHPOINT 263.343334133339,3535.3347262552 262.989736291444,3515.89769574176 263.638063764663,3551.535811665 PathPoint;PointKind.SMOOTHPOINT 260.03125,3489 261.805403217814,3470.73489687419 258.559881284291,3504.14790326939 PathPoint;PointKind.SMOOTHPOINT 270.285219698952,3458.71897623954 268.742969364994,3445.59761920565 271.827470032911,3471.84033327343 PathPoint;PointKind.SMOOTHPOINT 273.779408227758,3378.60461418034 269.256934981674,3353.71182038369 278.301527989924,3403.49740797699 PathPoint;PointKind.SMOOTHPOINT 269.12049018935,3331.68032956788 271.167869042041,3314.24922183775 267.07311133666,3349.1116730096 PathPoint;PointKind.SMOOTHPOINT 272.614678718156,3306.50161761358 272.318812678843,3296.84946374898 272.910191273552,3316.15377147819 PathPoint;PointKind.SMOOTHPOINT 276.108867246962,3271.0223092129 275.085177820617,3257.38686520305 277.132203189389,3284.65798893434 PathPoint;PointKind.SMOOTHPOINT 270.285219698952,3254.99957822801 268.470079780347,3244.38171398261 272.100359617558,3265.61744247341 PathPoint;PointKind.SMOOTHPOINT 277.273243272646,3206.93091385018 276.249907330219,3193.61721615953 278.296932698991,3220.24461154082 PathPoint;PointKind.SMOOTHPOINT 273.779408227758,3190.9079471537 273.551764584607,3180.11565633232 274.006698386992,3201.70023797508 PathPoint;PointKind.SMOOTHPOINT 274.94413773736,3160.00662923772 275.248840874622,3146.95245000674 274.639081116181,3173.06104418029 PathPoint;PointKind.SMOOTHPOINT 270.285219698952,3131.3943065641 276.349943278995,3106.98000729345 264.22049611891,3155.80884154633 PathPoint;PointKind.SMOOTHPOINT 273.779408227758,3100.49322435971 270.944820689823,3086.41487827382 276.613642281776,3114.571334734 PathPoint;PointKind.SMOOTHPOINT 270.285219698952,3054.71355522422 268.319849115223,3037.52829468159 272.250590282681,3071.89881576686 PathPoint;PointKind.SMOOTHPOINT 271.449949208554,3024.95661707363 274.402600375081,3005.17405053001 268.497298042028,3044.73941932883 PathPoint;PointKind.SMOOTHPOINT 276.108867246962,2967.73197172638 282.282463873729,2937.57738812486 269.934917136277,2997.88679103948 PathPoint;PointKind.SMOOTHPOINT 290.084914394349,2918.51892758316 289.752992995407,2892.9020277846 290.41718927721,2944.13582738171 PathPoint;PointKind.SMOOTHPOINT 272.614678718156,2883.03961918247 273.451728635831,2856.25146849737 271.777628800482,2909.82800557916 PathPoint;PointKind.SMOOTHPOINT 274.94413773736,2852.13853697808 277.664549969802,2832.21713630845 272.223372021,2872.05970193612 PathPoint;PointKind.SMOOTHPOINT 276.108867246962,2793.76927615386 278.310718571791,2770.76783214865 273.906662438215,2816.77095587066 PathPoint;PointKind.SMOOTHPOINT 272.614678718156,2754.85659274544 272.646492270771,2734.17077939216 272.582865165542,2775.54240609872 PathPoint;PointKind.SMOOTHPOINT 273.779408227758,2731.96687603349 274.097897237819,2721.38483994964 273.460919217697,2742.54891211733 PathPoint;PointKind.SMOOTHPOINT 271.449949208554,2688.47620214036 271.031424249717,2672.75282487371 271.868474167392,2704.19957940701 PathPoint;PointKind.SMOOTHPOINT 269.12049018935,2657.57488422438 273.861063012802,2624.23253709104 264.379917365899,2690.91699564613 PathPoint;PointKind.SMOOTHPOINT 270.285219698952,2590.04987814233 273.679372278982,2568.45657517078 266.891067118923,2611.64318111389 PathPoint;PointKind.SMOOTHPOINT 270.285219698952,2543.12559352988 279.352435677951,2509.50628527927 261.218003719954,2576.74513749208 PathPoint;PointKind.SMOOTHPOINT 274.94413773736,2488.19017913657 272.673710532452,2468.88563569578 277.214211458351,2507.49448686577 PathPoint;PointKind.SMOOTHPOINT 273.779408227758,2433.25452903167 279.193367914879,2411.57613417643 268.365448540637,2454.93268817533 PathPoint;PointKind.SMOOTHPOINT 267.955760679749,2400.06421587334 268.519921012776,2388.04268911448 267.391600346721,2412.0857426322 PathPoint;PointKind.SMOOTHPOINT 274.94413773736,2371.45189319972 270.362632676981,2360.61953140818 279.525289313822,2382.28425499125 PathPoint;PointKind.SMOOTHPOINT 270.285219698952,2334.82820503365 272.819345906642,2316.56998533715 267.751093491263,2353.08642473015 PathPoint;PointKind.SMOOTHPOINT 271.449949208554,2305.07150259464 279.156959071332,2290.10358097125 263.742939345777,2320.03918850644 PathPoint;PointKind.SMOOTHPOINT 266.791031170147,2259.29183345916 266.2678749716,2240.77433101458 267.314187368693,2277.80933590373 PathPoint;PointKind.SMOOTHPOINT 273.779408227758,2235.25750127024 275.762806491302,2217.05726662467 271.795656480297,2253.45750020422 PathPoint;PointKind.SMOOTHPOINT 278.437972782248,2205.50056311964 274.907728893813,2198.00328460316 281.968570154601,2212.99784163612 PathPoint;PointKind.SMOOTHPOINT 272.614678718156,2175.74386068063 273.419915083216,2157.57049715623 271.809442353096,2193.91722420504 PathPoint;PointKind.SMOOTHPOINT 272.614678718156,2144.84254276465 279.871350069482,2121.87221268921 265.358007366831,2167.8128728401 PathPoint;PointKind.SMOOTHPOINT 271.449949208554,2096.77387838682 275.790378236901,2079.62892452593 267.109520180208,2113.91883224771 PathPoint;PointKind.SMOOTHPOINT 272.614678718156,2045.27183900125 274.338973269852,2027.42045750764 270.89038416646,2063.12322049485 PathPoint;PointKind.SMOOTHPOINT 277.273243272646,2015.51490085065 273.333311523322,1997.49380701285 281.21317502197,2033.53623040004 PathPoint;PointKind.SMOOTHPOINT 266.791031170147,1985.75819841164 269.752872918539,1969.92309385173 263.829189421754,2001.59330297155 PathPoint;PointKind.SMOOTHPOINT 271.449949208554,1942.26752451851 275.494512197588,1917.89353192961 267.405386219521,1966.641752819 PathPoint;PointKind.SMOOTHPOINT 277.273243272646,1906.78821611783 277.99222956173,1877.83175452402 276.55461046748,1935.74491342322 PathPoint;PointKind.SMOOTHPOINT 271.449949208554,1858.71955173999 273.947666572696,1830.93881955293 268.952231844412,1886.50028392705 PathPoint;PointKind.SMOOTHPOINT 272.614678718156,1824.38485881628 276.93672658277,1805.59463806304 268.292630853542,1843.17507956951 PathPoint;PointKind.SMOOTHPOINT 271.449949208554,1777.46080991541 272.73733763768,1756.78843212271 270.162560779428,1798.13318770811 PathPoint;PointKind.SMOOTHPOINT 276.108867246962,1743.12588128011 271.559175739197,1708.50055596695 280.658205270809,1777.75144230485 PathPoint;PointKind.SMOOTHPOINT 272.614678718156,1685.90147164444 275.075987238751,1671.33590970376 270.153370197562,1700.46679787354 PathPoint;PointKind.SMOOTHPOINT 272.614678718156,1651.56654300914 274.852938886532,1629.7184358097 270.376065065862,1673.41488592017 PathPoint;PointKind.SMOOTHPOINT 273.779408227758,1610.36486435836 275.544706913935,1586.55870098776 272.014109541582,1634.17126344056 PathPoint;PointKind.SMOOTHPOINT 274.94413773736,1571.45218094994 274.033916648673,1550.96766529381 275.85400534213,1591.93693231767 PathPoint;PointKind.SMOOTHPOINT 269.12049018935,1525.67251181446 275.385285666945,1501.33859019572 262.855694711756,1550.0064334332 PathPoint;PointKind.SMOOTHPOINT 273.779408227758,1495.91580937545 273.815817071306,1469.14085853935 273.742999384211,1522.69052449997 PathPoint;PointKind.SMOOTHPOINT 278.437972782248,1463.87011169409 277.537295759345,1452.59060501791 279.339003289069,1475.14961837027 PathPoint;PointKind.SMOOTHPOINT 272.614678718156,1420.37943780096 263.192564885549,1401.00347374865 282.036792550763,1439.75516614168 PathPoint;PointKind.SMOOTHPOINT 272.614678718156,1391.76711512734 273.784003518691,1373.49545987025 271.445353917621,1410.03877038442 PathPoint;PointKind.SMOOTHPOINT 274.94413773736,1359.72118173439 268.078773083191,1344.14535992255 281.80950239153,1375.29700354622 PathPoint;PointKind.SMOOTHPOINT 271.449949208554,1304.78576734108 273.292660872759,1296.74305220728 269.607237544349,1312.82848247488 PathPoint;PointKind.SMOOTHPOINT 272.614678718156,1287.61818516763 274.74371235589,1268.45247585286 270.485291596505,1306.78413019399 PathPoint;PointKind.SMOOTHPOINT 271.449949208554,1259.00609820559 276.358780376943,1238.24862852921 266.540764556247,1279.76333217039 PathPoint;PointKind.SMOOTHPOINT 277.273243272646,1229.249160055 269.693841104244,1214.48701464895 284.852998924966,1244.01130546104 PathPoint;PointKind.SMOOTHPOINT 270.285219698952,1205.21482786608 272.51464276938,1186.92101571962 268.055796628525,1223.50887572413 PathPoint;PointKind.SMOOTHPOINT 279.60270229185,1175.45812542707 276.868504186608,1161.96104412006 282.337253881009,1188.9549710225 PathPoint;PointKind.SMOOTHPOINT 271.449949208554,1139.97881702639 274.621053436366,1123.24965840878 268.278844980743,1156.70821135558 PathPoint;PointKind.SMOOTHPOINT 276.108867246962,1110.22211458738 280.285279737386,1099.84114048909 271.93210127262,1120.60308868567 PathPoint;PointKind.SMOOTHPOINT 281.932161311054,1082.75417167913 280.094044937782,1056.09118384788 283.770277684325,1109.41739522198 PathPoint;PointKind.SMOOTHPOINT 277.273243272646,1034.68574301289 275.89500947661,1016.14584796734 278.6518305526,1053.22540234685 PathPoint;PointKind.SMOOTHPOINT 277.273243272646,998.06181913523 279.607297582783,974.367383057883 274.939542446427,1021.75649092417 PathPoint;PointKind.SMOOTHPOINT 273.779408227758,953.426765476718 272.318812678843,923.017141935731 275.239650292755,983.836153306116 PathPoint;PointKind.SMOOTHPOINT 272.614678718156,916.80307731065 276.827500052128,899.21993560551 268.401857384185,934.386219015789 PathPoint;PointKind.SMOOTHPOINT 279.60270229185,885.901759394671 280.46272866419,854.468440421953 278.743029403427,917.335078367389 PathPoint;PointKind.SMOOTHPOINT 280.767431801452,820.665748554977 272.769151190295,797.065125690117 288.765712412609,844.266371419837 PathPoint;PointKind.CORNERPOINT 274.94413773736,777.175074661847 274.94413773736,777.175074661847 274.94413773736,777.175074661847 PathPoint;PointKind.SMOOTHPOINT 276.108867246962,746.273756745868 285.298742145484,710.199983717315 266.918638864522,782.347529774422 PathPoint;PointKind.SMOOTHPOINT 284.261620330258,700.494087610386 283.378970987169,685.289275839892 285.144269673346,715.698899380879 PathPoint;PointKind.SMOOTHPOINT 281.932161311054,662.725783967346 282.60095288379,622.109848615638 281.263369738317,703.341955030643 PathPoint;PointKind.SMOOTHPOINT 280.03125,603 275.02662468985,582.153195631322 285.03587531015,623.846804368679 PathPoint;PointKind.SMOOTHPOINT 279.60270229185,555.143714711494 279.302594445522,538.798765984223 279.903163622096,571.488427727175 PathPoint;PointKind.SMOOTHPOINT 280.767431801452,526.531392037868 286.386058677058,508.532455089447 275.148804925846,544.53032898629 PathPoint;PointKind.SMOOTHPOINT 283.096890820656,468.162366925235 283.006045453746,447.986162027723 283.187736187566,488.338336111158 PathPoint;PointKind.SMOOTHPOINT 284.261620330258,414.37109658572 274.784716490371,384.672379197647 293.738524170145,444.069813973794 PathPoint;PointKind.SMOOTHPOINT 283.096890820656,376.60302865427 288.51544579871,356.927475172138 277.678335842602,396.278346424812 PathPoint;PointKind.SMOOTHPOINT 285.03125,343 283.311550739237,327.553819562205 286.750949260763,358.446180437795 PathPoint;PointKind.SMOOTHPOINT 279.03125,309 282.334203729202,270.140823122318 275.728296270798,347.858941166093 PathPoint;PointKind.SMOOTHPOINT 272.03125,271 274.623701054149,266.637685619376 268.691887427251,276.619599997215 PathPoint;PointKind.SMOOTHPOINT 285.596375604387,227.400185542112 288.297699705261,223.198390753707 276.224103004209,241.978004485434 PathPoint;PointKind.SMOOTHPOINT 291.249643903951,210.651698574196 315.390121111613,186.354547963362 286.964711850721,214.964513521095 PathPoint;PointKind.SMOOTHPOINT 341.353868367993,181.463061065069 356.458589665353,178.441002780421 326.249147070633,184.485355061306 PathPoint;PointKind.SMOOTHPOINT 419.01605255831,183.46024536004 432.514896416482,181.435011385958 405.517562184055,185.485479334121 PathPoint;PointKind.SMOOTHPOINT 446.894975682071,181.463061065069 459.215304157843,183.470380958373 434.5746472063,179.455741171764 PathPoint;PointKind.SMOOTHPOINT 479.752012822138,181.463061065069 496.740096434265,178.503466351549 462.763929210011,184.422655778589 PathPoint;PointKind.SMOOTHPOINT 510.617875052466,181.463061065069 529.798972891474,183.354175144917 491.436777213459,179.571946985221 PathPoint;PointKind.SMOOTHPOINT 550.444554602494,182.461771068349 559.985085547609,180.691341322152 540.904023657378,184.232200814546 PathPoint;PointKind.SMOOTHPOINT 575.336185135771,182.461771068349 584.899692535553,181.093701004852 565.773031219907,183.829841131846 PathPoint;PointKind.SMOOTHPOINT 598.729397340914,179.750380658216 612.023220526684,177.845831017786 585.435220671227,181.654930298647 PathPoint;PointKind.SMOOTHPOINT 638.328786731708,178.605765181245 666.595481713447,160.656091954959 610.062445233888,196.555674119121 PathPoint;PointKind.SMOOTHPOINT 682.03125,170 689.346953165621,169.101231710525 674.715546834379,170.898532577886 PathPoint;PointKind.SMOOTHPOINT 709.375519397837,163.727413961741 733.278808896563,162.918216076148 685.471876415193,164.536611847335 PathPoint;PointKind.SMOOTHPOINT 739.657426195733,179.750380658216 748.247085401599,186.78260020928 731.067766989868,172.717925395564 PathPoint;PointKind.SMOOTHPOINT 751.304367807835,178.605765181245 756.554664440951,174.926542986013 746.054071174719,182.285223088066 PathPoint;PointKind.SMOOTHPOINT 766.445497948742,179.750380658216 790.822102413586,186.55466710256 742.068539999981,172.946094213873 PathPoint;PointKind.SMOOTHPOINT 795.562675237037,175.172390173509 806.345348669783,174.197722752324 784.780355288209,176.147057594695 PathPoint;PointKind.SMOOTHPOINT 823.515476499647,185.472750908306 830.558290080621,187.422085750677 816.472662918673,183.523651777524 PathPoint;PointKind.SMOOTHPOINT 845.644630214248,186.617366385277 863.442545482369,185.490664989082 827.846714946128,187.743832069883 PathPoint;PointKind.CORNERPOINT 866.609054419247,180.894760423599 866.609054419247,180.894760423599 866.609054419247,180.894760423599 PathPoint;PointKind.SMOOTHPOINT 885.24437308896,184.328371142924 895.945038252745,185.200032599645 874.543707925176,183.456473974613 PathPoint;PointKind.SMOOTHPOINT 967.937693883272,186.617366385277 985.694605016912,187.350429427572 950.180782749632,185.884067631394 PathPoint;PointKind.SMOOTHPOINT 1006.37270724838,187.76174615066 1022.79663052748,187.868994923728 989.948783969282,187.654497377591 PathPoint;PointKind.SMOOTHPOINT 1043.64299110389,186.617366385277 1065.49925523384,185.995794924657 1021.78672697394,187.238702134309 PathPoint;PointKind.CORNERPOINT 1091.3954870619,186.617366385277 1091.3954870619,186.617366385277 1091.3954870619,186.617366385277 PathPoint;PointKind.SMOOTHPOINT 1085.57183951389,174.027774696538 1098.30150236663,172.400657596552 1072.84217666115,175.655127508113 PathPoint;PointKind.CORNERPOINT 1108.86572273809,174.027774696538 1108.86572273809,174.027774696538 1108.86572273809,174.027774696538 PathPoint;PointKind.SMOOTHPOINT 1126.3363118982,177.461385415863 1137.24623954141,176.643230489881 1115.426384255,178.279540341845 PathPoint;PointKind.SMOOTHPOINT 1148.4654656128,184.328371142924 1158.02861952867,183.438559893837 1138.90231169694,185.217946680422 PathPoint;PointKind.SMOOTHPOINT 1172.92407834661,180.894760423599 1193.68843065405,176.643230489881 1152.15972603916,185.146526068906 PathPoint;PointKind.SMOOTHPOINT 1207.86490318291,175.172390173509 1218.13325751506,176.576288398559 1197.59654885076,173.76849194846 PathPoint;PointKind.SMOOTHPOINT 1225.33549234302,183.183755665952 1237.25532353977,180.492400740899 1213.41530766236,185.875110591006 PathPoint;PointKind.SMOOTHPOINT 1245.13518703842,175.172390173509 1269.12048480611,173.951875564828 1221.14988927073,176.392904782191 PathPoint;PointKind.SMOOTHPOINT 1263.77015222422,184.328371142924 1284.04316188573,180.067648457229 1243.4971425627,188.58885811703 PathPoint;PointKind.SMOOTHPOINT 1292.88768299643,176.316769938892 1313.12887910533,175.127604971568 1272.64648688753,177.506170617804 PathPoint;PointKind.SMOOTHPOINT 1320.84048425904,179.750380658216 1334.03427149603,175.239332264831 1307.64669702205,184.261193340012 PathPoint;PointKind.SMOOTHPOINT 1356.94603860494,179.750380658216 1362.1733587834,181.923170087113 1351.71836494258,177.57759122932 PathPoint;PointKind.SMOOTHPOINT 1372.08681526193,185.472750908306 1392.32801137083,186.433982768909 1351.84597263695,184.511519047703 PathPoint;PointKind.SMOOTHPOINT 1391.88686344125,183.183755665952 1406.35001142755,175.203739814868 1377.42371545494,191.164007228626 PathPoint;PointKind.SMOOTHPOINT 1414.01601715585,176.316769938892 1414.89866649894,183.988475031352 1413.13336781276,168.64530055802 PathPoint;PointKind.SMOOTHPOINT 1429.03125,176 1433.53074679142,162.37799155073 1424.53175320858,189.622244160859 PathPoint;PointKind.SMOOTHPOINT 1439.63935939926,171.739015165773 1445.97697256395,173.267840533079 1433.30174623457,170.209954086879 PathPoint;PointKind.SMOOTHPOINT 1462.93324262346,179.750380658216 1468.11072156948,182.473085224628 1457.75576367744,177.027676091805 PathPoint;PointKind.SMOOTHPOINT 1476.90964325477,179.750380658216 1494.43926422917,176.67458013124 1459.38002228036,182.826181185193 PathPoint;PointKind.SMOOTHPOINT 1494.37987893096,172.883394931156 1505.44463253022,170.116140874392 1483.31547881562,175.650648987919 PathPoint;PointKind.SMOOTHPOINT 1511.85046809107,177.461385415863 1531.26345138024,180.707133998626 1492.43713131798,174.2156368331 PathPoint;PointKind.SMOOTHPOINT 1539.80291586976,179.750380658216 1562.71927826961,178.865047929323 1516.88690695383,180.63547767552 PathPoint;PointKind.SMOOTHPOINT 1592.21432986618,175.172390173509 1607.02318512422,169.923800217636 1577.40547460813,180.420980129383 PathPoint;PointKind.SMOOTHPOINT 1615.50821309038,177.461385415863 1637.20965126428,173.317104255214 1593.80677491648,181.605666576512 PathPoint;PointKind.SMOOTHPOINT 1646.9552028818,175.172390173509 1667.90124592306,172.087632606144 1626.00880635661,178.257147740874 PathPoint;PointKind.SMOOTHPOINT 1674.90765066049,179.750380658216 1686.06784491759,174.184287191742 1663.74745640339,185.316238413102 PathPoint;PointKind.SMOOTHPOINT 1691.213510311,182.03937590057 1701.18175679682,178.637114822604 1681.24526382518,185.441401266947 PathPoint;PointKind.SMOOTHPOINT 1712.177934516,175.172390173509 1735.13989634126,170.120619394586 1689.21632617466,180.224160952432 PathPoint;PointKind.SMOOTHPOINT 1748.2834888619,174.027774696538 1765.21254065974,174.841451102326 1731.35443706407,173.214334002339 PathPoint;PointKind.SMOOTHPOINT 1773.90683110531,182.03937590057 1787.50995271927,174.506269222537 1760.30370949135,189.572482578603 PathPoint;PointKind.SMOOTHPOINT 1803.02436187752,175.172390173509 1819.44828515662,174.738680849451 1786.60008511451,175.606099497568 PathPoint;PointKind.SMOOTHPOINT 1825.15351559212,176.316769938892 1843.78848077792,174.304971525393 1806.51819692241,178.32856835239 PathPoint;PointKind.SMOOTHPOINT 1853.10596337082,174.027774696538 1865.16259284381,174.036731736926 1841.04968738174,174.019053367739 PathPoint;PointKind.SMOOTHPOINT 1895.03516526473,183.183755665952 1923.33367379909,182.759003382282 1866.73665673038,183.608507949623 PathPoint;PointKind.CORNERPOINT 1928.81126059144,185.472750908306 1928.81126059144,185.472750908306 1928.81126059144,185.472750908306 PathPoint;PointKind.SMOOTHPOINT 1970.74046248535,176.316769938892 2011.65021675994,172.489992288844 1929.83035472685,180.143783300528 PathPoint;PointKind.SMOOTHPOINT 2033.63373510035,172.883394931156 2076.58662642061,176.866685076407 1990.681197264,168.900104785905 PathPoint;PointKind.SMOOTHPOINT 2100.02154972807,188.906361627631 2106.25453165305,186.724615158346 2093.78856780309,191.087872385327 PathPoint;PointKind.SMOOTHPOINT 2137.29183358358,178.605765181245 2160.3082319322,174.787944571586 2114.27543523495,182.423821502494 PathPoint;PointKind.SMOOTHPOINT 2187.37378856079,169.45001992342 2205.06247729827,170.259217809014 2169.68474633939,168.640822037826 PathPoint;PointKind.SMOOTHPOINT 2223.47934290669,182.03937590057 2235.82229435321,180.487922220705 2211.13603797626,183.590593868846 PathPoint;PointKind.SMOOTHPOINT 2270.0671093551,177.461385415863 2290.28992430027,176.240870807181 2249.84394092601,178.681900024544 PathPoint;PointKind.SMOOTHPOINT 2302.6784751722,176.316769938892 2332.77869123628,178.641593342798 2272.57825910812,173.992182246574 PathPoint;PointKind.SMOOTHPOINT 2351.59570063981,177.461385415863 2379.5757201641,170.02657047051 2323.61568111552,184.896200361215 PathPoint;PointKind.SMOOTHPOINT 2385.37179596651,172.883394931156 2414.42994144051,173.151634719622 2356.31365049251,172.615155142689 PathPoint;PointKind.SMOOTHPOINT 2417.98316178361,182.03937590057 2433.63861102512,177.447949855281 2402.32806602603,186.63080194586 PathPoint;PointKind.SMOOTHPOINT 2437.78320996293,175.172390173509 2456.57759639571,172.342436834029 2418.98882353014,178.00234351299 PathPoint;PointKind.SMOOTHPOINT 2464.57128171594,179.750380658216 2480.3126275495,179.017081904333 2448.82958239845,180.483443700511 PathPoint;PointKind.SMOOTHPOINT 2534.45293138855,177.461385415863 2560.1126824755,177.336222562018 2508.79318030159,177.586548269708 PathPoint;PointKind.SMOOTHPOINT 2564.73483818644,180.894760423599 2573.90703888907,180.085562538005 2555.56299096773,181.703958309192 PathPoint;PointKind.SMOOTHPOINT 2584.53488636576,176.316769938892 2603.03800205016,176.008459180267 2566.03141719743,176.625316409105 PathPoint;PointKind.SMOOTHPOINT 2614.81679316365,180.894760423599 2622.04165096236,182.428300022688 2607.59193536494,179.361456536099 PathPoint;PointKind.SMOOTHPOINT 2643.93432393587,178.605765181245 2661.48197259009,176.37051218122 2626.38632179773,180.841253892859 PathPoint;PointKind.SMOOTHPOINT 2669.55766617927,182.03937590057 2685.39445267068,183.416403004455 2653.72052620395,180.662348796685 PathPoint;PointKind.SMOOTHPOINT 2691.68681989387,180.894760423599 2702.4691398427,175.516529093686 2680.90414646113,186.272991753511 PathPoint;PointKind.SMOOTHPOINT 2734.78039781347,174.027774696538 2775.84957333505,174.255943514847 2693.7112222919,173.799841589818 PathPoint;PointKind.SMOOTHPOINT 2794.17983538358,176.316769938892 2808.99328593256,177.050068692775 2779.3663848346,175.583706896597 PathPoint;PointKind.SMOOTHPOINT 2827.95593071028,178.605765181245 2856.36826106621,173.030950385971 2799.54395383827,184.180815688108 PathPoint;PointKind.SMOOTHPOINT 2909.48487547891,176.316769938892 2922.86035344973,175.628492098538 2896.10904402418,177.005283490834 PathPoint;PointKind.SMOOTHPOINT 2949.08426486971,177.461385415863 2978.01056084232,172.972729623448 2920.1579688971,181.949805496688 PathPoint;PointKind.SMOOTHPOINT 2998.03125,171 3007.86764698443,172.573610569247 2988.19520649949,169.426389430754 PathPoint;PointKind.SMOOTHPOINT 3035.27177419282,179.750380658216 3055.69041922853,175.731262351413 3014.85312915712,183.76949896502 PathPoint;PointKind.SMOOTHPOINT 3070.21259902913,176.316769938892 3089.77121769249,174.381106368692 3050.65398036576,178.25266922068 PathPoint;PointKind.SMOOTHPOINT 3103.98869435583,177.461385415863 3124.45753410788,178.25266922068 3083.5202080877,176.670101611046 PathPoint;PointKind.SMOOTHPOINT 3142.42370772094,179.750380658216 3160.49946134856,176.486717994677 3124.34830757724,183.014043321756 PathPoint;PointKind.SMOOTHPOINT 3182.02345059565,176.316769938892 3212.66944582902,173.969789645604 3151.37745536228,178.663985943768 PathPoint;PointKind.SMOOTHPOINT 3219.29373445116,178.605765181245 3241.94604436431,179.106652308215 3196.64142453801,178.105113765865 PathPoint;PointKind.SMOOTHPOINT 3258.89312384196,176.316769938892 3275.46303597916,173.017514825389 3242.32356518867,179.616260763983 PathPoint;PointKind.SMOOTHPOINT 3283.35173657576,175.172390173509 3312.52829916227,173.263362012885 3254.17552747317,177.081418334134 PathPoint;PointKind.SMOOTHPOINT 3322.95147945047,174.027774696538 3347.00535309824,176.491196514871 3298.89795928662,171.564588589793 PathPoint;PointKind.SMOOTHPOINT 3366.04541085399,175.172390173509 3385.32654464177,170.482672395539 3346.76392358229,179.862107951479 PathPoint;PointKind.SMOOTHPOINT 3396.32731765189,174.027774696538 3417.68304855404,170.080312712839 3374.97158674973,177.975472391826 PathPoint;PointKind.SMOOTHPOINT 3452.23256669319,171.739015165773 3470.76325412319,170.241303728237 3433.7022327471,173.236490891721 PathPoint;PointKind.SMOOTHPOINT 3490.6675800583,169.45001992342 3522.11881165673,165.104441065627 3459.21634845987,173.795363069624 PathPoint;PointKind.SMOOTHPOINT 3523.27929935932,171.739015165773 3542.92416809866,169.034224680138 3503.63407713606,174.44356993982 PathPoint;PointKind.SMOOTHPOINT 3580.34927791022,166.016409204095 3603.92524130094,166.159486138716 3556.77331451951,165.873332269473 PathPoint;PointKind.SMOOTHPOINT 3639.74871548033,168.305404446448 3654.02062866703,168.019250577206 3625.47644880971,168.591558315691 PathPoint;PointKind.SMOOTHPOINT 3703.03125,162 3721.02040006772,160.336819026872 3685.04209993228,163.662945261539 PathPoint;PointKind.SMOOTHPOINT 3746.90064900845,164.872029438713 3786.62305080269,163.722935441547 3707.17824721421,166.020887724289 PathPoint;PointKind.SMOOTHPOINT 3799.31206300487,166.016409204095 3844.13912605803,164.483105316595 3754.48464646778,167.549948803184 PathPoint;PointKind.SMOOTHPOINT 3856.38204155577,164.872029438713 3864.88050191081,161.831821361699 3847.88322771681,167.912001804137 PathPoint;PointKind.SMOOTHPOINT 3884.33448933446,164.872029438713 3906.13631694105,160.039234726121 3862.53301521179,169.704824151304 PathPoint;PointKind.SMOOTHPOINT 3943.73428038849,167.161024681066 3962.41944029063,168.537816073362 3925.04912048635,165.783997577181 PathPoint;PointKind.SMOOTHPOINT 3972.85145767678,164.872029438713 3988.84342360817,163.164063263644 3956.85984522932,166.579759902192 PathPoint;PointKind.SMOOTHPOINT 4003.1337179586,167.161024681066 4030.41737416456,166.870392291629 3975.84970826873,167.451421358914 PathPoint;PointKind.SMOOTHPOINT 4041.56837783979,162.583034196359 4054.23017178029,157.446171533748 4028.90693738321,167.719661147381 PathPoint;PointKind.SMOOTHPOINT 4076.50955616001,159.149423477034 4100.26296847753,161.769357790571 4052.75614384249,156.529724875086 PathPoint;PointKind.SMOOTHPOINT 4109.12092197711,160.294038954005 4124.30729805952,160.253732272259 4093.93419241079,160.334109924163 PathPoint;PointKind.SMOOTHPOINT 4147.55593534222,160.294038954005 4162.90597447863,156.981112568331 4132.2055427219,163.60672962809 PathPoint;PointKind.SMOOTHPOINT 4176.67311263052,158.005043711652 4210.41279911367,157.213759906835 4142.93342614736,158.796327516469 PathPoint;PointKind.SMOOTHPOINT 4213.03125,160 4226.97088830384,165.847768815524 4199.09125821224,154.152466896065 PathPoint;PointKind.SMOOTHPOINT 4265.19008097284,160.294038954005 4287.86501385674,153.212555680807 4242.51479460503,167.375522227204 PathPoint;PointKind.SMOOTHPOINT 4298.96617629954,159.149423477034 4323.05610530694,157.499913776077 4274.87624729215,160.79916888958 PathPoint;PointKind.SMOOTHPOINT 4421.25923996857,156.86042823468 4433.8980574544,158.125728045303 4408.62042248274,155.595364135647 PathPoint;PointKind.SMOOTHPOINT 4450.37641725686,160.294038954005 4469.08455361367,156.029073459706 4431.66863438397,164.559004448305 PathPoint;PointKind.SMOOTHPOINT 4486.48197160277,156.86042823468 4501.45943868967,158.139163605885 4471.50485799978,155.581928575065 PathPoint;PointKind.SMOOTHPOINT 4527.24644398708,158.005043711652 4573.07457349584,157.83957417606 4481.41831447832,158.170513247244 PathPoint;PointKind.SMOOTHPOINT 4598.29282316929,161.438418719388 4634.73524768899,159.444534386665 4561.85075213351,163.43230305211 PathPoint;PointKind.SMOOTHPOINT 4660.02171975861,156.86042823468 4670.56755896633,154.665481916403 4649.47588055088,159.055610264548 PathPoint;PointKind.SMOOTHPOINT 4700.78619214292,162.583034196359 4725.78598875509,164.840679797354 4675.78604204684,160.325388595364 PathPoint;PointKind.SMOOTHPOINT 4767.17365328672,163.727413961741 4799.27105348714,157.285180518351 4735.0762530863,170.169647405132 PathPoint;PointKind.SMOOTHPOINT 4819.58506728314,162.583034196359 4847.92422646805,164.572440008888 4791.2455546143,160.593628383831 PathPoint;PointKind.SMOOTHPOINT 4856.85535113865,164.872029438713 4882.24645444797,158.572872929943 4831.46389434541,171.171185947482 PathPoint;PointKind.SMOOTHPOINT 4981.47752034296,166.016409204095 5007.80606300265,167.084889837767 4955.14897768327,164.947928570423 PathPoint;PointKind.SMOOTHPOINT 5025.73618125608,168.305404446448 5050.1400039826,173.804320110012 5001.33200504563,162.806488782885 PathPoint;PointKind.SMOOTHPOINT 5065.33557064687,171.739015165773 5090.34031603389,165.001670812752 5040.33117874377,178.476123807206 PathPoint;PointKind.SMOOTHPOINT 5109.59423155999,163.727413961741 5123.62506871466,163.821462885817 5095.5630409214,163.633600749255 PathPoint;PointKind.SMOOTHPOINT 5129.39392625539,166.016409204095 5161.94626025819,167.210052691612 5096.84159225258,164.822765716578 PathPoint;PointKind.SMOOTHPOINT 5209.75778803049,170.594399688802 5239.78518640748,163.392232081953 5179.73074313743,177.796567295651 PathPoint;PointKind.SMOOTHPOINT 5245.8633423764,162.583034196359 5255.65413993542,165.028541933916 5236.07254481739,160.137526458802 PathPoint;PointKind.SMOOTHPOINT 5284.29835574151,166.016409204095 5314.4165994854,166.526017659863 5254.18011199762,165.506800748326 PathPoint;PointKind.SMOOTHPOINT 5340.20360478281,166.016409204095 5362.80607346353,159.824501468394 5317.60148958601,172.208316939795 PathPoint;PointKind.SMOOTHPOINT 5390.28555976003,159.149423477034 5411.90074785795,153.431531747139 5368.67037166211,164.867550918519 PathPoint;PointKind.SMOOTHPOINT 5413.57944298423,158.005043711652 5434.03449686348,163.083685611739 5393.12474258889,152.926401811564 PathPoint;PointKind.SMOOTHPOINT 5443.86170326604,162.583034196359 5465.41291077482,157.227195467417 5422.31014227335,167.938872925301 PathPoint;PointKind.SMOOTHPOINT 5470.64977501905,159.149423477034 5486.9326582149,165.243039480054 5454.36653833929,153.056043185603 PathPoint;PointKind.SMOOTHPOINT 5517,169 5542.6823740577,167.752849981743 5491.3176259423,170.247385729846 PathPoint;PointKind.SMOOTHPOINT 5552.17836630376,172.883394931156 5569.36192652251,169.999699349346 5534.9944526011,175.767090512965 PathPoint;PointKind.SMOOTHPOINT 5580.13081408245,172.883394931156 5596.27301067896,177.407643173534 5563.98897096987,168.359146688777 PathPoint;PointKind.SMOOTHPOINT 5620.89528646677,170.594399688802 5646.80070887669,168.528859032974 5594.98986405685,172.65994034463 PathPoint;PointKind.SMOOTHPOINT 5647.68335821978,169.45001992342 5661.63106921052,170.781740844421 5634.04951361056,168.148266817708 PathPoint;PointKind.SMOOTHPOINT 5669,187 5672.69916814425,200.178472213077 5665.22790692751,173.561946199595 PathPoint;PointKind.SMOOTHPOINT 5674.32084582375,222.949243603963 5677.20268471851,224.198121415829 5662.10689948703,217.656190406936 PathPoint;PointKind.SMOOTHPOINT 5683.15334848123,248.371445629868 5676.04681305678,257.519954104442 5685.27488635457,245.640310687994 PathPoint;PointKind.SMOOTHPOINT 5673.15611631414,264.150922254739 5663.54276768193,279.056144595407 5682.76946494635,249.24569991407 PathPoint;PointKind.SMOOTHPOINT 5670.82665729494,290.474249686011 5681.23605171034,302.299192979508 5660.41726287953,278.649306392513 PathPoint;PointKind.SMOOTHPOINT 5678,311 5675.05653941534,320.822101920387 5680.94381406858,301.177898079613 PathPoint;PointKind.SMOOTHPOINT 5679,330 5673.37677783346,336.54076088766 5684.62322216654,323.459474823929 PathPoint;PointKind.SMOOTHPOINT 5678,356 5678.07281768709,365.299057904036 5677.9271823129,346.700942095964 PathPoint;PointKind.SMOOTHPOINT 5677.96526501767,375.458413177298 5682.72421900486,393.698718793022 5673.20666451441,357.218107561575 PathPoint;PointKind.SMOOTHPOINT 5683.78891256568,401.78174060857 5677.31025931774,411.000185149112 5690.26756581363,392.563296068028 PathPoint;PointKind.SMOOTHPOINT 5684.95364207529,422.382697789753 5683.3339787633,445.384141794962 5686.57330538727,399.381018072954 PathPoint;PointKind.SMOOTHPOINT 5681.45945354648,483.040718144739 5675.20384865075,501.8978809893 5687.71505844221,464.183319588589 PathPoint;PointKind.SMOOTHPOINT 5679.12999452728,516.230795591483 5674.34841756934,536.326622837091 5683.91157148521,496.135204057464 PathPoint;PointKind.SMOOTHPOINT 5673.30670046318,566.588455211673 5668.47033349797,589.380115902528 5678.14271394448,543.797030232407 PathPoint;PointKind.SMOOTHPOINT 5667.48305291517,611.223744581773 5666.67322125918,625.391189648364 5668.29288457117,597.056063803593 PathPoint;PointKind.SMOOTHPOINT 5673.30670046318,637.547072013045 5673.811475498,658.058458790346 5672.80157194445,617.035685235744 PathPoint;PointKind.SMOOTHPOINT 5672.14197095358,698.205092368032 5667.76513308169,730.461044786926 5676.51845534156,665.949139949138 PathPoint;PointKind.SMOOTHPOINT 5667.48305291517,749.707131753604 5667.96096317223,763.181820459647 5667.00549614204,736.23267875915 PathPoint;PointKind.SMOOTHPOINT 5668.64778242478,780.608449669583 5668.62975474496,796.609023765088 5668.66616358851,764.607875574078 PathPoint;PointKind.SMOOTHPOINT 5671,811 5667.56024799456,824.738449974316 5674.43939852153,797.261550025684 PathPoint;PointKind.SMOOTHPOINT 5671,832 5673.57053505124,846.587954541656 5668.42946494876,817.412281169933 PathPoint;PointKind.SMOOTHPOINT 5673,869 5669.09595988799,878.848044577979 5680.62781568874,849.758165313714 PathPoint;PointKind.SMOOTHPOINT 5674,901 5673.52208974295,910.848973041551 5674.47755677313,891.151026958449 PathPoint;PointKind.SMOOTHPOINT 5668.64778242478,913.369466591325 5668.53855589413,925.453692632901 5668.75700895542,901.285240549749 PathPoint;PointKind.SMOOTHPOINT 5668.64778242478,931.681428530154 5665.74956778161,943.600185036137 5671.54599706794,919.76267202417 PathPoint;PointKind.SMOOTHPOINT 5666.31832340557,1002.63980961994 5664.50318348697,1018.32735872503 5668.1338168081,986.95226051484 PathPoint;PointKind.SMOOTHPOINT 5666.31832340557,1024.3851465665 5667.19637745773,1034.71685694266 5665.44026935342,1014.05343619035 PathPoint;PointKind.SMOOTHPOINT 5670.97724144398,1049.56409423239 5668.82523135158,1056.91829581425 5673.12925153638,1042.20965693894 PathPoint;PointKind.SMOOTHPOINT 5663.98921787029,1072.45381094434 5663.40667637353,1085.48135476574 5664.57140588313,1059.42626712294 PathPoint;PointKind.SMOOTHPOINT 5666.31832340557,1093.05476812552 5668.19744391332,1099.33153203332 5664.43955638174,1086.77800421772 PathPoint;PointKind.SMOOTHPOINT 5668.64778242478,1107.93311934502 5667.27379043576,1116.6419554298 5670.0217744138,1099.22428326025 PathPoint;PointKind.SMOOTHPOINT 5668.64778242478,1125.10046580688 5669.26213747415,1136.53648497826 5668.03378085932,1113.6644466355 PathPoint;PointKind.SMOOTHPOINT 5665.15359389597,1147.99041823042 5662.3695545583,1156.99860803343 5667.93798671756,1138.98199271582 PathPoint;PointKind.SMOOTHPOINT 5672.14197095358,1169.73575517698 5672.37845169468,1192.82229106588 5671.90549021248,1146.64921928809 PathPoint;PointKind.SMOOTHPOINT 5667.48305291517,1204.0704481007 5666.48693523443,1213.26650004027 5668.47952407984,1194.87416044954 PathPoint;PointKind.SMOOTHPOINT 5672.14197095358,1228.10478028962 5669.99915144305,1236.9611718292 5674.28479046411,1219.24838875003 PathPoint;PointKind.SMOOTHPOINT 5667.48305291517,1249.85011723618 5664.66684654097,1260.50805245174 5670.29925928938,1239.19194630904 PathPoint;PointKind.SMOOTHPOINT 5670.97724144398,1281.89581491754 5671.90089492155,1290.2157268802 5670.05358796641,1273.57590295489 PathPoint;PointKind.SMOOTHPOINT 5672.14197095358,1302.49677209872 5668.31586102583,1324.77858862222 5675.96808088133,1280.21495557523 PathPoint;PointKind.SMOOTHPOINT 5669.81251193438,1331.10909477235 5668.68419126832,1348.44167505821 5670.94083260043,1313.7762787749 PathPoint;PointKind.SMOOTHPOINT 5672.14197095358,1356.28780672665 5671.35935755927,1369.42259932112 5672.92458434789,1343.15301413218 PathPoint;PointKind.SMOOTHPOINT 5672.14197095358,1379.1775234386 5671.96452202678,1394.75782377063 5672.31941988039,1363.59745881816 PathPoint;PointKind.SMOOTHPOINT 5672.14197095358,1405.50085086987 5670.68137540467,1426.0615013693 5673.60221301858,1384.94043608202 PathPoint;PointKind.SMOOTHPOINT 5672.14197095358,1440.98015927055 5673.03345739462,1459.01940290072 5671.25013102863,1422.94091564039 PathPoint;PointKind.SMOOTHPOINT 5674.47142997279,1475.31485219427 5673.41592699383,1498.24511129955 5675.52693295175,1452.38482880058 PathPoint;PointKind.SMOOTHPOINT 5673.30670046318,1518.8055260874 5675.14905864347,1534.59160263677 5671.46398879898,1503.01968524962 PathPoint;PointKind.SMOOTHPOINT 5675.63615948239,1565.72981069985 5671.75985483829,1581.02843568283 5679.51211064256,1550.43118571687 PathPoint;PointKind.SMOOTHPOINT 5670.97724144398,1596.63112861583 5670.84079665166,1607.39206979585 5671.1136862363,1585.87018743581 PathPoint;PointKind.SMOOTHPOINT 5674.47142997279,1618.3764655624 5675.54496063156,1636.80439760309 5673.39754583009,1599.94829781011 PathPoint;PointKind.SMOOTHPOINT 5676.80053550807,1652.71115848611 5672.02814913201,1669.06035002199 5681.57327536805,1636.36196695024 PathPoint;PointKind.SMOOTHPOINT 5673.30670046318,1682.46786092512 5673.12925153638,1697.65475861484 5673.48414938999,1667.2809632354 PathPoint;PointKind.SMOOTHPOINT 5680.29472403688,1706.50219311404 5679.57149594078,1721.35838744416 5681.01830561689,1691.6462344955 PathPoint;PointKind.SMOOTHPOINT 5680.29472403688,1732.82552054531 5678.65243775414,1746.86355994945 5681.93701031961,1718.78771685276 PathPoint;PointKind.SMOOTHPOINT 5681.45945354648,1754.57085749187 5681.96458206521,1773.93786450379 5680.95432502775,1735.20385047996 PathPoint;PointKind.SMOOTHPOINT 5679.12999452728,1791.19454565794 5678.89810907711,1803.35490654282 5679.36223346136,1779.03442048466 PathPoint;PointKind.SMOOTHPOINT 5682.62418305608,1812.93988260451 5680.15827924455,1828.03744560193 5685.09008686761,1797.84255531867 PathPoint;PointKind.SMOOTHPOINT 5680.29472403688,1838.1188302704 5680.77263429393,1853.6453883601 5679.81716726374,1822.5922721807 PathPoint;PointKind.SMOOTHPOINT 5679.12999452728,1873.59813867108 5679.32582461781,1891.62371102908 5678.93451792066,1855.5723306015 PathPoint;PointKind.SMOOTHPOINT 5679.12999452728,1898.77685062538 5679.19821692344,1908.86271381404 5679.06177213111,1888.69098743672 PathPoint;PointKind.SMOOTHPOINT 5681,1925 5680.39024024156,1933.47194593767 5681.60940627452,1916.52805406233 PathPoint;PointKind.SMOOTHPOINT 5673.34346279065,1948.98860477188 5672.11051088489,1959.36510034998 5674.57641469641,1938.61210919379 PathPoint;PointKind.SMOOTHPOINT 5675.67292180985,1969.58956195306 5675.00872552805,1981.43666213594 5676.33711809166,1957.7422260586 PathPoint;PointKind.SMOOTHPOINT 5674.50819230025,1997.05726914972 5667.05144905137,2008.34573286628 5681.96493554913,1985.76880543315 PathPoint;PointKind.SMOOTHPOINT 5673.34346279065,2017.6582263309 5675.91399784189,2034.05196735713 5670.77292773941,2001.26424959308 PathPoint;PointKind.SMOOTHPOINT 5679.16711033866,2047.41492876991 5674.02604023619,2059.52602593265 5684.30818044113,2035.30383160717 PathPoint;PointKind.SMOOTHPOINT 5684.95364207529,2071.59516643252 5686.69136901586,2085.28883120489 5683.21556165079,2057.90150166014 PathPoint;PointKind.SMOOTHPOINT 5679,2092 5674.27285956543,2103.34668447909 5683.72678695065,2080.6535512325 PathPoint;PointKind.SMOOTHPOINT 5687,2120 5694.32948903842,2128.3646971646 5679.67051096158,2111.6353028354 PathPoint;PointKind.SMOOTHPOINT 5679,2148 5676.41567907596,2164.85007866285 5681.58432092404,2131.15015704874 PathPoint;PointKind.SMOOTHPOINT 5675.67292180985,2164.15297899517 5676.62838884004,2175.12865343292 5674.71745477967,2153.17754026902 PathPoint;PointKind.SMOOTHPOINT 5680.33183984826,2180.17594569165 5682.53828646402,2189.37223334281 5678.12503974858,2170.97989375208 PathPoint;PointKind.SMOOTHPOINT 5675.67292180985,2198.48790763048 5674.54919643473,2204.53673843156 5676.79664718497,2192.4390768294 PathPoint;PointKind.SMOOTHPOINT 5681.49656935786,2208.78826836528 5682.90697019043,2216.75956288756 5680.08616852529,2200.81697384299 PathPoint;PointKind.SMOOTHPOINT 5682.66129886747,2223.66661958478 5682.02432084734,2230.3191077657 5683.29792340367,2217.01436711545 PathPoint;PointKind.SMOOTHPOINT 5679.16711033866,2238.54497080428 5673.92140899648,2246.87383980733 5684.41281168084,2230.21610180124 PathPoint;PointKind.SMOOTHPOINT 5675.67292180985,2253.42332202379 5680.4863123204,2259.21287007679 5670.85953129931,2247.63400968238 PathPoint;PointKind.SMOOTHPOINT 5682.66129886747,2263.72391847017 5679.95396553999,2275.01238218674 5685.36827871103,2252.43545475361 PathPoint;PointKind.SMOOTHPOINT 5679.16711033866,2279.74664945506 5675.63191767537,2285.08033129462 5682.70194951803,2274.41320332709 PathPoint;PointKind.SMOOTHPOINT 5679.16711033866,2296.91399591692 5681.76486365158,2312.39152599607 5676.56935702574,2281.43670154935 PathPoint;PointKind.SMOOTHPOINT 5682.66129886747,2319.80394834045 5679.84509249326,2324.18511964821 5685.47750524167,2315.4227770327 PathPoint;PointKind.SMOOTHPOINT 5676.83765131946,2333.53791979457 5671.61033114101,2338.8265807206 5682.06497149791,2328.24902315695 PathPoint;PointKind.SMOOTHPOINT 5676.83765131946,2342.6936650524 5683.11623266985,2348.34461469097 5670.55906996906,2337.04295112541 PathPoint;PointKind.SMOOTHPOINT 5678.00238082906,2355.28325674114 5670.2543668318,2361.9175951297 5685.75039482631,2348.64868264099 PathPoint;PointKind.SMOOTHPOINT 5686.15513391235,2370.16160796064 5683.80764721333,2382.41130353781 5688.50297409529,2357.91191238347 PathPoint;PointKind.SMOOTHPOINT 5680.33183984826,2387.3289544225 5673.11157734048,2396.86490247364 5687.55210235604,2377.79300637136 PathPoint;PointKind.SMOOTHPOINT 5684.99040440275,2405.64091636133 5684.61747886933,2413.34373538356 5685.36368342009,2397.93786162751 PathPoint;PointKind.SMOOTHPOINT 5682.66129886747,2426.24163783092 5682.37462341002,2434.7046267282 5682.94762084099,2417.77864893364 PathPoint;PointKind.SMOOTHPOINT 5683.82567489315,2446.8425950121 5685.26364747132,2455.95826929977 5682.3880557989,2437.72692072444 PathPoint;PointKind.SMOOTHPOINT 5678.00238082906,2459.43195098925 5673.71214651706,2465.98591172591 5682.29261514106,2452.8779902526 PathPoint;PointKind.CORNERPOINT 5676.83765131946,2472.0213069664 5676.83765131946,2472.0213069664 5676.83765131946,2472.0213069664 PathPoint;PointKind.SMOOTHPOINT 5682.66129886747,2474.31030220876 5691.10956450616,2485.41090378876 5674.21267974486,2463.20970062876 PathPoint;PointKind.SMOOTHPOINT 5686,2487 5684.77164338517,2491.56455492412 5687.22835661483,2482.43544507588 PathPoint;PointKind.SMOOTHPOINT 5674.50819230025,2492.62226414759 5674.53541056193,2509.24417399212 5674.48097403857,2476.00011859146 PathPoint;PointKind.SMOOTHPOINT 5681.49656935786,2509.78961060944 5687.84761491143,2509.15908210844 5675.14517032037,2510.41990339886 PathPoint;PointKind.SMOOTHPOINT 5689.64932244116,2516.65659633651 5688.38455698278,2529.03569757612 5690.91408789954,2504.2772593853 PathPoint;PointKind.SMOOTHPOINT 5675.67292180985,2523.52334635198 5675.05432495346,2541.29882871387 5676.29187215016,2505.74809970167 PathPoint;PointKind.SMOOTHPOINT 5678.00238082906,2550.99128926022 5682.28342455919,2555.03280016799 5673.72133709892,2546.94977835245 PathPoint;PointKind.SMOOTHPOINT 5686,2550 5688.56134446937,2558.27960528091 5683.43865553063,2541.72039471909 PathPoint;PointKind.SMOOTHPOINT 5684.99040440275,2559.00265475266 5685.18163920235,2570.85446916733 5684.79952308706,2547.150840338 PathPoint;PointKind.SMOOTHPOINT 5679.16711033866,2577.31461669149 5673.83021014565,2585.13835575896 5684.50365704775,2569.49087762402 PathPoint;PointKind.SMOOTHPOINT 5676.83765131946,2586.47059766091 5680.71855125448,2592.68018376579 5672.95675138443,2580.26077584443 PathPoint;PointKind.SMOOTHPOINT 5687.31986342195,2588.75959290326 5688.1661039215,2599.03756103709 5686.47362292241,2578.48138905784 PathPoint;PointKind.SMOOTHPOINT 5687.31986342195,2605.92693936512 5686.89214788125,2612.85191014311 5687.74757896266,2599.00173287553 PathPoint;PointKind.SMOOTHPOINT 5675.67292180985,2600.20433340344 5676.95606843196,2610.46462316808 5674.39012867166,2589.94427935039 PathPoint;PointKind.SMOOTHPOINT 5684.99040440275,2623.09428582698 5691.40083525454,2630.55125766171 5678.58032703488,2615.63707828065 PathPoint;PointKind.CORNERPOINT 5687.31986342195,2636.82802156951 5687.31986342195,2636.82802156951 5687.31986342195,2636.82802156951 PathPoint;PointKind.SMOOTHPOINT 5678.00238082906,2641.40601205421 5673.24342684187,2654.40692046604 5682.76133481624,2628.40533935398 PathPoint;PointKind.SMOOTHPOINT 5681.49656935786,2662.0069692354 5685.44993349607,2666.17812151721 5677.54285173574,2657.83581695358 PathPoint;PointKind.SMOOTHPOINT 5690.81405195076,2666.5849597201 5687.08338268085,2677.00600478855 5694.54472122067,2656.16367894007 PathPoint;PointKind.SMOOTHPOINT 5678.046875,2681 5679.79414600636,2691.98439576654 5676.29995747756,2670.01560423345 PathPoint;PointKind.SMOOTHPOINT 5691.97878146036,2684.89668594734 5694.11241038903,2696.41331848222 5689.84479904778,2673.38028912406 PathPoint;PointKind.SMOOTHPOINT 5690.81405195076,2710.07563361323 5690.68220244937,2713.86681881332 5690.94590145215,2706.28444841315 PathPoint;PointKind.SMOOTHPOINT 5680,2715 5679.59031213911,2729.27469383966 5680.40933437697,2700.72507044875 PathPoint;PointKind.SMOOTHPOINT 5690.81405195076,2726.09860030971 5695.47261650525,2734.30654926751 5686.15513391235,2717.89041564032 PathPoint;PointKind.SMOOTHPOINT 5676.83765131946,2735.25434556753 5677.1243267769,2743.8024263485 5676.55097586201,2726.70650049816 PathPoint;PointKind.SMOOTHPOINT 5690.81405195076,2748.98831702166 5693.384587002,2760.11578972282 5688.24351689952,2737.86084432049 PathPoint;PointKind.SMOOTHPOINT 5682.66129886747,2762.72228847578 5681.000631421,2769.62038813261 5684.32161283001,2755.82395310736 PathPoint;PointKind.SMOOTHPOINT 5693.14351096996,2776.45602421831 5692.31989344117,2788.90253897243 5693.96677501484,2764.00974517578 PathPoint;PointKind.SMOOTHPOINT 5689.64932244116,2798.20136116487 5683.93949671472,2810.00414756899 5695.35914816759,2786.39881047235 PathPoint;PointKind.SMOOTHPOINT 5687.31986342195,2816.5133231037 5690.231510454,2832.26357149152 5684.40821638991,2800.76307471589 PathPoint;PointKind.SMOOTHPOINT 5693.14351096996,2842.83665053497 5689.04875326458,2852.04613803513 5697.23791519143,2833.62716303482 PathPoint;PointKind.SMOOTHPOINT 5691,2861 5690.29479958372,2866.87911845688 5691.70520041628,2855.12111725471 PathPoint;PointKind.SMOOTHPOINT 5687.31986342195,2877.17134345869 5694.32626815938,2889.89481933007 5680.31345868453,2864.44786758731 PathPoint;PointKind.SMOOTHPOINT 5698.96680503406,2898.91668040525 5692.57935063694,2906.40948040154 5705.35461291509,2891.42388040897 PathPoint;PointKind.SMOOTHPOINT 5681,2901 5681.47791025705,2915.81565193679 5680.52244322687,2886.18411235162 PathPoint;PointKind.SMOOTHPOINT 5682.50819230025,2922.24000783653 5692.00771911089,2928.7673331636 5673.00866548962,2915.71291822104 PathPoint;PointKind.SMOOTHPOINT 5694.30824047957,2912.65065185938 5699.43092941831,2912.64169481899 5689.18519805691,2912.65960889976 PathPoint;PointKind.SMOOTHPOINT 5703.62572307246,2925.24000783653 5701.47371298006,2932.33492667031 5705.77773316486,2918.14508900275 PathPoint;PointKind.SMOOTHPOINT 5697,2945 5693.95155469171,2950.2306758751 5700.04809182437,2939.7693241249 PathPoint;PointKind.SMOOTHPOINT 5684.99040440275,2957.28570551789 5676.76023834143,2973.76925265959 5693.22057046407,2940.80239408778 PathPoint;PointKind.SMOOTHPOINT 5684.99040440275,2973.30867221436 5687.53831648324,2981.47655020201 5682.44284580618,2965.14079422672 PathPoint;PointKind.SMOOTHPOINT 5694.30824047957,2988.18702343387 5700.32276934326,3008.97112851983 5688.29335813195,2967.40291834791 PathPoint;PointKind.SMOOTHPOINT 5697.80207552445,3033.96669256935 5692.68398187665,3060.59856647083 5702.92052265618,3007.33505437945 PathPoint;PointKind.SMOOTHPOINT 5698.96680503406,3111.79229509778 5689.09722194316,3156.74453389918 5706.61386712389,3076.96265388357 PathPoint;PointKind.CORNERPOINT 5695.47261650525,3243.40869654255 5695.47261650525,3243.40869654255 5695.47261650525,3243.40869654255 PathPoint;PointKind.SMOOTHPOINT 5697.80207552445,3277.74338946627 5697.93427850976,3295.59924948007 5697.67022602306,3259.88752945247 PathPoint;PointKind.SMOOTHPOINT 5687.31986342195,3310.9337026246 5685.34530225636,3322.90172285272 5689.29442458755,3298.96568239648 PathPoint;PointKind.CORNERPOINT 5682.66129886747,3348.70200626764 5682.66129886747,3348.70200626764 5682.66129886747,3348.70200626764 PathPoint;PointKind.SMOOTHPOINT 5689.61220662977,3363.72626296084 5688.40682646961,3383.98284551025 5690.81794027386,3343.46968041142 PathPoint;PointKind.SMOOTHPOINT 5694.27112466818,3387.76059514975 5694.66702665627,3395.99541522872 5693.87522268009,3379.5255393592 PathPoint;PointKind.SMOOTHPOINT 5684.95364207529,3416.37291782338 5680.85428907897,3421.56776553692 5689.05264158768,3411.17783439825 PathPoint;PointKind.SMOOTHPOINT 5681.45945354648,3431.25126904288 5685.09008686761,3441.43990248442 5677.82882022535,3421.06263560135 PathPoint;PointKind.SMOOTHPOINT 5684.95364207529,3454.14098575483 5682.26468991154,3464.73197887906 5687.64224075511,3443.5499926306 PathPoint;PointKind.SMOOTHPOINT 5682.62418305608,3480.4643131861 5679.97163973588,3491.87346123632 5685.27672637628,3469.05516513589 PathPoint;PointKind.SMOOTHPOINT 5684.95364207529,3499.92065489031 5693.35666177248,3503.98903691925 5676.55062237809,3495.85250857296 PathPoint;PointKind.SMOOTHPOINT 5690,3523 5682.00207287276,3536.6757506916 5697.99828061116,3509.32401359681 PathPoint;PointKind.SMOOTHPOINT 5681.45945354648,3547.98931926815 5682.92004909539,3558.07070393661 5679.99921148148,3537.90793459968 PathPoint;PointKind.SMOOTHPOINT 5684.95364207529,3567.44566097236 5688.0971745575,3581.78753261493 5681.80975610915,3553.10378932979 PathPoint;PointKind.SMOOTHPOINT 5686.11837158489,3594.9136038806 5683.89354380539,3601.42277941532 5688.34284588046,3588.4041926343 PathPoint;PointKind.SMOOTHPOINT 5682.62418305608,3616.65894082717 5674.65312070661,3624.79994769365 5690.59489192164,3608.5176982491 PathPoint;PointKind.SMOOTHPOINT 5676.80053550807,3639.54865753911 5677.49230353547,3654.78929747116 5676.10912096459,3624.30825331866 PathPoint;PointKind.SMOOTHPOINT 5684,3664 5671.43400020126,3670.3484202309 5696.56564631482,3657.65181548068 PathPoint;PointKind.SMOOTHPOINT 5675,3686 5672.99822057272,3702.02296669648 5677.00177942728,3669.97703330352 PathPoint;PointKind.SMOOTHPOINT 5669.81251193438,3707.07366362116 5680.98189677335,3725.64938682826 5658.64312709541,3688.49817612565 PathPoint;PointKind.SMOOTHPOINT 5687,3722 5687.04984123243,3738.31336337432 5686.94980528365,3705.68640091409 PathPoint;PointKind.SMOOTHPOINT 5686.046875,3751 5681.96590316742,3760.36623570695 5690.12784683258,3741.63400000464 PathPoint;PointKind.SMOOTHPOINT 5673.046875,3773 5650.55363284992,3773.72882023369 5695.53976366616,3772.2714154779 PathPoint;PointKind.SMOOTHPOINT 5650.01281723898,3778.03228042253 5636.57335867902,3779.01119065233 5663.45227579894,3777.05313448116 PathPoint;PointKind.SMOOTHPOINT 5625.55420450518,3775.74328518018 5615.70437513187,3774.69271862729 5635.40403387849,3776.79385173308 PathPoint;PointKind.SMOOTHPOINT 5596.43667373296,3774.59866970321 5585.77701270366,3776.42284169174 5607.09633476227,3772.77473342627 PathPoint;PointKind.SMOOTHPOINT 5564.99003742546,3775.74328518018 5557.26464639895,3775.83709839267 5572.71507496806,3775.64923625611 PathPoint;PointKind.SMOOTHPOINT 5545.18998924615,3773.45428993783 5529.74415596798,3772.1934686474 5560.63582252432,3774.71487551667 PathPoint;PointKind.SMOOTHPOINT 5512.57862342905,3773.45428993783 5507.96530481606,3773.26194928107 5517.19194204204,3773.64639488299 PathPoint;PointKind.SMOOTHPOINT 5493.046875,3774 5483.16947388109,3774.04478520194 5502.92392263499,3773.95521479806 PathPoint;PointKind.SMOOTHPOINT 5460.046875,3779 5454.38724398991,3779.40683820289 5465.70685949401,3778.59316179711 PathPoint;PointKind.SMOOTHPOINT 5430.046875,3781 5424.94680903201,3783.22629595964 5435.14694096799,3778.77346832877 PathPoint;PointKind.CORNERPOINT 5414.046875,3776 5414.046875,3776 5414.046875,3776 PathPoint;PointKind.SMOOTHPOINT 5381.046875,3777 5380.79204131865,3777.07450867264 5396.20307919749,3772.56805416127 PathPoint;PointKind.SMOOTHPOINT 5344,3785 5338.6344339178,3790.12117576806 5348.97919583919,3780.24759611839 PathPoint;PointKind.SMOOTHPOINT 5304.09805043691,3789.47702092271 5295.90373386225,3795.78966754161 5322.07974178998,3775.6249245496 PathPoint;PointKind.SMOOTHPOINT 5262.16920202691,3786.04364591498 5245.57242511194,3783.04374451971 5278.76597894188,3789.04354731024 PathPoint;PointKind.SMOOTHPOINT 5238.87531880271,3787.18802568036 5214.04802234249,3784.32247989092 5263.702261779,3790.05380718139 PathPoint;PointKind.SMOOTHPOINT 5208.59305852089,3784.8992661496 5202.49687487215,3789.13736052273 5214.68959565355,3780.66093606487 PathPoint;PointKind.SMOOTHPOINT 5186.46390480629,3791.76601616507 5176.76890138904,3794.00150487668 5196.15926170746,3789.53076316504 PathPoint;PointKind.SMOOTHPOINT 5137.54667933868,3784.8992661496 5112.73316875127,3785.00651492266 5162.3601899261,3784.79178166494 PathPoint;PointKind.SMOOTHPOINT 5108.42950205039,3794.05501140742 5096.8734058052,3800.0189860364 5119.98524481166,3788.09127249003 PathPoint;PointKind.SMOOTHPOINT 5054.85335854437,3787.18802568036 5037.28732872642,3785.56986562076 5072.41938836232,3788.80642145155 PathPoint;PointKind.SMOOTHPOINT 4984.046875,3801 4963.81001528644,3797.40111234749 5009.25713274474,3805.4833480391 PathPoint;PointKind.SMOOTHPOINT 4960.51309613796,3790.62163639969 4934.88975389455,3789.12840348234 4986.13643838136,3792.11486931703 PathPoint;PointKind.SMOOTHPOINT 4919.74862375364,3796.34400664977 4909.57571007934,3795.89261895653 4929.92153742795,3796.79563005461 PathPoint;PointKind.SMOOTHPOINT 4889.46671695575,3792.91063164204 4869.32555679562,3795.72714942094 4909.60787711587,3790.09411386314 PathPoint;PointKind.SMOOTHPOINT 4847.53751506183,3796.34400664977 4830.79510277267,3794.3859504786 4864.28028083491,3798.30229853253 PathPoint;PointKind.SMOOTHPOINT 4814.92614924473,3798.63300189213 4799.93984505988,3798.88780612001 4829.91245342958,3798.37819766424 PathPoint;PointKind.SMOOTHPOINT 4784.64424244683,3792.91063164204 4770.07186792989,3792.54410012089 4799.21661696378,3793.27716316319 PathPoint;PointKind.SMOOTHPOINT 4715.92696879991,3802.06661261145 4698.02901758301,3802.29454571817 4733.82527350072,3801.83844379314 PathPoint;PointKind.SMOOTHPOINT 4679,3795 4658.20383413994,3790.30580370184 4699.79616586006,3799.69419629816 PathPoint;PointKind.SMOOTHPOINT 4653.046875,3795 4633.67913765232,3793.60081600673 4672.41425886376,3796.39941970486 PathPoint;PointKind.SMOOTHPOINT 4602.9517412077,3800.92199713448 4587.18282362854,3801.35570645854 4618.72065878686,3800.48828781042 PathPoint;PointKind.SMOOTHPOINT 4536.046875,3794 4512.739205903,3793.23087308456 4559.354544097,3794.76889120385 PathPoint;PointKind.SMOOTHPOINT 4452.046875,3800 4412.69280344825,3797.92550230378 4491.40094655175,3802.07426198463 PathPoint;PointKind.SMOOTHPOINT 4404.95338031806,3788.33264115733 4377.76056947901,3784.96620824092 4432.1461911571,3791.69907407375 PathPoint;PointKind.SMOOTHPOINT 4350.21286078636,3784.8992661496 4340.98162826944,3785.2971473121 4359.44373981936,3784.5011492755 PathPoint;PointKind.SMOOTHPOINT 4325.75424805255,3790.62163639969 4316.5322061175,3789.07913976021 4334.97628998761,3792.16389732757 PathPoint;PointKind.SMOOTHPOINT 4308.28365889244,3784.8992661496 4285.28104641662,3779.48072813794 4331.28662485218,3790.31756844967 PathPoint;PointKind.SMOOTHPOINT 4271.01337503693,3775.74328518018 4258.94331317506,3772.39028782435 4283.0834368988,3779.09628253601 PathPoint;PointKind.SMOOTHPOINT 4245.39003279353,3781.46565543027 4229.38463447326,3782.76654769086 4261.39578459771,3780.16476316968 PathPoint;PointKind.SMOOTHPOINT 4222.09614956932,3781.46565543027 4203.44280321979,3774.78653183977 4240.74949591885,3788.14477902077 PathPoint;PointKind.SMOOTHPOINT 4179.00257164972,3783.75465067262 4168.3839147549,3782.98128094858 4189.62122854455,3784.52802039666 PathPoint;PointKind.SMOOTHPOINT 4153.37922940632,3778.03228042253 4138.84326373292,3776.54352602539 4167.91519507972,3779.52103481968 PathPoint;PointKind.SMOOTHPOINT 4102.1325449195,3780.32127566489 4089.88079232381,3780.68780718604 4114.38465099911,3779.95450843215 PathPoint;PointKind.SMOOTHPOINT 4073.01536763121,3781.46565543027 4052.48749606486,3782.0021350072 4093.54288571364,3780.92917585334 PathPoint;PointKind.SMOOTHPOINT 4041.56837783979,3776.88766494556 4022.64214190562,3774.43767868781 4060.49496725788,3779.33765120331 PathPoint;PointKind.SMOOTHPOINT 4005.46282349389,3778.03228042253 3990.60412700341,3781.69358853699 4020.32187346828,3774.37073659649 PathPoint;PointKind.SMOOTHPOINT 3965.86343410309,3783.75465067262 3945.40378493291,3785.27923323132 3986.32272978936,3782.23006811392 PathPoint;PointKind.SMOOTHPOINT 3923.93423220918,3784.8992661496 3903.32470585778,3778.07235139269 3944.54411204448,3791.72594519491 PathPoint;PointKind.SMOOTHPOINT 3886.66394835367,3779.17666018792 3872.21458624016,3778.05019450331 3901.11366395109,3780.30336158411 PathPoint;PointKind.SMOOTHPOINT 3851.72312351736,3788.33264115733 3830.32179318979,3784.29560876975 3873.12445384493,3792.36967354491 PathPoint;PointKind.SMOOTHPOINT 3816.78229868106,3782.61027090724 3781.40916301312,3781.08568834854 3852.155434349,3784.13461775435 PathPoint;PointKind.SMOOTHPOINT 3772.52399125186,3796.34400664977 3752.85155076692,3796.83593673636 3792.1964317368,3795.85231227478 PathPoint;PointKind.CORNERPOINT 3496,3792 3496,3792 3496,3792 PathPoint;PointKind.CORNERPOINT 3304.046875,3798 3304.046875,3798 3304.046875,3798 PathPoint;PointKind.CORNERPOINT 3228.61121704406,3794.05501140742 3228.61121704406,3794.05501140742 3228.61121704406,3794.05501140742 PathPoint;PointKind.SMOOTHPOINT 3113.30653043265,3789.47702092271 3098.37466277116,3788.16269310155 3128.23804461022,3790.79158445547 PathPoint;PointKind.SMOOTHPOINT 3022.46010307112,3794.05501140742 2997.32350818271,3792.94645980359 3047.59669795953,3795.16379872284 PathPoint;PointKind.SMOOTHPOINT 2974.70760711311,3783.75465067262 2946.58195221463,3785.3820034842 3002.8332620116,3782.12729786105 PathPoint;PointKind.SMOOTHPOINT 2935,3794 2909.76336916282,3793.09698890192 2960.23663083718,3794.90324680967 PathPoint;PointKind.SMOOTHPOINT 2882.6968037259,3787.18802568036 2855.07168205522,3785.90952602074 2910.32192539659,3788.46676105156 PathPoint;PointKind.SMOOTHPOINT 2832.61484874869,3790.62163639969 2818.87068705147,3790.38026773238 2846.35901044591,3790.86300506699 PathPoint;PointKind.SMOOTHPOINT 2795.34456489318,3789.47702092271 2769.6074008282,3786.29397162267 2821.08172895817,3792.66030593435 PathPoint;PointKind.SMOOTHPOINT 2742.93315089677,3794.05501140742 2714.84850013277,3792.56625701027 2771.01780166077,3795.54376580457 PathPoint;PointKind.CORNERPOINT 2666.06347765047,3790.62163639969 2666.06347765047,3790.62163639969 2666.06347765047,3790.62163639969 PathPoint;PointKind.SMOOTHPOINT 2626.46373477575,3791.76601616507 2588.64767175095,3792.45005119682 2664.27979780056,3791.08198113332 PathPoint;PointKind.SMOOTHPOINT 2558.91154412235,3789.47702092271 2527.44193136019,3788.2833774352 2590.3808034006,3790.67090012182 PathPoint;PointKind.SMOOTHPOINT 2520.47653075724,3788.33264115733 2499.40747531253,3787.8765392323 2541.54558620195,3788.78874308236 PathPoint;PointKind.SMOOTHPOINT 2484.37097641133,3787.18802568036 2461.64584881109,3788.61879502657 2507.09610401158,3785.75749204574 PathPoint;PointKind.SMOOTHPOINT 2430.79483290532,3780.32127566489 2416.35006608274,3780.76370631775 2445.23995321181,3779.87860930044 PathPoint;PointKind.SMOOTHPOINT 2399.34819659782,3781.46565543027 2384.53015075791,3783.47297532358 2414.16624243773,3779.45833553697 PathPoint;PointKind.SMOOTHPOINT 2345.7720530918,3784.8992661496 2330.0261119673,3793.01340189491 2361.51834770022,3776.78489469269 PathPoint;PointKind.SMOOTHPOINT 2308.50212272021,3792.91063164204 2281.42278021882,3791.50673341699 2335.58111173768,3794.3142941555 PathPoint;PointKind.SMOOTHPOINT 2252.59652019499,3787.18802568036 2223.38814405587,3784.92590155917 2281.80489633411,3789.45038551314 PathPoint;PointKind.CORNERPOINT 2214.16150682988,3784.8992661496 2214.16150682988,3784.8992661496 2214.16150682988,3784.8992661496 PathPoint;PointKind.SMOOTHPOINT 2113.99795035937,3795.19962688439 2096.90947731455,3797.02804168152 2131.08606992028,3793.37097637567 PathPoint;PointKind.SMOOTHPOINT 2084.88041958716,3795.19962688439 2067.53743812143,3791.75705912468 2102.2234010529,3798.64195893252 PathPoint;PointKind.SMOOTHPOINT 2046.44540622205,3791.76601616507 2032.25090601338,3793.3443409661 2060.64025991464,3790.18792707563 PathPoint;PointKind.SMOOTHPOINT 2013.046875,3801 2008.04684498078,3800.81685209522 2018.04690501922,3801.18338361637 PathPoint;PointKind.SMOOTHPOINT 1836.80045720423,3790.62163639969 1821.44087400203,3792.33832390355 1852.1596869225,3788.90494889582 PathPoint;PointKind.CORNERPOINT 1815.83567951531,3794.05501140742 1815.83567951531,3794.05501140742 1815.83567951531,3794.05501140742 PathPoint;PointKind.SMOOTHPOINT 1804.18873790321,3790.62163639969 1794.84863233956,3789.45486403333 1813.52919695077,3791.78840876604 PathPoint;PointKind.SMOOTHPOINT 1766.91880753162,3787.18802568036 1733.98859922054,3785.04658589282 1799.84866235878,3789.32970117949 PathPoint;PointKind.SMOOTHPOINT 1721.4954171089,3788.33264115733 1703.04249614084,3787.10764802846 1739.94869156087,3789.55763428621 PathPoint;PointKind.SMOOTHPOINT 1681.8960277181,3787.18802568036 1657.98319415359,3787.48761511018 1705.80850779869,3786.88867196212 PathPoint;PointKind.SMOOTHPOINT 1631.81407274089,3789.47702092271 1621.88223509862,3790.65746456124 1641.74591038316,3788.29681299578 PathPoint;PointKind.SMOOTHPOINT 1601.53181245908,3790.62163639969 1583.1061097527,3789.11496792176 1619.95786864937,3792.12830487761 PathPoint;PointKind.SMOOTHPOINT 1557.27350502987,3787.18802568036 1525.49459383951,3784.13461775435 1589.05241622023,3790.24166931796 PathPoint;PointKind.SMOOTHPOINT 1468.75653668755,3791.76601616507 1448.77479777442,3795.55720136515 1488.7386290846,3787.97506667657 PathPoint;PointKind.CORNERPOINT 1386.06321589324,3789.47702092271 1386.06321589324,3789.47702092271 1386.06321589324,3789.47702092271 PathPoint;PointKind.CORNERPOINT 1186.90047897791,3794.05501140742 1186.90047897791,3794.05501140742 1186.90047897791,3794.05501140742 PathPoint;PointKind.SMOOTHPOINT 1169.4298898178,3780.32127566489 1157.64190812244,3780.8711908024 1181.21787151316,3779.77136052737 PathPoint;PointKind.SMOOTHPOINT 1160.1124072249,3794.05501140742 1134.89875284239,3795.91477584591 1185.32641509134,3792.19524696893 PathPoint;PointKind.CORNERPOINT 1110.03045224769,3794.05501140742 1110.03045224769,3794.05501140742 1110.03045224769,3794.05501140742 PathPoint;PointKind.SMOOTHPOINT 1092.046875,3794 1079.21258090755,3794.39788116251 1104.88116909245,3793.60211883749 PathPoint;PointKind.SMOOTHPOINT 1069.2663333473,3797.48862212675 1064.42077580022,3796.77771597383 1074.11153741046,3798.19929256807 PathPoint;PointKind.SMOOTHPOINT 1038.98407306548,3789.47702092271 1028.24240376722,3790.28174028811 1049.72574236375,3788.67230155731 PathPoint;PointKind.CORNERPOINT 993.561036126679,3791.76601616507 993.561036126679,3791.76601616507 993.561036126679,3791.76601616507 PathPoint;PointKind.SMOOTHPOINT 901.550232739469,3790.62163639969 886.795814004785,3791.08645965351 916.304297990236,3790.15657743427 PathPoint;PointKind.SMOOTHPOINT 849.138818743054,3791.76601616507 809.448230501432,3788.65462318813 888.829406984676,3794.8776448536 PathPoint;PointKind.SMOOTHPOINT 793.233569701751,3788.33264115733 767.546246869197,3789.50837056407 818.920539050386,3787.15691175059 PathPoint;PointKind.SMOOTHPOINT 741.986885214937,3791.76601616507 730.412761289931,3792.87928200068 753.561009139944,3790.65298604104 PathPoint;PointKind.SMOOTHPOINT 710.539895423521,3794.05501140742 637.992270041833,3793.87186350264 783.087874289127,3794.23839502379 PathPoint;PointKind.SMOOTHPOINT 631.340763158015,3792.91063164204 625.594528588033,3792.96861669297 637.086997727996,3792.85241087952 PathPoint;PointKind.SMOOTHPOINT 580.094078671201,3788.33264115733 565.530894736121,3788.41749732943 594.657262606282,3788.24778498523 PathPoint;PointKind.CORNERPOINT 552.141630892509,3788.33264115733 552.141630892509,3788.33264115733 552.141630892509,3788.33264115733 PathPoint;PointKind.SMOOTHPOINT 533.506312222795,3795.19962688439 527.528192202647,3795.46338815266 539.484432242944,3794.93586561612 PathPoint;PointKind.SMOOTHPOINT 477.601063181492,3796.34400664977 432.378098140241,3794.80174572189 522.824028222744,3797.88650328925 PathPoint;PointKind.CORNERPOINT 403.060495470476,3792.91063164204 403.060495470476,3792.91063164204 403.060495470476,3792.91063164204 PathPoint;PointKind.SMOOTHPOINT 374.046875,3785 356.417218076817,3784.00741849804 391.676531923183,3785.99258150196 PathPoint;PointKind.SMOOTHPOINT 357.637458531672,3788.33264115733 351.581925533496,3789.26700189677 363.692991529848,3787.39828041789 PathPoint;PointKind.SMOOTHPOINT 322.696633695368,3791.76601616507 314.461872343111,3797.32315259115 330.931395047625,3786.20911545057 PathPoint;PointKind.CORNERPOINT 292.414373413553,3805.49998761919 292.414373413553,3805.49998761919 292.414373413553,3805.49998761919 PathPoint";

	subshadow35mm[0] = "PointKind.SMOOTHPOINT 287.855626344681,200.660862922668 292.166204452515,190.522005558014 287.380914900276,201.777451823742 PathPoint;PointKind.SMOOTHPOINT 344.977247714996,175.894718170166 346.733554194725,176.167673052534 325.558580160141,172.876310348511 PathPoint;PointKind.SMOOTHPOINT 471.19354494132,176.161331640455 476.865871013888,176.155410105195 391.396535393849,176.244634468892 PathPoint;PointKind.SMOOTHPOINT 488.740327852304,176.141150423414 500.897814484698,171.872664781138 483.055906934986,178.136946907004 PathPoint;PointKind.SMOOTHPOINT 503.113075418348,176.122144616904 511.805509697971,176.110047470048 498.217334670437,176.128957955134 PathPoint;PointKind.SMOOTHPOINT 530.170246622674,176.081384757395 621.082297512359,175.934800062272 520.827017332319,176.096449585474 PathPoint;PointKind.SMOOTHPOINT 887.513562894867,175.256101633025 893.376991913983,175.240207055258 742.45429881262,175.649328147112 PathPoint;PointKind.SMOOTHPOINT 905.219507034274,175.207891790952 912.719029541803,170.19313211713 900.281376807829,178.509906859085 PathPoint;PointKind.SMOOTHPOINT 918.21928396284,175.172233056621 937.797014679486,175.118368025311 913.865972247053,175.184210505656 PathPoint;PointKind.SMOOTHPOINT 978.150131958018,175.005191685763 983.185386162394,174.990985875354 957.779154710699,175.062663707804 PathPoint;PointKind.SMOOTHPOINT 993.32692963344,174.962251331822 998.035948720156,172.039841690114 989.008411876269,177.642316478946 PathPoint;PointKind.SMOOTHPOINT 1003.92635849084,174.932119698142 1253.87986434547,174.220212003006 1000.38197354179,174.942214675251 PathPoint;PointKind.SMOOTHPOINT 1893.68237101377,172.161948184789 1898.83403401963,172.145095821086 1559.61245738628,173.254773488028 PathPoint;PointKind.SMOOTHPOINT 1909.15747562936,172.111300676797 1914.09807751306,175.642630250335 1904.95542406475,169.107855082736 PathPoint;PointKind.SMOOTHPOINT 1921.81061148061,172.069852963637 2161.03206869345,171.285936190356 1917.58851877243,172.083688550673 PathPoint;PointKind.SMOOTHPOINT 2671.55422100393,169.575020993615 2676.65665715333,169.557885400489 2414.25858963557,170.439101037563 PathPoint;PointKind.SMOOTHPOINT 2686.86625273405,169.523594224769 2692.16252757179,173.321293831526 2682.71709871962,166.548438846371 PathPoint;PointKind.SMOOTHPOINT 2705.97123242759,169.459417560487 2756.36452459343,169.29012334414 2699.60063855373,169.480819311616 PathPoint;PointKind.SMOOTHPOINT 2857.49297273443,168.950131000759 2859.89209587126,168.942064623651 2806.89655551426,169.120247230029 PathPoint;PointKind.SMOOTHPOINT 2864.69076850863,168.925930286279 2873.67827572904,167.490457844797 2862.32138147479,169.304365563923 PathPoint;PointKind.SMOOTHPOINT 2882.56621915569,168.865827737837 3689.9702985986,166.151073908612 2876.60697287562,168.885864652525 PathPoint;PointKind.SMOOTHPOINT 5042.75907049592,161.968652242387 5047.3947712691,161.956273559802 4510.63325782362,163.389584449405 PathPoint;PointKind.SMOOTHPOINT 5056.60027936947,161.931822328874 5061.31039419752,168.327591412142 5053.87743278909,158.234524362034 PathPoint;PointKind.SMOOTHPOINT 5067.411686436,161.903239589226 5103.21035803984,161.808871640356 5063.82166503629,161.91270315144 PathPoint;PointKind.SMOOTHPOINT 5170.59031700767,161.639721890361 5176.63836091957,161.624826564013 5137.63548469378,161.720884161866 PathPoint;PointKind.SMOOTHPOINT 5188.58528545909,161.595728310416 5192.08030319246,166.474157560406 5185.12099746937,156.760192370757 PathPoint;PointKind.SMOOTHPOINT 5201.35021781587,161.564929323649 5336.07752712553,161.241715457018 5197.12134878866,161.57507447623 PathPoint;PointKind.SMOOTHPOINT 5518.59742395898,160.998444800981 5522.90185261745,160.995932997751 5444.22955762419,161.041841372682 PathPoint;PointKind.SMOOTHPOINT 5534,164 5537.87966654926,163.998613464974 5529.92333120504,164.001456940693 PathPoint;PointKind.SMOOTHPOINT 5542.49624628169,160.98977619723 5552.34082822873,160.988650381006 5538.82532962708,160.990195999467 PathPoint;PointKind.SMOOTHPOINT 5569.741784569,160.996994327863 5574.03484024288,161.00007981521 5561.43042023756,160.991020818217 PathPoint;PointKind.SMOOTHPOINT 5581.99485205691,161.009149426975 5583.68137219608,158.63182969229 5577.77129532474,166.962677366997 PathPoint;PointKind.SMOOTHPOINT 5590.37989751626,161.022148526078 5618.16134118445,161.072933628857 5587.70510897682,161.017258952574 PathPoint;PointKind.SMOOTHPOINT 5633.14030051231,161.362316608429 5637.25296378136,164.753422737122 5632.92401675328,161.183982267966 PathPoint;PointKind.SMOOTHPOINT 5666.00230693817,174.965686798096 5667.6003856858,179.984958619728 5664.40422819054,169.946414976464 PathPoint;PointKind.SMOOTHPOINT 5669.8506443429,1199.24597503043 5669.87294851043,1204.33466365357 5667.3097578856,619.543549895564 PathPoint;PointKind.SMOOTHPOINT 5669.91771077866,1214.54239408881 5673.69645157989,1220.21671812216 5667.0859513337,1210.29009907296 PathPoint;PointKind.SMOOTHPOINT 5669.99255541317,1231.60198478935 5670.23672547263,1287.23844464136 5669.96754597113,1225.90334663074 PathPoint;PointKind.SMOOTHPOINT 5670.74090027295,1401.67122109089 5670.7656286106,1407.2790666426 5670.48668007038,1344.01964530097 PathPoint;PointKind.SMOOTHPOINT 5670.81520496771,1418.51921094902 5673.47415668551,1426.34722698794 5669.00635546608,1413.1939157148 PathPoint;PointKind.SMOOTHPOINT 5670.91602502503,1441.37129476491 5672.08007484834,1705.16731188616 5670.88234943715,1433.73976063363 PathPoint;PointKind.SMOOTHPOINT 5674.50838318537,2257.0507372369 5674.53553969105,2263.2793138599 5673.3250766575,1985.64927408387 PathPoint;PointKind.SMOOTHPOINT 5674.58975349575,2275.72180789473 5675.27928296313,2278.02520024825 5672.58952565705,2269.0399911966 PathPoint;PointKind.SMOOTHPOINT 5674.62115957324,2282.93259198981 5674.86700128355,2339.38722583658 5674.61069606234,2280.52977077882 PathPoint;PointKind.SMOOTHPOINT 5675.34875612232,2450.77214719319 5675.36971063736,2455.63016167801 5675.10996429798,2395.41156551882 PathPoint;PointKind.SMOOTHPOINT 5675.4115224339,2465.33069917497 5679.94040065598,2470.81001229793 5672.32311664926,2461.59415747192 PathPoint;PointKind.SMOOTHPOINT 5675.47634683333,2480.38171185083 5676.71609364966,2768.37718997562 5675.4547747676,2475.3704810878 PathPoint;PointKind.SMOOTHPOINT 5678.65061107034,3253.27503868869 5678.67290440747,3259.18821107822 5677.83564742227,3037.11087656916 PathPoint;PointKind.SMOOTHPOINT 5675,3267 5675.02002980104,3272.35182222261 5674.97816628484,3261.16618458686 PathPoint;PointKind.SMOOTHPOINT 5678.77630504368,3286.84976242696 5679.19171168825,3398.62821869103 5678.75666814435,3281.56582602064 PathPoint;PointKind.SMOOTHPOINT 5679.72924113274,3571.27944231033 5679.74871397018,3578.35197687149 5679.51855290146,3495.0991628044 PathPoint;PointKind.SMOOTHPOINT 5678.00005316734,3593.00003528595 5675.70933938026,3597.062895298 5681.59438490868,3586.62451028824 PathPoint;PointKind.SMOOTHPOINT 5679.81987833977,3605.7005739212 5679.83262419701,3610.86689472198 5679.80854868889,3601.21025562286 PathPoint;PointKind.SMOOTHPOINT 5679.85634565353,3620.85020542145 5679.8751103878,3628.80928516388 5679.84501600266,3615.91755867004 PathPoint;PointKind.SMOOTHPOINT 5676.99985742569,3645.99990606308 5670.69207429886,3657.25685834885 5680.58640003204,3639.59959745407 PathPoint;PointKind.SMOOTHPOINT 5676.99985742569,3670.99996089935 5675.11665701866,3722.14035272598 5677.31673359871,3662.39886760712 PathPoint;PointKind.SMOOTHPOINT 5675.00017404556,3755.99995851517 5675.17330527306,3761.37351751328 5674.73109483719,3747.67455339432 PathPoint;PointKind.SMOOTHPOINT 5646.00016236305,3785.00008821487 5644.08769240066,3785.18367130122 5653.04508090019,3784.75319623947 PathPoint;PointKind.SMOOTHPOINT 5494.75876832582,3785.73978062023 5490.01116063421,3785.75490637188 5590.24337798862,3785.43556919705 PathPoint;PointKind.SMOOTHPOINT 5480.20838138221,3785.78554389618 5476.7261078205,3783.67409124221 5485.97595627201,3789.28267331241 PathPoint;PointKind.SMOOTHPOINT 5467.78566288231,3785.82374967105 5456.58620024504,3785.85786176418 5471.99485794973,3785.81092901538 PathPoint;PointKind.SMOOTHPOINT 5432.75517327598,3785.92787129073 5425.94236594187,3785.94766268735 5444.90495343152,3785.8925758382 PathPoint;PointKind.SMOOTHPOINT 5411.87713344337,3785.9877902459 5408.57246069933,3785.08554658224 5422.35125149725,3788.84744001413 PathPoint;PointKind.SMOOTHPOINT 5401.49945779951,3786.0170646238 5307.52808698239,3786.28071708227 5404.99220988834,3786.00726512138 PathPoint;PointKind.SMOOTHPOINT 5052.06761144045,3786.88965157516 5041.88727199653,3786.91304243884 5189.35107190102,3786.57422214113 PathPoint;PointKind.SMOOTHPOINT 5021.21347029394,3786.96018262324 5017.71508633914,3785.3590436527 5031.99323137793,3791.89385936872 PathPoint;PointKind.SMOOTHPOINT 5009.62908657489,3786.98648366355 4778.70465552341,3787.50982254415 5013.50460335072,3786.97770066643 PathPoint;PointKind.SMOOTHPOINT 4189.86746669577,3788.69142015693 4183.19303101845,3788.70445353884 4498.00208558828,3788.08971592871 PathPoint;PointKind.SMOOTHPOINT 4169.80577429423,3788.7305506498 4163.14620295046,3785.28842774591 4176.73402148074,3792.31154364373 PathPoint;PointKind.SMOOTHPOINT 4147.26903056859,3788.77440364402 4116.65842495292,3788.83389250634 4154.79689533462,3788.75977393965 PathPoint;PointKind.SMOOTHPOINT 4054.68919557624,3788.95342601764 4049.26515434391,3788.96386322555 4085.791350308,3788.89357771605 PathPoint;PointKind.SMOOTHPOINT 4038.39573656874,3788.98475234554 4034.86603829164,3785.73485627924 4043.64806456992,3793.82072379972 PathPoint;PointKind.SMOOTHPOINT 4023.98547587657,3789.0124144046 3886.77208925488,3789.27561719244 4028.7943210671,3789.00319007532 PathPoint;PointKind.SMOOTHPOINT 3600.96824034362,3789.80800793245 3593.3839156647,3789.82201234496 3745.16304447133,3789.54175304419 PathPoint;PointKind.SMOOTHPOINT 3578.19406896657,3789.85002174847 3570.3080452281,3787.87404434383 3586.85891037787,3792.02114517029 PathPoint;PointKind.SMOOTHPOINT 3553.78133126209,3789.89497341869 3129.6633157093,3790.67515272765 3561.92658315644,3789.87998995474 PathPoint;PointKind.SMOOTHPOINT 2265.43387094823,3792.15988199648 2259.34294969513,3792.17013258964 2685.03457560615,3791.45372344754 PathPoint;PointKind.SMOOTHPOINT 2247.17706775766,3792.1905877846 2243.7204890735,3789.86447550243 2255.1293373058,3797.54208519209 PathPoint;PointKind.SMOOTHPOINT 2234.68561081518,3792.2115748641 2173.4723514836,3792.31437614192 2238.84685825403,3792.2045864835 PathPoint;PointKind.SMOOTHPOINT 2052.86758440972,3792.51499463958 2046.43016858363,3792.52566846977 2112.81878940585,3792.41559000283 PathPoint;PointKind.SMOOTHPOINT 2033.57980797139,3792.54695327476 2029.04760350624,3790.4343579307 2042.30991161821,3796.61631432395 PathPoint;PointKind.SMOOTHPOINT 2018.59378579682,3792.57175331589 1857.28963661415,3792.83854634573 2023.58405267188,3792.56349953925 PathPoint;PointKind.SMOOTHPOINT 1553.48944370496,3793.32717045649 1547.84838889426,3793.33615173296 1701.31582313473,3793.09181206574 PathPoint;PointKind.SMOOTHPOINT 1536.6020283441,3793.35403581331 1532.53727323744,3790.26719320884 1541.8897983553,3797.36965626889 PathPoint;PointKind.SMOOTHPOINT 1521.31993460531,3793.3783098995 1424.53906763685,3793.53192316107 1526.40396289743,3793.37024038957 PathPoint;PointKind.SMOOTHPOINT 1242.70459484187,3793.81406768243 1236.24072639795,3793.82401368668 1331.39724740975,3793.67759561356 PathPoint;PointKind.SMOOTHPOINT 1223.38419714675,3793.84375860661 1219.00626395165,3791.25833293509 1234.37947412211,3800.33711291122 PathPoint;PointKind.SMOOTHPOINT 1208.17639511095,3793.86707593208 1059.47209485634,3794.09484283119 1213.230522957,3793.85933464265 PathPoint;PointKind.SMOOTHPOINT 805.490419360469,3794.46308401484 797.722782191484,3794.47407103077 923.918697450048,3794.29557189364 PathPoint;PointKind.SMOOTHPOINT 787,3796 779.220773756147,3798.00726074561 800.704917190525,3792.46374312354 PathPoint;PointKind.SMOOTHPOINT 758.558404389301,3794.52897619758 475.536698052162,3794.92324258319 766.424781977348,3794.51801785696 PathPoint;PointKind.SMOOTHPOINT 298.768204450607,3794.98410701752 281.525892019272,3794.30149555206 301.863462281234,3795.10668603238 PathPoint;PointKind.SMOOTHPOINT 260.20136475563,3752.15873479843 259.793510191034,3750.19554331869 260.31466126442,3755.2859544754 PathPoint;PointKind.SMOOTHPOINT 260.739305325708,3534.16112929512 260.766891718786,3528.89633401897 260.029105809147,3669.70096044557 PathPoint;PointKind.SMOOTHPOINT 260.824202843828,3518.11896456872 262.440648666887,3514.54532586588 258.039323696615,3524.27577586499 PathPoint;PointKind.SMOOTHPOINT 260.888170177073,3506.22513710721 261.269174634947,3435.83561625209 260.866481713259,3510.23202087036 PathPoint;PointKind.SMOOTHPOINT 262.34867602528,3258.89114389127 262.390732119286,3252.17551024621 261.762750683696,3352.45332626612 PathPoint;PointKind.SMOOTHPOINT 262.476264171508,3238.58794364782 258.209940721183,3230.89213763882 266.128413424798,3245.17587175419 PathPoint;PointKind.SMOOTHPOINT 262.64503454412,3211.93617879144 262.698835543081,3203.47529316624 262.588008815168,3220.90419387818 PathPoint;PointKind.SMOOTHPOINT 262.808463049048,3186.33283230837 262.84435612928,3180.73059634023 262.753316207998,3194.94021887044 PathPoint;PointKind.SMOOTHPOINT 262.916985194174,3169.43474221387 263.525754113427,3165.1776962477 262.061923732456,3175.41408155153 PathPoint;PointKind.SMOOTHPOINT 263.000510330431,3156.48207830695 263.367406859968,3099.68411385843 262.972509118435,3160.81684769141 PathPoint;PointKind.SMOOTHPOINT 264.179408005607,2977.77013157736 264.220801423324,2971.61051991882 263.761594002336,3039.94359169675 PathPoint;PointKind.SMOOTHPOINT 264.304280399115,2959.22015326099 261.972412351449,2953.98008905448 268.009758335965,2967.54692900815 PathPoint;PointKind.SMOOTHPOINT 264.420885064151,2941.95455733737 265.726583020275,2748.91750185582 264.381823752273,2947.72946155067 PathPoint;PointKind.SMOOTHPOINT 268.877106269819,2311.82881378972 268.928610268165,2304.80902320629 267.246984684843,2534.00791676124 PathPoint;PointKind.SMOOTHPOINT 269.031943539341,2290.74813210185 266.194457293083,2286.85557560675 274.299543055034,2297.97439751035 PathPoint;PointKind.SMOOTHPOINT 269.138346643809,2276.2881603139 269.921349469797,2169.95864516425 269.102829838928,2281.11123951278 PathPoint;PointKind.SMOOTHPOINT 271.547040514642,1954.45300211182 271.606470335691,1946.63790017338 270.728045506695,2062.15195461114 PathPoint;PointKind.SMOOTHPOINT 271.725519907827,1931.01000379191 270.534774471248,1925.26734692878 273.52821586674,1939.70393954223 PathPoint;PointKind.SMOOTHPOINT 271.859724471032,1913.41832685207 272.179599889844,1871.52538371715 271.81495681117,1919.28138765189 PathPoint;PointKind.SMOOTHPOINT 272.823609715119,1787.97334775665 272.893094004194,1778.98734144384 272.501118839695,1829.67925107579 PathPoint;PointKind.SMOOTHPOINT 273.032191225341,1761.03579306796 273.056827873907,1757.85844299227 272.962623413508,1770.00784507438 PathPoint;PointKind.SMOOTHPOINT 271,1747 271.063474304558,1738.82183432534 270.975354017356,1750.17544131732 PathPoint;PointKind.SMOOTHPOINT 273.296623037773,1726.9922009806 276.470943033674,1319.04080372187 273.233093896971,1735.15672181983 PathPoint;PointKind.SMOOTHPOINT 282.370040837447,645.3326605096 282.409781520752,641.098805111659 279.7073537122,929.007507562858 PathPoint;PointKind.SMOOTHPOINT 280,630 280.052962720989,624.384633415078 279.960517031854,634.186177293461 PathPoint;PointKind.SMOOTHPOINT 282.647059138682,615.986553996886 283.416881866267,534.907637755415 282.594569048984,621.514891149914 PathPoint;PointKind.SMOOTHPOINT 284.786296188652,403.296764851763 284.863406122677,396.193323273828 284.135325964087,463.264770500257 PathPoint;PointKind.SMOOTHPOINT 285.01475899764,382.481602194196 286.694495575187,377.314784295991 282.81314615954,389.253695371699 PathPoint;PointKind.SMOOTHPOINT 285.193820379626,366.508968194475 285.237681142327,362.635414392624 285.134768951875,371.724082305131 PathPoint;PointKind.SMOOTHPOINT 285.324337270706,355.070715837956 285.349658703284,352.869067981241 285.28118865908,358.822401214136 PathPoint;PointKind.SMOOTHPOINT 283,346 283.104639018311,336.988679988197 282.97492691346,348.159248147958 PathPoint;PointKind.SMOOTHPOINT 285.707245522878,322.618761568213 286.642277075968,245.561298630314 285.60703498454,330.877274148263 PathPoint";
	
} else if (mask_variant_35mm == 3) {
	
	mask35mm[0] = "PointKind.SMOOTHPOINT 201.171759366989,132.635514736176 202.460467750855,131.517089428072 195.756894350052,137.334959506989 PathPoint;PointKind.SMOOTHPOINT 212.781433937743,130.628377118913 214.875051691074,130.529855120354 206.846008157205,130.907687900102 PathPoint;PointKind.SMOOTHPOINT 219.572907569872,130.448168185201 221.594201312369,129.681991829559 217.317946940643,131.302916547943 PathPoint;PointKind.SMOOTHPOINT 227.035085612129,130.466223713316 245.408856893737,130.706015337155 224.469167005975,130.432736533151 PathPoint;PointKind.CORNERPOINT 266.683695316315,132.224106788635 266.683695316315,132.224106788635 266.683695316315,132.224106788635 PathPoint;PointKind.SMOOTHPOINT 282.098039388657,132.127568721771 289.555073976517,133.429062366486 274.641004800797,130.826075077057 PathPoint;PointKind.SMOOTHPOINT 297.512737512589,132.030794620514 303.254392147064,132.057938575745 291.770728826523,132.003886699677 PathPoint;PointKind.SMOOTHPOINT 459.364943504333,131.014666557312 465.048533678055,130.945980548859 453.681353330612,131.083588600159 PathPoint;PointKind.SMOOTHPOINT 490.193985700607,130.821590423584 496.774742603302,129.970922470093 481.720114946365,131.916790008545 PathPoint;PointKind.SMOOTHPOINT 505.608683824539,130.724580287933 510.36713719368,130.991771221161 500.849876403809,130.457153320312 PathPoint;PointKind.SMOOTHPOINT 528.730022907257,130.579419136047 532.746738195419,130.62025308609 524.713661670685,130.538349151611 PathPoint;PointKind.SMOOTHPOINT 544.145075082779,130.482409000397 549.203056097031,128.409554958344 537.835875749588,133.0686378479 PathPoint;PointKind.SMOOTHPOINT 555.705921649933,130.410182476044 559.070827960968,130.320017337799 552.340307235718,130.499875545502 PathPoint;PointKind.SMOOTHPOINT 613.509800434113,130.047397613525 620.435403585434,129.694526195526 606.584197282791,130.400269031525 PathPoint;PointKind.SMOOTHPOINT 698.289932012558,129.51514005661 702.071911096573,129.124975204468 694.507952928543,129.905304908752 PathPoint;PointKind.SMOOTHPOINT 713.70463013649,129.418365955353 721.540499925613,130.20388841629 705.693150758743,128.615140914917 PathPoint;PointKind.SMOOTHPOINT 740.679466724396,129.249129295349 751.488307714462,129.190356731415 729.871687889099,129.307901859283 PathPoint;PointKind.SMOOTHPOINT 883.288260698318,132.197434902191 874.554516077042,132.216081619263 892.022713422775,132.178552150726 PathPoint;PointKind.SMOOTHPOINT 894.849107265472,132.124736309052 906.860661506653,131.850936412811 882.838261127472,132.398536205292 PathPoint;PointKind.SMOOTHPOINT 921.824651956558,131.955499649048 929.403834342957,132.096884250641 913.949128389359,131.808214187622 PathPoint;PointKind.SMOOTHPOINT 964.214540719986,131.689252853394 978.224716186523,131.907820701599 950.204011201859,131.470921039581 PathPoint;PointKind.SMOOTHPOINT 1064.40901637077,131.060221195221 1081.74373626709,130.92756986618 1047.07358837128,131.193344593048 PathPoint;PointKind.SMOOTHPOINT 1264.82204318047,133.645741939545 1254.80415344238,133.928039073944 1274.83993291855,133.363680839539 PathPoint;PointKind.SMOOTHPOINT 1330.33327102661,133.234570026398 1337.86005377769,133.169660568237 1322.80684232712,133.299715518951 PathPoint;PointKind.SMOOTHPOINT 1349.62589621544,136.957068443298 1357.41750955582,136.844952106476 1341.83499097824,137.068712711334 PathPoint;PointKind.SMOOTHPOINT 1376.57736539841,132.944247722626 1391.42664313316,134.439761638641 1365.31852483749,131.810338497162 PathPoint;PointKind.SMOOTHPOINT 1426.67424917221,132.629849910736 1445.40287017822,135.962891578674 1419.46929931641,131.347711086273 PathPoint;PointKind.SMOOTHPOINT 1727.28210568428,134.586338996887 1768.16727519035,134.570052623749 1686.39587402344,134.602861404419 PathPoint;PointKind.SMOOTHPOINT 2031.74239754677,136.518752574921 2048.73368740082,136.695070266724 2007.96216845512,136.271624565125 PathPoint;PointKind.SMOOTHPOINT 2085.69348692894,136.180279254913 2104.62958216667,136.859822273254 2066.75739169121,135.500264167786 PathPoint;PointKind.SMOOTHPOINT 2540.47027587891,141.012139320374 2583.02196621895,141.567764282227 2497.91893959045,140.456750392914 PathPoint;PointKind.SMOOTHPOINT 2898.85793566704,138.762731552124 2957.5303030014,138.586649894714 2840.18486022949,138.938813209534 PathPoint;PointKind.SMOOTHPOINT 3318.92775535583,139.969339370728 3357.41847395897,139.235272407532 3280.43632864952,140.70317029953 PathPoint;PointKind.SMOOTHPOINT 3422.97537446022,139.316468238831 3437.0758330822,138.020639419556 3408.87526988983,140.611588954926 PathPoint;PointKind.SMOOTHPOINT 3453.8288462162,142.966032028198 3465.91687560081,142.439675331116 3441.74081683159,143.492388725281 PathPoint;PointKind.SMOOTHPOINT 3476.92646384239,138.97775888443 3481.19172334671,137.866744995117 3463.5780107975,142.453601360321 PathPoint;PointKind.SMOOTHPOINT 3511.63307905197,142.60324716568 3525.65281391144,142.851555347443 3497.6133441925,142.354938983917 PathPoint;PointKind.SMOOTHPOINT 3554.02332186699,142.337000370026 3576.94957852364,139.820873737335 3531.09706521034,144.852890968323 PathPoint;PointKind.SMOOTHPOINT 3669.63178753853,141.611666679382 3686.95234537125,141.971147060394 3652.31193780899,141.251714229584 PathPoint;PointKind.SMOOTHPOINT 4209.13984894753,138.224809169769 4229.16748523712,139.131889343262 4189.11256670952,137.317728996277 PathPoint;PointKind.SMOOTHPOINT 4247.70102381706,141.826221942902 4269.99317407608,140.97767829895 4225.40816545486,142.674765586853 PathPoint;PointKind.SMOOTHPOINT 4394.11410212517,137.063755989075 4422.63401985168,136.482403278351 4365.59383034706,137.645344734192 PathPoint;PointKind.SMOOTHPOINT 4648.47786426544,139.310567378998 4663.50877046585,139.396483898163 4648.47786426544,139.310567378998 PathPoint;PointKind.SMOOTHPOINT 4714.01422977448,142.742507457733 4749.42434549332,142.364144325256 4678.60411405563,143.121106624603 PathPoint;PointKind.SMOOTHPOINT 4825.74476838112,138.198137283325 4833.22517037392,136.565487384796 4818.26436638832,139.830079078674 PathPoint;PointKind.SMOOTHPOINT 4891.28113389015,141.629841327667 4922.18948364258,140.684995651245 4860.37278413773,142.574450969696 PathPoint;PointKind.SMOOTHPOINT 4987.62175798416,141.025121212006 5030.39366841316,141.242980957031 4944.84949350357,140.807025432587 PathPoint;PointKind.SMOOTHPOINT 5149.47396397591,140.008993148804 5188.04788470268,139.106397628784 5110.89968919754,140.91206073761 PathPoint;PointKind.SMOOTHPOINT 5504.00777220726,137.783896923065 5546.27409696579,138.016862869263 5461.74109339714,137.550694942474 PathPoint;PointKind.SMOOTHPOINT 5638.88443350792,136.937005519867 5642.4734544754,136.924967765808 5617.70860791206,137.009468078613 PathPoint;PointKind.SMOOTHPOINT 5665.69640636444,148.145098686218 5668.66813294975,149.983761018496 5661.38334989548,145.476493835449 PathPoint;PointKind.SMOOTHPOINT 5684.89319411466,166.965629390404 5686.51306071441,168.971824797584 5677.26261246006,157.51519818085 PathPoint;PointKind.SMOOTHPOINT 5689.55946569306,173.207553454708 5690.8346424564,175.066610941827 5688.08948887343,171.064500435729 PathPoint;PointKind.SMOOTHPOINT 5693,179 5693.84904344535,179.848167338877 5691.6121096893,177.613690149195 PathPoint;PointKind.SMOOTHPOINT 5694.81498234638,181.977005565773 5696.72151297072,185.497866129231 5694.26162593143,180.955101823939 PathPoint;PointKind.SMOOTHPOINT 5699.9519598484,192.130107879639 5702.06352353096,196.636004447937 5698.42680579646,188.87637272696 PathPoint;PointKind.SMOOTHPOINT 5705.30805230141,204.976279735565 5705.89577794075,206.596183776855 5703.83059501648,200.902562141418 PathPoint;PointKind.SMOOTHPOINT 5706.93704366684,209.747242927551 5708.11143279076,212.031111717224 5706.18716239929,208.288078308105 PathPoint;PointKind.SMOOTHPOINT 5708.72252583504,215.864546298981 5710.55247830569,222.808558363074 5708.19675922394,213.869819641113 PathPoint;PointKind.SMOOTHPOINT 5713,236 5713.62866422693,242.856612561366 5712.43028391153,229.78631339069 PathPoint;PointKind.SMOOTHPOINT 5712.85891056061,255.619819164276 5712.88581848145,277.84576177597 5712.85092401298,248.901584824472 PathPoint;PointKind.SMOOTHPOINT 5709.32299733162,305.606710910797 5710.03110051155,322.393476963043 5708.61418604851,288.820652961731 PathPoint;PointKind.SMOOTHPOINT 5713.395652771,340.172295570374 5713.45442533493,352.333023548126 5713.33652615547,328.011803627014 PathPoint;PointKind.SMOOTHPOINT 5713.54187607765,363.232147693634 5711.43456101418,374.709792137146 5715.64883708954,351.754739284515 PathPoint;PointKind.SMOOTHPOINT 5713.80989313126,405.508503913879 5710.495262146,419.275681972504 5717.12452411652,391.741561889648 PathPoint;PointKind.SMOOTHPOINT 5710.19998311996,443.96582365036 5709.75671052933,453.811526298523 5710.6432557106,434.120121002197 PathPoint;PointKind.SMOOTHPOINT 5714.37035679817,493.904328346252 5714.15119886398,507.74231672287 5714.72440838814,471.576182842255 PathPoint;PointKind.SMOOTHPOINT 5710.90667009354,555.4212641716 5710.12917280197,564.176723957062 5711.74400210381,545.993814468384 PathPoint;PointKind.SMOOTHPOINT 5714.06764268875,581.417148113251 5714.35336232185,582.219429016113 5710.35010099411,570.976874828339 PathPoint;PointKind.SMOOTHPOINT 5714.95560407639,586.143972873688 5719.44002151489,597.317605018616 5714.62669014931,585.325405597687 PathPoint;PointKind.SMOOTHPOINT 5711.32126450539,620.757472515106 5711.73408865929,625.887916088104 5710.58908581734,611.664011478424 PathPoint;PointKind.SMOOTHPOINT 5715.06288170815,644.775388240814 5715.67220449448,648.785848617554 5713.69588851929,635.777049064636 PathPoint;PointKind.SMOOTHPOINT 5715.73062300682,655.756652355194 5717.38333582878,658.801259994507 5713.9918756485,652.55366563797 PathPoint;PointKind.SMOOTHPOINT 5715.44277906418,663.009753227234 5713.82370114326,674.502267837524 5715.74159860611,660.890636444092 PathPoint;PointKind.SMOOTHPOINT 5711.85729861259,705.31042098999 5712.16319918633,716.182873249054 5711.55104398727,694.417433738708 PathPoint;PointKind.SMOOTHPOINT 5715.34753918648,756.946721076965 5714.77645397186,771.070075035095 5715.90871095657,743.060345649719 PathPoint;PointKind.SMOOTHPOINT 5712.39368677139,789.862897396088 5713.08054685593,796.707186698914 5711.33294820786,779.294221401215 PathPoint;PointKind.SMOOTHPOINT 5712.56433963776,816.76586151123 5713.11630606651,822.123606204987 5711.5499818325,806.920394897461 PathPoint;PointKind.SMOOTHPOINT 5716.51520133018,832.115178108215 5715.50509214401,847.519254684448 5716.87173128128,826.686623096466 PathPoint;PointKind.SMOOTHPOINT 5709.00293469429,862.909877300262 5708.77952814102,868.109242916107 5709.41717505455,853.250405788422 PathPoint;PointKind.SMOOTHPOINT 5712.97857999802,882.10230588913 5713.76492857933,888.738884925842 5712.06194043159,874.36509847641 PathPoint;PointKind.SMOOTHPOINT 5713.10072779655,901.318573951721 5714.77574586868,908.65216255188 5712.09557533264,896.918892860413 PathPoint;PointKind.SMOOTHPOINT 5713.24695110321,924.378426074982 5711.37862086296,931.528143882751 5715.41126847267,916.092438697815 PathPoint;PointKind.SMOOTHPOINT 5705.6366121769,939.79996919632 5704.16552782059,945.067312717438 5706.72921538353,935.889587402344 PathPoint;PointKind.SMOOTHPOINT 5717.29517698288,955.100662708282 5717.35961437225,967.387433052063 5717.23994493484,944.580137729645 PathPoint;PointKind.SMOOTHPOINT 5713.61233234406,982.02817440033 5713.63676190376,988.214163780212 5713.57126235962,971.782865524292 PathPoint;PointKind.SMOOTHPOINT 5713.78298521042,1008.93113851547 5714.44966435432,1014.25347805023 5712.76650309563,1000.81958055496 PathPoint;PointKind.SMOOTHPOINT 5717.70941734314,1020.4366350174 5719.10367250443,1029.13875102997 5716.79065346718,1014.69887495041 PathPoint;PointKind.SMOOTHPOINT 5717.8556406498,1043.49672317505 5717.50937819481,1049.22834634781 5718.37822079659,1034.8677778244 PathPoint;PointKind.SMOOTHPOINT 5717.97743439674,1062.71299123764 5720.12334108353,1073.49126577377 5717.12098360062,1058.41102838516 PathPoint;PointKind.SMOOTHPOINT 5718.1236577034,1085.7728433609 5715.91614603996,1093.71988534927 5720.33152341843,1077.82580137253 PathPoint;PointKind.SMOOTHPOINT 5722.26995587349,1131.8687081337 5720.82400918007,1152.16931819916 5723.41425061226,1115.79641819 PathPoint;PointKind.SMOOTHPOINT 5718.80626916885,1193.38564395905 5718.7836098671,1213.55147838593 5718.82892847061,1173.21910142899 PathPoint;PointKind.SMOOTHPOINT 5715.12342453003,1220.31244754791 5717.70623087883,1226.60347223282 5710.58448314667,1209.25683259964 PathPoint;PointKind.SMOOTHPOINT 5730.6354868412,1235.58906555176 5732.92584657669,1237.18749046326 5726.79438114166,1232.90889501572 PathPoint;PointKind.SMOOTHPOINT 5734.61077809334,1254.78149414062 5734.53961372375,1262.05158948898 5734.71840977669,1243.79928588867 PathPoint;PointKind.SMOOTHPOINT 5738.58606934547,1273.9736866951 5736.72446608543,1280.20829916 5739.89535212517,1269.59029197693 PathPoint;PointKind.SMOOTHPOINT 5730.97643852234,1289.39522981644 5730.34693479538,1294.77114915848 5731.78827881813,1282.46832847595 PathPoint;PointKind.SMOOTHPOINT 5734.90357875824,1300.90096235275 5739.87800359726,1307.11126327515 5729.06137347221,1293.60797166824 PathPoint;PointKind.SMOOTHPOINT 5739.02509331703,1343.15300703049 5739.39189076424,1352.25331306458 5738.55031013489,1331.38834476471 PathPoint;PointKind.SMOOTHPOINT 5737.10223913193,1366.59971952438 5734.1675055027,1371.06808662415 5740.03626465797,1362.13135242462 PathPoint;PointKind.SMOOTHPOINT 5731.61019086838,1389.32133436203 5729.84311938286,1400.25019884109 5732.63375401497,1382.99325227737 PathPoint;PointKind.SMOOTHPOINT 5731.87820792198,1431.59745454788 5730.15716314316,1447.84086942673 5733.5996067524,1415.35427570343 PathPoint;PointKind.SMOOTHPOINT 5743.78071427345,1485.33092021942 5749.80950474739,1507.42916822433 5737.75156974792,1463.2329082489 PathPoint;PointKind.SMOOTHPOINT 5743.97544264793,1516.07770442963 5742.97418475151,1529.03740882874 5744.97705459595,1503.11752796173 PathPoint;PointKind.SMOOTHPOINT 5751.85309052467,1542.93204545975 5752.58031249046,1556.96806669235 5751.12622261047,1528.89602422714 PathPoint;PointKind.SMOOTHPOINT 5756.87708258629,1727.38655090332 5758.29824566841,1756.33852958679 5754.6713411808,1682.44395017624 PathPoint;PointKind.SMOOTHPOINT 5757.63262867928,1846.52868747711 5758.69761586189,1878.68082046509 5756.56728744507,1814.37631845474 PathPoint;PointKind.SMOOTHPOINT 5758.02243947983,1908.02154779434 5759.56327199936,1924.10044670105 5756.4816069603,1891.94264888763 PathPoint;PointKind.SMOOTHPOINT 5762.26610183716,1969.49033260345 5760.92530846596,1993.56253623962 5763.60724925995,1945.41812896729 PathPoint;PointKind.SMOOTHPOINT 5762.70477175713,2038.66965293884 5762.4625486923,2045.34504719105 5763.79666686058,2008.5875415802 PathPoint;PointKind.SMOOTHPOINT 5762.58396902154,2101.10703606903 5762.59391978199,2103.56016296662 5762.45267943259,2068.74066333516 PathPoint;PointKind.SMOOTHPOINT 5762.61621425711,2108.61764016449 5763.57657207303,2112.32755384946 5761.9764657021,2106.14625722804 PathPoint;PointKind.SMOOTHPOINT 5762.64912507334,2115.60991001399 5763.22080512991,2232.58097408927 5762.63755193303,2113.24193771815 PathPoint;PointKind.CORNERPOINT 5765.24013519287,2438.37312698364 5765.24013519287,2438.37312698364 5765.24013519287,2438.37312698364 PathPoint;PointKind.SMOOTHPOINT 5765.36192893982,2457.58939504623 5765.07656335831,2459.41677331924 5765.68553209305,2455.51252841949 PathPoint;PointKind.SMOOTHPOINT 5757.70273089409,2465.32424211502 5757.12244033813,2476.26986503601 5757.94702649117,2460.72936058044 PathPoint;PointKind.SMOOTHPOINT 5757.94667243958,2503.75748634338 5756.59490346909,2508.87164354324 5760.39918780327,2494.48180675507 PathPoint;PointKind.SMOOTHPOINT 5754.23975229263,2526.84165000916 5751.3970720768,2533.65596294403 5757.73247122765,2518.46644163132 PathPoint;PointKind.SMOOTHPOINT 5742.80034542084,2546.13061666489 5741.19011878967,2557.32785224915 5743.83240580559,2538.95186662674 PathPoint;PointKind.SMOOTHPOINT 5742.9709982872,2573.03381681442 5743.67874741554,2577.17810869217 5741.32076382637,2563.3738732338 PathPoint;PointKind.SMOOTHPOINT 5746.92185997963,2588.38289737701 5746.64463758469,2591.1567735672 5747.49754786491,2582.63121128082 PathPoint;PointKind.SMOOTHPOINT 5743.14200520515,2599.93678092957 5741.18693232536,2605.0448012352 5745.09601593018,2594.82899665833 PathPoint;PointKind.SMOOTHPOINT 5747.26351976395,2642.18906164169 5747.67563581467,2651.21218442917 5746.9512462616,2635.36766767502 PathPoint;PointKind.SMOOTHPOINT 5743.55624556541,2665.27275323868 5745.67453622818,2671.79343938828 5741.43724679947,2658.75230312347 PathPoint;PointKind.SMOOTHPOINT 5747.55561232567,2688.30852985382 5747.41859436035,2700.83652734756 5747.69333839417,2675.78029632568 PathPoint;PointKind.SMOOTHPOINT 5739.97041106224,2707.57365703583 5739.79267716408,2718.47443342209 5740.14849901199,2696.67240858078 PathPoint;PointKind.SMOOTHPOINT 5736.31164193153,2738.34380865097 5732.19897866249,2750.68109035492 5740.42465925217,2726.00699901581 PathPoint;PointKind.SMOOTHPOINT 5728.72644066811,2757.60893583298 5731.31845235825,2776.11332416534 5726.13407492638,2739.10431146622 PathPoint;PointKind.SMOOTHPOINT 5728.94595265388,2792.19859600067 5729.13537025452,2804.94091272354 5728.75653505325,2779.45651531219 PathPoint;PointKind.SMOOTHPOINT 5729.06774640083,2811.41510009766 5727.74819612503,2819.84884500504 5730.38694262505,2802.98111915588 PathPoint;PointKind.SMOOTHPOINT 5729.2136156559,2834.47471618652 5726.67683601379,2843.70885372162 5731.750395298,2825.24081468582 PathPoint;PointKind.CORNERPOINT 5729.28690433502,2846.00476026535 5729.28690433502,2846.00476026535 5729.28690433502,2846.00476026535 PathPoint;PointKind.SMOOTHPOINT 5733.26254963875,2865.19695281982 5731.86971068382,2880.08104562759 5734.65574264526,2850.31286001205 PathPoint;PointKind.SMOOTHPOINT 5729.55492138863,2888.2808804512 5731.31137132645,2898.43130350113 5727.7988255024,2878.13092947006 PathPoint;PointKind.SMOOTHPOINT 5733.62828493118,2922.84670114517 5732.15932488441,2937.14849710464 5735.09653687477,2908.54466915131 PathPoint;PointKind.CORNERPOINT 5729.94508624077,2949.77374076843 5729.94508624077,2949.77374076843 5729.94508624077,2949.77374076843 PathPoint;PointKind.SMOOTHPOINT 5726.21373653412,2969.01479244232 5727.10169792175,2978.50266695023 5725.42349338531,2960.58057546616 PathPoint;PointKind.SMOOTHPOINT 5734.11545991898,2999.71248149872 5735.34578919411,3018.05731058121 5732.88513064384,2981.36788845062 PathPoint;PointKind.SMOOTHPOINT 5734.40826058388,3045.83218574524 5732.93328166008,3055.40810108185 5735.8825314045,3036.25627040863 PathPoint;PointKind.SMOOTHPOINT 5730.65177321434,3061.22988939285 5730.24492858497,3064.74031998768 5731.41687870026,3054.62493896484 PathPoint;PointKind.SMOOTHPOINT 5735.64894123406,3071.86359860521 5735.73586348419,3072.7328303487 5735.15600025207,3066.93413637246 PathPoint;PointKind.SMOOTHPOINT 5738.53012919426,3088.08446645737 5733.644333879,3103.55991910815 5739.20746384112,3085.93871249621 PathPoint;PointKind.SMOOTHPOINT 5734.84693050385,3115.01174211502 5733.47639679909,3133.48686218262 5736.21711015701,3096.53638601303 PathPoint;PointKind.SMOOTHPOINT 5735.23638725281,3176.50460243225 5733.2678604126,3200.71535825729 5736.32615804672,3163.10847043991 PathPoint;PointKind.SMOOTHPOINT 5739.28567528725,3207.22660303116 5740.51069378853,3222.9231262207 5738.65829586983,3199.19860124588 PathPoint;PointKind.SMOOTHPOINT 5735.57840108871,3230.31076669693 5733.33973288536,3249.6441078186 5737.8160071373,3210.97742557526 PathPoint;PointKind.SMOOTHPOINT 5735.89456915855,3280.27358293533 5733.86833190918,3322.43805885315 5736.87458395958,3259.88351583481 PathPoint;PointKind.SMOOTHPOINT 5728.40708613396,3314.91186618805 5728.0385184288,3320.24293899536 5729.31133389473,3301.81006908417 PathPoint;PointKind.SMOOTHPOINT 5732.33351826668,3326.41759872437 5734.04925227165,3336.28265619278 5730.61813831329,3316.55254125595 PathPoint;PointKind.SMOOTHPOINT 5732.50417113304,3353.32056283951 5733.54579091072,3371.3302230835 5731.88635110855,3342.63552188873 PathPoint;PointKind.SMOOTHPOINT 5736.5775346756,3387.88614749908 5736.09602451324,3400.47811031342 5736.87883257866,3379.97828722 PathPoint;PointKind.SMOOTHPOINT 5732.84547686577,3407.12672710419 5731.66967153549,3423.985247612 5734.02092814445,3390.26820659637 PathPoint;PointKind.SMOOTHPOINT 5736.86962723732,3434.00561571121 5737.12135791779,3435.96564531326 5734.70991253853,3417.19807863235 PathPoint;PointKind.SMOOTHPOINT 5737.01585054398,3457.06546783447 5738.66856336594,3479.97709035873 5736.79775476456,3454.0406870842 PathPoint;PointKind.SMOOTHPOINT 5737.47895002365,3530.08813619614 5736.43874645233,3535.64060926437 5739.81993913651,3517.59601593018 PathPoint;PointKind.SMOOTHPOINT 5734.99138355255,3544.49921607971 5734.04500365257,3550.9214758873 5735.6035387516,3540.34713506699 PathPoint;PointKind.SMOOTHPOINT 5733.82053494453,3560.85875988007 5734.02730107307,3575.03333330154 5733.74972462654,3556.01320981979 PathPoint;PointKind.SMOOTHPOINT 5741.67410731316,3583.8702249527 5741.38803362846,3614.7159075737 5741.84723854065,3565.21855115891 PathPoint;PointKind.SMOOTHPOINT 5738.06384325027,3622.32754468918 5740.49086689949,3638.02194356918 5735.22293329239,3603.95391941071 PathPoint;PointKind.SMOOTHPOINT 5738.30778479576,3660.76055288315 5741.18020534515,3687.38240003586 5738.30778479576,3660.76055288315 PathPoint;PointKind.SMOOTHPOINT 5715.67362070084,3737.77173042297 5710.96615076065,3748.04866790771 5727.52231121063,3711.90401315689 PathPoint;PointKind.SMOOTHPOINT 5696.4978325367,3773.56965065002 5694.95204329491,3776.14100933075 5704.08445000648,3760.95337629318 PathPoint;PointKind.SMOOTHPOINT 5691.78469777107,3781.22282981873 5689.62675333023,3782.3421049118 5694.64083194733,3779.74124193192 PathPoint;PointKind.SMOOTHPOINT 5687.87561416626,3787.28796958923 5678.80198001862,3801.06576919556 5689.18525099754,3785.2991437912 PathPoint;PointKind.SMOOTHPOINT 5662.23448991776,3818.8193321228 5653.12297224998,3826.04599714279 5669.51449871063,3813.04569482803 PathPoint;PointKind.SMOOTHPOINT 5605.49630641937,3830.0715637207 5602.12113261223,3830.23796796799 5629.27334904671,3828.9003610611 PathPoint;PointKind.SMOOTHPOINT 5595.41645765305,3830.47636270523 5593.44262003899,3831.18541002274 5599.27845239639,3829.08966064453 PathPoint;PointKind.SMOOTHPOINT 5589.1869199276,3830.64772367477 5577.22953557968,3830.92718839645 5591.23900294304,3830.59980869293 PathPoint;PointKind.SMOOTHPOINT 5558.25945138931,3831.00248336792 5553.87098193169,3831.04874610901 5566.22242569923,3830.91869115829 PathPoint;PointKind.SMOOTHPOINT 5542.82103180885,3827.25614547729 5541.89235448837,3827.24717617035 5554.5302259922,3827.37133026123 PathPoint;PointKind.SMOOTHPOINT 5538.47823500633,3827.27077960968 5533.50345611572,3827.31208562851 5540.33381938934,3827.25496530533 PathPoint;PointKind.SMOOTHPOINT 5523.55283617973,3827.37699508667 5515.65819382668,3827.28848218918 5526.39232993126,3827.40885972977 PathPoint;PointKind.SMOOTHPOINT 5488.86994242668,3827.5948548317 5421.33141517639,3826.75103187561 5498.33197116852,3827.71287202835 PathPoint;PointKind.SMOOTHPOINT 5292.33484268188,3828.82860660553 5240.5434679985,3829.7540974617 5328.14432859421,3828.18824529648 PathPoint;PointKind.SMOOTHPOINT 5045.67842960358,3826.53293609619 5025.9251832962,3827.05339193344 5065.43167591095,3826.01295232773 PathPoint;PointKind.SMOOTHPOINT 4999.43433523178,3826.82349443436 4988.43111991882,3827.42703437805 5010.43861269951,3826.21995449066 PathPoint;PointKind.SMOOTHPOINT 4733.51008057594,3824.64914560318 4704.85951781273,3825.54395198822 4762.16099739075,3823.75504732132 PathPoint;PointKind.SMOOTHPOINT 4610.19391179085,3825.42310237885 4588.00939321518,3826.18077278137 4632.37878441811,3824.66543197632 PathPoint;PointKind.SMOOTHPOINT 4305.75734138489,3827.33427286148 4250.42509675026,3827.31539011002 4361.08923196793,3827.35339164734 PathPoint;PointKind.SMOOTHPOINT 4078.36876988411,3824.91822481155 4064.54978227615,3824.9446606636 4092.18846559525,3824.89155292511 PathPoint;PointKind.SMOOTHPOINT 4051.36914968491,3821.24411344528 4028.44076871872,3820.57117938995 4074.29753065109,3821.91681146622 PathPoint;PointKind.SMOOTHPOINT 4012.85718798637,3825.3293967247 3972.29172706604,3826.42483234406 4053.42335700989,3824.23372507095 PathPoint;PointKind.SMOOTHPOINT 3839.44413542747,3826.41775131226 3815.02661347389,3825.76086759567 3854.47008490562,3826.822078228 PathPoint;PointKind.SMOOTHPOINT 3804.73681211472,3822.79226303101 3783.17542433739,3819.19203042984 3818.25520992279,3825.04922389984 PathPoint;PointKind.SMOOTHPOINT 3777.76197552681,3822.9617357254 3757.95526742935,3823.6745595932 3797.56797552109,3822.24867582321 PathPoint;PointKind.SMOOTHPOINT 3396.25262260437,3825.35630464554 3375.06759166718,3827.05669641495 3417.43729948997,3823.65614891052 PathPoint;PointKind.SMOOTHPOINT 3222.83921599388,3826.44489526749 3179.69165682793,3827.83277750015 3265.98642110825,3825.05724906921 PathPoint;PointKind.SMOOTHPOINT 2914.52436447144,3824.53679323196 2844.36302304268,3825.69194555283 2984.68570590019,3823.38211297989 PathPoint;PointKind.SMOOTHPOINT 2625.47770857811,3822.50760555267 2607.49401211739,3823.77393007278 2643.46211314201,3821.24175310135 PathPoint;PointKind.SMOOTHPOINT 2598.4784424305,3818.83373022079 2590.95095157623,3818.8089466095 2606.00557923317,3818.85851383209 PathPoint;PointKind.SMOOTHPOINT 2571.52732729912,3822.84631490707 2554.55763459206,3823.11799049377 2590.28108596802,3822.54607915878 PathPoint;PointKind.SMOOTHPOINT 2529.13743853569,3823.11232566833 2511.0326564312,3824.2004442215 2548.21232199669,3821.96567058563 PathPoint;PointKind.SMOOTHPOINT 2494.45489883423,3823.33018541336 2457.97271490097,3822.79061079025 2530.93637466431,3823.86976003647 PathPoint;PointKind.SMOOTHPOINT 1993.45879912376,3822.63152360916 1912.9839348793,3825.03435373306 2073.93330931664,3820.22892951965 PathPoint;PointKind.SMOOTHPOINT 1604.21802163124,3821.23113155365 1567.69158124924,3822.22932100296 1640.74410796165,3820.23341417313 PathPoint;PointKind.SMOOTHPOINT 1496.31619691849,3821.90855026245 1477.35956668854,3823.67314338684 1515.27318120003,3820.14395713806 PathPoint;PointKind.SMOOTHPOINT 1469.34100627899,3822.07778692245 1458.31973433495,3822.74765253067 1480.36192417145,3821.40839338303 PathPoint;PointKind.SMOOTHPOINT 1438.51196408272,3822.27109909058 1425.60855388641,3823.36134195328 1451.41502022743,3821.18156433105 PathPoint;PointKind.SMOOTHPOINT 1384.56087470055,3822.61028051376 1376.35148048401,3821.94796800613 1394.438560009,3823.40666055679 PathPoint;PointKind.SMOOTHPOINT 1319.04929280281,3823.02121639252 1268.21704387665,3824.20516490936 1369.88189578056,3821.83750391006 PathPoint;PointKind.SMOOTHPOINT 1180.29470443726,3820.04907131195 1160.57650923729,3821.37369632721 1200.01254558563,3818.72397422791 PathPoint;PointKind.SMOOTHPOINT 952.930562496185,3821.47589921951 930.451472997665,3822.31358528137 975.409651994705,3820.63821315765 PathPoint;PointKind.SMOOTHPOINT 906.68682217598,3821.76645755768 892.084672451019,3821.73176050186 921.28968000412,3821.80068254471 PathPoint;PointKind.SMOOTHPOINT 868.126355409622,3818.16480875015 855.580537319183,3819.65465784073 880.671465396881,3816.67495965958 PathPoint;PointKind.SMOOTHPOINT 717.858717441559,3822.95182228088 694.02290225029,3822.47668504715 738.04815530777,3823.35402488708 PathPoint;PointKind.SMOOTHPOINT 648.493638038635,3823.38706970215 625.903022289276,3821.80516719818 671.084253787994,3824.96850013733 PathPoint;PointKind.SMOOTHPOINT 609.957600831985,3823.62900495529 582.483197450638,3822.07778692245 637.431650161743,3825.17998695374 PathPoint;PointKind.SMOOTHPOINT 536.714594364166,3820.24545192719 509.729844331741,3823.71775388718 563.698636293411,3816.7729139328 PathPoint;PointKind.SMOOTHPOINT 463.495309352875,3820.70477485657 434.636210203171,3821.01209163666 492.354762554169,3820.39745807648 PathPoint;PointKind.SMOOTHPOINT 371.008182764053,3821.28541946411 333.108730316162,3821.32507324219 408.907281160355,3821.24552965164 PathPoint;PointKind.SMOOTHPOINT 293.935400247574,3821.7692899704 274.017874002457,3822.53073692322 312.764925956726,3821.04914903641 PathPoint;PointKind.CORNERPOINT 239.985373020172,3822.1079993248 239.985373020172,3822.1079993248 239.985373020172,3822.1079993248 PathPoint;PointKind.SMOOTHPOINT 236.009373664856,3802.91533470154 235.606462955475,3790.10197162628 236.420427560806,3815.99588871002 PathPoint;PointKind.SMOOTHPOINT 232.008944749832,3779.87979412079 232.985064983368,3770.38507461548 231.033886671066,3789.3745136261 PathPoint;PointKind.SMOOTHPOINT 235.716572999954,3756.7961025238 231.51575088501,3745.73623895645 239.917749166489,3767.85549402237 PathPoint;PointKind.SMOOTHPOINT 231.71685218811,3733.76032590866 229.349663257599,3725.97402334213 234.084749221802,3741.54662847519 PathPoint;PointKind.SMOOTHPOINT 231.595058441162,3714.54358577728 230.615751743317,3707.23525285721 232.574365139008,3721.85239076614 PathPoint;PointKind.CORNERPOINT 235.327116250992,3695.30300617218 235.327116250992,3695.30300617218 235.327116250992,3695.30300617218 PathPoint;PointKind.SMOOTHPOINT 235.205322504044,3676.08673810959 234.792144298553,3666.08430862427 235.617792606354,3686.08893156052 PathPoint;PointKind.SMOOTHPOINT 231.253752708435,3660.737657547 229.065005779266,3649.83947753906 233.442853689194,3671.63560152054 PathPoint;PointKind.SMOOTHPOINT 231.083099842072,3633.83422136307 230.723737478256,3626.50983810425 231.442816257477,3641.15884065628 PathPoint;PointKind.SMOOTHPOINT 230.961306095123,3614.61818933487 231.790848970413,3604.87209320068 230.132471323013,3624.36404943466 PathPoint;PointKind.SMOOTHPOINT 230.79065322876,3587.71475315094 229.897027015686,3575.93191623688 231.684279441833,3599.4978260994 PathPoint;PointKind.SMOOTHPOINT 230.620354413986,3560.81202507019 227.78440117836,3552.25979089737 233.456307649612,3569.36355113983 PathPoint;PointKind.SMOOTHPOINT 230.327553749084,3514.69208478928 233.422672748566,3501.57116889954 226.190814971924,3532.23274469376 PathPoint;PointKind.SMOOTHPOINT 230.132825374603,3483.94577264786 231.437859535217,3466.67206764221 228.827437162399,3501.21924161911 PathPoint;PointKind.SMOOTHPOINT 229.937388896942,3453.19898843765 234.331877231598,3436.7830324173 225.543962717056,3469.61565256119 PathPoint;PointKind.SMOOTHPOINT 229.64529633522,3407.07999229431 229.414454698563,3393.9439702034 229.998993873596,3427.19130277634 PathPoint;PointKind.SMOOTHPOINT 225.548211336136,3368.67082357407 223.12649846077,3353.32410335541 227.969216108322,3384.01754379272 PathPoint;PointKind.SMOOTHPOINT 225.280194282532,3326.39446735382 227.157375812531,3313.87355089188 223.401950597763,3338.91585588455 PathPoint;PointKind.SMOOTHPOINT 225.109187364578,3299.49126720428 226.754111051559,3274.99703407288 223.463909626007,3323.98597240448 PathPoint;PointKind.SMOOTHPOINT 224.890029430389,3264.90184307098 220.580159425735,3251.84300422668 229.199899435043,3277.96044588089 PathPoint;PointKind.SMOOTHPOINT 220.7437312603,3218.80645036697 220.129451751709,3202.64966011047 221.35836482048,3234.96276855469 PathPoint;PointKind.SMOOTHPOINT 224.353995323181,3180.34913063049 225.127598047256,3166.62160634995 223.698999881744,3191.9610786438 PathPoint;PointKind.SMOOTHPOINT 220.231772661209,3138.09684991837 219.550931453705,3126.86538934708 221.77189707756,3163.50241184235 PathPoint;PointKind.SMOOTHPOINT 223.939046859741,3115.01292228699 226.045299768448,3100.55675983429 221.833148002625,3129.46908473969 PathPoint;PointKind.SMOOTHPOINT 219.695738554001,3053.54413747787 218.56808423996,3040.98215103149 220.823038816452,3066.10683202744 PathPoint;PointKind.SMOOTHPOINT 219.451797008514,3015.1113653183 220.11458158493,2999.01263952255 218.789366483688,3031.20985507965 PathPoint;PointKind.SMOOTHPOINT 223.013201951981,2968.96758556366 222.738457918167,2955.15107631683 223.287237882614,2982.78433084488 PathPoint;PointKind.SMOOTHPOINT 218.940192461014,2934.40200090408 217.627369165421,2918.23175668716 220.253015756607,2950.572245121 PathPoint;PointKind.SMOOTHPOINT 218.647745847702,2888.28229665756 215.590864419937,2869.55296754837 221.704627275467,2907.01209783554 PathPoint;PointKind.SMOOTHPOINT 218.379374742508,2846.00594043732 214.32158946991,2837.53985881805 222.437514066696,2854.47225809097 PathPoint;PointKind.SMOOTHPOINT 214.379653930664,2822.97063589096 214.399126768112,2814.03956651688 214.326900243759,2846.92930698395 PathPoint;PointKind.SMOOTHPOINT 218.086928129196,2799.88647222519 217.715612814732,2793.99917721952 218.862655162811,2812.18504428864 PathPoint;PointKind.SMOOTHPOINT 214.941932738876,2782.88816248718 215.856706581231,2778.47579238415 214.72813355464,2783.91941314707 PathPoint;PointKind.SMOOTHPOINT 206.355428695679,2773.0557346344 202.385804105463,2770.75217788014 210.604305857447,2775.52151651679 PathPoint;PointKind.SMOOTHPOINT 197.120675483715,2757.24489709928 196.778407362069,2755.79582936 199.203648674857,2766.0636244717 PathPoint;PointKind.SMOOTHPOINT 196.184288184672,2752.55540580208 196.740862236827,2750.00602058405 195.820992760987,2754.21947903606 PathPoint;PointKind.SMOOTHPOINT 195.20905345806,2744.995239392 194.909516837998,2741.880326401 195.473988744372,2747.7503294539 PathPoint;PointKind.SMOOTHPOINT 194.550640583038,2734.69566106796 193.864842653275,2715.94957351685 194.688354624622,2738.45660239777 PathPoint;PointKind.SMOOTHPOINT 190.526490211487,2707.81630039215 188.987782001495,2696.87232971191 192.065198421478,2718.76050710678 PathPoint;PointKind.SMOOTHPOINT 194.282623529434,2692.41930484772 194.900234765596,2687.73355350328 192.708510160446,2704.36170101166 PathPoint;PointKind.SMOOTHPOINT 196.130330579443,2671.98538071303 196.261442393701,2670.15681550434 195.554308886862,2680.01893003471 PathPoint;PointKind.SMOOTHPOINT 196.510184114568,2666.4820725789 196.150835029898,2664.49189776696 196.868197882547,2668.46485203697 PathPoint;PointKind.SMOOTHPOINT 196.891265168805,2660.52756345594 197.399614861732,2652.26883698974 196.772007231539,2662.46504605209 PathPoint;PointKind.SMOOTHPOINT 197.819598913193,2642.43194103241 197.971841096878,2636.00543260574 197.755829587838,2645.13017132108 PathPoint;PointKind.SMOOTHPOINT 193.892812728882,2630.92644453049 194.047533273697,2622.06760168076 193.738446235657,2639.78528738022 PathPoint;PointKind.SMOOTHPOINT 197.648946046829,2615.52921295166 196.906499862671,2591.51224136353 198.391392230988,2639.5459485054 PathPoint;PointKind.SMOOTHPOINT 189.405562877655,2531.0246515274 187.357374429703,2519.52529191971 191.453397274017,2542.52448320389 PathPoint;PointKind.CORNERPOINT 189.235264062881,2504.12145137787 189.235264062881,2504.12145137787 189.235264062881,2504.12145137787 PathPoint;PointKind.SMOOTHPOINT 185.283340215683,2488.77284288406 183.92433590889,2486.37591218948 187.658547156181,2492.9598224227 PathPoint;PointKind.CORNERPOINT 189.064257144928,2477.21872329712 189.064257144928,2477.21872329712 189.064257144928,2477.21872329712 PathPoint;PointKind.SMOOTHPOINT 185,2472 183.307284062078,2468.3854383877 186.4735759065,2475.14661827488 PathPoint;PointKind.CORNERPOINT 181.283619403839,2465.73683023453 181.283619403839,2465.73683023453 181.283619403839,2465.73683023453 PathPoint;PointKind.SMOOTHPOINT 180.712298415542,2375.64740534861 180.697612349154,2373.33161562298 181.064404036454,2431.16959609042 PathPoint;PointKind.SMOOTHPOINT 180.667552927471,2368.59166020861 180.066273100701,2366.61618991661 181.445195098545,2371.14655884046 PathPoint;PointKind.SMOOTHPOINT 180.627767171596,2362.31799629831 180.284011918439,2308.11254315948 180.641194605331,2364.43531704736 PathPoint;PointKind.SMOOTHPOINT 179.341693047216,2159.5218788803 179.32637239657,2157.10602398639 179.832661591896,2236.94083378197 PathPoint;PointKind.SMOOTHPOINT 179.295617426193,2152.25639015461 178.671574065165,2150.17668404193 180.301638167719,2155.6090858426 PathPoint;PointKind.SMOOTHPOINT 179.254222570743,2145.7289934772 177.632401337546,1889.99019661973 179.268049077499,2147.90924252698 PathPoint;PointKind.CORNERPOINT 175.629061460495,1574.09118175507 175.629061460495,1574.09118175507 175.629061460495,1574.09118175507 PathPoint;PointKind.SMOOTHPOINT 183.263829946518,1562.51298666 187.229207754135,1550.76531887054 179.297389984131,1574.26018238068 PathPoint;PointKind.SMOOTHPOINT 179.312260150909,1547.16390609741 179.30624127388,1546.44164085388 179.40891623497,1558.53155851364 PathPoint;PointKind.SMOOTHPOINT 181.527560949326,1541.69003248215 183.476969003677,1532.06053733826 181.405413150787,1542.29357242584 PathPoint;PointKind.SMOOTHPOINT 186.897815465927,1527.8990149498 186.617052555084,1520.76393127441 187.300726175308,1538.15990209579 PathPoint;PointKind.SMOOTHPOINT 179.537436962128,1519.9104309082 178.748255968094,1519.68383789062 181.453210115433,1520.46039104462 PathPoint;PointKind.SMOOTHPOINT 175.215175151825,1508.75473737717 174.580714702606,1503.35403442383 176.021704673767,1515.6268787384 PathPoint;PointKind.SMOOTHPOINT 174.562304019928,1496.15120887756 173.925719261169,1479.19827461243 174.690824747086,1499.57229137421 PathPoint;PointKind.SMOOTHPOINT 178.849160671234,1474.14123773575 178.387831449509,1464.04911518097 179.232952594757,1482.53886938095 PathPoint;PointKind.SMOOTHPOINT 178.678507804871,1447.23780155182 177.894283533096,1444.02560949326 181.577836275101,1459.11670446396 PathPoint;PointKind.SMOOTHPOINT 179.30588722229,1439.88556623459 179.607893228531,1437.31845617294 179.057343006134,1442.00090646744 PathPoint;PointKind.SMOOTHPOINT 186.215204000473,1420.28668642044 184.083130846667,1409.6123073371 188.604344129562,1432.24702119827 PathPoint;PointKind.SMOOTHPOINT 183.51592872794,1385.20620324983 183.533818029217,1382.90084033882 183.419923999731,1397.57816436065 PathPoint;PointKind.SMOOTHPOINT 183.644088633279,1378.26153757244 182.839609916608,1375.13202426198 183.896818479272,1379.24468529356 PathPoint;PointKind.SMOOTHPOINT 184.0335621415,1368.55976320887 184.46635388695,1360.015247126 183.869858605922,1371.79172755956 PathPoint;PointKind.SMOOTHPOINT 185.72767496109,1343.42043399811 186.787351369858,1329.57819700241 185.107156562622,1351.52588441773 PathPoint;PointKind.SMOOTHPOINT 181.630589962006,1305.01173734665 181.80104940021,1300.91986277285 180.974532365799,1320.75971603394 PathPoint;PointKind.SMOOTHPOINT 182.544494835245,1293.77301431002 182.991670876459,1290.22805666271 182.118685108591,1297.14859195211 PathPoint;PointKind.SMOOTHPOINT 184.198756937448,1284.53431015547 186.02297001262,1281.00068593171 182.995649229886,1286.86481123404 PathPoint;PointKind.SMOOTHPOINT 187.413668632507,1276.74425840378 190.035774707794,1273.89036655426 186.277014089725,1277.98115785764 PathPoint;PointKind.SMOOTHPOINT 200.581555366516,1254.92783546448 201.317982673645,1243.44004154205 199.772547483444,1267.55237102509 PathPoint;PointKind.SMOOTHPOINT 204.215894937515,1220.31386375427 203.622858524323,1212.24644422531 204.809285402298,1228.38128328323 PathPoint;PointKind.SMOOTHPOINT 207.89873957634,1193.38658809662 206.64893746376,1180.73113203049 209.124820232391,1205.79515218735 PathPoint;PointKind.SMOOTHPOINT 203.75244140625,1147.291431427 202.363497018814,1134.29230928421 205.142093896866,1160.29008150101 PathPoint;PointKind.SMOOTHPOINT 207.411564588547,1116.52033567429 207.298997371321,1106.4654776304 207.619746923447,1135.14816999435 PathPoint;PointKind.SMOOTHPOINT 205.331183266449,1079.16377263912 205.17327862181,1077.10969933781 206.339147053607,1092.27568273294 PathPoint;PointKind.SMOOTHPOINT 204.856999490628,1073.10095241117 204.328292166633,1071.17671651741 205.487630703599,1075.39614137613 PathPoint;PointKind.SMOOTHPOINT 204.392306218235,1067.2939874353 203.875583096667,1060.87332406127 204.543222869788,1069.16923740325 PathPoint;PointKind.SMOOTHPOINT 203.143472671509,1051.20867490768 202.20027923584,1037.34212636948 203.417686223556,1055.24008075245 PathPoint;PointKind.SMOOTHPOINT 199.09524679184,1020.48643827438 198.456183671951,1010.65418958664 201.070146560669,1050.89144468307 PathPoint;PointKind.SMOOTHPOINT 204.053031206131,988.609521389008 200.711138248444,966.370360851288 205.675649642944,999.402430057526 PathPoint;PointKind.SMOOTHPOINT 202.387926578522,932.0663022995 204.440009593964,915.34704208374 201.002168655396,943.357951641083 PathPoint;PointKind.SMOOTHPOINT 206.046341657639,901.29567861557 206.264083385468,885.265874862671 205.8289539814,917.325482368469 PathPoint;PointKind.SMOOTHPOINT 201.924827098846,859.043633937836 201.758068799973,841.340818405151 202.09158539772,876.74644947052 PathPoint;PointKind.SMOOTHPOINT 205.51030755043,816.743202209473 206.214870214462,799.605453014374 204.806098937988,833.880715370178 PathPoint;PointKind.SMOOTHPOINT 205.290795564651,782.153306007385 203.380325794217,773.077456958361 207.563098669052,792.949047088623 PathPoint;PointKind.SMOOTHPOINT 198.981900544314,763.99149846155 198.082876867947,761.468414696171 200.674568325315,768.741921293217 PathPoint;PointKind.SMOOTHPOINT 197.413147687912,755.298728942871 196.383111882358,752.817377986721 198.766443417652,758.559035782953 PathPoint;PointKind.SMOOTHPOINT 198.327287866411,743.669627272659 200.258244899057,735.050374720879 197.705234417274,746.446300025172 PathPoint;PointKind.SMOOTHPOINT 204.925414323807,724.504029750824 205.504642724991,707.549443244934 204.567385519211,734.989248289999 PathPoint;PointKind.SMOOTHPOINT 200.779116153717,678.408637046814 201.440484523773,660.196223258972 200.415505170822,688.428061008453 PathPoint;PointKind.SMOOTHPOINT 200.486315488815,632.289168834686 198.639936447144,600.754265785217 201.925535202026,656.852796077728 PathPoint;PointKind.SMOOTHPOINT 204.047720432281,586.145153045654 202.40846157074,577.357356548309 205.687333345413,594.932713508606 PathPoint;PointKind.SMOOTHPOINT 203.877421617508,559.241952896118 202.527068853378,547.575716972351 205.227774381638,570.907952785492 PathPoint;PointKind.SMOOTHPOINT 203.75527381897,540.025448799133 203.673487901688,530.867786407471 203.837767839432,549.182875156403 PathPoint;PointKind.SMOOTHPOINT 203.584975004196,513.122248649597 202.485644817352,492.698664665222 204.68359708786,533.545832633972 PathPoint;PointKind.SMOOTHPOINT 203.413968086243,486.219284534454 202.865896224976,474.806313514709 203.9623939991,497.632019519806 PathPoint;PointKind.SMOOTHPOINT 199.413893222809,463.183507919312 196.612991094589,451.574628353119 202.215503454208,474.792387485504 PathPoint;PointKind.SMOOTHPOINT 199.268023967743,440.123891830444 201.196542978287,427.611000537872 196.703274250031,456.765732765198 PathPoint;PointKind.SMOOTHPOINT 203.02451133728,424.726424217224 202.683559656143,419.407625198364 203.364754915237,430.044987201691 PathPoint;PointKind.SMOOTHPOINT 199.072941541672,409.377343654633 197.756931781769,397.440848350525 200.389659404755,421.313602924347 PathPoint;PointKind.CORNERPOINT 202.780215740204,386.293416023254 202.780215740204,386.293416023254 202.780215740204,386.293416023254 PathPoint;PointKind.SMOOTHPOINT 198.78049492836,363.257639408112 194.623929262161,342.855298519135 201.772938966751,377.946059703827 PathPoint;PointKind.SMOOTHPOINT 202.439264059067,332.487251758575 203.205652769472,327.530675056101 200.388951301575,345.748136043549 PathPoint;PointKind.SMOOTHPOINT 203.557855624808,320.044586233496 203.579905445366,317.105923588209 203.532105295051,323.476429679343 PathPoint;PointKind.SMOOTHPOINT 203.049967172199,312.421945087471 202.310495570704,311.211377179212 204.210610542382,314.322001308749 PathPoint;PointKind.SMOOTHPOINT 198.317395448685,290.235207080841 197.721526622772,275.044977664948 198.695149532056,299.859112972072 PathPoint;PointKind.SMOOTHPOINT 198.098237514496,255.645310878754 197.598670721054,239.571840763092 198.597804307938,271.718780994415 PathPoint;PointKind.SMOOTHPOINT 201.78108215332,228.7180352211 205.50924539566,216.449675559998 198.05362701416,240.986394882202 PathPoint;PointKind.SMOOTHPOINT 201.610783338547,201.814835071564 200.205906629562,191.110203266144 203.015305995941,212.519702911377 PathPoint;PointKind.SMOOTHPOINT 201.464560031891,178.754982948303 200.661925077438,173.769700527191 202.266486883163,183.740501403809 PathPoint;PointKind.SMOOTHPOINT 197.53741979599,167.249486446381 197.85181760788,156.966412067413 197.22373008728,177.532796859741 PathPoint;PointKind.CORNERPOINT 197.464485168457,155.719442367554 197.464485168457,155.719442367554 197.464485168457,155.719442367554 PathPoint";
		
	mask35mm[1] = "PointKind.SMOOTHPOINT 202.984375,133 204.072169202722,132.055941141097 201.58968211597,134.210423927512 PathPoint;PointKind.SMOOTHPOINT 210.108623598378,130.783761238019 228.290475030965,129.485627737757 205.538212049608,131.110075880037 PathPoint;PointKind.CORNERPOINT 260.984375,132 260.984375,132 260.984375,132 PathPoint;PointKind.SMOOTHPOINT 282.082414388657,132.127568721771 289.539448976517,133.429062366486 274.625379800797,130.826075077057 PathPoint;PointKind.SMOOTHPOINT 297.497112512589,132.030794620514 303.238767147064,132.057938575745 291.755103826523,132.003886699677 PathPoint;PointKind.SMOOTHPOINT 459.349318504333,131.014666557312 465.032908678055,130.945980548859 453.665728330612,131.083588600159 PathPoint;PointKind.SMOOTHPOINT 490.178360700607,130.821590423584 496.759117603302,129.970922470093 481.704489946365,131.916790008545 PathPoint;PointKind.SMOOTHPOINT 505.593058824539,130.724580287933 510.35151219368,130.991771221161 500.834251403809,130.457153320312 PathPoint;PointKind.SMOOTHPOINT 528.714397907257,130.579419136047 532.731113195419,130.62025308609 524.698036670685,130.538349151611 PathPoint;PointKind.SMOOTHPOINT 540.984375,131 546.042356014252,128.927145957947 534.675175666809,133.586228847504 PathPoint;PointKind.SMOOTHPOINT 555.690296649933,130.410182476044 559.055202960968,130.320017337799 552.324682235718,130.499875545502 PathPoint;PointKind.SMOOTHPOINT 613.494175434113,130.047397613525 616.540081262589,129.892086982727 606.568572282791,130.400269031525 PathPoint;PointKind.SMOOTHPOINT 649.905194997787,129.809710979462 651.714398622513,129.805934429169 632.574723720551,129.846060276031 PathPoint;PointKind.SMOOTHPOINT 654.984419107437,131.000032424927 656.363804101944,130.997200012207 653.159991264343,131.003572940826 PathPoint;PointKind.SMOOTHPOINT 660.984375,130 679.970391511917,129.96081829071 659.609592676163,130.00283241272 PathPoint;PointKind.SMOOTHPOINT 698.274307012558,129.51514005661 702.056286096573,129.124975204468 696.460500717163,129.702315330505 PathPoint;PointKind.SMOOTHPOINT 713.68900513649,129.418365955353 721.524874925613,130.20388841629 705.677525758743,128.615140914917 PathPoint;PointKind.SMOOTHPOINT 740.663841724396,129.249129295349 751.472682714462,129.190356731415 729.856062889099,129.307901859283 PathPoint;PointKind.SMOOTHPOINT 883.272635698318,132.197434902191 874.538891077042,132.216081619263 892.007088422775,132.178552150726 PathPoint;PointKind.SMOOTHPOINT 894.833482265472,132.124736309052 906.845036506653,131.850936412811 882.822636127472,132.398536205292 PathPoint;PointKind.SMOOTHPOINT 921.809026956558,131.955499649048 929.388209342957,132.096884250641 913.933503389359,131.808214187622 PathPoint;PointKind.SMOOTHPOINT 964.198915719986,131.689252853394 978.209091186523,131.907820701599 950.188386201859,131.470921039581 PathPoint;PointKind.SMOOTHPOINT 1064.39339137077,131.060221195221 1081.72811126709,130.92756986618 1047.05796337128,131.193344593048 PathPoint;PointKind.SMOOTHPOINT 1264.80641818047,133.645741939545 1254.78852844238,133.928039073944 1274.82430791855,133.363680839539 PathPoint;PointKind.SMOOTHPOINT 1325.984375,133 1333.51115775108,132.93509054184 1318.45794630051,133.065145492554 PathPoint;PointKind.SMOOTHPOINT 1349.61027121544,136.957068443298 1353.40936129986,137.517938254252 1342.43167066574,135.896837711334 PathPoint;PointKind.SMOOTHPOINT 1363.984375,134 1366.67798275635,133.579037454549 1360.16468343714,134.596949232624 PathPoint;PointKind.SMOOTHPOINT 1379.984375,132 1394.73511122105,134.270108379327 1377.40932587011,131.603705470799 PathPoint;PointKind.SMOOTHPOINT 1426.65862417221,132.629849910736 1445.38724517822,135.962891578674 1419.45367431641,131.347711086273 PathPoint;PointKind.SMOOTHPOINT 1727.26648068428,134.586338996887 1756.51609873772,134.574773311615 1686.38024902344,134.602861404419 PathPoint;PointKind.SMOOTHPOINT 1964.984375,136 1966.55707216263,136.011329650879 1884.05278420448,135.41463470459 PathPoint;PointKind.SMOOTHPOINT 1973.98449873924,137.000026702881 1975.88064956665,137.903943538666 1972.59997081471,136.340027369075 PathPoint;PointKind.SMOOTHPOINT 1980.51922893524,136.114897727966 2006.6524848938,136.306793689728 1978.12300777435,136.097431182861 PathPoint;PointKind.SMOOTHPOINT 2031.72677254677,136.518752574921 2048.71806240082,136.695070266724 2025.83039736748,136.45738363266 PathPoint;PointKind.SMOOTHPOINT 2085.67786192894,136.180279254913 2095.27835573513,136.524803744082 2066.74176669121,135.500264167786 PathPoint;PointKind.SMOOTHPOINT 2308.66079654057,138.686971513171 2314.53975222643,138.745333608934 2201.1038467531,137.619222521872 PathPoint;PointKind.SMOOTHPOINT 2330.984375,139 2429.60932945966,139.975121131737 2325.11050423591,138.941924074505 PathPoint;PointKind.SMOOTHPOINT 2540.45465087891,141.012139320374 2583.00634121895,141.567764282227 2520.65577725375,140.753720287113 PathPoint;PointKind.SMOOTHPOINT 2898.84231066704,138.762731552124 2957.5146780014,138.586649894714 2840.16923522949,138.938813209534 PathPoint;PointKind.SMOOTHPOINT 3318.91213035583,139.969339370728 3357.40284895897,139.235272407532 3280.42070364952,140.70317029953 PathPoint;PointKind.SMOOTHPOINT 3422.95974946022,139.316468238831 3430.22638166272,138.64866645454 3408.85964488983,140.611588954926 PathPoint;PointKind.SMOOTHPOINT 3439.984375,142 3444.9909014657,142.237534302206 3435.231943979,141.774521238609 PathPoint;PointKind.SMOOTHPOINT 3453.8132212162,142.966032028198 3462.25499024405,141.139227245908 3447.84713597593,144.257090883724 PathPoint;PointKind.SMOOTHPOINT 3466.984375,141 3468.96513337432,140.672462118725 3462.04301605628,141.817102307898 PathPoint;PointKind.SMOOTHPOINT 3476.91083884239,138.97775888443 3479.69669609779,138.252099378542 3473.09118960241,139.97236844905 PathPoint;PointKind.SMOOTHPOINT 3497.984375,141 3502.86571851623,141.126689953153 3488.33128992674,140.749464693144 PathPoint;PointKind.SMOOTHPOINT 3511.61745405197,142.60324716568 3525.63718891144,142.851555347443 3506.75471891021,142.517121648076 PathPoint;PointKind.SMOOTHPOINT 3551.98429203033,143.000020980835 3574.61526966095,138.797900676727 3529.3079957962,147.210166454315 PathPoint;PointKind.SMOOTHPOINT 3669.61616253853,141.611666679382 3686.93672037125,141.971147060394 3652.29631280899,141.251714229584 PathPoint;PointKind.SMOOTHPOINT 4205.984375,138 4226.0120112896,138.907080173492 4185.95709276199,137.092919826508 PathPoint;PointKind.SMOOTHPOINT 4247.68539881706,141.826221942902 4269.97754907608,140.97767829895 4225.39254045486,142.674765586853 PathPoint;PointKind.SMOOTHPOINT 4394.09847712517,137.063755989075 4422.61839485168,136.482403278351 4365.57820534706,137.645344734192 PathPoint;PointKind.SMOOTHPOINT 4648.46223926544,139.310567378998 4663.49314546585,139.396483898163 4648.46223926544,139.310567378998 PathPoint;PointKind.SMOOTHPOINT 4713.99860477448,142.742507457733 4749.40872049332,142.364144325256 4678.58848905563,143.121106624603 PathPoint;PointKind.SMOOTHPOINT 4825.72914338112,138.198137283325 4833.20954537392,136.565487384796 4818.24874138832,139.830079078674 PathPoint;PointKind.SMOOTHPOINT 4891.26550889015,141.629841327667 4922.17385864258,140.684995651245 4860.35715913773,142.574450969696 PathPoint;PointKind.SMOOTHPOINT 4987.60613298416,141.025121212006 5030.37804341316,141.242980957031 4944.83386850357,140.807025432587 PathPoint;PointKind.SMOOTHPOINT 5149.45833897591,140.008993148804 5188.03225970268,139.106397628784 5110.88406419754,140.91206073761 PathPoint;PointKind.SMOOTHPOINT 5503.99214720726,137.783896923065 5546.25847196579,138.016862869263 5461.72546839714,137.550694942474 PathPoint;PointKind.SMOOTHPOINT 5638.86880850792,136.937005519867 5642.4578294754,136.924967765808 5617.69298291206,137.009468078613 PathPoint;PointKind.SMOOTHPOINT 5665.68078136444,148.145098686218 5667.84894824877,149.486583734012 5661.36772489548,145.476493835449 PathPoint;PointKind.SMOOTHPOINT 5678.984375,161 5681.52696302243,163.638786651376 5673.32357727448,155.125026413055 PathPoint;PointKind.SMOOTHPOINT 5693.0879149437,178.874888420105 5695.70081567764,183.526182174683 5689.19946943851,171.953830756718 PathPoint;PointKind.SMOOTHPOINT 5699.9363348484,192.130107879639 5702.04789853096,196.636004447937 5697.96851611137,187.932000160217 PathPoint;PointKind.SMOOTHPOINT 5705.29242730141,204.976279735565 5705.88015294075,206.596183776855 5703.81497001648,200.902562141418 PathPoint;PointKind.SMOOTHPOINT 5706.92141866684,209.747242927551 5708.09580779076,212.031111717224 5706.17153739929,208.288078308105 PathPoint;PointKind.SMOOTHPOINT 5708.70690083504,215.864546298981 5712.55614972115,230.471062660217 5708.18113422394,213.869819641113 PathPoint;PointKind.SMOOTHPOINT 5712.84328556061,255.619819164276 5712.87019348145,277.84576177597 5712.82806134224,242.813301086426 PathPoint;PointKind.SMOOTHPOINT 5709.30737233162,305.606710910797 5710.01547551155,322.393476963043 5708.59856104851,288.820652961731 PathPoint;PointKind.SMOOTHPOINT 5713.380027771,340.172295570374 5713.43880033493,352.333023548126 5713.32090115547,328.011803627014 PathPoint;PointKind.SMOOTHPOINT 5713.52625107765,363.232147693634 5711.41893601418,374.709792137146 5715.63321208954,351.754739284515 PathPoint;PointKind.SMOOTHPOINT 5713.79426813126,405.508503913879 5710.479637146,419.275681972504 5717.10889911652,391.741561889648 PathPoint;PointKind.SMOOTHPOINT 5708.98447728157,444.00004863739 5708.54120469093,453.845751285553 5709.42774987221,434.154345989227 PathPoint;PointKind.SMOOTHPOINT 5714.35473179817,493.904328346252 5714.13557386398,507.74231672287 5714.70878338814,471.576182842255 PathPoint;PointKind.SMOOTHPOINT 5710.89104509354,555.4212641716 5710.11354780197,564.176723957062 5711.72837710381,545.993814468384 PathPoint;PointKind.SMOOTHPOINT 5714.05201768875,581.417148113251 5714.33773732185,582.219429016113 5710.33447599411,570.976874828339 PathPoint;PointKind.SMOOTHPOINT 5714.93997907639,586.143972873688 5717.01826190948,598.700530529022 5714.79552602768,585.273714065552 PathPoint;PointKind.SMOOTHPOINT 5711.30563950539,620.757472515106 5711.71846365929,625.887916088104 5710.57346081734,611.664011478424 PathPoint;PointKind.SMOOTHPOINT 5715.04725670815,644.775388240814 5715.65657949448,648.785848617554 5713.68026351929,635.777049064636 PathPoint;PointKind.SMOOTHPOINT 5715.71499800682,655.756652355194 5717.36771082878,658.801259994507 5713.9762506485,652.55366563797 PathPoint;PointKind.SMOOTHPOINT 5713.984375,666 5713.74127364159,675.641928672791 5714.03858888806,663.860605245969 PathPoint;PointKind.SMOOTHPOINT 5710.984375,707 5711.29027557373,717.872452259064 5710.67812037468,696.107012748718 PathPoint;PointKind.SMOOTHPOINT 5715.33191418648,756.946721076965 5714.76082897186,771.070075035095 5715.89308595657,743.060345649719 PathPoint;PointKind.SMOOTHPOINT 5712.37806177139,789.862897396088 5713.06492185593,796.707186698914 5711.31732320786,779.294221401215 PathPoint;PointKind.SMOOTHPOINT 5712.54871463776,816.76586151123 5713.10068106651,822.123606204987 5711.5343568325,806.920394897461 PathPoint;PointKind.SMOOTHPOINT 5716.49957633018,832.115178108215 5717.35567808151,836.297574996948 5715.4091673348,826.785325263679 PathPoint;PointKind.SMOOTHPOINT 5708.98730969429,862.909877300262 5708.76390314102,868.109242916107 5709.40155005455,853.250405788422 PathPoint;PointKind.SMOOTHPOINT 5712.96295499802,882.10230588913 5713.74930357933,888.738884925842 5712.04631543159,874.36509847641 PathPoint;PointKind.SMOOTHPOINT 5713.08510279655,901.318573951721 5714.76012086868,908.65216255188 5712.07995033264,896.918892860413 PathPoint;PointKind.SMOOTHPOINT 5713.23132610321,924.378426074982 5711.90940930675,929.437131359752 5715.39564347267,916.092438697815 PathPoint;PointKind.SMOOTHPOINT 5708.984375,934 5708.16741820162,935.13094218644 5710.96080681376,931.263955546709 PathPoint;PointKind.SMOOTHPOINT 5704.98440241814,937.999970912933 5705.01819412743,941.096760013343 5704.96340512466,936.054709763717 PathPoint;PointKind.SMOOTHPOINT 5709.984375,944 5711.91533165842,946.08241429793 5708.40944819265,942.301541317611 PathPoint;PointKind.SMOOTHPOINT 5717.27955198288,955.100662708282 5716.86446447269,967.38058860451 5717.43446641586,950.516938806128 PathPoint;PointKind.SMOOTHPOINT 5713.59670734406,982.02817440033 5713.62113690376,988.214163780212 5713.55563735962,971.782865524292 PathPoint;PointKind.SMOOTHPOINT 5713.76736021042,1008.93113851547 5714.43403935432,1014.25347805023 5712.75087809563,1000.81958055496 PathPoint;PointKind.SMOOTHPOINT 5717.69379234314,1020.4366350174 5719.08804750443,1029.13875102997 5716.77502846718,1014.69887495041 PathPoint;PointKind.SMOOTHPOINT 5717.8400156498,1043.49672317505 5717.49375319481,1049.22834634781 5718.36259579659,1034.8677778244 PathPoint;PointKind.SMOOTHPOINT 5717.96180939674,1062.71299123764 5720.10771608353,1073.49126577377 5717.10535860062,1058.41102838516 PathPoint;PointKind.SMOOTHPOINT 5718.1080327034,1085.7728433609 5715.90052103996,1093.71988534927 5720.31589841843,1077.82580137253 PathPoint;PointKind.SMOOTHPOINT 5722.25433087349,1131.8687081337 5720.80838418007,1152.16931819916 5723.39862561226,1115.79641819 PathPoint;PointKind.SMOOTHPOINT 5718.79064416885,1193.38564395905 5718.7679848671,1213.55147838593 5718.81330347061,1173.21910142899 PathPoint;PointKind.SMOOTHPOINT 5715.984375,1222 5718.5671813488,1228.29102468491 5711.44543361664,1210.94438505173 PathPoint;PointKind.SMOOTHPOINT 5730.6198618412,1235.58906555176 5732.62311220169,1238.21874046326 5727.78126146846,1231.86351122775 PathPoint;PointKind.SMOOTHPOINT 5734.59515309334,1254.78149414062 5734.52398872375,1262.05158948898 5734.70278477669,1243.79928588867 PathPoint;PointKind.SMOOTHPOINT 5737.984375,1275 5736.12277173996,1281.2346124649 5739.29365777969,1270.61660528183 PathPoint;PointKind.SMOOTHPOINT 5730.96081352234,1289.39522981644 5730.33130979538,1294.77114915848 5731.77265381813,1282.46832847595 PathPoint;PointKind.SMOOTHPOINT 5734.88795375824,1300.90096235275 5739.86237859726,1307.11126327515 5729.04574847221,1293.60797166824 PathPoint;PointKind.SMOOTHPOINT 5739.00946831703,1343.15300703049 5739.37626576424,1352.25331306458 5738.53468513489,1331.38834476471 PathPoint;PointKind.SMOOTHPOINT 5737.08661413193,1366.59971952438 5734.1518805027,1371.06808662415 5740.02063965797,1362.13135242462 PathPoint;PointKind.SMOOTHPOINT 5731.59456586838,1389.32133436203 5729.82749438286,1400.25019884109 5732.61812901497,1382.99325227737 PathPoint;PointKind.SMOOTHPOINT 5731.86258292198,1431.59745454788 5730.14153814316,1447.84086942673 5733.5839817524,1415.35427570343 PathPoint;PointKind.SMOOTHPOINT 5743.76508927345,1485.33092021942 5749.79387974739,1507.42916822433 5737.73594474792,1463.2329082489 PathPoint;PointKind.SMOOTHPOINT 5743.95981764793,1516.07770442963 5742.95855975151,1529.03740882874 5744.96142959595,1503.11752796173 PathPoint;PointKind.SMOOTHPOINT 5751.83746552467,1542.93204545975 5752.56468749046,1556.96806669235 5751.11059761047,1528.89602422714 PathPoint;PointKind.SMOOTHPOINT 5756.86145758629,1727.38655090332 5757.33043485336,1736.94057043138 5754.6557161808,1682.44395017624 PathPoint;PointKind.SMOOTHPOINT 5757.45237956235,1763.5752599265 5757.45173698286,1765.94286781617 5757.4561556986,1749.66194621331 PathPoint;PointKind.SMOOTHPOINT 5757.4402554926,1770.77189546881 5757.10253538347,1773.9642755453 5757.69557275066,1768.35844804365 PathPoint;PointKind.SMOOTHPOINT 5757.40924815402,1778.69471970266 5757.2941729014,1803.02291827495 5757.42183788305,1776.03310983598 PathPoint;PointKind.SMOOTHPOINT 5757.61700367928,1846.52868747711 5758.68199086189,1878.68082046509 5757.0275346473,1828.73830704797 PathPoint;PointKind.SMOOTHPOINT 5758.00681447983,1908.02154779434 5759.54764699936,1924.10044670105 5756.4659819603,1891.94264888763 PathPoint;PointKind.SMOOTHPOINT 5762.25047683716,1969.49033260345 5760.90968346596,1993.56253623962 5763.59162425995,1945.41812896729 PathPoint;PointKind.SMOOTHPOINT 5762.68914675713,2038.66965293884 5761.97644090652,2058.31314325333 5763.78104186058,2008.5875415802 PathPoint;PointKind.SMOOTHPOINT 5763.984375,2333 5763.99747490883,2334.50259494781 5762.996571064,2221.25329303741 PathPoint;PointKind.SMOOTHPOINT 5762.98442578316,2339.00005102158 5762.21147402954,2340.76040358915 5763.68031024933,2337.41524839401 PathPoint;PointKind.SMOOTHPOINT 5764.35354328156,2344.68470335007 5764.83717775345,2398.8911819458 5764.33690285683,2342.79666423798 PathPoint;PointKind.CORNERPOINT 5765.22451019287,2438.37312698364 5765.22451019287,2438.37312698364 5765.22451019287,2438.37312698364 PathPoint;PointKind.SMOOTHPOINT 5765.34630393982,2457.58939504623 5765.06093835831,2459.41677331924 5765.66990709305,2455.51252841949 PathPoint;PointKind.SMOOTHPOINT 5757.68710589409,2465.32424211502 5757.10681533813,2476.26986503601 5757.93140149117,2460.72936058044 PathPoint;PointKind.SMOOTHPOINT 5757.93104743958,2503.75748634338 5756.57927846909,2508.87164354324 5760.38356280327,2494.48180675507 PathPoint;PointKind.SMOOTHPOINT 5754.22412729263,2526.84165000916 5751.3814470768,2533.65596294403 5757.71684622765,2518.46644163132 PathPoint;PointKind.SMOOTHPOINT 5742.78472042084,2546.13061666489 5741.17449378967,2557.32785224915 5743.81678080559,2538.95186662674 PathPoint;PointKind.SMOOTHPOINT 5742.9553732872,2573.03381681442 5743.40225166645,2575.65055537797 5741.30513882637,2563.3738732338 PathPoint;PointKind.SMOOTHPOINT 5746.12756427364,2582.19510484969 5745.68908771114,2582.99588609969 5746.56604083614,2581.39432359969 PathPoint;PointKind.SMOOTHPOINT 5746.90623497963,2588.38289737701 5746.62901258469,2591.1567735672 5747.11842899565,2586.26287122595 PathPoint;PointKind.SMOOTHPOINT 5743.12638020515,2599.93678092957 5741.17130732536,2605.0448012352 5745.08039093018,2594.82899665833 PathPoint;PointKind.SMOOTHPOINT 5747.24789476395,2642.18906164169 5747.66001081467,2651.21218442917 5746.9356212616,2635.36766767502 PathPoint;PointKind.SMOOTHPOINT 5743.54062056541,2665.27275323868 5745.65891122818,2671.79343938828 5741.42162179947,2658.75230312347 PathPoint;PointKind.SMOOTHPOINT 5746.984375,2687 5746.84735703468,2699.52799749374 5747.1221010685,2674.47176647186 PathPoint;PointKind.SMOOTHPOINT 5739.95478606224,2707.57365703583 5739.77705216408,2718.47443342209 5740.13287401199,2696.67240858078 PathPoint;PointKind.SMOOTHPOINT 5735.984375,2736 5735.74896843609,2736.7061791603 5740.09739232063,2723.66319036484 PathPoint;PointKind.SMOOTHPOINT 5735.22325215264,2737.99584750141 5735.14073185284,2741.01119968795 5735.2418828269,2737.31506901993 PathPoint;PointKind.SMOOTHPOINT 5728.984375,2747 5727.81524679313,2749.26918036592 5729.60811608966,2745.78937055341 PathPoint;PointKind.SMOOTHPOINT 5728.71081566811,2757.60893583298 5732.28767894528,2775.94842768126 5727.65306855458,2752.1860871641 PathPoint;PointKind.SMOOTHPOINT 5728.93032765388,2792.19859600067 5729.11974525452,2804.94091272354 5728.74091005325,2779.45651531219 PathPoint;PointKind.SMOOTHPOINT 5729.05212140083,2811.41510009766 5727.73257112503,2819.84884500504 5730.37131762505,2802.98111915588 PathPoint;PointKind.SMOOTHPOINT 5729.1979906559,2834.47471618652 5726.66121101379,2843.70885372162 5731.734770298,2825.24081468582 PathPoint;PointKind.CORNERPOINT 5729.27127933502,2846.00476026535 5729.27127933502,2846.00476026535 5729.27127933502,2846.00476026535 PathPoint;PointKind.SMOOTHPOINT 5733.24692463875,2865.19695281982 5731.85408568382,2880.08104562759 5734.64011764526,2850.31286001205 PathPoint;PointKind.SMOOTHPOINT 5729.53929638863,2888.2808804512 5731.29574632645,2898.43130350113 5727.7832005024,2878.13092947006 PathPoint;PointKind.SMOOTHPOINT 5733.61265993118,2922.84670114517 5732.14369988441,2937.14849710464 5735.08091187477,2908.54466915131 PathPoint;PointKind.CORNERPOINT 5729.92946124077,2949.77374076843 5729.92946124077,2949.77374076843 5729.92946124077,2949.77374076843 PathPoint;PointKind.SMOOTHPOINT 5724.98442268372,2967.00000286102 5725.87238407135,2976.48787736893 5724.19417953491,2958.56578588486 PathPoint;PointKind.SMOOTHPOINT 5734.09983491898,2999.71248149872 5735.33016419411,3018.05731058121 5732.86950564384,2981.36788845062 PathPoint;PointKind.SMOOTHPOINT 5734.39263558388,3045.83218574524 5732.91765666008,3055.40810108185 5735.8669064045,3036.25627040863 PathPoint;PointKind.SMOOTHPOINT 5730.63614821434,3061.22988939285 5729.87068867683,3067.83460378647 5731.40125370026,3054.62493896484 PathPoint;PointKind.SMOOTHPOINT 5738.51450419426,3088.08446645737 5738.04003465175,3091.25253549186 5740.91745233536,3072.03483581543 PathPoint;PointKind.SMOOTHPOINT 5735.984375,3096 5734.72184156519,3102.9434701679 5736.29488598407,3094.29230363707 PathPoint;PointKind.SMOOTHPOINT 5734.83130550385,3115.01174211502 5733.46077179909,3133.48686218262 5735.93101864802,3100.18332753321 PathPoint;PointKind.SMOOTHPOINT 5735.22076225281,3176.50460243225 5733.2522354126,3200.71535825729 5736.31053304672,3163.10847043991 PathPoint;PointKind.SMOOTHPOINT 5739.27005028725,3207.22660303116 5740.49506878853,3222.9231262207 5738.64267086983,3199.19860124588 PathPoint;PointKind.SMOOTHPOINT 5735.56277608871,3230.31076669693 5733.32410788536,3249.6441078186 5737.8003821373,3210.97742557526 PathPoint;PointKind.SMOOTHPOINT 5735.87894415855,3280.27358293533 5733.85270690918,3322.43805885315 5736.85895895958,3259.88351583481 PathPoint;PointKind.SMOOTHPOINT 5726.98446011543,3317.00006246567 5726.61589241028,3322.33113527298 5727.88870787621,3303.89826536179 PathPoint;PointKind.SMOOTHPOINT 5732.31789326668,3326.41759872437 5734.03362727165,3336.28265619278 5730.60251331329,3316.55254125595 PathPoint;PointKind.SMOOTHPOINT 5732.48854613304,3353.32056283951 5733.53016591072,3371.3302230835 5731.87072610855,3342.63552188873 PathPoint;PointKind.SMOOTHPOINT 5736.5619096756,3387.88614749908 5736.08039951324,3400.47811031342 5736.86320757866,3379.97828722 PathPoint;PointKind.SMOOTHPOINT 5732.82985186577,3407.12672710419 5731.65404653549,3423.985247612 5734.00530314445,3390.26820659637 PathPoint;PointKind.SMOOTHPOINT 5736.85400223732,3434.00561571121 5737.10573291779,3435.96564531326 5734.69428753853,3417.19807863235 PathPoint;PointKind.SMOOTHPOINT 5737.00022554398,3457.06546783447 5738.65293836594,3479.97709035873 5736.78212976456,3454.0406870842 PathPoint;PointKind.SMOOTHPOINT 5737.46332502365,3530.08813619614 5736.42312145233,3535.64060926437 5739.80431413651,3517.59601593018 PathPoint;PointKind.SMOOTHPOINT 5734.97575855255,3544.49921607971 5734.02937865257,3550.9214758873 5735.5879137516,3540.34713506699 PathPoint;PointKind.SMOOTHPOINT 5733.80490994453,3560.85875988007 5734.01167607307,3575.03333330154 5733.73409962654,3556.01320981979 PathPoint;PointKind.SMOOTHPOINT 5741.65848231316,3583.8702249527 5741.37240862846,3614.7159075737 5741.83161354065,3565.21855115891 PathPoint;PointKind.SMOOTHPOINT 5738.04821825027,3622.32754468918 5740.47524189949,3638.02194356918 5735.20730829239,3603.95391941071 PathPoint;PointKind.SMOOTHPOINT 5738.29215979576,3660.76055288315 5741.16458034515,3687.38240003586 5738.29215979576,3660.76055288315 PathPoint;PointKind.SMOOTHPOINT 5715.65799570084,3737.77173042297 5710.95052576065,3748.04866790771 5727.50668621063,3711.90401315689 PathPoint;PointKind.SMOOTHPOINT 5696.4822075367,3773.56965065002 5694.93641829491,3776.14100933075 5704.06882500648,3760.95337629318 PathPoint;PointKind.SMOOTHPOINT 5690.984375,3781 5688.82643055916,3782.11927509308 5693.84050917625,3779.51841211319 PathPoint;PointKind.SMOOTHPOINT 5687.85998916626,3787.28796958923 5678.78635501862,3801.06576919556 5689.16962599754,3785.2991437912 PathPoint;PointKind.SMOOTHPOINT 5662.21886491776,3818.8193321228 5653.10734724998,3826.04599714279 5669.49887371063,3813.04569482803 PathPoint;PointKind.SMOOTHPOINT 5605.48068141937,3830.0715637207 5602.10550761223,3830.23796796799 5629.25772404671,3828.9003610611 PathPoint;PointKind.SMOOTHPOINT 5595.40083265305,3830.47636270523 5593.42699503899,3831.18541002274 5599.26282739639,3829.08966064453 PathPoint;PointKind.SMOOTHPOINT 5589.1712949276,3830.64772367477 5577.21391057968,3830.92718839645 5591.22337794304,3830.59980869293 PathPoint;PointKind.SMOOTHPOINT 5558.24382638931,3831.00248336792 5553.85535693169,3831.04874610901 5566.20680069923,3830.91869115829 PathPoint;PointKind.SMOOTHPOINT 5542.80540680885,3827.25614547729 5541.87672948837,3827.24717617035 5554.5146009922,3827.37133026123 PathPoint;PointKind.SMOOTHPOINT 5532.984375,3828 5528.00959610939,3828.04130601883 5534.83995938301,3827.98418569565 PathPoint;PointKind.SMOOTHPOINT 5523.53721117973,3827.37699508667 5515.64256882668,3827.28848218918 5526.37670493126,3827.40885972977 PathPoint;PointKind.SMOOTHPOINT 5488.85431742668,3827.5948548317 5421.31579017639,3826.75103187561 5498.31634616852,3827.71287202835 PathPoint;PointKind.SMOOTHPOINT 5292.31921768188,3828.82860660553 5240.5278429985,3829.7540974617 5328.12870359421,3828.18824529648 PathPoint;PointKind.SMOOTHPOINT 5045.66280460358,3826.53293609619 5025.9095582962,3827.05339193344 5065.41605091095,3826.01295232773 PathPoint;PointKind.SMOOTHPOINT 4999.41871023178,3826.82349443436 4988.41549491882,3827.42703437805 5010.42298769951,3826.21995449066 PathPoint;PointKind.SMOOTHPOINT 4733.49445557594,3824.64914560318 4704.84389281273,3825.54395198822 4762.14537239075,3823.75504732132 PathPoint;PointKind.SMOOTHPOINT 4610.17828679085,3825.42310237885 4587.99376821518,3826.18077278137 4632.36315941811,3824.66543197632 PathPoint;PointKind.SMOOTHPOINT 4305.74171638489,3827.33427286148 4250.40947175026,3827.31539011002 4361.07360696793,3827.35339164734 PathPoint;PointKind.SMOOTHPOINT 4078.35314488411,3824.91822481155 4064.53415727615,3824.9446606636 4092.17284059525,3824.89155292511 PathPoint;PointKind.SMOOTHPOINT 4051.35352468491,3821.24411344528 4028.42514371872,3820.57117938995 4074.28190565109,3821.91681146622 PathPoint;PointKind.SMOOTHPOINT 4005.984375,3825 3987.91950927118,3825.48782626721 4046.55054402351,3823.90432834625 PathPoint;PointKind.SMOOTHPOINT 3924.59625735411,3826.17675500178 3922.44868445019,3826.19557299536 3955.89343242399,3825.90251516634 PathPoint;PointKind.SMOOTHPOINT 3918.16858109619,3826.23120330771 3916.1534635926,3827.08712688657 3920.33872329132,3825.309432805 PathPoint;PointKind.SMOOTHPOINT 3911.63160248679,3826.28275672937 3877.53635124526,3826.54159930841 3913.79859642371,3826.26630545598 PathPoint;PointKind.SMOOTHPOINT 3839.42851042747,3826.41775131226 3815.01098847389,3825.76086759567 3846.83322870674,3826.61700174286 PathPoint;PointKind.SMOOTHPOINT 3804.72118711472,3822.79226303101 3783.15979933739,3819.19203042984 3818.23958492279,3825.04922389984 PathPoint;PointKind.SMOOTHPOINT 3777.74635052681,3822.9617357254 3764.83102721129,3823.42654545927 3797.55235052109,3822.24867582321 PathPoint;PointKind.SMOOTHPOINT 3507.36333850005,3824.10263667306 3504.78660177778,3824.11507392897 3615.55156619942,3823.58043948355 PathPoint;PointKind.SMOOTHPOINT 3499.705453741,3824.14058438531 3497.76812673054,3824.57666850771 3504.15309623189,3823.13943885754 PathPoint;PointKind.SMOOTHPOINT 3493.79688663984,3824.17131114248 3442.54447024492,3824.44372439745 3495.74976869431,3824.16093132052 PathPoint;PointKind.SMOOTHPOINT 3396.23699760437,3825.35630464554 3375.05196666718,3827.05669641495 3403.02034737246,3824.81191347672 PathPoint;PointKind.SMOOTHPOINT 3222.82359099388,3826.44489526749 3179.67603182793,3827.83277750015 3265.97079610825,3825.05724906921 PathPoint;PointKind.SMOOTHPOINT 2914.50873947144,3824.53679323196 2844.34739804268,3825.69194555283 2984.67008090019,3823.38211297989 PathPoint;PointKind.SMOOTHPOINT 2625.46208357811,3822.50760555267 2607.47838711739,3823.77393007278 2643.44648814201,3821.24175310135 PathPoint;PointKind.SMOOTHPOINT 2598.4628174305,3818.83373022079 2596.39228685659,3819.44758944543 2605.18838143349,3816.83971166611 PathPoint;PointKind.SMOOTHPOINT 2590.984375,3820 2586.98050438878,3821.25239946407 2592.59521843201,3819.49613270586 PathPoint;PointKind.SMOOTHPOINT 2571.51170229912,3822.84631490707 2554.54200959206,3823.11799049377 2584.88506781804,3822.63221583101 PathPoint;PointKind.SMOOTHPOINT 2529.12181353569,3823.11232566833 2511.0170314312,3824.2004442215 2548.19669699669,3821.96567058563 PathPoint;PointKind.SMOOTHPOINT 2494.43927383423,3823.33018541336 2457.95708990097,3822.79061079025 2530.92074966431,3823.86976003647 PathPoint;PointKind.SMOOTHPOINT 1993.44317412376,3822.63152360916 1912.9683098793,3825.03435373306 2073.91768431664,3820.22892951965 PathPoint;PointKind.SMOOTHPOINT 1604.20239663124,3821.23113155365 1567.67595624924,3822.22932100296 1640.72848296165,3820.23341417313 PathPoint;PointKind.SMOOTHPOINT 1496.30057191849,3821.90855026245 1477.34394168854,3823.67314338684 1515.25755620003,3820.14395713806 PathPoint;PointKind.SMOOTHPOINT 1469.32538127899,3822.07778692245 1458.30410933495,3822.74765253067 1480.34629917145,3821.40839338303 PathPoint;PointKind.SMOOTHPOINT 1438.49633908272,3822.27109909058 1425.59292888641,3823.36134195328 1451.39939522743,3821.18156433105 PathPoint;PointKind.SMOOTHPOINT 1384.54524970055,3822.61028051376 1376.33585548401,3821.94796800613 1394.422935009,3823.40666055679 PathPoint;PointKind.SMOOTHPOINT 1319.03366780281,3823.02121639252 1268.20141887665,3824.20516490936 1369.86627078056,3821.83750391006 PathPoint;PointKind.SMOOTHPOINT 1180.27907943726,3820.04907131195 1160.56088423729,3821.37369632721 1199.99692058563,3818.72397422791 PathPoint;PointKind.SMOOTHPOINT 952.914937496185,3821.47589921951 930.435847997665,3822.31358528137 975.394026994705,3820.63821315765 PathPoint;PointKind.SMOOTHPOINT 906.67119717598,3821.76645755768 892.069047451019,3821.73176050186 921.27405500412,3821.80068254471 PathPoint;PointKind.SMOOTHPOINT 868.110730409622,3818.16480875015 855.564912319183,3819.65465784073 880.655840396881,3816.67495965958 PathPoint;PointKind.SMOOTHPOINT 717.843092441559,3822.95182228088 694.00727725029,3822.47668504715 738.03253030777,3823.35402488708 PathPoint;PointKind.SMOOTHPOINT 648.478013038635,3823.38706970215 625.887397289276,3821.80516719818 671.068628787994,3824.96850013733 PathPoint;PointKind.SMOOTHPOINT 609.941975831985,3823.62900495529 582.467572450638,3822.07778692245 637.416025161743,3825.17998695374 PathPoint;PointKind.SMOOTHPOINT 536.698969364166,3820.24545192719 509.714219331741,3823.71775388718 563.683011293411,3816.7729139328 PathPoint;PointKind.SMOOTHPOINT 463.479684352875,3820.70477485657 434.620585203171,3821.01209163666 492.339137554169,3820.39745807648 PathPoint;PointKind.SMOOTHPOINT 370.992557764053,3821.28541946411 333.093105316162,3821.32507324219 408.891656160355,3821.24552965164 PathPoint;PointKind.SMOOTHPOINT 293.919775247574,3821.7692899704 286.103943846809,3822.06808917521 312.749300956726,3821.04914903641 PathPoint;PointKind.SMOOTHPOINT 267.548310164726,3822.17890587251 266.173166573457,3822.18060920125 276.424835457232,3822.1679109184 PathPoint;PointKind.SMOOTHPOINT 262.984375,3823 261.621942206635,3822.37756535615 263.925340715966,3823.42988517536 PathPoint;PointKind.SMOOTHPOINT 259.122765947091,3822.16474826109 249.304948414736,3822.12134780123 260.532005957376,3822.17097792102 PathPoint;PointKind.CORNERPOINT 241.984375,3822 241.984375,3822 241.984375,3822 PathPoint;PointKind.SMOOTHPOINT 238.071059840619,3817.19697890041 237.282328159144,3813.99700490344 238.486441125064,3818.88222794045 PathPoint;PointKind.SMOOTHPOINT 235.993748664856,3802.91533470154 235.590837955475,3790.10197162628 236.194568675823,3809.30582759144 PathPoint;PointKind.SMOOTHPOINT 232.984375,3781 233.960495233536,3771.50528049469 232.009316921234,3790.49471950531 PathPoint;PointKind.SMOOTHPOINT 235.700947999954,3756.7961025238 229.965666294098,3746.44835472107 241.981823205948,3768.12740564346 PathPoint;PointKind.SMOOTHPOINT 231.70122718811,3733.76032590866 229.334038257599,3725.97402334213 234.069124221802,3741.54662847519 PathPoint;PointKind.SMOOTHPOINT 231.579433441162,3714.54358577728 230.600126743317,3707.23525285721 232.558740139008,3721.85239076614 PathPoint;PointKind.CORNERPOINT 235.311491250992,3695.30300617218 235.311491250992,3695.30300617218 235.311491250992,3695.30300617218 PathPoint;PointKind.SMOOTHPOINT 235.189697504044,3676.08673810959 234.776519298553,3666.08430862427 235.602167606354,3686.08893156052 PathPoint;PointKind.SMOOTHPOINT 231.238127708435,3660.737657547 229.049380779266,3649.83947753906 233.427228689194,3671.63560152054 PathPoint;PointKind.SMOOTHPOINT 231.067474842072,3633.83422136307 230.708112478256,3626.50983810425 231.427191257477,3641.15884065628 PathPoint;PointKind.SMOOTHPOINT 230.945681095123,3614.61818933487 231.775223970413,3604.87209320068 230.116846323013,3624.36404943466 PathPoint;PointKind.SMOOTHPOINT 230.77502822876,3587.71475315094 229.881402015686,3575.93191623688 231.668654441833,3599.4978260994 PathPoint;PointKind.SMOOTHPOINT 230.604729413986,3560.81202507019 229.297985936992,3556.87134788318 233.440682649612,3569.36355113983 PathPoint;PointKind.SMOOTHPOINT 227.914880583751,3543.04696744265 227.844757555544,3541.51159558086 228.255016753645,3550.49438547043 PathPoint;PointKind.SMOOTHPOINT 226.984375,3538 226.975533177536,3535.81449937974 226.990906328553,3539.61439823779 PathPoint;PointKind.SMOOTHPOINT 227.966383081256,3531.6051762148 228.271447017728,3526.01243946576 227.842087898977,3533.88387962923 PathPoint;PointKind.SMOOTHPOINT 230.311928749084,3514.69208478928 233.407047748566,3501.57116889954 229.006256865145,3520.22841369394 PathPoint;PointKind.SMOOTHPOINT 230.117200374603,3483.94577264786 231.422234535217,3466.67206764221 228.811812162399,3501.21924161911 PathPoint;PointKind.SMOOTHPOINT 229.921763896942,3453.19898843765 234.316252231598,3436.7830324173 225.528337717056,3469.61565256119 PathPoint;PointKind.SMOOTHPOINT 229.62967133522,3407.07999229431 229.398829698563,3393.9439702034 229.983368873596,3427.19130277634 PathPoint;PointKind.SMOOTHPOINT 225.532586336136,3368.67082357407 224.551498204999,3362.45353612783 227.953591108322,3384.01754379272 PathPoint;PointKind.SMOOTHPOINT 223.844561488523,3350.54409566782 223.793153922167,3348.76066546652 224.013078207403,3356.39027410375 PathPoint;PointKind.SMOOTHPOINT 224.984375,3346 224.996002337754,3344.68309689349 224.969001098459,3347.7412359671 PathPoint;PointKind.SMOOTHPOINT 223.881057866848,3341.34400474155 224.074078734278,3336.12557552113 223.833307077845,3342.63497455196 PathPoint;PointKind.SMOOTHPOINT 225.264569282532,3326.39446735382 227.141750812531,3313.87355089188 224.554924094427,3331.12534609511 PathPoint;PointKind.SMOOTHPOINT 225.093562364578,3299.49126720428 226.738486051559,3274.99703407288 223.448284626007,3323.98597240448 PathPoint;PointKind.SMOOTHPOINT 224.874404430389,3264.90184307098 221.570304507045,3254.89047187468 229.184274435043,3277.96044588089 PathPoint;PointKind.SMOOTHPOINT 221.013213897036,3230.17788316173 220.966156001609,3227.76989775118 221.256620131748,3242.63315037461 PathPoint;PointKind.SMOOTHPOINT 220.858819388403,3222.94653025709 220.315945542198,3221.6735799776 221.804537375087,3225.16408408454 PathPoint;PointKind.SMOOTHPOINT 220.7281062603,3218.80645036697 220.6820451115,3217.5949492348 220.780442412165,3220.18216360009 PathPoint;PointKind.SMOOTHPOINT 220.657502112447,3215.2614889605 220.632757535116,3201.04152270928 220.659507967483,3216.41419367363 PathPoint;PointKind.SMOOTHPOINT 224.338370323181,3180.34913063049 225.111973047256,3166.62160634995 223.732489074989,3191.09036806691 PathPoint;PointKind.SMOOTHPOINT 220.216147661209,3138.09684991837 219.535306453705,3126.86538934708 221.75627207756,3163.50241184235 PathPoint;PointKind.SMOOTHPOINT 223.923421859741,3115.01292228699 226.029674768448,3100.55675983429 221.817523002625,3129.46908473969 PathPoint;PointKind.SMOOTHPOINT 219.680113554001,3053.54413747787 218.55245923996,3040.98215103149 220.807413816452,3066.10683202744 PathPoint;PointKind.SMOOTHPOINT 219.436172008514,3015.1113653183 220.09895658493,2999.01263952255 218.773741483688,3031.20985507965 PathPoint;PointKind.SMOOTHPOINT 222.997576951981,2968.96758556366 222.722832918167,2955.15107631683 223.271612882614,2982.78433084488 PathPoint;PointKind.SMOOTHPOINT 218.924567461014,2934.40200090408 217.611744165421,2918.23175668716 220.237390756607,2950.572245121 PathPoint;PointKind.SMOOTHPOINT 218.632120847702,2888.28229665756 215.575239419937,2869.55296754837 221.689002275467,2907.01209783554 PathPoint;PointKind.SMOOTHPOINT 218.363749742508,2846.00594043732 214.30596446991,2837.53985881805 222.421889066696,2854.47225809097 PathPoint;PointKind.SMOOTHPOINT 214.364028930664,2822.97063589096 214.383501768112,2814.03956651688 214.311275243759,2846.92930698395 PathPoint;PointKind.SMOOTHPOINT 218.071303129196,2799.88647222519 217.41418337822,2789.46767807007 218.847030162811,2812.18504428864 PathPoint;PointKind.SMOOTHPOINT 206.339803695679,2773.0557346344 199.822067975998,2769.27351951599 216.108795166016,2778.72504472733 PathPoint;PointKind.SMOOTHPOINT 194.535015583038,2734.69566106796 193.849217653275,2715.94957351685 195.427225589752,2759.0617275238 PathPoint;PointKind.SMOOTHPOINT 190.510865211487,2707.81630039215 188.972157001495,2696.87232971191 192.049573421478,2718.76050710678 PathPoint;PointKind.SMOOTHPOINT 194.266998529434,2692.41930484772 195.841111898422,2680.47667264938 192.692885160446,2704.36170101166 PathPoint;PointKind.SMOOTHPOINT 197.803973913193,2642.43194103241 197.956216096878,2636.00543260574 197.652085781097,2648.85868549347 PathPoint;PointKind.SMOOTHPOINT 193.877187728882,2630.92644453049 194.031908273697,2622.06760168076 193.722821235657,2639.78528738022 PathPoint;PointKind.SMOOTHPOINT 197.633321046829,2615.52921295166 196.890874862671,2591.51224136353 198.375767230988,2639.5459485054 PathPoint;PointKind.SMOOTHPOINT 189.389937877655,2531.0246515274 187.341749429703,2519.52529191971 191.437772274017,2542.52448320389 PathPoint;PointKind.CORNERPOINT 189.219639062881,2504.12145137787 189.219639062881,2504.12145137787 189.219639062881,2504.12145137787 PathPoint;PointKind.SMOOTHPOINT 184.984375,2490 183.467595927498,2485.43110364406 187.101082086563,2496.37106800079 PathPoint;PointKind.SMOOTHPOINT 189.048632144928,2477.21872329712 188.070116519928,2474.94430923462 190.027147769928,2479.49313735962 PathPoint;PointKind.CORNERPOINT 180.984375,2463 180.984375,2463 180.984375,2463 PathPoint;PointKind.SMOOTHPOINT 179.731964940096,2255.72182354743 179.718800148045,2253.54300514201 180.456614149915,2375.6537624449 PathPoint;PointKind.SMOOTHPOINT 179.692277602143,2249.15343248882 179.302346410372,2247.62057855426 180.594242249095,2252.69913513352 PathPoint;PointKind.SMOOTHPOINT 179.663510977353,2244.39245705427 178.90449221597,2118.77223905253 179.673131921906,2245.98475649883 PathPoint;PointKind.SMOOTHPOINT 177.154216478976,1829.09557909255 177.137516417964,1826.33166150357 177.94740152894,1960.37043547508 PathPoint;PointKind.SMOOTHPOINT 177.104337647108,1820.84046070591 176.735058738209,1819.6789343113 178.287881202038,1824.56316743273 PathPoint;PointKind.SMOOTHPOINT 177.082290637032,1817.1916046395 176.248708961523,1679.23096766009 177.089624389909,1818.40536598772 PathPoint;PointKind.CORNERPOINT 175.613436460495,1574.09118175507 175.613436460495,1574.09118175507 175.613436460495,1574.09118175507 PathPoint;PointKind.SMOOTHPOINT 183.984375,1562 186.076705932617,1554.15858221054 180.786724920613,1573.97932749552 PathPoint;PointKind.SMOOTHPOINT 179.296635150909,1547.16390609741 179.29061627388,1546.44164085388 179.39329123497,1558.53155851364 PathPoint;PointKind.SMOOTHPOINT 181.511935949326,1541.69003248215 183.461344003677,1532.06053733826 181.389788150787,1542.29357242584 PathPoint;PointKind.SMOOTHPOINT 187.984353065491,1528.00003767014 187.703590154648,1520.86495399475 188.387263774872,1538.26092481613 PathPoint;PointKind.SMOOTHPOINT 179.521811962128,1519.9104309082 178.732630968094,1519.68383789062 181.437585115433,1520.46039104462 PathPoint;PointKind.SMOOTHPOINT 175.199550151825,1508.75473737717 174.565089702606,1503.35403442383 176.006079673767,1515.6268787384 PathPoint;PointKind.SMOOTHPOINT 174.546679019928,1496.15120887756 173.910094261169,1479.19827461243 174.675199747086,1499.57229137421 PathPoint;PointKind.SMOOTHPOINT 178.833535671234,1474.14123773575 176.219926834106,1464.38263177872 181.117168426514,1482.66845226288 PathPoint;PointKind.SMOOTHPOINT 178.662882804871,1447.23780155182 177.878658533096,1444.02560949326 181.562211275101,1459.11670446396 PathPoint;PointKind.SMOOTHPOINT 179.29026222229,1439.88556623459 179.592268228531,1437.31845617294 179.041718006134,1442.00090646744 PathPoint;PointKind.SMOOTHPOINT 186.199579000473,1420.28668642044 181.656743049622,1397.54264831543 188.588719129562,1432.24702119827 PathPoint;PointKind.SMOOTHPOINT 185.71204996109,1343.42043399811 186.771726369858,1329.57819700241 183.782468795776,1368.62536668777 PathPoint;PointKind.SMOOTHPOINT 181.614964962006,1305.01173734665 182.231722831726,1290.20648002625 180.958907365799,1320.75971603394 PathPoint;PointKind.SMOOTHPOINT 189.984375,1275 192.085573222736,1271.74345198292 186.613513946533,1280.22326850891 PathPoint;PointKind.SMOOTHPOINT 200.565930366516,1254.92783546448 201.302357673645,1243.44004154205 199.756922483444,1267.55237102509 PathPoint;PointKind.SMOOTHPOINT 204.200269937515,1220.31386375427 203.607233524323,1212.24644422531 204.793660402298,1228.38128328323 PathPoint;PointKind.SMOOTHPOINT 207.88311457634,1193.38658809662 206.63331246376,1180.73113203049 209.109195232391,1205.79515218735 PathPoint;PointKind.SMOOTHPOINT 203.73681640625,1147.291431427 202.347872018814,1134.29230928421 205.126468896866,1160.29008150101 PathPoint;PointKind.SMOOTHPOINT 207.395939588547,1116.52033567429 207.320880651474,1109.80987787247 207.604121923447,1135.14816999435 PathPoint;PointKind.SMOOTHPOINT 206.276074409485,1092.41319894791 206.145429372787,1090.46662330627 206.868402719498,1101.25764369965 PathPoint;PointKind.SMOOTHPOINT 203.984298467636,1085.99990844727 203.848342657089,1084.11706209183 204.125919103622,1087.95828580856 PathPoint;PointKind.SMOOTHPOINT 205.449717998505,1080.92021226883 204.550781011581,1069.08143520355 205.591338634491,1082.78393983841 PathPoint;PointKind.SMOOTHPOINT 203.127847671509,1051.20867490768 202.18465423584,1037.34212636948 203.584574222565,1057.92314529419 PathPoint;PointKind.SMOOTHPOINT 199.07962179184,1020.48643827438 198.440558671951,1010.65418958664 201.054521560669,1050.89144468307 PathPoint;PointKind.SMOOTHPOINT 204.037406206131,988.609521389008 200.695513248444,966.370360851288 205.660024642944,999.402430057526 PathPoint;PointKind.SMOOTHPOINT 202.372301578522,932.0663022995 204.424384593964,915.34704208374 200.986543655396,943.357951641083 PathPoint;PointKind.SMOOTHPOINT 206.030716657639,901.29567861557 206.248458385468,885.265874862671 205.8133289814,917.325482368469 PathPoint;PointKind.SMOOTHPOINT 201.909202098846,859.043633937836 201.742443799973,841.340818405151 202.07596039772,876.74644947052 PathPoint;PointKind.SMOOTHPOINT 205.49468255043,816.743202209473 206.199245214462,799.605453014374 204.790473937988,833.880715370178 PathPoint;PointKind.SMOOTHPOINT 205.275170564651,782.153306007385 202.349996328354,768.25701713562 207.547473669052,792.949047088623 PathPoint;PointKind.SMOOTHPOINT 197.397522687912,755.298728942871 193.640681266785,734.096939563751 199.172737360001,765.31886100769 PathPoint;PointKind.SMOOTHPOINT 204.909789323807,724.504029750824 205.489017724991,707.549443244934 204.436422348022,738.367037773132 PathPoint;PointKind.SMOOTHPOINT 200.763491153717,678.408637046814 201.424859523773,660.196223258972 200.399880170822,688.428061008453 PathPoint;PointKind.SMOOTHPOINT 200.470690488815,632.289168834686 198.624311447144,600.754265785217 201.909910202026,656.852796077728 PathPoint;PointKind.SMOOTHPOINT 204.032095432281,586.145153045654 202.39283657074,577.357356548309 205.671708345413,594.932713508606 PathPoint;PointKind.SMOOTHPOINT 203.861796617508,559.241952896118 202.511443853378,547.575716972351 205.212149381638,570.907952785492 PathPoint;PointKind.SMOOTHPOINT 203.73964881897,540.025448799133 203.657862901688,530.867786407471 203.822142839432,549.182875156403 PathPoint;PointKind.SMOOTHPOINT 203.569350004196,513.122248649597 202.470019817352,492.698664665222 204.66797208786,533.545832633972 PathPoint;PointKind.SMOOTHPOINT 203.398343086243,486.219284534454 202.850271224976,474.806313514709 203.9467689991,497.632019519806 PathPoint;PointKind.SMOOTHPOINT 199.398268222809,463.183507919312 196.597366094589,451.574628353119 202.199878454208,474.792387485504 PathPoint;PointKind.SMOOTHPOINT 199.252398967743,440.123891830444 201.180917978287,427.611000537872 196.687649250031,456.765732765198 PathPoint;PointKind.SMOOTHPOINT 203.00888633728,424.726424217224 202.667934656143,419.407625198364 203.349129915237,430.044987201691 PathPoint;PointKind.SMOOTHPOINT 197.984375,411 197.336270352888,406.767125438145 199.80186721312,422.870330801627 PathPoint;PointKind.SMOOTHPOINT 202.764590740204,386.293416023254 202.764590740204,386.293416023254 202.761073505491,386.283373194855 PathPoint;PointKind.SMOOTHPOINT 198.76486992836,363.257639408112 194.608304262161,342.855298519135 201.757313966751,377.946059703827 PathPoint;PointKind.SMOOTHPOINT 204.98449420929,330.999999046326 208.867023944855,305.88995218277 202.934181451797,344.260883331299 PathPoint;PointKind.SMOOTHPOINT 198.301770448685,290.235207080841 197.967899799347,281.725223064423 198.897993326187,305.424964427948 PathPoint;PointKind.SMOOTHPOINT 198.185641527176,271.548600196838 198.210071086884,270.079522132874 198.096066474915,276.938681602478 PathPoint;PointKind.SMOOTHPOINT 196.984344482422,266.999981403351 196.992841720581,265.353169441223 196.975847244263,268.646321296692 PathPoint;PointKind.SMOOTHPOINT 198.216444015503,261.493062973022 198.192014455795,259.734134674072 198.24406003952,263.492982387543 PathPoint;PointKind.SMOOTHPOINT 198.082612514496,255.645310878754 197.583045721054,239.571840763092 198.149882316589,257.804789543152 PathPoint;PointKind.SMOOTHPOINT 201.76545715332,228.7180352211 205.49362039566,216.449675559998 198.03800201416,240.986394882202 PathPoint;PointKind.SMOOTHPOINT 201.595158338547,201.814835071564 200.190281629562,191.110203266144 202.999680995941,212.519702911377 PathPoint;PointKind.SMOOTHPOINT 201.448935031891,178.754982948303 200.646300077438,173.769700527191 202.250861883163,183.740501403809 PathPoint;PointKind.SMOOTHPOINT 197.52179479599,167.249486446381 197.83619260788,156.966412067413 197.20810508728,177.532796859741 PathPoint;PointKind.CORNERPOINT 197.448860168457,155.719442367554 197.448860168457,155.719442367554 197.448860168457,155.719442367554 PathPoint;PointKind.SMOOTHPOINT 198.238706422929,138.442442367873 198.839259318227,135.964241466253 196.507625665539,145.585802973292 PathPoint";
	
	mask35mm[2] = "PointKind.SMOOTHPOINT 201.999886035919,133.874931335449 202.541230916977,133.51922750473 199.542059898376,135.49058675766 PathPoint;PointKind.SMOOTHPOINT 205.999960899353,131.875011920929 210.251412391663,129.51230764389 205.463572740555,132.17312335968 PathPoint;PointKind.SMOOTHPOINT 230.99989771843,130.874934196472 242.91267156601,130.388467311859 218.811671733856,131.372730731964 PathPoint;PointKind.CORNERPOINT 266.683695316315,132.099008560181 266.683695316315,132.099008560181 266.683695316315,132.099008560181 PathPoint;PointKind.SMOOTHPOINT 282.098039388657,132.002470493317 289.555073976517,133.303964138031 274.641004800797,130.700976848602 PathPoint;PointKind.SMOOTHPOINT 297.512737512589,131.905696392059 303.254392147064,131.93284034729 291.770728826523,131.878788471222 PathPoint;PointKind.SMOOTHPOINT 459.364943504333,130.889568328857 465.048533678055,130.820882320404 453.681353330612,130.958490371704 PathPoint;PointKind.SMOOTHPOINT 490.193985700607,130.696492195129 496.774742603302,129.845824241638 481.720114946365,131.79169178009 PathPoint;PointKind.SMOOTHPOINT 505.608683824539,130.599482059479 510.36713719368,130.866672992706 500.849876403809,130.332055091858 PathPoint;PointKind.SMOOTHPOINT 528.730022907257,130.454320907593 532.746738195419,130.495154857635 524.713661670685,130.413250923157 PathPoint;PointKind.SMOOTHPOINT 544.145075082779,130.357310771942 549.203056097031,128.284456729889 537.835875749588,132.943539619446 PathPoint;PointKind.SMOOTHPOINT 555.705921649933,130.285084247589 559.070827960968,130.194919109344 552.340307235718,130.374777317047 PathPoint;PointKind.SMOOTHPOINT 613.509800434113,129.922299385071 620.435403585434,129.569427967072 606.584197282791,130.27517080307 PathPoint;PointKind.SMOOTHPOINT 698.289932012558,129.390041828156 702.071911096573,128.999876976013 694.507952928543,129.780206680298 PathPoint;PointKind.SMOOTHPOINT 718.999825716019,129.875092506409 726.835695505142,130.660614967346 710.988346338272,129.071867465973 PathPoint;PointKind.SMOOTHPOINT 740.679466724396,129.124031066895 751.488307714462,129.06525850296 729.871687889099,129.182803630829 PathPoint;PointKind.SMOOTHPOINT 883.288260698318,132.072336673737 874.554516077042,132.090983390808 892.022713422775,132.053453922272 PathPoint;PointKind.SMOOTHPOINT 894.849107265472,131.999638080597 906.860661506653,131.725838184357 882.838261127472,132.273437976837 PathPoint;PointKind.SMOOTHPOINT 921.824651956558,131.830401420593 929.403834342957,131.971786022186 913.949128389359,131.683115959167 PathPoint;PointKind.SMOOTHPOINT 964.214540719986,131.564154624939 978.224716186523,131.782722473145 950.204011201859,131.345822811127 PathPoint;PointKind.SMOOTHPOINT 1064.40901637077,130.935122966766 1081.74373626709,130.802471637726 1047.07358837128,131.068246364594 PathPoint;PointKind.SMOOTHPOINT 1264.82204318047,133.52064371109 1254.80415344238,133.80294084549 1274.83993291855,133.238582611084 PathPoint;PointKind.SMOOTHPOINT 1326.00003361702,132.874853610992 1333.5268163681,132.809944152832 1318.47360491753,132.939999103546 PathPoint;PointKind.SMOOTHPOINT 1349.62589621544,136.831970214844 1352.65445351601,135.794599056244 1346.87031269073,137.775871753693 PathPoint;PointKind.SMOOTHPOINT 1361.99999928474,134.875009059906 1364.87348198891,134.396095275879 1357.44016885757,135.635039806366 PathPoint;PointKind.SMOOTHPOINT 1376.57736539841,132.819149494171 1391.45496726036,133.998613357544 1373.31477999687,132.560691833496 PathPoint;PointKind.SMOOTHPOINT 1426.67424917221,132.504751682281 1445.40287017822,135.83779335022 1419.46929931641,131.222612857819 PathPoint;PointKind.SMOOTHPOINT 1727.28210568428,134.461240768433 1743.21159482002,134.455103874207 1686.39587402344,134.477763175964 PathPoint;PointKind.SMOOTHPOINT 1841.11358642578,135.036928653717 1842.90331721306,135.048258304596 1789.33531165123,134.709312915802 PathPoint;PointKind.SMOOTHPOINT 1846.50189757347,135.071153640747 1848.40917348862,133.645033836365 1845.05878329277,136.150538921356 PathPoint;PointKind.SMOOTHPOINT 1850.49843192101,135.096645355225 1852.55016088486,135.10986328125 1849.16330337524,135.088148117065 PathPoint;PointKind.SMOOTHPOINT 1856.67167544365,135.136535167694 1933.94343495369,135.635747909546 1854.60861682892,135.123081207275 PathPoint;PointKind.SMOOTHPOINT 2031.74239754677,136.393654346466 2048.73368740082,136.569972038269 2018.14681649208,136.252505779266 PathPoint;PointKind.SMOOTHPOINT 2085.69348692894,136.055181026459 2104.62958216667,136.7347240448 2066.75739169121,135.375165939331 PathPoint;PointKind.SMOOTHPOINT 2540.47027587891,140.887041091919 2583.02196621895,141.442666053772 2497.91893959045,140.331652164459 PathPoint;PointKind.SMOOTHPOINT 2898.85793566704,138.637633323669 2957.5303030014,138.46155166626 2840.18486022949,138.813714981079 PathPoint;PointKind.SMOOTHPOINT 3318.92775535583,139.844241142273 3357.41847395897,139.110174179077 3280.43632864952,140.578072071075 PathPoint;PointKind.SMOOTHPOINT 3422.97537446022,139.191370010376 3437.0758330822,137.895541191101 3408.87526988983,140.486490726471 PathPoint;PointKind.SMOOTHPOINT 3453.8288462162,142.840933799744 3465.91687560081,142.314577102661 3441.74081683159,143.367290496826 PathPoint;PointKind.SMOOTHPOINT 3479.00014400482,138.874847888947 3480.07787704468,138.5942029953 3465.65169095993,142.350690364838 PathPoint;PointKind.SMOOTHPOINT 3484.99990224838,138.87508392334 3491.53994321823,139.214265346527 3483.68141412735,138.80663394928 PathPoint;PointKind.SMOOTHPOINT 3511.63307905197,142.478148937225 3514.24208521843,142.524411678314 3501.15633845329,142.292625904083 PathPoint;PointKind.SMOOTHPOINT 3518.73677015305,142.758557796478 3520.03366112709,142.834088802338 3516.55368804932,142.631335258484 PathPoint;PointKind.SMOOTHPOINT 3522.00006365776,143.875000476837 3523.94557714462,142.559344768524 3520.96977353096,144.571537971497 PathPoint;PointKind.SMOOTHPOINT 3525.06119370461,143.160288333893 3532.12310671806,143.590342998505 3524.21324014664,143.108832836151 PathPoint;PointKind.SMOOTHPOINT 3554.02332186699,142.211902141571 3576.94957852364,139.695775508881 3539.62616801262,143.791916370392 PathPoint;PointKind.SMOOTHPOINT 3669.63178753853,141.486568450928 3686.95234537125,141.84604883194 3652.31193780899,141.126616001129 PathPoint;PointKind.SMOOTHPOINT 4209.13984894753,138.099710941315 4216.06403589249,138.413400650024 4189.11256670952,137.192630767822 PathPoint;PointKind.SMOOTHPOINT 4222.99990653992,139.874925613403 4230.60104012489,140.300495624542 4219.28625941277,139.66721534729 PathPoint;PointKind.SMOOTHPOINT 4249.99988079071,141.874845027924 4258.11332702637,141.566112041473 4235.41437149048,142.430233955383 PathPoint;PointKind.SMOOTHPOINT 4296.00003361702,139.874925613403 4305.17138600349,139.467530250549 4275.63888072968,140.779645442963 PathPoint;PointKind.SMOOTHPOINT 4324.69449877739,139.130473136902 4328.79972696304,138.3225274086 4315.13014912605,141.012847423553 PathPoint;PointKind.SMOOTHPOINT 4337.10294485092,138.696405887604 4360.69588065147,137.879490852356 4333.00125718117,138.838498592377 PathPoint;PointKind.SMOOTHPOINT 4394.11410212517,136.93865776062 4422.63401985168,136.357305049896 4382.64389276505,137.172567844391 PathPoint;PointKind.SMOOTHPOINT 4648.47786426544,139.185469150543 4663.50877046585,139.271385669708 4648.47786426544,139.185469150543 PathPoint;PointKind.SMOOTHPOINT 4714.01422977448,142.617409229279 4749.42434549332,142.239046096802 4678.60411405563,142.996008396149 PathPoint;PointKind.SMOOTHPOINT 4825.74476838112,138.073039054871 4833.22517037392,136.440389156342 4818.26436638832,139.70498085022 PathPoint;PointKind.SMOOTHPOINT 4891.28113389015,141.504743099213 4922.18948364258,140.559897422791 4860.37278413773,142.449352741241 PathPoint;PointKind.SMOOTHPOINT 4987.62175798416,140.900022983551 5030.39366841316,141.117882728577 4944.84949350357,140.681927204132 PathPoint;PointKind.SMOOTHPOINT 5149.47396397591,139.883894920349 5164.95876431465,139.521582126617 5110.89968919754,140.786962509155 PathPoint;PointKind.SMOOTHPOINT 5279.41514611244,138.639285564423 5281.76002979279,138.623235225677 5218.33310365677,139.053997993469 PathPoint;PointKind.SMOOTHPOINT 5286.48272395134,138.591606616974 5288.89310717583,139.109702110291 5284.1693508625,138.094518184662 PathPoint;PointKind.SMOOTHPOINT 5293.3081305027,138.546524047852 5381.19364857674,137.97178030014 5291.0252058506,138.561630249023 PathPoint;PointKind.SMOOTHPOINT 5504.00777220726,137.658798694611 5534.07985210419,137.824730873108 5479.98395562172,137.526383399963 PathPoint;PointKind.SMOOTHPOINT 5600.00000953674,136.874928474426 5605.00771522522,136.825361251831 5569.0042090416,137.181537151337 PathPoint;PointKind.SMOOTHPOINT 5622.00006723404,136.874928474426 5623.40458989143,136.522057056427 5617.85270690918,137.917256355286 PathPoint;PointKind.SMOOTHPOINT 5638.88443350792,136.811907291412 5642.4734544754,136.799869537354 5635.20902395248,136.824653148651 PathPoint;PointKind.SMOOTHPOINT 5671.00009918213,150.875072479248 5675.14993786812,153.44265460968 5666.68704271317,148.206467628479 PathPoint;PointKind.SMOOTHPOINT 5693.1035399437,178.74979019165 5695.29122471809,183.615639209747 5690.60216546059,173.187167644501 PathPoint;PointKind.SMOOTHPOINT 5699.9519598484,192.005009651184 5702.06352353096,196.510906219482 5697.98414111137,187.806901931763 PathPoint;PointKind.SMOOTHPOINT 5705.30805230141,204.851181507111 5705.89577794075,206.471085548401 5703.83059501648,200.777463912964 PathPoint;PointKind.SMOOTHPOINT 5705.9998691082,210.875015258789 5707.17425823212,213.158884048462 5705.24998784065,209.415850639343 PathPoint;PointKind.SMOOTHPOINT 5708.72252583504,215.739448070526 5712.57177472115,230.345964431763 5708.19675922394,213.744721412659 PathPoint;PointKind.SMOOTHPOINT 5712.85891056061,255.494720935822 5712.88581848145,277.720663547516 5712.84368634224,242.688202857971 PathPoint;PointKind.SMOOTHPOINT 5709.99994397163,308.875079154968 5710.70804715157,325.661845207214 5709.29113268852,292.089021205902 PathPoint;PointKind.SMOOTHPOINT 5713.395652771,340.047197341919 5713.45442533493,352.207925319672 5713.33652615547,327.88670539856 PathPoint;PointKind.SMOOTHPOINT 5713.54187607765,363.107049465179 5711.43456101418,374.584693908691 5715.64883708954,351.629641056061 PathPoint;PointKind.SMOOTHPOINT 5713.80989313126,405.383405685425 5710.495262146,419.150583744049 5717.12452411652,391.616463661194 PathPoint;PointKind.SMOOTHPOINT 5710.19998311996,443.840725421906 5709.75671052933,453.686428070068 5710.6432557106,433.995022773743 PathPoint;PointKind.SMOOTHPOINT 5714.37035679817,493.779230117798 5714.15119886398,507.617218494415 5714.72440838814,471.4510846138 PathPoint;PointKind.SMOOTHPOINT 5710.90667009354,555.296165943146 5710.12917280197,564.051625728607 5711.74400210381,545.868716239929 PathPoint;PointKind.SMOOTHPOINT 5714.06764268875,581.292049884796 5714.35336232185,582.094330787659 5710.35010099411,570.851776599884 PathPoint;PointKind.SMOOTHPOINT 5716.00005626678,590.875046253204 5718.91106843948,594.309346675873 5715.42932510376,590.202348232269 PathPoint;PointKind.SMOOTHPOINT 5711.32126450539,620.632374286652 5711.73408865929,625.76281785965 5710.58908581734,611.538913249969 PathPoint;PointKind.SMOOTHPOINT 5715.06288170815,644.65029001236 5715.67220449448,648.660750389099 5713.69588851929,635.651950836182 PathPoint;PointKind.SMOOTHPOINT 5714.99986052513,651.875066757202 5716.65257334709,654.919674396515 5713.26111316681,648.672080039978 PathPoint;PointKind.SMOOTHPOINT 5715.44277906418,662.884654998779 5713.82370114326,674.37716960907 5715.74159860611,660.765538215637 PathPoint;PointKind.SMOOTHPOINT 5711.85729861259,705.185322761536 5712.16319918633,716.057775020599 5711.55104398727,694.292335510254 PathPoint;PointKind.SMOOTHPOINT 5715.34753918648,756.821622848511 5714.77645397186,770.944976806641 5715.90871095657,742.935247421265 PathPoint;PointKind.SMOOTHPOINT 5712.39368677139,789.737799167633 5713.08054685593,796.582088470459 5711.33294820786,779.16912317276 PathPoint;PointKind.SMOOTHPOINT 5712.56433963776,816.640763282776 5713.11630606651,821.998507976532 5711.5499818325,806.795296669006 PathPoint;PointKind.SMOOTHPOINT 5716.00005626678,831.874895095825 5717.81421661377,838.381655216217 5714.53959345818,826.634459495544 PathPoint;PointKind.SMOOTHPOINT 5709.00293469429,862.784779071808 5708.77952814102,867.984144687653 5709.41717505455,853.125307559967 PathPoint;PointKind.SMOOTHPOINT 5712.97857999802,881.977207660675 5713.76492857933,888.613786697388 5712.06194043159,874.240000247955 PathPoint;PointKind.SMOOTHPOINT 5713.10072779655,901.193475723267 5714.77574586868,908.527064323425 5712.09557533264,896.793794631958 PathPoint;PointKind.SMOOTHPOINT 5713.24695110321,924.253327846527 5712.60399341583,926.930429935455 5714.97649312019,917.049558162689 PathPoint;PointKind.SMOOTHPOINT 5705.00002741814,936.874794960022 5705.37850856781,939.826877117157 5704.48417425156,932.847576141357 PathPoint;PointKind.SMOOTHPOINT 5705.9998691082,943.875102996826 5712.60363936424,947.460465431213 5705.1742208004,943.426637649536 PathPoint;PointKind.SMOOTHPOINT 5717.29517698288,954.975564479828 5719.33061957359,967.092862129211 5716.65292739868,951.151807308197 PathPoint;PointKind.SMOOTHPOINT 5713.61233234406,981.903076171875 5713.63676190376,988.089065551758 5713.57126235962,971.657767295837 PathPoint;PointKind.SMOOTHPOINT 5713.78298521042,1008.80604028702 5714.44966435432,1014.12837982178 5712.76650309563,1000.69448232651 PathPoint;PointKind.SMOOTHPOINT 5717.70941734314,1020.31153678894 5719.10367250443,1029.01365280151 5716.79065346718,1014.57377672195 PathPoint;PointKind.SMOOTHPOINT 5717.8556406498,1043.37162494659 5717.50937819481,1049.10324811935 5718.37822079659,1034.74267959595 PathPoint;PointKind.SMOOTHPOINT 5717.97743439674,1062.58789300919 5720.12334108353,1073.36616754532 5717.12098360062,1058.28593015671 PathPoint;PointKind.SMOOTHPOINT 5718.1236577034,1085.64774513245 5715.91614603996,1093.59478712082 5720.33152341843,1077.70070314407 PathPoint;PointKind.SMOOTHPOINT 5722.26995587349,1131.74360990524 5720.82400918007,1152.0442199707 5723.41425061226,1115.67131996155 PathPoint;PointKind.SMOOTHPOINT 5718.80626916885,1193.26054573059 5718.7836098671,1213.42638015747 5718.82892847061,1173.09400320053 PathPoint;PointKind.SMOOTHPOINT 5715.12342453003,1220.18734931946 5715.42401432991,1220.91952800751 5710.58448314667,1209.13173437119 PathPoint;PointKind.SMOOTHPOINT 5718.99993538857,1224.87499237061 5720.24902939796,1225.12495279312 5717.75084137917,1224.62503194809 PathPoint;PointKind.SMOOTHPOINT 5730.6354868412,1235.4639673233 5732.92584657669,1237.0623922348 5727.2411942482,1233.09583425522 PathPoint;PointKind.SMOOTHPOINT 5732.99984335899,1255.87504148483 5732.63729453087,1257.1392416954 5734.66742634773,1250.06411075592 PathPoint;PointKind.SMOOTHPOINT 5738.58606934547,1273.84858846664 5736.86856508255,1280.12450695038 5739.0828037262,1272.03395605087 PathPoint;PointKind.SMOOTHPOINT 5730.97643852234,1289.27013158798 5730.34693479538,1294.64605093002 5731.78827881813,1282.3432302475 PathPoint;PointKind.SMOOTHPOINT 5734.90357875824,1300.7758641243 5739.87800359726,1306.98616504669 5729.06137347221,1293.48287343979 PathPoint;PointKind.SMOOTHPOINT 5739.02509331703,1343.02790880203 5739.39189076424,1352.12821483612 5738.55031013489,1331.26324653625 PathPoint;PointKind.SMOOTHPOINT 5737.10223913193,1366.47462129593 5734.1675055027,1370.94298839569 5740.03626465797,1362.00625419617 PathPoint;PointKind.SMOOTHPOINT 5731.61019086838,1389.19623613358 5729.84311938286,1400.12510061264 5732.63375401497,1382.86815404892 PathPoint;PointKind.SMOOTHPOINT 5731.87820792198,1431.47235631943 5730.15716314316,1447.71577119827 5733.5996067524,1415.22917747498 PathPoint;PointKind.SMOOTHPOINT 5743.78071427345,1485.20582199097 5749.80950474739,1507.30406999588 5737.75156974792,1463.10781002045 PathPoint;PointKind.SMOOTHPOINT 5743.97544264793,1515.95260620117 5742.97418475151,1528.91231060028 5744.97705459595,1502.99242973328 PathPoint;PointKind.SMOOTHPOINT 5751.85309052467,1542.80694723129 5752.1133184433,1547.83141136169 5751.12622261047,1528.77092599869 PathPoint;PointKind.SMOOTHPOINT 5753.1011223793,1591.91177845001 5753.12626004219,1593.0376625061 5752.54844784737,1567.13454008102 PathPoint;PointKind.SMOOTHPOINT 5753.17688941956,1595.32294750214 5753.89950871468,1598.01468372345 5752.87948608398,1594.21405792236 PathPoint;PointKind.SMOOTHPOINT 5753.3199262619,1601.72254800797 5754.28861141205,1645.07994174957 5753.27142119408,1599.55764055252 PathPoint;PointKind.SMOOTHPOINT 5756.87708258629,1727.26145267487 5758.29824566841,1756.21343135834 5755.56248903275,1700.47508955002 PathPoint;PointKind.SMOOTHPOINT 5757.63262867928,1846.40358924866 5758.69761586189,1878.55572223663 5756.56728744507,1814.25122022629 PathPoint;PointKind.SMOOTHPOINT 5758.02243947983,1907.89644956589 5759.56327199936,1923.9753484726 5756.4816069603,1891.81755065918 PathPoint;PointKind.SMOOTHPOINT 5762.26610183716,1969.365234375 5760.92530846596,1993.43743801117 5763.60724925995,1945.29303073883 PathPoint;PointKind.SMOOTHPOINT 5762.70477175713,2038.54455471039 5762.1800673008,2053.00661802292 5763.79666686058,2008.46244335175 PathPoint;PointKind.SMOOTHPOINT 5763.4748339653,2238.56458425522 5763.48828792572,2240.25104999542 5762.74584174156,2145.94704866409 PathPoint;PointKind.SMOOTHPOINT 5761.9998550415,2243.87488603592 5762.01330900192,2245.53987264633 5761.98675513268,2242.1891283989 PathPoint;PointKind.SMOOTHPOINT 5763.00005078316,2253.87495517731 5763.77223730087,2350.4208111763 5762.98695087433,2252.21162080765 PathPoint;PointKind.CORNERPOINT 5765.24013519287,2438.24802875519 5765.24013519287,2438.24802875519 5765.24013519287,2438.24802875519 PathPoint;PointKind.SMOOTHPOINT 5765.36192893982,2457.46429681778 5765.07656335831,2459.29167509079 5765.68553209305,2455.38743019104 PathPoint;PointKind.SMOOTHPOINT 5757.70273089409,2465.19914388657 5757.12244033813,2476.14476680756 5757.94702649117,2460.60426235199 PathPoint;PointKind.SMOOTHPOINT 5757.94667243958,2503.63238811493 5756.59490346909,2508.74654531479 5760.39918780327,2494.35670852661 PathPoint;PointKind.SMOOTHPOINT 5754.23975229263,2526.7165517807 5751.3970720768,2533.53086471558 5757.73247122765,2518.34134340286 PathPoint;PointKind.SMOOTHPOINT 5742.80034542084,2546.00551843643 5741.19011878967,2557.20275402069 5743.83240580559,2538.82676839828 PathPoint;PointKind.SMOOTHPOINT 5743.00003051758,2569.87496852875 5742.7136027813,2575.05356311798 5743.54066729546,2560.08992671967 PathPoint;PointKind.SMOOTHPOINT 5746.92185997963,2588.25779914856 5746.94841384888,2591.04536533356 5746.84609293938,2580.12476205826 PathPoint;PointKind.SMOOTHPOINT 5743.14200520515,2599.81168270111 5741.18693232536,2604.91970300674 5745.09601593018,2594.70389842987 PathPoint;PointKind.SMOOTHPOINT 5747.26351976395,2642.06396341324 5747.71281123161,2645.79802751541 5746.44707679749,2635.28458356857 PathPoint;PointKind.SMOOTHPOINT 5743.99987220764,2666.87495470047 5745.93051552773,2673.45370531082 5741.16533517838,2657.21878767014 PathPoint;PointKind.SMOOTHPOINT 5747.55561232567,2688.18343162537 5747.41859436035,2700.71142911911 5747.69333839417,2675.65519809723 PathPoint;PointKind.SMOOTHPOINT 5739.97041106224,2707.44855880737 5739.79267716408,2718.34933519363 5740.14849901199,2696.54731035233 PathPoint;PointKind.SMOOTHPOINT 5736.31164193153,2738.21871042252 5732.19897866249,2750.55599212646 5740.42465925217,2725.88190078735 PathPoint;PointKind.SMOOTHPOINT 5728.72644066811,2757.48383760452 5731.31845235825,2775.98822593689 5726.13407492638,2738.97921323776 PathPoint;PointKind.SMOOTHPOINT 5728.94595265388,2792.07349777222 5729.13537025452,2804.81581449509 5728.75653505325,2779.33141708374 PathPoint;PointKind.SMOOTHPOINT 5729.06774640083,2811.2900018692 5727.74819612503,2819.72374677658 5730.38694262505,2802.85602092743 PathPoint;PointKind.SMOOTHPOINT 5729.2136156559,2834.34961795807 5726.67683601379,2843.58375549316 5731.750395298,2825.11571645737 PathPoint;PointKind.CORNERPOINT 5729.28690433502,2845.8796620369 5729.28690433502,2845.8796620369 5729.28690433502,2845.8796620369 PathPoint;PointKind.SMOOTHPOINT 5732.99984335899,2866.87492132187 5729.68060970306,2881.45075321198 5735.90873122215,2854.10333633423 PathPoint;PointKind.SMOOTHPOINT 5729.55492138863,2888.15578222275 5731.31137132645,2898.30620527267 5727.7988255024,2878.00583124161 PathPoint;PointKind.SMOOTHPOINT 5734.00003910065,2923.87486696243 5732.53107905388,2938.17666292191 5735.46829104424,2909.57283496857 PathPoint;PointKind.CORNERPOINT 5729.94508624077,2949.64864253998 5729.94508624077,2949.64864253998 5729.94508624077,2949.64864253998 PathPoint;PointKind.SMOOTHPOINT 5726.21373653412,2968.88969421387 5727.10169792175,2978.37756872177 5725.42349338531,2960.4554772377 PathPoint;PointKind.SMOOTHPOINT 5734.11545991898,2999.58738327026 5735.34578919411,3017.93221235275 5732.88513064384,2981.24279022217 PathPoint;PointKind.SMOOTHPOINT 5734.40826058388,3045.70708751678 5732.93328166008,3055.28300285339 5735.8825314045,3036.13117218018 PathPoint;PointKind.SMOOTHPOINT 5730.65177321434,3061.1047911644 5729.88631367683,3067.70950555801 5731.41687870026,3054.49984073639 PathPoint;PointKind.SMOOTHPOINT 5738.53012919426,3087.95936822891 5736.12647294998,3104.00876283646 5740.93307733536,3071.90973758698 PathPoint;PointKind.SMOOTHPOINT 5734.84693050385,3114.88664388657 5733.47639679909,3133.36176395416 5736.21711015701,3096.41128778458 PathPoint;PointKind.SMOOTHPOINT 5735.23638725281,3176.3795042038 5733.2678604126,3200.59026002884 5736.32615804672,3162.98337221146 PathPoint;PointKind.SMOOTHPOINT 5739.28567528725,3207.1015048027 5740.51069378853,3222.79802799225 5738.65829586983,3199.07350301743 PathPoint;PointKind.SMOOTHPOINT 5735.57840108871,3230.18566846848 5733.33973288536,3249.51900959015 5737.8160071373,3210.8523273468 PathPoint;PointKind.SMOOTHPOINT 5735.89456915855,3280.14848470688 5733.86833190918,3322.31296062469 5736.87458395958,3259.75841760635 PathPoint;PointKind.SMOOTHPOINT 5728.40708613396,3314.78676795959 5729.72557425499,3319.96536254883 5725.31904816628,3302.66309738159 PathPoint;PointKind.SMOOTHPOINT 5732.33351826668,3326.29250049591 5734.04925227165,3336.15755796432 5730.61813831329,3316.4274430275 PathPoint;PointKind.SMOOTHPOINT 5732.50417113304,3353.19546461105 5733.54579091072,3371.20512485504 5731.88635110855,3342.51042366028 PathPoint;PointKind.SMOOTHPOINT 5736.5775346756,3387.76104927063 5736.09602451324,3400.35301208496 5736.87883257866,3379.85318899155 PathPoint;PointKind.SMOOTHPOINT 5732.84547686577,3407.00162887573 5731.66967153549,3423.86014938354 5734.02092814445,3390.14310836792 PathPoint;PointKind.SMOOTHPOINT 5736.86962723732,3433.88051748276 5737.12135791779,3435.84054708481 5734.70991253853,3417.0729804039 PathPoint;PointKind.SMOOTHPOINT 5737.01585054398,3456.94036960602 5738.66856336594,3479.85199213028 5736.79775476456,3453.91558885574 PathPoint;PointKind.SMOOTHPOINT 5737.47895002365,3529.96303796768 5736.43874645233,3535.51551103592 5739.81993913651,3517.47091770172 PathPoint;PointKind.SMOOTHPOINT 5734.99138355255,3544.37411785126 5734.04500365257,3550.79637765884 5735.6035387516,3540.22203683853 PathPoint;PointKind.SMOOTHPOINT 5732.00000166893,3559.87496852875 5730.80047488213,3562.77819156647 5733.85027527809,3555.39621591568 PathPoint;PointKind.SMOOTHPOINT 5741.67410731316,3583.74512672424 5742.04125881195,3614.59010124207 5741.55833244324,3573.99596214294 PathPoint;PointKind.SMOOTHPOINT 5738.06384325027,3622.20244646072 5740.49086689949,3637.89684534073 5735.22293329239,3603.82882118225 PathPoint;PointKind.SMOOTHPOINT 5738.30778479576,3660.63545465469 5741.18020534515,3687.2573018074 5738.30778479576,3660.63545465469 PathPoint;PointKind.SMOOTHPOINT 5715.67362070084,3737.64663219452 5710.96615076065,3747.92356967926 5727.52231121063,3711.77891492844 PathPoint;PointKind.SMOOTHPOINT 5696.4978325367,3773.44455242157 5694.95204329491,3776.01591110229 5704.08445000648,3760.82827806473 PathPoint;PointKind.SMOOTHPOINT 5691.00011944771,3780.87491512299 5688.84217500687,3781.99419021606 5693.85625362396,3779.39332723618 PathPoint;PointKind.SMOOTHPOINT 5687.87561416626,3787.16287136078 5678.80198001862,3800.9406709671 5689.18525099754,3785.17404556274 PathPoint;PointKind.SMOOTHPOINT 5662.23448991776,3818.69423389435 5653.12297224998,3825.92089891434 5669.51449871063,3812.92059659958 PathPoint;PointKind.SMOOTHPOINT 5605.49630641937,3829.94646549225 5602.12113261223,3830.11286973953 5629.27334904671,3828.77526283264 PathPoint;PointKind.SMOOTHPOINT 5595.41645765305,3830.35126447678 5593.44262003899,3831.06031179428 5599.27845239639,3828.96456241608 PathPoint;PointKind.SMOOTHPOINT 5589.1869199276,3830.52262544632 5577.22953557968,3830.802090168 5591.23900294304,3830.47471046448 PathPoint;PointKind.SMOOTHPOINT 5558.25945138931,3830.87738513947 5553.87098193169,3830.92364788055 5566.22242569923,3830.79359292984 PathPoint;PointKind.SMOOTHPOINT 5535.82107782364,3827.13104724884 5534.89240050316,3827.12207794189 5547.53027200699,3827.24623203278 PathPoint;PointKind.SMOOTHPOINT 5530.00011563301,3827.87502765656 5525.19669771194,3826.57967090607 5531.92403197289,3828.39335918427 PathPoint;PointKind.SMOOTHPOINT 5516.55288219452,3827.25189685822 5508.65823984146,3827.16338396072 5519.39237594604,3827.28376150131 PathPoint;PointKind.SMOOTHPOINT 5488.86994242668,3827.46975660324 5421.33141517639,3826.62593364716 5498.33197116852,3827.5877737999 PathPoint;PointKind.SMOOTHPOINT 5292.33484268188,3828.70350837708 5240.5434679985,3829.62899923325 5328.14432859421,3828.06314706802 PathPoint;PointKind.SMOOTHPOINT 5045.67842960358,3826.40783786774 5025.9251832962,3826.92829370499 5065.43167591095,3825.88785409927 PathPoint;PointKind.SMOOTHPOINT 4999.43433523178,3826.6983962059 4988.43111991882,3827.3019361496 5010.43861269951,3826.09485626221 PathPoint;PointKind.SMOOTHPOINT 4733.51008057594,3824.52404737473 4704.85951781273,3825.41885375977 4762.16099739075,3823.62994909286 PathPoint;PointKind.SMOOTHPOINT 4610.19391179085,3825.29800415039 4588.00939321518,3826.05567455292 4632.37878441811,3824.54033374786 PathPoint;PointKind.SMOOTHPOINT 4305.75734138489,3827.20917463303 4250.42509675026,3827.19029188156 4361.08923196793,3827.22829341888 PathPoint;PointKind.SMOOTHPOINT 4078.36876988411,3824.7931265831 4064.54978227615,3824.81956243515 4092.18846559525,3824.76645469666 PathPoint;PointKind.SMOOTHPOINT 4050.99987387657,3819.87487792969 4028.07149291039,3819.20194387436 4073.92825484276,3820.54757595062 PathPoint;PointKind.SMOOTHPOINT 4012.85718798637,3825.20429849625 3972.29172706604,3826.2997341156 4053.42335700989,3824.1086268425 PathPoint;PointKind.SMOOTHPOINT 3839.44413542747,3826.2926530838 3815.02661347389,3825.63576936722 3854.47008490562,3826.69697999954 PathPoint;PointKind.SMOOTHPOINT 3804.73681211472,3822.66716480255 3783.17542433739,3819.06693220139 3818.25520992279,3824.92412567139 PathPoint;PointKind.SMOOTHPOINT 3777.76197552681,3822.83663749695 3757.95526742935,3823.54946136475 3797.56797552109,3822.12357759476 PathPoint;PointKind.SMOOTHPOINT 3396.25262260437,3825.23120641708 3375.06759166718,3826.93159818649 3417.43729948997,3823.53105068207 PathPoint;PointKind.SMOOTHPOINT 3222.83921599388,3826.31979703903 3179.69165682793,3827.7076792717 3265.98642110825,3824.93215084076 PathPoint;PointKind.SMOOTHPOINT 2914.52436447144,3824.41169500351 2844.36302304268,3825.56684732437 2984.68570590019,3823.25701475143 PathPoint;PointKind.SMOOTHPOINT 2625.47770857811,3822.38250732422 2607.49401211739,3823.64883184433 2643.46211314201,3821.11665487289 PathPoint;PointKind.SMOOTHPOINT 2601.9998395443,3818.87503623962 2594.63910698891,3820.45009374619 2609.82862830162,3817.1999001503 PathPoint;PointKind.SMOOTHPOINT 2571.52732729912,3822.72121667862 2554.55763459206,3822.99289226532 2590.28108596802,3822.42098093033 PathPoint;PointKind.SMOOTHPOINT 2529.13743853569,3822.98722743988 2511.0326564312,3824.07534599304 2548.21232199669,3821.84057235718 PathPoint;PointKind.SMOOTHPOINT 2494.45489883423,3823.20508718491 2457.97271490097,3822.6655125618 2530.93637466431,3823.74466180801 PathPoint;PointKind.SMOOTHPOINT 1993.45879912376,3822.50642538071 1912.9839348793,3824.90925550461 2073.93330931664,3820.1038312912 PathPoint;PointKind.SMOOTHPOINT 1604.21802163124,3821.1060333252 1567.69158124924,3822.10422277451 1640.74410796165,3820.10831594467 PathPoint;PointKind.SMOOTHPOINT 1496.31619691849,3821.783452034 1477.35956668854,3823.54804515839 1515.27318120003,3820.01885890961 PathPoint;PointKind.SMOOTHPOINT 1469.34100627899,3821.952688694 1458.31973433495,3822.62255430222 1480.36192417145,3821.28329515457 PathPoint;PointKind.SMOOTHPOINT 1438.51196408272,3822.14600086212 1425.60855388641,3823.23624372482 1451.41502022743,3821.0564661026 PathPoint;PointKind.SMOOTHPOINT 1384.56087470055,3822.48518228531 1376.35148048401,3821.82286977768 1394.438560009,3823.28156232834 PathPoint;PointKind.SMOOTHPOINT 1319.04929280281,3822.89611816406 1268.21704387665,3824.08006668091 1369.88189578056,3821.71240568161 PathPoint;PointKind.SMOOTHPOINT 1180.29470443726,3819.9239730835 1160.57650923729,3821.24859809875 1200.01254558563,3818.59887599945 PathPoint;PointKind.SMOOTHPOINT 952.930562496185,3821.35080099106 930.451472997665,3822.18848705292 975.409651994705,3820.5131149292 PathPoint;PointKind.SMOOTHPOINT 906.68682217598,3821.64135932922 892.084672451019,3821.60666227341 921.28968000412,3821.67558431625 PathPoint;PointKind.SMOOTHPOINT 867.999958992004,3816.87488079071 855.454140901566,3818.36472988129 880.545068979263,3815.38503170013 PathPoint;PointKind.SMOOTHPOINT 717.858717441559,3822.82672405243 694.02290225029,3822.3515868187 738.04815530777,3823.22892665863 PathPoint;PointKind.SMOOTHPOINT 648.493638038635,3823.26197147369 625.903022289276,3821.68006896973 671.084253787994,3824.84340190887 PathPoint;PointKind.SMOOTHPOINT 609.957600831985,3823.50390672684 582.483197450638,3821.952688694 637.431650161743,3825.05488872528 PathPoint;PointKind.SMOOTHPOINT 536.714594364166,3820.12035369873 509.729844331741,3823.59265565872 563.698636293411,3816.64781570435 PathPoint;PointKind.SMOOTHPOINT 463.495309352875,3820.57967662811 434.636210203171,3820.8869934082 492.354762554169,3820.27235984802 PathPoint;PointKind.SMOOTHPOINT 371.008182764053,3821.16032123566 335.348106622696,3821.1976146698 408.907281160355,3821.12043142319 PathPoint;PointKind.SMOOTHPOINT 301.999987363815,3820.87495565414 300.873395204544,3820.91083288193 319.938011169434,3820.30375242233 PathPoint;PointKind.SMOOTHPOINT 293.935400247574,3821.64419174194 274.017874002457,3822.40563869476 295.047830343246,3821.60170555115 PathPoint;PointKind.CORNERPOINT 241.999926567078,3821.87479734421 241.999926567078,3821.87479734421 241.999926567078,3821.87479734421 PathPoint;PointKind.SMOOTHPOINT 238.76389503479,3816.34144306183 238.901975154877,3814.20580387115 238.650952577591,3818.08809757233 PathPoint;PointKind.SMOOTHPOINT 237.228373289108,3811.15836381912 236.622945070267,3808.78716230392 237.736791372299,3813.14954996109 PathPoint;PointKind.SMOOTHPOINT 236.009373664856,3802.79023647308 235.606462955475,3789.97687339783 236.110986471176,3806.0217833519 PathPoint;PointKind.SMOOTHPOINT 232.008944749832,3779.75469589233 234.815511703491,3770.63173055649 228.899663686752,3789.86664533615 PathPoint;PointKind.SMOOTHPOINT 235.716572999954,3756.67100429535 231.51575088501,3745.611140728 239.917749166489,3767.73039579391 PathPoint;PointKind.SMOOTHPOINT 231.71685218811,3733.63522768021 230.292148590088,3731.1797618866 235.801545381546,3740.67424535751 PathPoint;PointKind.SMOOTHPOINT 230.99989771843,3726.8749666214 231.005208492279,3722.57300376892 230.99777340889,3728.77173900604 PathPoint;PointKind.SMOOTHPOINT 231.595058441162,3714.41848754883 230.615751743317,3707.11015462875 232.274837493896,3719.49110269547 PathPoint;PointKind.CORNERPOINT 235.327116250992,3695.17790794373 235.327116250992,3695.17790794373 235.327116250992,3695.17790794373 PathPoint;PointKind.SMOOTHPOINT 235.205322504044,3675.96163988113 234.792144298553,3665.95921039581 235.617792606354,3685.96383333206 PathPoint;PointKind.SMOOTHPOINT 231.253752708435,3660.61255931854 229.065005779266,3649.71437931061 233.442853689194,3671.51050329208 PathPoint;PointKind.SMOOTHPOINT 231.083099842072,3633.70912313461 230.723737478256,3626.38473987579 231.442816257477,3641.03374242783 PathPoint;PointKind.SMOOTHPOINT 230.961306095123,3614.49309110641 231.790848970413,3604.74699497223 230.132471323013,3624.23895120621 PathPoint;PointKind.SMOOTHPOINT 230.79065322876,3587.58965492249 229.897027015686,3575.80681800842 231.684279441833,3599.37272787094 PathPoint;PointKind.SMOOTHPOINT 230.620354413986,3560.68692684174 229.13050532341,3556.19448423386 233.456307649612,3569.23845291138 PathPoint;PointKind.SMOOTHPOINT 227.830073833466,3539.73344564438 227.814495563507,3538.8365149498 227.983732223511,3548.53516817093 PathPoint;PointKind.SMOOTHPOINT 227.814849615097,3537.00913667679 229.215123653412,3535.35713195801 227.221105098724,3537.70992279053 PathPoint;PointKind.SMOOTHPOINT 227.896989583969,3533.31378221512 228.132787942886,3527.15989351273 227.849192619324,3534.55933570862 PathPoint;PointKind.SMOOTHPOINT 230.327553749084,3514.56698656082 233.422672748566,3501.44607067108 228.878774642944,3520.7109618187 PathPoint;PointKind.SMOOTHPOINT 230.132825374603,3483.8206744194 231.437859535217,3466.54696941376 228.827437162399,3501.09414339066 PathPoint;PointKind.SMOOTHPOINT 229.937388896942,3453.0738902092 234.331877231598,3436.65793418884 225.543962717056,3469.49055433273 PathPoint;PointKind.SMOOTHPOINT 229.64529633522,3406.95489406586 229.414454698563,3393.81887197495 229.998993873596,3427.06620454788 PathPoint;PointKind.SMOOTHPOINT 225.548211336136,3368.54572534561 223.12649846077,3353.19900512695 227.969216108322,3383.89244556427 PathPoint;PointKind.SMOOTHPOINT 225.280194282532,3326.26936912537 227.157375812531,3313.74845266342 223.401950597763,3338.7907576561 PathPoint;PointKind.SMOOTHPOINT 225.109187364578,3299.36616897583 226.754111051559,3274.87193584442 223.463909626007,3323.86087417603 PathPoint;PointKind.SMOOTHPOINT 224.890029430389,3264.77674484253 220.580159425735,3251.71790599823 229.199899435043,3277.83534765244 PathPoint;PointKind.SMOOTHPOINT 220.7437312603,3218.68135213852 220.129451751709,3202.52456188202 221.35836482048,3234.83767032623 PathPoint;PointKind.SMOOTHPOINT 224.353995323181,3180.22403240204 224.799392223358,3172.31971263885 223.698999881744,3191.83598041534 PathPoint;PointKind.SMOOTHPOINT 224.916583299637,3160.41744232178 224.77531671524,3158.93089771271 225.603443384171,3167.64575958252 PathPoint;PointKind.SMOOTHPOINT 223.000102043152,3155.87496042252 222.7055311203,3154.0548992157 223.283343315125,3157.62775182724 PathPoint;PointKind.SMOOTHPOINT 223.130393028259,3149.55513954163 222.412376403809,3146.25773906708 223.613673448563,3151.77291870117 PathPoint;PointKind.SMOOTHPOINT 220.231772661209,3137.97175168991 218.737320899963,3132.53894805908 221.46599650383,3142.45829343796 PathPoint;PointKind.SMOOTHPOINT 219.000027179718,3128.87498617172 219.925872087479,3126.20166063309 218.662970066071,3129.84768390656 PathPoint;PointKind.SMOOTHPOINT 223.939046859741,3114.88782405853 224.858872890472,3108.57461214066 222.832989692688,3122.48128652573 PathPoint;PointKind.SMOOTHPOINT 223.456828594208,3087.99642562866 223.317332267761,3086.41688346863 224.380903244019,3098.44802856445 PathPoint;PointKind.SMOOTHPOINT 223.010723590851,3083.24764966965 221.582833528519,3082.08942890167 225.132200717926,3084.96857643127 PathPoint;PointKind.SMOOTHPOINT 222.444241046906,3077.79619932175 221.370402574539,3067.87472963333 222.638969421387,3079.59478139877 PathPoint;PointKind.SMOOTHPOINT 219.695738554001,3053.41903924942 218.56808423996,3040.85705280304 220.170167684555,3058.70762586594 PathPoint;PointKind.SMOOTHPOINT 219.451797008514,3014.98626708984 220.11458158493,2998.8875412941 218.789366483688,3031.0847568512 PathPoint;PointKind.SMOOTHPOINT 223.013201951981,2968.84248733521 222.738457918167,2955.02597808838 223.287237882614,2982.65923261642 PathPoint;PointKind.SMOOTHPOINT 218.940192461014,2934.27690267563 217.627369165421,2918.10665845871 220.253015756607,2950.44714689255 PathPoint;PointKind.SMOOTHPOINT 218.647745847702,2888.15719842911 215.590864419937,2869.42786931992 221.704627275467,2906.88699960709 PathPoint;PointKind.SMOOTHPOINT 219.000027179718,2845.87494134903 214.94224190712,2837.40885972977 223.058166503906,2854.34125900269 PathPoint;PointKind.SMOOTHPOINT 213.379812240601,2822.84553766251 213.399285078049,2813.91446828842 213.327058553696,2846.80420875549 PathPoint;PointKind.SMOOTHPOINT 218.086928129196,2799.76137399673 217.73677110672,2794.20842885971 218.862655162811,2812.05994606018 PathPoint;PointKind.SMOOTHPOINT 214.999952316284,2781.87492370605 215.620250701904,2780.90033769608 214.380007982254,2782.84950971603 PathPoint;PointKind.SMOOTHPOINT 210.882686376572,2776.48437023163 209.421515464783,2775.37713289261 212.104518413544,2777.41033315659 PathPoint;PointKind.SMOOTHPOINT 205.00011920929,2771.87509059906 202.814558744431,2770.60664176941 206.772147417068,2772.90325641632 PathPoint;PointKind.SMOOTHPOINT 200.567039251328,2766.66604757309 197.284272909164,2760.70853948593 202.222938537598,2769.67123746872 PathPoint;PointKind.SMOOTHPOINT 194.550640583038,2734.57056283951 193.864842653275,2715.82447528839 195.143676996231,2750.7662987709 PathPoint;PointKind.SMOOTHPOINT 190.526490211487,2707.6912021637 188.987782001495,2696.74723148346 192.065198421478,2718.63540887833 PathPoint;PointKind.SMOOTHPOINT 194.282623529434,2692.29420661926 195.856736898422,2680.35157442093 192.708510160446,2704.2366027832 PathPoint;PointKind.SMOOTHPOINT 198.000165224075,2643.87505531311 198.152407407761,2637.44854688644 197.84827709198,2650.30179977417 PathPoint;PointKind.SMOOTHPOINT 193.892812728882,2630.80134630203 194.252529144287,2628.61968040466 192.952097654343,2636.50700569153 PathPoint;PointKind.SMOOTHPOINT 197.648946046829,2615.40411472321 196.591039896011,2604.64991569519 199.201108217239,2631.17970943451 PathPoint;PointKind.SMOOTHPOINT 193.869445323944,2573.57362747192 193.606739044189,2570.63594341278 195.231481790543,2588.8032746315 PathPoint;PointKind.SMOOTHPOINT 194.000090360641,2564.87505197525 193.755086660385,2562.1988940239 194.260672330856,2567.72587537766 PathPoint;PointKind.SMOOTHPOINT 192.35587477684,2557.04531908035 191.232469081879,2545.17609357834 192.595213651657,2559.57489967346 PathPoint;PointKind.SMOOTHPOINT 189.405562877655,2530.89955329895 188.116106987,2523.66037845612 190.188016891479,2535.29380559921 PathPoint;PointKind.SMOOTHPOINT 189.000173807144,2510.87510347366 189.159851074219,2507.6239657402 188.682943582535,2517.32309103012 PathPoint;PointKind.SMOOTHPOINT 192.000052928925,2503.87479543686 192.028023004532,2502.46803045273 191.975269317627,2505.12695789337 PathPoint;PointKind.SMOOTHPOINT 187.999978065491,2497.8750371933 187.453676462173,2495.6695318222 188.622754812241,2500.38951158524 PathPoint;PointKind.SMOOTHPOINT 185.283340215683,2488.64774465561 184.59152340889,2483.88362646103 185.687667131424,2491.42822980881 PathPoint;PointKind.SMOOTHPOINT 189.064257144928,2477.09362506866 189.226412773132,2475.89905500412 188.708789348602,2479.71289873123 PathPoint;PointKind.SMOOTHPOINT 185.00009894371,2472.87498235703 184.297306537628,2470.85712432861 185.974448919296,2475.67364215851 PathPoint;PointKind.CORNERPOINT 181.283619403839,2465.61173200607 181.283619403839,2465.61173200607 181.283619403839,2465.61173200607 PathPoint;PointKind.SMOOTHPOINT 180.381850004196,2323.44396829605 180.372290611267,2321.92036628723 180.922132730484,2408.6157989502 PathPoint;PointKind.SMOOTHPOINT 180.352817773819,2318.84625434875 179.541685581207,2317.05616950989 181.308757066727,2320.95616579056 PathPoint;PointKind.SMOOTHPOINT 180.315288305283,2312.90833711624 179.61497426033,2202.47870206833 180.327680110931,2314.90164756775 PathPoint;PointKind.SMOOTHPOINT 177.762930393219,1910.44562101364 177.74983048439,1908.39825868607 178.641332387924,2048.95815610886 PathPoint;PointKind.SMOOTHPOINT 178.000144958496,1904.87497329712 177.995896339417,1903.75451803207 178.007580041885,1906.91572666168 PathPoint;PointKind.SMOOTHPOINT 177.696722745895,1900.01077651978 177.403922080994,1853.87667417526 177.705574035645,1901.44326925278 PathPoint;PointKind.SMOOTHPOINT 176.867887973785,1769.33741569519 176.857974529266,1767.75881767273 177.123159170151,1809.59095716476 PathPoint;PointKind.SMOOTHPOINT 178.000144958496,1764.87494945526 177.985628843307,1762.59532928467 178.010058403015,1766.44103765488 PathPoint;PointKind.SMOOTHPOINT 176.794953346252,1757.82247781754 176.780083179474,1755.47417163849 176.809469461441,1760.0747179985 PathPoint;PointKind.SMOOTHPOINT 176.750696897507,1750.8233499527 176.742553710938,1749.57378387451 176.765213012695,1753.14097166061 PathPoint;PointKind.SMOOTHPOINT 178.000144958496,1746.8749666214 177.990231513977,1745.35820960999 178.007934093475,1748.11532735825 PathPoint;PointKind.SMOOTHPOINT 176.698297262192,1742.55884170532 176.066669225693,1642.95775651932 176.707856655121,1744.06167268753 PathPoint;PointKind.CORNERPOINT 175.629061460495,1573.96608352661 175.629061460495,1573.96608352661 175.629061460495,1573.96608352661 PathPoint;PointKind.SMOOTHPOINT 183.263829946518,1562.38788843155 187.229207754135,1550.64022064209 179.297389984131,1574.13508415222 PathPoint;PointKind.SMOOTHPOINT 179.999828338623,1547.87507772446 179.993809461594,1547.15281248093 180.096484422684,1559.24273014069 PathPoint;PointKind.SMOOTHPOINT 181.527560949326,1541.56493425369 183.476969003677,1531.9354391098 181.405413150787,1542.16847419739 PathPoint;PointKind.SMOOTHPOINT 186.897815465927,1527.77391672134 186.316108703613,1522.80798912048 188.091323375702,1537.97319889069 PathPoint;PointKind.SMOOTHPOINT 181.000024080276,1519.87502574921 180.210843086243,1519.64843273163 182.915797233582,1520.42498588562 PathPoint;PointKind.SMOOTHPOINT 175.215175151825,1508.62963914871 174.580714702606,1503.22893619537 176.021704673767,1515.50178050995 PathPoint;PointKind.SMOOTHPOINT 174.562304019928,1496.02611064911 173.925719261169,1479.07317638397 174.690824747086,1499.44719314575 PathPoint;PointKind.SMOOTHPOINT 178.849160671234,1474.01613950729 178.387831449509,1463.92401695251 179.232952594757,1482.4137711525 PathPoint;PointKind.SMOOTHPOINT 178.678507804871,1447.11270332336 177.894283533096,1443.9005112648 181.577836275101,1458.9916062355 PathPoint;PointKind.SMOOTHPOINT 179.30588722229,1439.76046800613 179.607893228531,1437.19335794449 179.057343006134,1441.87580823898 PathPoint;PointKind.SMOOTHPOINT 185.999940633774,1417.87488698959 182.396757602692,1408.19204807281 189.472832679749,1427.20697879791 PathPoint;PointKind.SMOOTHPOINT 185.72767496109,1343.29533576965 186.787351369858,1329.45309877396 183.798093795776,1368.50026845932 PathPoint;PointKind.SMOOTHPOINT 181.630589962006,1304.88663911819 182.247347831726,1290.08138179779 180.974532365799,1320.63461780548 PathPoint;PointKind.SMOOTHPOINT 187.413668632507,1276.61916017532 188.758710622787,1275.15527486801 184.790854454041,1279.47328805923 PathPoint;PointKind.SMOOTHPOINT 194.900089502335,1269.09839630127 198.539739847183,1266.52231693268 190.843366384506,1271.96975469589 PathPoint;PointKind.SMOOTHPOINT 199.999848604202,1252.87504434586 200.736275911331,1241.38725042343 199.60614323616,1259.02326822281 PathPoint;PointKind.SMOOTHPOINT 204.215894937515,1220.18876552582 203.622858524323,1212.12134599686 204.809285402298,1228.25618505478 PathPoint;PointKind.SMOOTHPOINT 207.89873957634,1193.26148986816 206.150786876678,1182.39800691605 209.880012273788,1205.57209968567 PathPoint;PointKind.SMOOTHPOINT 203.75244140625,1147.16633319855 202.363497018814,1134.16721105576 205.142093896866,1160.16498327255 PathPoint;PointKind.SMOOTHPOINT 207.411564588547,1116.39523744583 207.319511175156,1108.17935228348 207.619746923447,1135.0230717659 PathPoint;PointKind.SMOOTHPOINT 205.874626636505,1086.3093495369 205.751770734787,1084.60895776749 206.662037372589,1097.20280885696 PathPoint;PointKind.SMOOTHPOINT 205.00011920929,1080.87489366531 205.766286849976,1078.19071054459 204.535957574844,1082.50046253204 PathPoint;PointKind.SMOOTHPOINT 205.008616447449,1074.89283800125 204.255548715591,1065.32589197159 205.171834230423,1076.96828842163 PathPoint;PointKind.SMOOTHPOINT 203.143472671509,1051.08357667923 202.20027923584,1037.21702814102 203.523370027542,1056.66791439056 PathPoint;PointKind.SMOOTHPOINT 199.09524679184,1020.36134004593 198.456183671951,1010.52909135818 201.070146560669,1050.76634645462 PathPoint;PointKind.SMOOTHPOINT 204.053031206131,988.484423160553 202.355353832245,977.18640089035 205.675649642944,999.277331829071 PathPoint;PointKind.SMOOTHPOINT 201.439776420593,955.629851818085 201.415346860886,954.036619663239 201.595205068588,965.6889295578 PathPoint;PointKind.SMOOTHPOINT 203.000081777573,950.874938964844 201.777895689011,948.073446750641 203.605509996414,952.263293266296 PathPoint;PointKind.SMOOTHPOINT 201.488281488419,945.53230047226 201.630610227585,940.116019248962 201.442608833313,947.269041538239 PathPoint;PointKind.SMOOTHPOINT 202.387926578522,931.941204071045 204.440009593964,915.221943855286 201.955983638763,935.459532737732 PathPoint;PointKind.SMOOTHPOINT 206.046341657639,901.170580387115 206.23646736145,887.178461551666 205.8289539814,917.200384140015 PathPoint;PointKind.SMOOTHPOINT 202.165228128433,865.258183479309 202.032104730606,863.270537853241 203.081513643265,878.908524513245 PathPoint;PointKind.SMOOTHPOINT 203.000081777573,858.875105381012 202.967863082886,855.450246334076 203.021324872971,861.125221252441 PathPoint;PointKind.SMOOTHPOINT 202.148587703705,849.650173187256 202.849609851837,837.967178821564 201.980767250061,852.452609539032 PathPoint;PointKind.SMOOTHPOINT 205.51030755043,816.618103981018 206.214870214462,799.480354785919 204.942408800125,830.440278053284 PathPoint;PointKind.SMOOTHPOINT 205.290795564651,782.028207778931 202.365621328354,768.131918907166 207.563098669052,792.823948860168 PathPoint;PointKind.SMOOTHPOINT 198.000165224075,759.874963760376 197.917317152023,756.86222076416 198.279157876968,770.047338008881 PathPoint;PointKind.SMOOTHPOINT 199.000006914139,742.87505865097 200.731319189072,740.35539150238 196.19202375412,746.961994171143 PathPoint;PointKind.SMOOTHPOINT 204.925414323807,724.378931522369 205.504642724991,707.424345016479 204.671913385391,731.807405948639 PathPoint;PointKind.SMOOTHPOINT 200.779116153717,678.283538818359 201.440484523773,660.071125030518 200.415505170822,688.302962779999 PathPoint;PointKind.SMOOTHPOINT 200.486315488815,632.164070606232 198.639936447144,600.629167556763 201.925535202026,656.727697849274 PathPoint;PointKind.SMOOTHPOINT 204.047720432281,586.0200548172 202.40846157074,577.232258319855 205.687333345413,594.807615280151 PathPoint;PointKind.SMOOTHPOINT 203.877421617508,559.116854667664 202.527068853378,547.450618743896 205.227774381638,570.782854557037 PathPoint;PointKind.SMOOTHPOINT 203.75527381897,539.900350570679 203.673487901688,530.742688179016 203.837767839432,549.057776927948 PathPoint;PointKind.SMOOTHPOINT 203.584975004196,512.997150421143 203.493629693985,511.297702789307 204.68359708786,533.420734405518 PathPoint;PointKind.SMOOTHPOINT 203.361568450928,508.401324748993 203.154802322388,503.552706241608 203.419986963272,509.773864746094 PathPoint;PointKind.SMOOTHPOINT 205.00011920929,497.874898910522 204.695988893509,495.800392627716 205.30814409256,499.978201389313 PathPoint;PointKind.SMOOTHPOINT 203.413968086243,486.094186306 202.865896224976,474.681215286255 203.75562787056,493.20188999176 PathPoint;PointKind.SMOOTHPOINT 199.413893222809,463.058409690857 196.612991094589,451.449530124664 202.215503454208,474.66728925705 PathPoint;PointKind.SMOOTHPOINT 199.268023967743,439.99879360199 201.196542978287,427.485902309418 196.703274250031,456.640634536743 PathPoint;PointKind.SMOOTHPOINT 203.02451133728,424.60132598877 202.683559656143,419.28252696991 203.364754915237,429.919888973236 PathPoint;PointKind.SMOOTHPOINT 199.072941541672,409.252245426178 198.449810743332,405.807559490204 201.211413145065,421.069071292877 PathPoint;PointKind.SMOOTHPOINT 201.000044345856,398.87499332428 202.179744243622,392.96941280365 200.176874399185,402.995445728302 PathPoint;PointKind.CORNERPOINT 202.780215740204,386.1683177948 202.780215740204,386.1683177948 202.780215740204,386.1683177948 PathPoint;PointKind.SMOOTHPOINT 198.78049492836,363.132541179657 194.623929262161,342.73020029068 201.772938966751,377.820961475372 PathPoint;PointKind.SMOOTHPOINT 202.439264059067,332.362153530121 206.321793794632,307.252106666565 200.388951301575,345.623037815094 PathPoint;PointKind.SMOOTHPOINT 198.317395448685,290.110108852386 197.721526622772,274.919879436493 198.913618326187,305.299866199493 PathPoint;PointKind.SMOOTHPOINT 198.098237514496,255.520212650299 197.598670721054,239.446742534637 198.597804307938,271.593682765961 PathPoint;PointKind.SMOOTHPOINT 201.78108215332,228.592936992645 205.50924539566,216.324577331543 198.05362701416,240.861296653748 PathPoint;PointKind.SMOOTHPOINT 201.610783338547,201.689736843109 200.205906629562,190.985105037689 203.015305995941,212.394604682922 PathPoint;PointKind.SMOOTHPOINT 201.000044345856,179.874966144562 200.197409391403,174.88968372345 201.801971197128,184.860484600067 PathPoint;PointKind.SMOOTHPOINT 196.999969482422,163.87490272522 197.314367294312,153.591828346252 196.686279773712,174.15821313858 PathPoint;PointKind.CORNERPOINT 197.464485168457,155.594344139099 197.464485168457,155.594344139099 197.464485168457,155.594344139099 PathPoint;PointKind.SMOOTHPOINT 197.292416095734,140.478701591492 197.490330934525,139.316232204437 196.096075773239,147.502377033234 PathPoint";
	
	shadow35mm[0] = "PointKind.SMOOTHPOINT 191.765670776367,171.81250333786 191.858432292938,171.687877178192 189.063903093338,175.436811447144 PathPoint;PointKind.SMOOTHPOINT 200.765662193298,136.812615394592 203.534699678421,130.07265329361 197.161771059036,145.583889484406 PathPoint;PointKind.SMOOTHPOINT 216.421823501587,131.718757152557 221.767294406891,130.669348239899 209.55570101738,133.066513538361 PathPoint;PointKind.CORNERPOINT 288.142408132553,161.484110355377 288.142408132553,161.484110355377 288.142408132553,161.484110355377 PathPoint;PointKind.SMOOTHPOINT 5329.4217467308,171.718797683716 5361.64433598518,171.795508861542 4439.50103759766,169.599680900574 PathPoint;PointKind.SMOOTHPOINT 5421.06269001961,146.812448501587 5471.37696146965,141.483736038208 5377.01831817627,151.477196216583 PathPoint;PointKind.SMOOTHPOINT 5577.06242322922,142.812373638153 5616.49775147438,141.994278430939 5532.55353569984,143.735740184784 PathPoint;PointKind.CORNERPOINT 5641.09371542931,138.000104427338 5641.09371542931,138.000104427338 5641.09371542931,138.000104427338 PathPoint;PointKind.SMOOTHPOINT 5688.09370994568,168.000075817108 5707.26418733597,188.716106414795 5667.13775038719,145.354936122894 PathPoint;PointKind.SMOOTHPOINT 5704.88106608391,242.861924171448 5706.35392069817,246.576161384583 5698.50955367088,226.794826984406 PathPoint;PointKind.SMOOTHPOINT 5710.76504945755,256.292517185211 5713.2260620594,261.215250492096 5708.58302950859,251.927061080933 PathPoint;PointKind.SMOOTHPOINT 5715.09368419647,269.999978542328 5715.67220449448,274.7079205513 5714.60438489914,266.017370223999 PathPoint;PointKind.SMOOTHPOINT 5718.64730000496,286.365423202515 5718.66960525513,289.042997360229 5718.59844088554,280.270071029663 PathPoint;PointKind.SMOOTHPOINT 5716.7474591732,293.800270557404 5716.70957565308,295.660221576691 5716.80623173714,290.882649421692 PathPoint;PointKind.SMOOTHPOINT 5718.43168258667,300.481224060059 5718.04435014725,311.910009384155 5718.49789023399,298.528747558594 PathPoint;PointKind.SMOOTHPOINT 5715.75044989586,339.204790592194 5715.32169342041,349.870948791504 5716.02944254875,332.255938053131 PathPoint;PointKind.SMOOTHPOINT 5722.77837395668,370.777223110199 5722.79820084572,377.099404335022 5722.74261474609,359.664723873138 PathPoint;PointKind.SMOOTHPOINT 5719.78699207306,392.491915225983 5720.43419837952,397.527000904083 5718.90929818153,385.666036605835 PathPoint;PointKind.SMOOTHPOINT 5717.79297351837,422.103610038757 5717.55469679832,434.382119178772 5717.99407482147,411.763415336609 PathPoint;PointKind.SMOOTHPOINT 5717.79297351837,459.61136341095 5717.88467288017,461.448183059692 5717.1709048748,447.187221050262 PathPoint;PointKind.SMOOTHPOINT 5716.79596424103,465.533702373505 5716.89191222191,467.180750370026 5716.68904066086,463.697590827942 PathPoint;PointKind.SMOOTHPOINT 5718.39663147926,470.060606002808 5718.81193399429,476.435422897339 5718.28970789909,468.41450214386 PathPoint;PointKind.SMOOTHPOINT 5719.8454105854,489.13360118866 5720.06563067436,491.712985038757 5719.30477380753,482.798202037811 PathPoint;PointKind.SMOOTHPOINT 5721.78101062775,496.132020950317 5721.96405529976,498.143742084503 5721.54733657837,493.563022613525 PathPoint;PointKind.SMOOTHPOINT 5721.08636140823,502.880480289459 5722.03521966934,512.931532859802 5720.89765191078,500.876312255859 PathPoint;PointKind.SMOOTHPOINT 5712.9403424263,533.67258310318 5713.10214400291,534.039616584778 5712.20320701599,532.000751495361 PathPoint;PointKind.SMOOTHPOINT 5707.91174769402,541.718759536743 5708.00238490105,547.468557357788 5707.79491066933,534.369356632233 PathPoint;PointKind.SMOOTHPOINT 5714.53215837479,549.837870597839 5713.71819376945,556.39018535614 5715.02110362053,545.908842086792 PathPoint;PointKind.SMOOTHPOINT 5715.70937991142,570.173885822296 5716.07051253319,572.388360500336 5714.44187521935,562.388763427734 PathPoint;PointKind.SMOOTHPOINT 5717.7037525177,578.070180416107 5718.59596252441,588.945229053497 5717.51221060753,575.736508369446 PathPoint;PointKind.SMOOTHPOINT 5716.70638918877,608.668735027313 5716.46811246872,614.581632614136 5717.01406002045,601.066303253174 PathPoint;PointKind.SMOOTHPOINT 5716.09565019608,630.31875371933 5716.01528048515,634.282007217407 5716.26524090767,621.900351047516 PathPoint;PointKind.SMOOTHPOINT 5720.97837567329,643.718662261963 5727.34776377678,651.320149898529 5720.90650320053,643.633217811584 PathPoint;PointKind.SMOOTHPOINT 5716.70638918877,657.033834457397 5716.6380572319,661.579856872559 5716.77472114563,652.541155815125 PathPoint;PointKind.SMOOTHPOINT 5718.29360246658,671.277093887329 5718.16154122353,680.008950233459 5718.36653709412,666.437208652496 PathPoint;PointKind.SMOOTHPOINT 5717.88573503494,698.61837387085 5717.82413005829,702.809164524078 5718.02381515503,689.175581932068 PathPoint;PointKind.SMOOTHPOINT 5715.70937991142,711.321272850037 5715.66937208176,714.136219024658 5715.77098488808,707.035596370697 PathPoint;PointKind.SMOOTHPOINT 5717.58089661598,719.832909107208 5717.43892192841,730.006227493286 5717.62090444565,716.987042427063 PathPoint;PointKind.SMOOTHPOINT 5717.16913461685,750.695114135742 5717.14187264442,752.850816249847 5717.29942560196,740.353031158447 PathPoint;PointKind.SMOOTHPOINT 5715.70937991142,757.712888717651 5715.67326664925,760.742154121399 5715.73593378067,755.559310913086 PathPoint;PointKind.SMOOTHPOINT 5716.9804251194,766.231842041016 5716.88376903534,774.541432857513 5717.0158302784,763.214378356934 PathPoint;PointKind.SMOOTHPOINT 5714.70599770546,780.881080627441 5714.67484116554,784.115931987762 5714.78459715843,772.789113521576 PathPoint;PointKind.SMOOTHPOINT 5716.69045686722,790.155816078186 5716.669921875,792.558174133301 5716.71842694283,786.976668834686 PathPoint;PointKind.SMOOTHPOINT 5714.55835819244,797.656280994415 5714.50737476349,804.105448722839 5714.57676887512,795.291924476624 PathPoint;PointKind.SMOOTHPOINT 5718.96807074547,816.718654632568 5718.95143032074,818.304569721222 5719.03250813484,810.62424659729 PathPoint;PointKind.SMOOTHPOINT 5712.70241975784,825.689613819122 5711.05360150337,827.216992378235 5718.10737133026,820.683324337006 PathPoint;PointKind.SMOOTHPOINT 5714.37389731407,832.622888088226 5714.36044335365,839.342551231384 5714.37814593315,830.452079772949 PathPoint;PointKind.SMOOTHPOINT 5714.3869972229,851.638762950897 5712.20568537712,861.694300174713 5715.64458847046,845.84246635437 PathPoint;PointKind.SMOOTHPOINT 5714.69643831253,878.002860546112 5714.90957736969,886.918587684631 5714.52543139458,870.828831195831 PathPoint;PointKind.SMOOTHPOINT 5715.51571369171,907.849645614624 5715.61980485916,911.361365318298 5715.19423484802,896.981914043427 PathPoint;PointKind.SMOOTHPOINT 5715.83860874176,918.626267910004 5717.39041686058,928.390302658081 5715.23565888405,914.83295917511 PathPoint;PointKind.SMOOTHPOINT 5713.6990749836,949.070456027985 5715.28593420982,969.785778522491 5712.88298606873,938.41326713562 PathPoint;PointKind.SMOOTHPOINT 5721.72400832176,1022.29328155518 5721.81287527084,1024.38596248627 5720.81692814827,1000.78370332718 PathPoint;PointKind.SMOOTHPOINT 5723.71802687645,1029.20248031616 5723.81362080574,1031.32442951202 5723.62278699875,1027.07958698273 PathPoint;PointKind.SMOOTHPOINT 5722.29580163956,1035.01860380173 5723.1306552887,1052.80379533768 5722.19489693642,1032.87564754486 PathPoint;PointKind.SMOOTHPOINT 5728.72148394585,1085.43838262558 5728.98454427719,1094.82523441315 5728.26369524002,1069.12793397903 PathPoint;PointKind.SMOOTHPOINT 5730.71550250053,1111.10169410706 5730.55901169777,1117.00609445572 5730.91518759727,1103.56393575668 PathPoint;PointKind.SMOOTHPOINT 5730.71408629417,1136.59104824066 5730.76188325882,1140.17216205597 5730.56892514229,1125.6938123703 PathPoint;PointKind.SMOOTHPOINT 5732.70952105522,1148.60944747925 5732.79201507568,1153.01384925842 5732.63375401497,1144.5711350441 PathPoint;PointKind.SMOOTHPOINT 5742.19527125359,1161.99661016464 5742.46328830719,1173.57928991318 5742.0819747448,1157.09913253784 PathPoint;PointKind.SMOOTHPOINT 5730.06263136864,1187.8123998642 5730.20389795303,1192.56306409836 5729.64945316315,1173.96851062775 PathPoint;PointKind.SMOOTHPOINT 5727.06239819527,1210.81253528595 5727.15763807297,1213.85360240936 5726.90696954727,1205.85085630417 PathPoint;PointKind.SMOOTHPOINT 5738.94082903862,1223.11653614044 5739.25416469574,1232.84894227982 5738.84063243866,1220.00513076782 PathPoint;PointKind.SMOOTHPOINT 5740.92210173607,1251.71281099319 5743.09031367302,1272.84544229507 5739.9612057209,1242.34602212906 PathPoint;PointKind.SMOOTHPOINT 5733.06286454201,1290.81261634827 5730.55016040802,1299.78711605072 5738.43170285225,1271.63623809814 PathPoint;PointKind.SMOOTHPOINT 5744.06253933907,1312.81243801117 5747.90010452271,1324.69370126724 5741.10266804695,1303.64816665649 PathPoint;PointKind.SMOOTHPOINT 5746.63153767586,1378.71866941452 5746.72925591469,1380.79317569733 5745.00183820724,1343.93428087234 PathPoint;PointKind.SMOOTHPOINT 5741.60577535629,1396.71865224838 5741.785633564,1401.40228271484 5741.52717590332,1394.66161251068 PathPoint;PointKind.SMOOTHPOINT 5744.62123274803,1417.71863222122 5746.2452673912,1440.04488945007 5744.28913235664,1413.15325498581 PathPoint;PointKind.CORNERPOINT 5796.0001373291,1477.00008630753 5796.0001373291,1477.00008630753 5796.0001373291,1477.00008630753 PathPoint;PointKind.CORNERPOINT 5805.00012874603,2500.99989652634 5805.00012874603,2500.99989652634 5805.00012874603,2500.99989652634 PathPoint;PointKind.SMOOTHPOINT 5756.06240987778,2569.81241941452 5756.04860186577,2570.0283908844 5756.18384957314,2567.93570995331 PathPoint;PointKind.SMOOTHPOINT 5764.5897424221,2576.55096530914 5763.87986898422,2591.75134420395 5764.87298369408,2570.47827243805 PathPoint;PointKind.SMOOTHPOINT 5750.66206097603,2637.71857023239 5750.21312355995,2646.79975748062 5752.4836564064,2600.83654403687 PathPoint;PointKind.SMOOTHPOINT 5757.10084319115,2686.71860218048 5756.18880629539,2706.248087883 5757.55190491676,2677.06597566605 PathPoint;PointKind.SMOOTHPOINT 5747.64660358429,2749.718542099 5747.90081262589,2764.77966070175 5747.30848431587,2729.65302228928 PathPoint;PointKind.SMOOTHPOINT 5729.95287537575,2794.80040311813 5729.84276533127,2798.88002157211 5730.33666729927,2780.65344572067 PathPoint;PointKind.SMOOTHPOINT 5729.65157747269,2806.84948682785 5728.42514276505,2809.84972000122 5731.98017477989,2801.15138053894 PathPoint;PointKind.SMOOTHPOINT 5730.76436161995,2819.02012825012 5730.22372484207,2845.80295085907 5730.82738280296,2815.89574098587 PathPoint;PointKind.SMOOTHPOINT 5730.64858675003,2881.86522960663 5732.1210873127,2918.13569068909 5730.09520411491,2868.24344873428 PathPoint;PointKind.SMOOTHPOINT 5728.62624406815,2969.71864700317 5728.68572473526,2972.89708614349 5728.11888813972,2942.56430625916 PathPoint;PointKind.SMOOTHPOINT 5736.54496192932,2981.84916257858 5734.80019569397,2985.40997743607 5737.92647123337,2979.0292596817 PathPoint;PointKind.SMOOTHPOINT 5736.70357704163,2991.35025501251 5736.9301700592,3005.29445886612 5736.65223956108,2988.1963634491 PathPoint;PointKind.SMOOTHPOINT 5737.37521290779,3033.35800409317 5737.37521290779,3033.84517908096 5737.37521290779,3031.61182165146 PathPoint;PointKind.SMOOTHPOINT 5739.64539170265,3045.68914890289 5740.1764690876,3047.86845445633 5738.0489730835,3039.13140535355 PathPoint;PointKind.SMOOTHPOINT 5734.65715885162,3062.71855831146 5735.07139921188,3081.4568567276 5734.59697008133,3060.0074672699 PathPoint;PointKind.SMOOTHPOINT 5734.65715885162,3127.71865367889 5735.47218561172,3150.74475288391 5733.89063715935,3106.07241153717 PathPoint;PointKind.SMOOTHPOINT 5739.6825671196,3189.71851587296 5739.68044281006,3192.57405996323 5739.70522642136,3156.47661209106 PathPoint;PointKind.SMOOTHPOINT 5742.69767045975,3216.71849012375 5741.46769523621,3219.60117816925 5746.61879181862,3207.52990722656 PathPoint;PointKind.SMOOTHPOINT 5740.68913578987,3226.23091220856 5740.63496589661,3240.70029258728 5740.70117354393,3223.05860996246 PathPoint;PointKind.SMOOTHPOINT 5740.39244055748,3270.57445764542 5740.37509202957,3272.46013641357 5740.53052067757,3255.58509349823 PathPoint;PointKind.SMOOTHPOINT 5732.04992294312,3275.71859121323 5734.01844978333,3281.03786230087 5729.18210506439,3267.96816587448 PathPoint;PointKind.SMOOTHPOINT 5743.10624599457,3277.71851062775 5742.90691494942,3297.0454788208 5743.1264269352,3275.7301568985 PathPoint;PointKind.SMOOTHPOINT 5737.67226219177,3326.71854257584 5737.62411117554,3330.14741420746 5737.93709278107,3307.97269105911 PathPoint;PointKind.SMOOTHPOINT 5739.41915273666,3349.85864639282 5740.80703496933,3353.3595085144 5738.17112088203,3346.70900344849 PathPoint;PointKind.SMOOTHPOINT 5739.26337003708,3360.4273223877 5739.01695013046,3376.88104391098 5739.3154156208,3356.93519353867 PathPoint;PointKind.SMOOTHPOINT 5739.08563613892,3410.71846246719 5739.04633641243,3413.23883771896 5739.31329131126,3396.17850780487 PathPoint;PointKind.SMOOTHPOINT 5726.01936221123,3413.71845960617 5727.05567121506,3425.1918554306 5724.87860798836,3401.08825922012 PathPoint;PointKind.SMOOTHPOINT 5738.31734418869,3421.54323577881 5737.83937454224,3452.71252155304 5738.3523952961,3419.27022457123 PathPoint;PointKind.SMOOTHPOINT 5746.69809937477,3485.88644742966 5746.76147460938,3491.27133607864 5746.56568408012,3474.76474285126 PathPoint;PointKind.SMOOTHPOINT 5742.09932327271,3512.13866472244 5742.21191167831,3516.69129610062 5741.9017624855,3504.1623544693 PathPoint;PointKind.SMOOTHPOINT 5742.4558532238,3526.77846193314 5741.63055896759,3529.3271613121 5744.57980871201,3520.21977424622 PathPoint;PointKind.SMOOTHPOINT 5742.63889789581,3535.0151181221 5742.71395683289,3538.59009504318 5742.57977128029,3532.20324039459 PathPoint;PointKind.SMOOTHPOINT 5742.61942505836,3546.14272356033 5742.56950378418,3549.51235055923 5742.6746571064,3542.3189663887 PathPoint;PointKind.SMOOTHPOINT 5738.54075074196,3556.73854351044 5737.96081423759,3560.11123895645 5738.76309514046,3555.44885158539 PathPoint;PointKind.SMOOTHPOINT 5742.66934633255,3565.91508865356 5743.03862214088,3574.63750362396 5742.53516077995,3562.74703502655 PathPoint;PointKind.SMOOTHPOINT 5743.03649783134,3591.94590568542 5742.03736424446,3597.04424858093 5744.74196434021,3583.24496984482 PathPoint;PointKind.SMOOTHPOINT 5742.75644302368,3606.41575813293 5742.67217874527,3609.53046798706 5742.88567185402,3601.62732839584 PathPoint;PointKind.SMOOTHPOINT 5744.52316045761,3616.94855690002 5744.86694455147,3618.56798887253 5744.45093393326,3616.60937547684 PathPoint;PointKind.SMOOTHPOINT 5741.45317912102,3634.65892553329 5740.95396637917,3641.84900522232 5741.8773329258,3628.54020595551 PathPoint;PointKind.SMOOTHPOINT 5743.24078559875,3648.55214595795 5741.99735641479,3653.88416290283 5744.66655135155,3642.43696689606 PathPoint;PointKind.SMOOTHPOINT 5737.58410334587,3664.24937725067 5735.5153799057,3674.48123216629 5738.53437781334,3659.55064058304 PathPoint;PointKind.SMOOTHPOINT 5736.74818754196,3690.20537137985 5732.91628718376,3700.51771402359 5740.50255060196,3680.10215520859 PathPoint;PointKind.SMOOTHPOINT 5719.09375905991,3743.99996995926 5712.36925721169,3754.99634027481 5735.94201207161,3716.44814729691 PathPoint;PointKind.SMOOTHPOINT 5696.09385967255,3785.99992990494 5684.04654622078,3799.39629793167 5705.52260756493,3775.51528215408 PathPoint;PointKind.SMOOTHPOINT 5659.42190408707,3819.71862316132 5624.1891682148,3838.444647789 5676.55375242233,3810.61312437057 PathPoint;PointKind.CORNERPOINT 5531.42198681831,3825.71861743927 5531.42198681831,3825.71861743927 5531.42198681831,3825.71861743927 PathPoint;PointKind.SMOOTHPOINT 5330.40530204773,3802.07458019257 4470.48196792603,3801.87843561172 5385.74498176575,3802.08709001541 PathPoint;PointKind.SMOOTHPOINT 384.481261968613,3786.2942647934 309.392230510712,3786.05468988419 1059.15241241455,3788.44689846039 PathPoint;PointKind.CORNERPOINT 275.422042608261,3819.71862316132 275.422042608261,3819.71862316132 275.422042608261,3819.71862316132 PathPoint;PointKind.SMOOTHPOINT 239.765506982803,3821.81248426437 237.772550582886,3815.84293842316 240.751186609268,3824.77164745331 PathPoint;PointKind.SMOOTHPOINT 234.765590429306,3796.8124294281 232.843798398972,3791.53706073761 237.756264209747,3805.02123355865 PathPoint;PointKind.SMOOTHPOINT 228.765478134155,3783.81259918213 227.116305828094,3773.03550481796 229.584753513336,3789.16562318802 PathPoint;PointKind.SMOOTHPOINT 230.765515565872,3761.81254148483 227.633221149445,3753.07077169418 233.308314085007,3768.9093875885 PathPoint;PointKind.SMOOTHPOINT 228.765478134155,3717.81242609024 226.301987171173,3714.69866037369 232.635262012482,3722.70541906357 PathPoint;PointKind.SMOOTHPOINT 230.461385250092,3695.16681432724 230.657175779343,3689.66579675674 230.438017845154,3695.82959890366 PathPoint;PointKind.SMOOTHPOINT 223.482320308685,3681.34818077087 223.682713508606,3675.57572364807 223.274846076965,3687.31465816498 PathPoint;PointKind.SMOOTHPOINT 223.915679454803,3637.71863937378 223.672800064087,3623.62644195557 224.022248983383,3643.89707565308 PathPoint;PointKind.SMOOTHPOINT 222.845735549927,3597.79460191727 222.744476795197,3594.69334602356 223.266348838806,3610.65753221512 PathPoint;PointKind.SMOOTHPOINT 233.966850042343,3588.71860742569 234.121216535568,3578.18321228027 233.79265666008,3600.59892654419 PathPoint;PointKind.SMOOTHPOINT 222.262966632843,3579.75425720215 222.035665512085,3572.40745067596 222.353603839874,3582.68273591995 PathPoint;PointKind.SMOOTHPOINT 221.662495136261,3557.17567920685 221.608325242996,3554.62131500244 221.826775074005,3564.94262695312 PathPoint;PointKind.SMOOTHPOINT 231.956545114517,3549.71864461899 231.242777109146,3542.47120857239 232.894073724747,3559.23767566681 PathPoint;PointKind.SMOOTHPOINT 221.387751102448,3539.86609697342 221.244006156921,3525.94974517822 221.421386003494,3543.1094455719 PathPoint;PointKind.SMOOTHPOINT 221.628506183624,3493.57998847961 221.691881418228,3490.38809537888 221.281889677048,3510.81073522568 PathPoint;PointKind.SMOOTHPOINT 223.409739732742,3484.87362384796 223.452225923538,3482.62209177017 223.348134756088,3488.08746814728 PathPoint;PointKind.SMOOTHPOINT 221.943612098694,3477.20085382462 222.076735496521,3469.98457431793 221.902542114258,3479.46253538132 PathPoint;PointKind.SMOOTHPOINT 225.925630331039,3456.7187333107 226.050256490707,3454.70559597015 225.476338863373,3463.99024486542 PathPoint;PointKind.SMOOTHPOINT 222.412730455399,3449.34006214142 222.60781288147,3448.28144788742 222.044870853424,3451.33478879929 PathPoint;PointKind.SMOOTHPOINT 220.900222063065,3403.71862649918 221.786413192749,3387.81462907791 220.005533695221,3419.77699041367 PathPoint;PointKind.SMOOTHPOINT 217.681185007095,3353.53039741516 217.494599819183,3350.54833889008 218.716431856155,3370.09953975677 PathPoint;PointKind.SMOOTHPOINT 222.910526990891,3346.71868085861 222.894594669342,3344.37910795212 222.929999828339,3349.60915803909 PathPoint;PointKind.SMOOTHPOINT 217.290666103363,3337.69579410553 217.94247508049,3314.72988367081 217.224458456039,3340.03347873688 PathPoint;PointKind.SMOOTHPOINT 219.895423650742,3274.71874952316 219.297784566879,3267.34125852585 221.786767244339,3298.07860136032 PathPoint;PointKind.SMOOTHPOINT 210.849405527115,3244.718542099 209.636424779892,3213.38072776794 211.129460334778,3251.95913314819 PathPoint;PointKind.SMOOTHPOINT 212.369703054428,3155.19990205765 212.393070459366,3151.62846565247 212.184180021286,3183.51175546646 PathPoint;PointKind.SMOOTHPOINT 215.360730886459,3145.32941579819 215.384806394577,3142.75144815445 215.328158140182,3148.83948326111 PathPoint;PointKind.SMOOTHPOINT 212.531858682632,3136.89543485641 212.692952156067,3122.15909957886 212.504242658615,3139.43846940994 PathPoint;PointKind.SMOOTHPOINT 212.328987121582,3095.1154589653 212.332173585892,3093.08957576752 212.309514284134,3108.40749979019 PathPoint;PointKind.SMOOTHPOINT 214.869661331177,3089.71853256226 214.897985458374,3087.46770858765 214.844523668289,3091.72506093979 PathPoint;PointKind.SMOOTHPOINT 212.492558956146,3082.35449552536 212.808018922806,3068.9413690567 212.440513372421,3084.57770347595 PathPoint;PointKind.SMOOTHPOINT 209.843899011612,3046.71873092651 209.838234186172,3046.08143806458 209.947990179062,3058.1689953804 PathPoint;PointKind.SMOOTHPOINT 220.492000579834,3042.71865606308 219.997036457062,2999.10138845444 220.499081611633,3043.34886789322 PathPoint;PointKind.SMOOTHPOINT 231.548323631287,2965.71857213974 229.209812879562,2957.40284442902 233.280344009399,2971.87883377075 PathPoint;PointKind.SMOOTHPOINT 214.461439847946,2908.71862649918 214.022769927979,2898.04373502731 215.890746116638,2943.53228330612 PathPoint;PointKind.SMOOTHPOINT 213.456287384033,2855.71875572205 211.405620574951,2846.43528699875 213.669072389603,2856.68272018433 PathPoint;PointKind.SMOOTHPOINT 208.430525064468,2835.71861743927 210.562977790833,2827.27071046829 207.450156211853,2839.60397958755 PathPoint;PointKind.SMOOTHPOINT 212.45113492012,2799.71865177155 215.190078020096,2789.57412958145 210.058100223541,2808.57961893082 PathPoint;PointKind.SMOOTHPOINT 191.156347990036,2762.71860837936 190.843720436096,2702.140853405 191.188566684723,2768.99547100067 PathPoint;PointKind.SMOOTHPOINT 192.999894618988,2576.99990272522 192.903238534927,2574.5555305481 195.202803611755,2632.60299682617 PathPoint;PointKind.SMOOTHPOINT 189.000173807144,2548.00000905991 179.881575107574,2521.95715427399 190.665278434753,2552.75610208511 PathPoint;PointKind.CORNERPOINT 138.999946117401,2500.00005483627 138.999946117401,2500.00005483627 138.999946117401,2500.00005483627 PathPoint;PointKind.CORNERPOINT 131.999992132187,1473.00001144409 131.999992132187,1473.00001144409 131.999992132187,1473.00001144409 PathPoint;PointKind.CORNERPOINT 183.000061511993,1429.99997377396 183.000061511993,1429.99997377396 183.000061511993,1429.99997377396 PathPoint;PointKind.SMOOTHPOINT 177.44392991066,1382.26626634598 176.988973617554,1365.84629774094 177.64467716217,1389.51535463333 PathPoint;PointKind.SMOOTHPOINT 180.421857833862,1349.71877574921 178.002269268036,1319.51392650604 181.246443986893,1360.01105546951 PathPoint;PointKind.SMOOTHPOINT 173.156365156174,1313.71857404709 172.618206739426,1310.35012722015 174.293932914734,1320.84043979645 PathPoint;PointKind.SMOOTHPOINT 177.765762805939,1289.81253862381 181.704586744308,1277.56589412689 174.23055768013,1300.80277204514 PathPoint;PointKind.SMOOTHPOINT 192.422082424164,1247.71863698959 198.152407407761,1228.2448554039 187.854816913605,1263.2402586937 PathPoint;PointKind.SMOOTHPOINT 203.813692331314,1201.71860218048 204.671913385391,1195.35015821457 203.471678495407,1204.25337553024 PathPoint;PointKind.SMOOTHPOINT 197.455279827118,1140.64847946167 196.995012760162,1129.65399742126 198.201974630356,1158.50471735001 PathPoint;PointKind.SMOOTHPOINT 196.660079956055,1120.64527273178 197.099103927612,1116.94236516953 196.598474979401,1121.1666727066 PathPoint;PointKind.SMOOTHPOINT 206.828795671463,1102.71869659424 207.551769018173,1093.08424472809 205.540755987167,1119.90388870239 PathPoint;PointKind.SMOOTHPOINT 194.84379529953,1091.71949386597 194.965943098068,1088.55096817017 194.734039306641,1094.55497503281 PathPoint;PointKind.SMOOTHPOINT 194.472041130066,1083.38653564453 194.573653936386,1080.58457136154 194.365825653076,1086.31808280945 PathPoint;PointKind.SMOOTHPOINT 195.46905040741,1074.5031452179 196.160513162613,1053.93298387527 195.383015871048,1077.07355976105 PathPoint;PointKind.SMOOTHPOINT 190.400801897049,1035.87871313095 197.976443767548,1033.21270465851 189.401668310165,1036.23040437698 PathPoint;PointKind.SMOOTHPOINT 190.625978708267,1025.51963567734 190.017364025116,1024.98572587967 193.925031423569,1028.41200113297 PathPoint;PointKind.SMOOTHPOINT 191.432154178619,1007.38393306732 192.325780391693,1003.5951089859 189.520983695984,1015.48840999603 PathPoint;PointKind.SMOOTHPOINT 192.04749584198,983.567118644714 191.997220516205,981.881124973297 192.35693693161,993.992757797241 PathPoint;PointKind.SMOOTHPOINT 201.26204252243,982.414798736572 203.529034852982,981.740684509277 198.995404243469,983.088440895081 PathPoint;PointKind.SMOOTHPOINT 208.241107463837,974.518268108368 208.187999725342,973.308827877045 208.299880027771,975.851390361786 PathPoint;PointKind.SMOOTHPOINT 198.271014690399,972.544076442719 194.616494178772,971.438019275665 201.483324766159,973.516774177551 PathPoint;PointKind.SMOOTHPOINT 191.337976455688,966.876654624939 191.021100282669,960.914661884308 191.406662464142,968.173191547394 PathPoint;PointKind.SMOOTHPOINT 193.450602293015,949.109401702881 192.76905298233,939.392337799072 193.697376251221,952.626078128815 PathPoint;PointKind.SMOOTHPOINT 197.43863940239,886.925432682037 198.078764677048,873.068797588348 196.349576711655,910.480720996857 PathPoint;PointKind.SMOOTHPOINT 196.441630125046,857.313737869263 196.748592853546,852.733490467072 196.327625513077,859.010353088379 PathPoint;PointKind.SMOOTHPOINT 194.447257518768,850.404539108276 194.548870325089,845.98361492157 194.397336244583,852.592105865479 PathPoint;PointKind.SMOOTHPOINT 196.441630125046,835.598809719086 196.657247543335,820.692057609558 196.375068426132,840.197231769562 PathPoint;PointKind.SMOOTHPOINT 201.803387403488,794.718596935272 201.88517332077,785.815143585205 201.653269529343,811.056661605835 PathPoint;PointKind.SMOOTHPOINT 194.463897943497,766.583061218262 194.240491390228,765.498247146606 196.313817501068,775.576915740967 PathPoint;PointKind.SMOOTHPOINT 200.798234939575,741.718726158142 200.862672328949,735.814325809479 200.716449022293,749.159002304077 PathPoint;PointKind.SMOOTHPOINT 195.36460518837,680.718705654144 195.769286155701,648.668067455292 195.289192199707,686.66464805603 PathPoint;PointKind.SMOOTHPOINT 199.465230703354,626.370606422424 199.489660263062,621.758258342743 199.30165886879,657.120223045349 PathPoint;PointKind.SMOOTHPOINT 199.465230703354,611.564877033234 199.486473798752,607.099106311798 199.443633556366,616.092252731323 PathPoint;PointKind.SMOOTHPOINT 197.362518310547,598.236486911774 197.425185441971,582.863566875458 197.345169782639,602.605955600739 PathPoint;PointKind.SMOOTHPOINT 199.465230703354,554.31615114212 199.468063116074,547.059509754181 199.458857774734,568.12652349472 PathPoint;PointKind.SMOOTHPOINT 198.68065237999,533.001301288605 198.659763336182,527.225775718689 198.705435991287,539.701845645905 PathPoint;PointKind.SMOOTHPOINT 196.473848819733,514.833970069885 196.434195041656,510.156240463257 196.518459320068,520.13813495636 PathPoint;PointKind.SMOOTHPOINT 196.467829942703,501.503455638885 196.485178470612,499.100625514984 196.438443660736,505.710532665253 PathPoint;PointKind.SMOOTHPOINT 209.843899011612,493.718569278717 211.00093960762,484.731323719025 209.055072069168,499.846966266632 PathPoint;PointKind.SMOOTHPOINT 199.793082475662,486.718733310699 200.061099529266,472.297031879425 199.744931459427,489.291272163391 PathPoint;PointKind.SMOOTHPOINT 196.473848819733,455.611288547516 195.517201423645,448.300831317902 197.258073091507,461.597120761871 PathPoint;PointKind.SMOOTHPOINT 200.798234939575,390.718588829041 201.78320646286,367.790443897247 199.588794708252,418.86616230011 PathPoint;PointKind.SMOOTHPOINT 191.752216815948,355.718700885773 192.300288677216,351.581726074219 191.075624227524,360.82554101944 PathPoint;PointKind.SMOOTHPOINT 195.77247262001,331.718723773956 195.783802270889,327.181670665741 195.731402635574,348.597543239594 PathPoint;PointKind.SMOOTHPOINT 197.782777547836,315.718660354614 197.031480073929,287.13725566864 197.919087409973,320.906224250793 PathPoint;PointKind.SMOOTHPOINT 192.429517507553,252.292442321777 192.67062664032,250.584261417389 192.246472835541,253.589451313019 PathPoint;PointKind.SMOOTHPOINT 191.291949748993,234.232506752014 191.417284011841,230.512840747833 191.086953878403,240.310864448547 PathPoint;PointKind.SMOOTHPOINT 201.26204252243,237.193558216095 204.197130203247,235.971372127533 198.374751806259,238.396389484406 PathPoint;PointKind.SMOOTHPOINT 207.244098186493,231.271455287933 207.149920463562,230.239748954773 207.348189353943,232.40984916687 PathPoint;PointKind.SMOOTHPOINT 201.26204252243,224.362020492554 197.993084192276,223.32795381546 204.195359945297,225.290107727051 PathPoint;PointKind.SMOOTHPOINT 190.624916553497,226.225039958954 190.045688152313,219.801599979401 190.722634792328,227.307257652283 PathPoint;PointKind.SMOOTHPOINT 191.752216815948,212.718679904938 193.632230758667,206.849212646484 191.490572690964,213.534178733826 PathPoint;PointKind.SMOOTHPOINT 190.765475034714,184.812569618225 190.80371260643,180.450654029846 190.669881105423,195.762205123901 PathPoint";
	
	shadow35mm[1] = "PointKind.SMOOTHPOINT 201.906062364578,132.343776226044 497.176237106323,131.798536777496 199.181281328201,132.348732948303 PathPoint;PointKind.SMOOTHPOINT 2766.65613412857,154.296863079071 3988.24599981308,156.608347892761 1613.94417285919,152.115669250488 PathPoint;PointKind.SMOOTHPOINT 5621.65628314018,141.312375068665 5631.66532158852,141.307654380798 5251.48153781891,141.492705345154 PathPoint;PointKind.SMOOTHPOINT 5645.65602421761,152.296943664551 5653.4295809269,156.509685516357 5632.47964024544,145.155487060547 PathPoint;PointKind.SMOOTHPOINT 5681.65598988533,186.296753883362 5691.92277789116,196.381087303162 5666.64951324463,171.556878089905 PathPoint;PointKind.SMOOTHPOINT 5712.99982309341,232.000093460083 5713.25013756752,241.870107650757 5712.57920980453,215.414428710938 PathPoint;PointKind.SMOOTHPOINT 5715.75363636017,277.568657398224 5715.98978877068,288.301613330841 5715.50013542175,266.039085388184 PathPoint;PointKind.SMOOTHPOINT 5711.65619730949,311.297028064728 5706.50333046913,317.52857208252 5719.09128069878,302.305061817169 PathPoint;PointKind.SMOOTHPOINT 5716.94679021835,337.001645565033 5717.7320766449,379.442045688629 5716.78605079651,328.322896957397 PathPoint;PointKind.SMOOTHPOINT 5718.34175348282,469.386255741119 5718.47239851952,478.326530456543 5717.53168344498,413.891265392303 PathPoint;PointKind.SMOOTHPOINT 5701.6563642025,496.296772956848 5705.14872908592,510.249710083008 5694.44362521172,467.48051404953 PathPoint;PointKind.SMOOTHPOINT 5719.01232719421,516.486682891846 5719.0905725956,522.129085063934 5718.91956567764,509.807145595551 PathPoint;PointKind.SMOOTHPOINT 5719.24741744995,533.573212623596 5719.30866837502,538.049132823944 5719.16917204857,527.824831008911 PathPoint;PointKind.SMOOTHPOINT 5704.65624332428,549.296879768372 5705.29920101166,555.059659481049 5702.93555259705,533.876752853394 PathPoint;PointKind.SMOOTHPOINT 5719.66626048088,564.643363952637 5720.23132681847,607.157170772552 5719.58766102791,558.74368429184 PathPoint;PointKind.SMOOTHPOINT 5716.32790803909,688.343796730042 5716.41854524612,695.840721130371 5715.75505256653,640.907492637634 PathPoint;PointKind.SMOOTHPOINT 5718.65615129471,722.296872138977 5723.96409273148,726.469960212708 5711.27807021141,716.496090888977 PathPoint;PointKind.SMOOTHPOINT 5720.88703036308,741.774430274963 5721.09131813049,759.092037677765 5720.80666065216,734.935097694397 PathPoint;PointKind.SMOOTHPOINT 5721.50060176849,794.549360275269 5721.60398483276,803.570830821991 5721.2956058979,776.688401699066 PathPoint;PointKind.SMOOTHPOINT 5711.65619730949,820.296936035156 5706.95120573044,822.165620326996 5728.19961190224,813.726210594177 PathPoint;PointKind.SMOOTHPOINT 5721.98317408562,837.061042785645 5722.74863362312,905.191662311554 5721.92581772804,831.958923339844 PathPoint;PointKind.SMOOTHPOINT 5724.2912364006,1051.30214452744 5724.3443441391,1056.44344568253 5723.51904988289,976.84839963913 PathPoint;PointKind.SMOOTHPOINT 5718.65615129471,1067.29677915573 5718.70076179504,1071.62895441055 5718.60268950462,1062.12927818298 PathPoint;PointKind.SMOOTHPOINT 5724.58509922028,1079.78889942169 5724.69556331635,1090.52610397339 5724.54048871994,1075.43878555298 PathPoint;PointKind.SMOOTHPOINT 5724.91649150848,1112.16408491135 5725.14414668083,1134.51606988907 5724.80602741241,1101.31854057312 PathPoint;PointKind.SMOOTHPOINT 5725.59981107712,1179.87810373306 5725.68442940712,1188.34300518036 5725.37215590477,1157.0937037468 PathPoint;PointKind.SMOOTHPOINT 5718.65615129471,1204.29680585861 5715.48172473907,1207.82268762589 5723.75307798386,1198.63528490067 PathPoint;PointKind.SMOOTHPOINT 5722.00016856194,1262.9999756813 5722.45158433914,1308.58813047409 5721.95307970047,1258.23892593384 PathPoint;PointKind.SMOOTHPOINT 5743.99987220764,1349.00005102158 5744.06997442245,1356.29563808441 5743.54881048203,1302.01834917068 PathPoint;PointKind.SMOOTHPOINT 5739.65636730194,1379.29671764374 5740.31490325928,1393.20410013199 5739.31010484695,1371.97941541672 PathPoint;PointKind.SMOOTHPOINT 5741.7643904686,1408.89094591141 5741.89007878304,1422.06355333328 5741.69641256332,1401.73839569092 PathPoint;PointKind.SMOOTHPOINT 5742.14074730873,1448.54094743729 5742.20801711082,1455.66116094589 5742.01541304588,1435.28147935867 PathPoint;PointKind.SMOOTHPOINT 5742.65624642372,1461.29671812057 5742.70687580109,1466.63605213165 5742.58897662163,1454.15290117264 PathPoint;PointKind.SMOOTHPOINT 5751.49372816086,1477.97420024872 5751.57516002655,1486.65814161301 5751.44345283508,1472.6221203804 PathPoint;PointKind.SMOOTHPOINT 5751.73837780952,1504.074883461 5751.82228803635,1513.02247524261 5751.65694594383,1495.35860538483 PathPoint;PointKind.SMOOTHPOINT 5738.65652561188,1533.29688549042 5738.74468445778,1542.76280879974 5738.57261538506,1524.31695699692 PathPoint;PointKind.SMOOTHPOINT 5752.2542309761,1559.41550731659 5754.85509395599,1839.75190401077 5752.1660721302,1549.91606712341 PathPoint;PointKind.SMOOTHPOINT 5756.87743663788,2411.67055606842 5757.09128379822,2436.13929748535 5754.42492127419,2131.17271184921 PathPoint;PointKind.SMOOTHPOINT 5760.65622925758,2476.29677295685 5761.0368347168,2519.78705406189 5760.44415235519,2452.05840110779 PathPoint;PointKind.SMOOTHPOINT 5731.00015997887,2585.99989414215 5731.38182759285,2635.2413892746 5730.66947579384,2543.30245256424 PathPoint;PointKind.SMOOTHPOINT 5747.99994707108,2738.99998426437 5748.05942773819,2747.6792049408 5747.67209529877,2691.2308716774 PathPoint;PointKind.SMOOTHPOINT 5735.65629243851,2779.29672002792 5738.33398461342,2787.54919052124 5734.18804049492,2774.77194070816 PathPoint;PointKind.SMOOTHPOINT 5745.0000679493,2843.99988412857 5745.24082303047,2880.50095081329 5744.9434196949,2835.38203239441 PathPoint;PointKind.SMOOTHPOINT 5741.65640473366,2908.29683303833 5741.70951247215,2916.97274923325 5741.4397251606,2872.93652057648 PathPoint;PointKind.SMOOTHPOINT 5729.65653419495,2938.2968044281 5728.40000510216,2953.49199056625 5731.19240999222,2919.71971750259 PathPoint;PointKind.SMOOTHPOINT 5740.99999308586,2968.99992227554 5741.04566574097,2976.66419506073 5740.95715284348,2961.79332017899 PathPoint;PointKind.SMOOTHPOINT 5747.17465281487,2985.14302253723 5747.20226883888,2989.86064195633 5747.12968826294,2977.54247903824 PathPoint;PointKind.SMOOTHPOINT 5739.65636730194,3001.29674434662 5739.6931886673,3007.5426864624 5739.62875127792,2996.60390853882 PathPoint;PointKind.SMOOTHPOINT 5744.65628385544,3024.29687976837 5744.84676361084,3057.00369358063 5744.62017059326,3018.09602022171 PathPoint;PointKind.SMOOTHPOINT 5747.9178071022,3114.07326936722 5747.95073390007,3119.87499475479 5747.73971915245,3082.70783901215 PathPoint;PointKind.SMOOTHPOINT 5737.65632987022,3134.29669618607 5737.70625114441,3143.07693958282 5737.62375712395,3128.5440659523 PathPoint;PointKind.SMOOTHPOINT 5741.16391897202,3158.57188940048 5741.31757736206,3185.71324825287 5741.1150598526,3149.90801095963 PathPoint;PointKind.SMOOTHPOINT 5741.61675095558,3238.21367025375 5741.66667222977,3246.91035747528 5741.46769523621,3212.27679491043 PathPoint;PointKind.SMOOTHPOINT 5737.65632987022,3262.29673147202 5740.43103218079,3271.40364646912 5736.62285327911,3258.90468120575 PathPoint;PointKind.SMOOTHPOINT 5741.93114876747,3292.37907886505 5742.04940199852,3312.39196300507 5741.87627077103,3283.04061412811 PathPoint;PointKind.SMOOTHPOINT 5742.28520035744,3351.12355470657 5742.34043240547,3360.03456115723 5742.16694712639,3331.98163747787 PathPoint;PointKind.SMOOTHPOINT 5735.65629243851,3374.29670333862 5738.41860294342,3379.24492835999 5731.12124562263,3366.17263555527 PathPoint;PointKind.SMOOTHPOINT 5742.55923628807,3394.43610191345 5742.81981825829,3434.58980083466 5742.52312302589,3388.85436058044 PathPoint;PointKind.SMOOTHPOINT 5740.36624073982,3505.99303722382 5740.42218089104,3513.03417921066 5740.08583188057,3470.52816152573 PathPoint;PointKind.SMOOTHPOINT 5734.65645074844,3533.2967877388 5734.7322177887,3542.44548082352 5734.59944844246,3526.45273447037 PathPoint;PointKind.SMOOTHPOINT 5740.76667308807,3553.72981309891 5740.93307733536,3572.38762378693 5740.6880736351,3544.94154453278 PathPoint;PointKind.SMOOTHPOINT 5741.2842965126,3607.18711853027 5741.49035453796,3626.68143510818 5741.10514640808,3590.22214651108 PathPoint;PointKind.SMOOTHPOINT 5745.0000679493,3655.99997520447 5745.13071298599,3665.82821130753 5744.77276682854,3638.8716673851 PathPoint;PointKind.SMOOTHPOINT 5738.99995565414,3691.99994087219 5734.76868510246,3699.8292016983 5748.17732691765,3675.01939058304 PathPoint;PointKind.SMOOTHPOINT 5727.9999268055,3736.00005626678 5696.44649505615,3783.39245796204 5733.57800960541,3727.62225151062 PathPoint;PointKind.SMOOTHPOINT 5625.95765590668,3827.64206171036 4783.76522541046,3816.96056127548 5658.07615399361,3828.04945707321 PathPoint;PointKind.SMOOTHPOINT 239.90606546402,3822.34356164932 239.417474269867,3822.35512733459 826.766048669815,3808.49565982819 PathPoint;PointKind.SMOOTHPOINT 230.184516906738,3783.82322072983 229.514651298523,3781.68687343597 236.411222219467,3803.67560148239 PathPoint;PointKind.SMOOTHPOINT 226.906353235245,3778.34368228912 226.180193424225,3776.25784635544 227.651631832123,3780.48545837402 PathPoint;PointKind.SMOOTHPOINT 225.774096250534,3771.18121862411 222.234288454056,3762.10262775421 226.573190689087,3773.23117733002 PathPoint;PointKind.SMOOTHPOINT 212.906091213226,3747.3436331749 212.215336561203,3746.49343729019 217.968320846558,3753.57281684875 PathPoint;PointKind.SMOOTHPOINT 227.906194925308,3696.34391784668 226.427675485611,3689.95281457901 232.244743108749,3715.09850263596 PathPoint;PointKind.SMOOTHPOINT 228.906036615372,3672.34394073486 228.540301322937,3670.39972543716 230.918819904327,3683.03606271744 PathPoint;PointKind.SMOOTHPOINT 223.906120061874,3657.34371900558 221.46564245224,3643.9279961586 224.254860877991,3659.26079034805 PathPoint;PointKind.SMOOTHPOINT 222.906278371811,3634.34381961823 221.98468208313,3617.22282886505 223.010723590851,3636.28355026245 PathPoint;PointKind.SMOOTHPOINT 219.28893327713,3569.97558832169 219.236179590225,3554.90762472153 219.362930059433,3591.09476566315 PathPoint;PointKind.SMOOTHPOINT 217.656047344208,3526.29695177078 214.579339027405,3515.74739456177 219.869931936264,3533.88758182526 PathPoint;PointKind.SMOOTHPOINT 218.946211338043,3464.20692443848 218.745818138123,3412.31169462204 219.090664386749,3501.61861181259 PathPoint;PointKind.SMOOTHPOINT 213.90628695488,3253.34371089935 213.849638700485,3240.69486379623 214.392399787903,3361.94643974304 PathPoint;PointKind.SMOOTHPOINT 205.72557091713,3203.4568977356 207.775883674622,3191.84660196304 203.413968086243,3216.54901742935 PathPoint;PointKind.SMOOTHPOINT 205.492959022522,3173.15551042557 205.444808006287,3162.64419078827 205.572974681854,3190.73346376419 PathPoint;PointKind.SMOOTHPOINT 207.346419095993,3139.12383556366 207.297559976578,3128.51786613464 207.395986318588,3149.96513128281 PathPoint;PointKind.SMOOTHPOINT 219.656084775925,3117.29702711105 212.719506025314,3101.31183385849 226.170279979706,3132.3088145256 PathPoint;PointKind.SMOOTHPOINT 207.144255638123,3074.21791791916 207.102123498917,3065.09306430817 207.162312269211,3078.11224937439 PathPoint;PointKind.SMOOTHPOINT 207.016088962555,3046.54052495956 206.987056732178,3040.25587320328 207.059283256531,3055.86624383926 PathPoint;PointKind.SMOOTHPOINT 225.656197071075,3028.29695463181 226.353678703308,3006.46188497543 225.171146392822,3043.47892284393 PathPoint;PointKind.SMOOTHPOINT 194.000090360641,2977.99991369247 196.81055188179,2960.5015039444 192.681248188019,2986.20871782303 PathPoint;PointKind.SMOOTHPOINT 199.357244968414,2906.92358493805 199.306615591049,2896.19912624359 199.514443874359,2940.16053199768 PathPoint;PointKind.SMOOTHPOINT 206.65601849556,2869.29687023163 204.304761886597,2859.46013689041 209.192444086075,2879.90756034851 PathPoint;PointKind.SMOOTHPOINT 199.034703969955,2838.94284725189 198.88281583786,2807.11408138275 199.09135222435,2850.88783979416 PathPoint;PointKind.SMOOTHPOINT 186.328146457672,2753.34355831146 186.260168552399,2739.24664020538 186.488177776337,2786.52834177017 PathPoint;PointKind.SMOOTHPOINT 186.65635228157,2703.29671382904 186.595809459686,2690.81851959229 186.725746393204,2717.61857271194 PathPoint;PointKind.SMOOTHPOINT 191.328063011169,2669.3436384201 191.613782644272,2665.53616762161 190.381683111191,2681.94858312607 PathPoint;PointKind.SMOOTHPOINT 192.327904701233,2652.3437333107 193.677903413773,2643.17025661469 191.279203891754,2659.4712638855 PathPoint;PointKind.SMOOTHPOINT 189.328025579453,2637.34374761581 188.953793048859,2632.28010177612 189.66118812561,2641.84846401215 PathPoint;PointKind.SMOOTHPOINT 189.328025579453,2626.34360074997 191.22220158577,2623.05469751358 188.163195848465,2628.36641550064 PathPoint;PointKind.SMOOTHPOINT 194.32794213295,2611.34361505508 193.606739044189,2604.56234693527 195.493125915527,2622.29655504227 PathPoint;PointKind.SMOOTHPOINT 180.328034162521,2566.34365797043 180.417963266373,2556.00110292435 180.298293828964,2569.78079080582 PathPoint;PointKind.SMOOTHPOINT 179.328192472458,2480.34358263016 179.31084394455,2479.52241897583 179.771465063095,2501.46818876266 PathPoint;PointKind.SMOOTHPOINT 181.120401620865,2447.3370051384 179.268711805344,2075.58779239655 181.162179708481,2455.71646213531 PathPoint;PointKind.SMOOTHPOINT 190.898952484131,1289.70962762833 190.677670240402,1251.79235458374 193.08557510376,1664.73358154297 PathPoint;PointKind.SMOOTHPOINT 195.235730409622,1177.29824781418 195.138366222382,1160.97694158554 195.456658601761,1214.29262638092 PathPoint;PointKind.SMOOTHPOINT 199.656064510345,1128.29703569412 196.655123233795,1115.89791297913 203.447248935699,1143.96216630936 PathPoint;PointKind.SMOOTHPOINT 194.619326591492,1075.25633096695 194.315550327301,1025.58407306671 194.727312326431,1092.91193962097 PathPoint;PointKind.SMOOTHPOINT 193.712600469589,929.827044010162 193.661262989044,921.784644126892 194.01283621788,977.030618190765 PathPoint;PointKind.SMOOTHPOINT 193.558942079544,905.8180975914 189.808119535446,897.090017795563 198.201620578766,916.621155738831 PathPoint;PointKind.SMOOTHPOINT 196.327979564667,847.343881130219 195.854612588882,774.219954013824 196.388876438141,856.726720333099 PathPoint;PointKind.SMOOTHPOINT 192.97758936882,684.852375984192 192.929438352585,678.001005649567 193.435732126236,749.849638938904 PathPoint;PointKind.SMOOTHPOINT 196.327979564667,661.343822479248 192.286480665207,655.679941177368 201.078997850418,668.001644611359 PathPoint;PointKind.SMOOTHPOINT 194.32794213295,629.343931674957 194.12223815918,600.771968364716 194.377155303955,636.191289424896 PathPoint;PointKind.SMOOTHPOINT 198.074516057968,532.021522521973 197.986357212067,520.385735034943 198.275617361069,558.567838668823 PathPoint;PointKind.SMOOTHPOINT 205.656176805496,502.297003269196 208.573207855225,495.158851146698 201.410390138626,512.686293125153 PathPoint;PointKind.SMOOTHPOINT 193.571333885193,462.178001403809 193.481758832932,450.929546356201 193.650995492935,472.17901468277 PathPoint;PointKind.SMOOTHPOINT 198.656222820282,429.29699420929 198.56983423233,418.777885437012 198.744381666183,440.069603919983 PathPoint;PointKind.SMOOTHPOINT 196.327979564667,381.343774795532 195.542339086533,288.646695613861 196.413305997849,391.394119262695 PathPoint;PointKind.SMOOTHPOINT 196.327979564667,266.343805789948 196.158034801483,254.454753398895 196.989347934723,312.62542963028 PathPoint;PointKind.SMOOTHPOINT 199.327858686447,185.343883037567 199.230848550797,180.273864269257 199.487890005112,193.680617809296 PathPoint;PointKind.SMOOTHPOINT 191.906229257584,164.343667030334 196.055713891983,153.242969512939 188.328183889389,173.914389610291 PathPoint";
	
	subshadow35mm[0] = "PointKind.CORNERPOINT 190.780915737152,140.953079223633 190.780915737152,140.953079223633 190.780915737152,140.953079223633 PathPoint;PointKind.SMOOTHPOINT 210.781290054321,130.953010082245 228.984144449234,130.303443431854 199.970678806305,131.338454246521 PathPoint;PointKind.SMOOTHPOINT 1398.78148984909,132.953165531158 1437.57492256165,132.510601043701 1359.98770308495,133.395730018616 PathPoint;PointKind.SMOOTHPOINT 4638.78123235703,138.953159809113 4683.90015077591,136.633885860443 4593.66266798973,141.272433757782 PathPoint;PointKind.SMOOTHPOINT 5639.78137922287,135.953162670135 5646.70875263214,135.983611106873 5605.38809967041,135.802100658417 PathPoint;PointKind.SMOOTHPOINT 5679.28125,152.140625 5685.07530426979,154.681299209595 5662.39652967453,144.736934185028 PathPoint;PointKind.SMOOTHPOINT 5711.28138971329,217.140732765198 5711.66341137886,229.195717334747 5711.07108306885,210.499433040619 PathPoint;PointKind.SMOOTHPOINT 5716.28130626678,260.14053440094 5716.73095178604,277.942012310028 5715.90176296234,245.128274917603 PathPoint;PointKind.SMOOTHPOINT 5718.2813436985,326.140707492828 5725.34361076355,339.681292533875 5711.21907663345,312.599886417389 PathPoint;PointKind.SMOOTHPOINT 5714.8445649147,385.691240787506 5722.61245679855,401.420572757721 5707.07702708244,369.961908817291 PathPoint;PointKind.SMOOTHPOINT 5715.76793146133,463.817208766937 5722.63759446144,482.977772712708 5708.89791440964,444.656644821167 PathPoint;PointKind.SMOOTHPOINT 5716.69377636909,548.279992103577 5722.02473115921,563.913258075714 5711.36317563057,532.646962165833 PathPoint;PointKind.SMOOTHPOINT 5717.4029417038,616.36954164505 5722.78983664513,638.536475658417 5712.01569271088,594.202607631683 PathPoint;PointKind.SMOOTHPOINT 5719.28118538857,701.140585899353 5727.53802251816,726.049295425415 5711.02434825897,676.231876373291 PathPoint;PointKind.SMOOTHPOINT 5719.00856566429,779.801171779633 5724.34766364098,805.44748878479 5713.6698217392,754.154854774475 PathPoint;PointKind.SMOOTHPOINT 5719.92378902435,877.838529109955 5730.85831832886,899.780994415283 5708.98961377144,855.896063804626 PathPoint;PointKind.SMOOTHPOINT 5718.28125,935.140625 5722.89135575294,948.508668899536 5716.64340734482,930.390668869019 PathPoint;PointKind.SMOOTHPOINT 5726.28113937378,1018.14067697525 5737.59698224068,1041.11366844177 5720.74554276466,1006.90284347534 PathPoint;PointKind.SMOOTHPOINT 5728.2811768055,1110.14051055908 5733.34517669678,1127.56598567963 5722.04455804825,1088.67908334732 PathPoint;PointKind.SMOOTHPOINT 5724.28110194206,1200.14066076279 5724.27862358093,1205.56142663956 5724.29101538658,1178.56168842316 PathPoint;PointKind.SMOOTHPOINT 5727.28125,1219.140625 5736.19556093216,1234.97428417206 5725.60481572151,1216.16305112839 PathPoint;PointKind.SMOOTHPOINT 5743.28125,1261.140625 5744.606094586,1265.4572164101 5734.6717774868,1233.08911752701 PathPoint;PointKind.SMOOTHPOINT 5741.28125,1292.140625 5741.99325579068,1319.98987759489 5740.87865029733,1276.39342046742 PathPoint;PointKind.SMOOTHPOINT 5747.28125,1350.140625 5748.89868780528,1340.58238583447 5746.24803682251,1356.24639217518 PathPoint;PointKind.SMOOTHPOINT 5738.28125,1401.140625 5738.7691706681,1404.05650262325 5738.10245245885,1400.07210754745 PathPoint;PointKind.CORNERPOINT 5744.28125,1463.140625 5744.28125,1463.140625 5744.28125,1463.140625 PathPoint;PointKind.CORNERPOINT 5753.28125,1513.140625 5753.28125,1513.140625 5753.28125,1513.140625 PathPoint;PointKind.CORNERPOINT 5766.28125,2463.140625 5766.28125,2463.140625 5766.28125,2463.140625 PathPoint;PointKind.SMOOTHPOINT 5759.28125,2537.140625 5754.16310428658,2547.04377809216 5769.32780548887,2517.70144084503 PathPoint;PointKind.SMOOTHPOINT 5750.28125,2576.140625 5750.07377576828,2580.59105348587 5752.49796700478,2528.62005662918 PathPoint;PointKind.SMOOTHPOINT 5752.28127193451,2611.14057397842 5751.12033677101,2617.82270765305 5753.44185304642,2604.4584403038 PathPoint;PointKind.SMOOTHPOINT 5755.28115105629,2642.14062309265 5755.19086790085,2644.86091947556 5755.61325144768,2632.16014480591 PathPoint;PointKind.SMOOTHPOINT 5756.28134679794,2683.14074134827 5757.87103843689,2689.61469268799 5752.80774664879,2668.99685239792 PathPoint;PointKind.SMOOTHPOINT 5744.98426866531,2731.4439997673 5747.05263805389,2736.43966770172 5742.59619069099,2725.67555522919 PathPoint;PointKind.SMOOTHPOINT 5737.28125,2798.140625 5739.04867553711,2817.5860824585 5736.03357219696,2784.40885210037 PathPoint;PointKind.SMOOTHPOINT 5739.13427424431,2864.4033536911 5731.23007249832,2884.51773262024 5747.03812193871,2844.28873872757 PathPoint;PointKind.SMOOTHPOINT 5739.74041056633,2931.75623989105 5729.79226899147,2954.84512424469 5749.68855214119,2908.66735553741 PathPoint;PointKind.SMOOTHPOINT 5740.39469790459,3004.46026182175 5735.24006080627,3028.65543937683 5745.54898095131,2980.26508426666 PathPoint;PointKind.SMOOTHPOINT 5738.85103297234,3053.83936500549 5735.86389970779,3064.08254957199 5745.19138884544,3032.09776496887 PathPoint;PointKind.SMOOTHPOINT 5746.28115963936,3083.14067459106 5747.30826330185,3098.89313793182 5745.65484237671,3073.53077030182 PathPoint;PointKind.SMOOTHPOINT 5738.28125,3127.140625 5739.07928228378,3154.175532341 5737.73388624191,3108.59233427048 PathPoint;PointKind.SMOOTHPOINT 5746.28115963936,3223.14069843292 5737.75170278549,3243.12714672089 5754.81026244164,3203.15448617935 PathPoint;PointKind.SMOOTHPOINT 5742.82490801811,3274.48077535629 5737.79064846039,3298.61977672577 5747.85916757584,3250.34153795242 PathPoint;PointKind.SMOOTHPOINT 5741.28124308586,3312.14053487778 5737.66637635231,3321.1690864563 5750.56412172318,3288.95534849167 PathPoint;PointKind.SMOOTHPOINT 5742.28108477592,3351.14073371887 5742.44359445572,3352.92963838577 5740.64395022392,3333.10510969162 PathPoint;PointKind.SMOOTHPOINT 5744.28125,3369.140625 5748.49375581741,3378.58152866364 5740.06874418259,3359.69948530197 PathPoint;PointKind.SMOOTHPOINT 5740.28125,3407.140625 5734.53357648849,3426.37341547012 5743.56861901283,3396.14024209976 PathPoint;PointKind.SMOOTHPOINT 5740.28125,3497.140625 5733.1467564106,3528.57521343231 5747.4157435894,3465.70603656769 PathPoint;PointKind.SMOOTHPOINT 5745.24555873871,3543.44314670563 5739.44973421097,3562.11464738846 5751.04102921486,3524.7716460228 PathPoint;PointKind.SMOOTHPOINT 5745.78088474274,3602.95308208466 5739.80874252319,3621.22379636765 5751.75302696228,3584.68236780167 PathPoint;PointKind.SMOOTHPOINT 5743.61019444466,3655.19622659683 5737.27762770653,3670.17190074921 5749.94311523438,3640.22031641006 PathPoint;PointKind.SMOOTHPOINT 5734.28125,3715.140625 5727.78015470505,3730.58931207657 5740.78269934654,3699.69193792343 PathPoint;PointKind.SMOOTHPOINT 5671.28125,3812.140625 5657.97875978256,3827.19729158666 5705.31680961987,3773.61847069271 PathPoint;PointKind.SMOOTHPOINT 5632.78142523766,3829.14059257507 5573.36590361595,3828.03335523605 5646.47047591209,3829.39621782303 PathPoint;PointKind.CORNERPOINT 3747.78137397766,3821.95310926437 3747.78137397766,3821.95310926437 3747.78137397766,3821.95310926437 PathPoint;PointKind.CORNERPOINT 1709.78146862984,3821.95310926437 1709.78146862984,3821.95310926437 1709.78146862984,3821.95310926437 PathPoint;PointKind.CORNERPOINT 239.781218290329,3820.95303153992 239.781218290329,3820.95303153992 239.781218290329,3820.95303153992 PathPoint;PointKind.SMOOTHPOINT 223.781160593033,3793.95305728912 223.534740686417,3790.8454284668 224.645046472549,3804.83542299271 PathPoint;PointKind.SMOOTHPOINT 222.310430288315,3683.56378412247 216.035219907761,3668.18260288239 228.585640668869,3698.94472932816 PathPoint;PointKind.SMOOTHPOINT 221.74040722847,3628.19530820847 216.800679445267,3618.02718257904 226.679780960083,3638.36343383789 PathPoint;PointKind.SMOOTHPOINT 221.194459676743,3572.91487312317 215.950601577759,3564.8299870491 226.438317775726,3580.99999523163 PathPoint;PointKind.SMOOTHPOINT 220.431832551956,3493.11919784546 214.063860654831,3481.80111265182 226.799804449081,3504.4370470047 PathPoint;PointKind.SMOOTHPOINT 219.87349319458,3433.31233119965 213.366379022598,3422.30392313004 226.380607366562,3444.32097530365 PathPoint;PointKind.SMOOTHPOINT 219.199024915695,3359.84001731873 214.991475820541,3349.54797363281 223.406574010849,3370.13182497025 PathPoint;PointKind.SMOOTHPOINT 218.537302494049,3286.67006349564 213.546237230301,3276.4141330719 223.528721809387,3296.92575788498 PathPoint;PointKind.SMOOTHPOINT 217.80335354805,3204.49634170532 211.672596216202,3196.41145563126 223.934110879898,3212.58146381378 PathPoint;PointKind.SMOOTHPOINT 216.957878351212,3108.71146059036 210.321889400482,3101.41540145874 223.593867301941,3116.00751972198 PathPoint;PointKind.SMOOTHPOINT 216.170467615128,3018.57181406021 211.808197975159,3009.69267225266 220.532383203506,3027.45071983337 PathPoint;PointKind.SMOOTHPOINT 215.578847408295,2950.32648181915 207.220397472382,2941.47849655151 223.936943292618,2959.17470312119 PathPoint;PointKind.SMOOTHPOINT 215.126369476318,2897.85603618622 213.274679660797,2894.54541778564 220.932461500168,2908.23564863205 PathPoint;PointKind.SMOOTHPOINT 207.281294345856,2845.14058685303 202.391487836838,2828.24642515182 212.769802093506,2864.10288190842 PathPoint;PointKind.SMOOTHPOINT 212.281210899353,2806.14062404633 210.454658746719,2785.72058057785 213.65776348114,2821.53124666214 PathPoint;PointKind.SMOOTHPOINT 199.281144618988,2778.14057207108 189.953655481339,2768.97795295715 202.903800487518,2781.69879055023 PathPoint;PointKind.CORNERPOINT 180.28125,2473.140625 180.28125,2473.140625 180.28125,2473.140625 PathPoint;PointKind.SMOOTHPOINT 173.542116059926,1491.15253658923 173.479736636215,1482.06296341991 174.811467722929,1676.11520748393 PathPoint;PointKind.SMOOTHPOINT 176,1469 175.931580058236,1459.03023705718 176.040943603259,1474.9660679035 PathPoint;PointKind.CORNERPOINT 176,1453 176,1453 176,1453 PathPoint;PointKind.SMOOTHPOINT 178,1433 180.027741938983,1425.52191690614 173.408902789467,1449.93144762276 PathPoint;PointKind.SMOOTHPOINT 179,1400 179.276597252218,1390.14837795128 178.569244140538,1415.34232133063 PathPoint;PointKind.SMOOTHPOINT 178.957309188941,1364.26379513534 180.237447299247,1359.75430734207 174.680919097919,1379.32805168661 PathPoint;PointKind.SMOOTHPOINT 178,1347 181.618635578884,1323.52174587445 176.959663374266,1353.74986114038 PathPoint;PointKind.SMOOTHPOINT 176,1287 175.983662435698,1282.92299525621 176.100952609915,1312.22227589677 PathPoint;PointKind.SMOOTHPOINT 189,1263 197.055065741901,1252.96704970679 181.515046168013,1272.32285001135 PathPoint;PointKind.SMOOTHPOINT 198.281144618988,1220.14056301117 199.754353284836,1207.25591754913 196.834984743494,1232.79022220263 PathPoint;PointKind.SMOOTHPOINT 205.281098604202,1178.14060306549 204.450493574142,1171.02204179764 206.776966571808,1190.95750665665 PathPoint;PointKind.SMOOTHPOINT 194.867025136948,1161.5742931366 194.745231389999,1131.13718605042 194.876584529877,1163.98113584518 PathPoint;PointKind.SMOOTHPOINT 194.477922439575,1064.42749357224 198.340271234512,1050.04591798782 190.615927696228,1078.80883312225 PathPoint;PointKind.SMOOTHPOINT 194.053060531616,958.221930027008 199.675399780273,946.307385921478 188.430367231369,970.136474132538 PathPoint;PointKind.SMOOTHPOINT 193.765924692154,886.535688400269 199.029255628586,871.466072559357 188.502593755722,901.605540275574 PathPoint;PointKind.SMOOTHPOINT 193.422848701477,800.883999824524 199.490230798721,785.351284503937 187.355820655823,816.416715145111 PathPoint;PointKind.SMOOTHPOINT 193.08189702034,715.674875736237 197.473906993866,696.621235370636 188.689887046814,734.728280067444 PathPoint;PointKind.SMOOTHPOINT 192.740591287613,630.434123039246 197.339721441269,621.260646343231 188.141461133957,639.60759973526 PathPoint;PointKind.SMOOTHPOINT 192.442833900452,556.042691230774 196.524340629578,545.316108226776 188.361327171326,566.769510269165 PathPoint;PointKind.SMOOTHPOINT 192.203849077225,496.391607284546 197.887439250946,486.170609951019 186.520612955093,506.612840652466 PathPoint;PointKind.SMOOTHPOINT 191.900426864624,420.516463279724 196.615331888199,404.977611064911 187.185167789459,436.055079460144 PathPoint;PointKind.SMOOTHPOINT 191.596296548843,344.582546710968 198.412851810455,338.576651573181 184.779741287231,350.588677883148 PathPoint;PointKind.SMOOTHPOINT 191.336776733398,279.753340244293 195.393853902817,268.752485275269 187.27969956398,290.754195213318 PathPoint;PointKind.SMOOTHPOINT 191.128948450089,227.842768192291 193.638820171356,216.872361660004 188.619076728821,238.813174724579 PathPoint";
	
} else if (mask_variant_35mm == 2) {	

	mask35mm[0] = "PointKind.CORNERPOINT 5661.409306881,3828.49960836333 5661.409306881,3828.49960836333 5661.409306881,3828.49960836333 PathPoint;PointKind.SMOOTHPOINT 5409.72248622482,3827.6781044547 5398.76120440755,3827.8542025505 5474.71728621642,3826.63393273226 PathPoint;PointKind.SMOOTHPOINT 5385.84773554993,3827.50517369938 5369.56580695729,3830.52612177081 5388.197393452,3827.06921831071 PathPoint;PointKind.SMOOTHPOINT 5357.7124982371,3839 5349.73322028774,3838.50822595433 5365.69177618646,3839.49177404567 PathPoint;PointKind.SMOOTHPOINT 5324.12835255629,3833.06728273724 5313.3234547677,3833.3013032445 5334.93325034488,3832.83326222998 PathPoint;PointKind.SMOOTHPOINT 5224.64306745255,3829.35349918223 5204.81698175167,3830.55465404005 5244.46915315343,3828.15234432442 PathPoint;PointKind.SMOOTHPOINT 5193.79769053912,3830.13160476034 5189.6871251554,3828.93593406955 5207.88251386424,3834.2285619579 PathPoint;PointKind.SMOOTHPOINT 5183.89997879977,3823.0492289861 5176.17580997861,3820.20914346905 5187.08324327527,3824.21967768332 PathPoint;PointKind.SMOOTHPOINT 5160.03954270827,3820.87334928996 5146.97399622954,3820.33274137757 5169.29199321588,3821.25618424919 PathPoint;PointKind.SMOOTHPOINT 5087.41612959356,3826.34942300886 5065.25027667828,3825.32116267996 5109.58198250884,3827.37768333775 PathPoint;PointKind.SMOOTHPOINT 5018.76906411155,3826.85372155771 4987.1126586805,3827.0767733158 5050.4254695426,3826.63066979962 PathPoint;PointKind.SMOOTHPOINT 4913.52780303169,3823.09467445071 4884.63695567098,3822.59198103723 4942.41865039241,3823.59736786419 PathPoint;PointKind.SMOOTHPOINT 4769.68725227295,3822.09599614782 4717.74850797605,3820.6461509313 4821.62599656985,3823.54584136434 PathPoint;PointKind.SMOOTHPOINT 4669.58311849356,3827.28266614852 4657.92121983917,3826.84344087536 4681.24501714794,3827.72189142169 PathPoint;PointKind.SMOOTHPOINT 4649.64454918098,3833.1474040082 4637.69713433178,3833.50179619777 4661.59196403019,3832.79301181864 PathPoint;PointKind.SMOOTHPOINT 4595.95498932925,3828.75241192709 4582.6416626875,3828.37009166767 4609.268315971,3829.13473218652 PathPoint;PointKind.SMOOTHPOINT 4570.12553104587,3825.58790173934 4555.31684119309,3826.35772051443 4584.93422089864,3824.81808296425 PathPoint;PointKind.SMOOTHPOINT 4495.89420393217,3824.0933527536 4473.05765107546,3823.80349740847 4518.73075678887,3824.38320809874 PathPoint;PointKind.SMOOTHPOINT 3923.50771960918,3823.9167108392 3895.94900163453,3823.50491862242 3951.06643758382,3824.32850305597 PathPoint;PointKind.SMOOTHPOINT 3851.8834675845,3823.39791857322 3837.82349150466,3823.13574752622 3865.94344366434,3823.66008962023 PathPoint;PointKind.SMOOTHPOINT 3819.06999998991,3821.15718984384 3793.98992878572,3821.00362522547 3844.1500711941,3821.3107544622 PathPoint;PointKind.SMOOTHPOINT 3722.13124122996,3821.09731784493 3708.09350726876,3820.50730070398 3736.16897519116,3821.68733498588 PathPoint;PointKind.SMOOTHPOINT 3649.71496395142,3820.09863954204 3626.18210854276,3820.07196740335 3673.24781936008,3820.12531168073 PathPoint;PointKind.SMOOTHPOINT 3456.96961475404,3818.53440672142 3427.96565255388,3818.54036367891 3485.9735769542,3818.52844976394 PathPoint;PointKind.SMOOTHPOINT 3092.86535237855,3817.90016164355 3080.46824887075,3818.09072981637 3105.26245588635,3817.70959347073 PathPoint;PointKind.SMOOTHPOINT 3067.99582042554,3817.72002544009 3053.60363706264,3818.01182836444 3082.38800378843,3817.42822251574 PathPoint;PointKind.SMOOTHPOINT 3046.12494689027,3815.55855664022 3035.0667784471,3815.54592539306 3057.18311533345,3815.57118788739 PathPoint;PointKind.SMOOTHPOINT 3028.20456930072,3817.43180751455 3008.39476336092,3818.19732155487 3048.01437524052,3816.66629347422 PathPoint;PointKind.SMOOTHPOINT 2943.64100336878,3817.82081889318 2926.0334472317,3817.49957897821 2961.24855950586,3818.14205880816 PathPoint;PointKind.SMOOTHPOINT 2798.40293676318,3816.76882346496 2772.95615243611,3819.59280329541 2823.84972109026,3813.94484363451 PathPoint;PointKind.SMOOTHPOINT 2577.55433572874,3816.17068844862 2552.86477513535,3815.64909333999 2602.24389632212,3816.69228355726 PathPoint;PointKind.SMOOTHPOINT 2484.0520528771,3814.4919018532 2476.5404821416,3814.20142223784 2491.56362361261,3814.78238146856 PathPoint;PointKind.SMOOTHPOINT 2423.38470949514,3812.04942057593 2402.5799657794,3813.45929097205 2444.18945321088,3810.63955017982 PathPoint;PointKind.SMOOTHPOINT 2383.57198649524,3814.76562606162 2370.22263134998,3816.67173722993 2396.9213416405,3812.8595148933 PathPoint;PointKind.SMOOTHPOINT 2259.21716943848,3814.86641951471 2245.08945949399,3815.15065909277 2273.34487938297,3814.58217993666 PathPoint;PointKind.SMOOTHPOINT 2238.32676259795,3814.7151051038 2227.95579578556,3814.57289947962 2248.69772941034,3814.85731072798 PathPoint;PointKind.SMOOTHPOINT 2201.5055407241,3816.4514524635 2167.93776834555,3816.87307295145 2235.07331310266,3816.02983197555 PathPoint;PointKind.SMOOTHPOINT 2133.85325652021,3816.96295646049 2116.57396685885,3818.04346333742 2151.13254618158,3815.88244958355 PathPoint;PointKind.SMOOTHPOINT 2078.15981952885,3814.55650242391 2059.82111878553,3814.35213306097 2096.49852027218,3814.76087178685 PathPoint;PointKind.SMOOTHPOINT 1993.60341088861,3813.94403933214 1984.49566174997,3813.61513483684 2022.50059818719,3814.98759187837 PathPoint;PointKind.SMOOTHPOINT 1967.7104684907,3817.76259556217 1960.2657431058,3821.7308380574 1975.1551938756,3813.79435306694 PathPoint;PointKind.SMOOTHPOINT 1941.83899796787,3818.57672838098 1933.39558010067,3818.8813949089 1948.27798569192,3818.34438834238 PathPoint;PointKind.SMOOTHPOINT 1922.95962555867,3815.43540145512 1869.70694902332,3821.10952519598 1932.4231537893,3814.42705344899 PathPoint;PointKind.SMOOTHPOINT 1849.36012556114,3812.89924935206 1835.66535264789,3812.40099433758 1863.05489847438,3813.39750436654 PathPoint;PointKind.SMOOTHPOINT 1782.70977992706,3812.41648432678 1750.07741554524,3812.2995238879 1815.34214430889,3812.53344476566 PathPoint;PointKind.SMOOTHPOINT 1707.07777362313,3815.87476814989 1671.9225542359,3822.30410330358 1742.23299301036,3809.44543299619 PathPoint;PointKind.SMOOTHPOINT 1657.33155242541,3816.51597021337 1629.55258038001,3815.92866144918 1685.1105244708,3817.10327897756 PathPoint;PointKind.SMOOTHPOINT 1587.67539108189,3819.0160122549 1550.06418440312,3816.71290706633 1625.28659776066,3821.31911744347 PathPoint;PointKind.SMOOTHPOINT 1466.31207515119,3818.136947582 1428.23578508988,3819.54445835917 1504.3883652125,3816.72943680483 PathPoint;PointKind.SMOOTHPOINT 1410.62579545152,3814.72901907502 1408.19062468361,3814.87563474872 1430.36583427311,3813.54051963643 PathPoint;PointKind.SMOOTHPOINT 1390.70154072234,3818.59080799389 1366.14820258088,3821.22141487183 1415.25487886379,3815.96020111594 PathPoint;PointKind.SMOOTHPOINT 1229.53981637512,3818.42499986586 1200.47478342924,3818.0183484792 1258.604849321,3818.83165125252 PathPoint;PointKind.SMOOTHPOINT 1183.77272028988,3819.09502372189 1181.15016692821,3819.39421636531 1195.00069617765,3817.81408590186 PathPoint;PointKind.SMOOTHPOINT 1173.85353667545,3815.01707135888 1167.60060793421,3813.41904011151 1177.69885983639,3815.99980230332 PathPoint;PointKind.SMOOTHPOINT 1152.03276418205,3812.8360293864 1143.88690472767,3811.1127628048 1160.03546492852,3814.52901056735 PathPoint;PointKind.SMOOTHPOINT 1127.18470410412,3809.65146977171 1106.15164502422,3809.82088415664 1135.31630912298,3809.5859723632 PathPoint;PointKind.SMOOTHPOINT 1060.54151576174,3808.16723027602 1037.95954906465,3808.25676510084 1089.24943170395,3808.05340678761 PathPoint;PointKind.SMOOTHPOINT 1006.78754028476,3812.78550842858 1002.29003501174,3813.8504982759 1012.48191361901,3811.43710538741 PathPoint;PointKind.SMOOTHPOINT 989.776056472996,3819.6929102757 985.385508222301,3819.96077421806 994.317280908374,3819.41585369622 PathPoint;PointKind.SMOOTHPOINT 971.905779925296,3814.55583985717 967.935463480393,3811.60543976359 978.269445380803,3819.28477252942 PathPoint;PointKind.SMOOTHPOINT 956.955431586713,3818.45365601673 941.925603963352,3817.38992006903 961.936073455578,3818.80616091108 PathPoint;PointKind.SMOOTHPOINT 905.226805124447,3818.07897271352 897.103152994175,3818.56747260406 924.381808757392,3816.92712413262 PathPoint;PointKind.SMOOTHPOINT 865.211667326236,3819.50993797863 860.08803715224,3819.72832594113 882.261769106406,3818.78319993125 PathPoint;PointKind.SMOOTHPOINT 832.622086405037,3815.5500260586 828.359347941109,3814.56911424653 843.633626807743,3818.08392536804 PathPoint;PointKind.SMOOTHPOINT 811.717364981119,3817.4016605885 783.198487113301,3817.28531719943 820.499450268107,3817.43748729845 PathPoint;PointKind.SMOOTHPOINT 727.153799049182,3817.79067196714 700.956166840882,3817.91977152273 739.038435226016,3817.73210555791 PathPoint;PointKind.SMOOTHPOINT 643.568825008411,3817.07733260143 639.119803253488,3817.05767406263 665.395674265067,3817.17377716535 PathPoint;PointKind.SMOOTHPOINT 626.63607140528,3819.9592633943 620.686239141498,3820.08849398985 633.16507695618,3819.81745313171 PathPoint;PointKind.SMOOTHPOINT 607.742384412685,3818.82088540926 603.768434319189,3818.70921975421 614.492582367229,3819.01056199266 PathPoint;PointKind.SMOOTHPOINT 592.806350657489,3820.715752628 584.27117982613,3820.46146847291 596.840817296283,3820.83594951225 PathPoint;PointKind.SMOOTHPOINT 569.962167719187,3815.54265496877 562.354613732454,3812.90635095513 575.687911300311,3817.52684079385 PathPoint;PointKind.SMOOTHPOINT 550.05222757339,3817.40149494682 532.112283494836,3817.50664097227 554.890904175843,3817.37313545969 PathPoint;PointKind.SMOOTHPOINT 509.280509753836,3815.10312263232 492.806287459423,3814.68828490236 542.166991336818,3815.93123780052 PathPoint;PointKind.SMOOTHPOINT 484.475393426068,3805.90971619519 480.197810186283,3804.14174552432 488.769126295872,3807.68436167999 PathPoint;PointKind.SMOOTHPOINT 466.555015836511,3807.78296706951 455.90366963589,3807.99501139565 475.64996280317,3807.60190714859 PathPoint;PointKind.SMOOTHPOINT 442.716051620088,3802.60266396215 437.509593813256,3801.92090571991 450.038992007971,3803.56156445689 PathPoint;PointKind.SMOOTHPOINT 423.800892752411,3804.46870938833 406.231639104751,3803.89451115776 431.101608747904,3804.70731133982 PathPoint;PointKind.SMOOTHPOINT 384.002484335897,3805.1819659332 362.730052676655,3805.7569682398 405.274915995139,3804.6069636266 PathPoint;PointKind.SMOOTHPOINT 342.250299821611,3800.87343922975 337.80066200607,3800.94337717054 349.793029709485,3800.75488508711 PathPoint;PointKind.SMOOTHPOINT 322.304573217343,3807.73965155984 319.493535062276,3808.99987786801 331.52293757671,3803.60693451966 PathPoint;PointKind.SMOOTHPOINT 311.361979158017,3807.66039163031 309.120228395937,3811.25057712958 313.221975361019,3804.6815897449 PathPoint;PointKind.SMOOTHPOINT 300.369284056835,3814.59145299365 297.675849498702,3815.261964555 304.204272855706,3813.63675954488 PathPoint;PointKind.SMOOTHPOINT 289.383746247346,3820.52103988657 281.704567838956,3819.60512004728 295.778924459575,3821.283812971 PathPoint;PointKind.SMOOTHPOINT 269.538221726793,3813.36660963094 267.548574312457,3813.23498860606 281.466087886613,3814.15567303856 PathPoint;PointKind.SMOOTHPOINT 261.630072543686,3806.29864475298 258.827478115545,3804.69859579598 264.618453541918,3808.00476243141 PathPoint;PointKind.SMOOTHPOINT 255.67569945835,3804.25246312333 254.242879089069,3800.28379649811 256.208552446777,3805.72837449132 PathPoint;PointKind.SMOOTHPOINT 239.816457341974,3796.12538018985 236.60956230163,3794.59660917196 245.525349116814,3798.84688749827 PathPoint;PointKind.SMOOTHPOINT 233.890713423414,3790.07330067857 229.70576271058,3787.54798531564 236.57415413415,3791.69256324995 PathPoint;PointKind.SMOOTHPOINT 220.951399516152,3790.98110432318 219.679339628454,3790.17137873761 225.971161122564,3794.1764172526 PathPoint;PointKind.CORNERPOINT 219.004780710075,3784.95784660445 219.004780710075,3784.95784660445 219.004780710075,3784.95784660445 PathPoint;PointKind.SMOOTHPOINT 220.264381780868,3747.91049664749 219.704669267362,3713.89254241452 220.824094294374,3781.92845088046 PathPoint;PointKind.CORNERPOINT 222.884032808137,3242.15868364325 222.884032808137,3242.15868364325 222.884032808137,3242.15868364325 PathPoint;PointKind.CORNERPOINT 223.252243815756,2358.13691411667 223.252243815756,2358.13691411667 223.252243815756,2358.13691411667 PathPoint;PointKind.CORNERPOINT 220.854470780502,1441.50758584943 220.854470780502,1441.50758584943 220.854470780502,1441.50758584943 PathPoint;PointKind.SMOOTHPOINT 222.250142660802,1246.22006411985 222.282171411339,1228.06725201544 222.218113910265,1264.37287622425 PathPoint;PointKind.CORNERPOINT 223.380912481105,1227.19925463023 223.380912481105,1227.19925463023 223.380912481105,1227.19925463023 PathPoint;PointKind.SMOOTHPOINT 221.985405135453,1144.06246269008 222.940438523782,1116.14206724606 221.030371747124,1171.98285813409 PathPoint;PointKind.SMOOTHPOINT 223.617267641649,915.726283437025 223.601587980112,886.706979002639 223.632947303186,944.745587871409 PathPoint;PointKind.SMOOTHPOINT 225.649856215376,770.519690675984 225.899953850634,734.939732138815 225.399758580119,806.099649213153 PathPoint;PointKind.SMOOTHPOINT 226.64471976082,631.314739289254 227.210076859808,586.019258319631 226.140120300868,671.742418142925 PathPoint;PointKind.SMOOTHPOINT 233.572484516518,497.160392943395 239.184128492056,482.298093581938 223.507693236608,523.816742074713 PathPoint;PointKind.CORNERPOINT 229.729347946219,478.103556213087 229.729347946219,478.103556213087 229.729347946219,478.103556213087 PathPoint;PointKind.SMOOTHPOINT 229.27852083683,401.984291013931 227.223831347049,366.357119638933 231.333210326611,437.611462388928 PathPoint;PointKind.SMOOTHPOINT 231.182360427392,135.592081885368 231.294031797216,119.381233452393 231.070689057568,151.802930318343 PathPoint;PointKind.SMOOTHPOINT 246.182809807833,124.683944432956 256.012290533057,123.085346485332 236.353329082608,126.282542380581 PathPoint;PointKind.SMOOTHPOINT 266.078435370242,124.828053395726 281.017351757478,124.843060620606 257.778485514285,124.819715494185 PathPoint;PointKind.CORNERPOINT 290.976596490031,121.002291717556 290.976596490031,121.002291717556 290.976596490031,121.002291717556 PathPoint;PointKind.SMOOTHPOINT 330.753533031463,123.293458583912 349.740569418231,122.384899152253 309.526242739501,124.309217673982 PathPoint;PointKind.SMOOTHPOINT 431.226442121635,124.021208845901 473.019781326066,123.772313843467 389.433102917203,124.270103848335 PathPoint;PointKind.SMOOTHPOINT 782.398547881562,124.561783097974 803.027137369036,123.064815227046 761.769958394089,126.058750968902 PathPoint;PointKind.SMOOTHPOINT 841.10495787406,122.983955597329 852.873516374681,123.425864943921 829.336399373438,122.542046250739 PathPoint;PointKind.SMOOTHPOINT 1126.57855552787,129.057817094711 1168.31150546876,129.067716807435 1084.84560558698,129.047917381987 PathPoint;PointKind.SMOOTHPOINT 1615.02332037674,131.594217660306 1660.07782399363,131.158560189094 1569.96881675984,132.029875131517 PathPoint;PointKind.SMOOTHPOINT 2080.58095853713,134.966367389122 2124.35468727165,133.173425873023 2036.80722980262,136.759308905222 PathPoint;PointKind.SMOOTHPOINT 2151.21758657538,134.476479736547 2161.46113535959,134.991593500708 2140.97403779118,133.961365972386 PathPoint;PointKind.SMOOTHPOINT 2206.92533815013,134.879984832303 2224.07907347151,131.429469984843 2193.9545018783,137.489099541223 PathPoint;PointKind.SMOOTHPOINT 2244.72702671871,135.153791861566 2261.9342356694,131.260068094804 2227.51981776802,139.047515628328 PathPoint;PointKind.SMOOTHPOINT 2303.41912212782,135.578913301738 2318.14666552047,130.870089902251 2288.69157873517,140.287736701224 PathPoint;PointKind.SMOOTHPOINT 2428.76156317101,136.486799767188 2453.79534354978,134.381109115758 2403.72778279224,138.592490418618 PathPoint;PointKind.SMOOTHPOINT 2497.40147136132,136.983975688745 2506.23008262022,138.995327896378 2489.93396746086,135.282713733128 PathPoint;PointKind.SMOOTHPOINT 2534.22269323517,135.247628329053 2542.02340569504,132.569334321892 2524.71439029409,138.512205880959 PathPoint;PointKind.SMOOTHPOINT 2578.9735361672,137.574822436101 2597.51197249861,135.738674904161 2560.4350998358,139.410969968043 PathPoint;PointKind.SMOOTHPOINT 2614.79997676293,135.831269628271 2624.47447728666,135.915013044217 2605.1254762392,135.747526212325 PathPoint;PointKind.SMOOTHPOINT 2649.61016420545,137.084934783527 2662.26039818357,134.739035280934 2636.95993022734,139.430834286119 PathPoint;PointKind.SMOOTHPOINT 2687.41901006573,136.357267342381 2698.82965400648,135.536794630117 2676.00836612497,137.177740054646 PathPoint;PointKind.SMOOTHPOINT 2724.22591735619,136.623868923506 2737.56138411587,139.552794613973 2710.8904505965,133.694943233039 PathPoint;PointKind.SMOOTHPOINT 2751.07785457375,137.819890493653 2766.33836115612,135.416581476695 2735.81734799137,140.223199510612 PathPoint;PointKind.SMOOTHPOINT 2781.91607419548,138.043259385947 2799.31372119901,141.736937413862 2764.51842719195,134.349581358032 PathPoint;PointKind.SMOOTHPOINT 2803.80126231413,138.201779244994 2813.33296145339,137.356984643304 2794.26956317488,139.046573846684 PathPoint;PointKind.SMOOTHPOINT 2859.50185659719,139.606758811158 2892.18617419939,139.193535505368 2833.40355498866,139.93671602787 PathPoint;PointKind.CORNERPOINT 2969.94405034365,137.402140143307 2969.94405034365,137.402140143307 2969.94405034365,137.402140143307 PathPoint;PointKind.SMOOTHPOINT 3045.56174206419,135.946805261017 3058.64876654155,135.721747281411 3032.47471758683,136.171863240622 PathPoint;PointKind.SMOOTHPOINT 3091.30020898265,139.282679286612 3112.61873300672,134.719292470891 3069.98168495858,143.846066102333 PathPoint;PointKind.SMOOTHPOINT 3129.11621213462,137.553537375058 3149.61714309546,128.51352151494 3117.94474718719,142.47966587617 PathPoint;PointKind.SMOOTHPOINT 3174.89046551155,135.882039048613 3194.76761995525,131.258309478553 3155.02660855198,140.502675420864 PathPoint;PointKind.SMOOTHPOINT 3207.72222005586,136.159685321654 3226.61282919308,127.033963459744 3198.70361306942,140.516416136547 PathPoint;PointKind.SMOOTHPOINT 3250.49384264871,136.429653107139 3268.78621454124,129.074045945758 3232.20147075618,143.78526026852 PathPoint;PointKind.SMOOTHPOINT 3330.09065948174,135.003140017403 3368.05263963043,135.78017271679 3295.61234180048,134.29741338899 PathPoint;PointKind.SMOOTHPOINT 3505.18647901434,134.268349948962 3536.87737270546,133.94928319852 3440.84572221403,134.916138439667 PathPoint;PointKind.SMOOTHPOINT 3581.79179472131,133.821694985218 3603.42353302153,132.623053244973 3560.16005642109,135.020336725464 PathPoint;PointKind.SMOOTHPOINT 3681.26992253336,134.542239799068 3703.4318611124,134.205691185856 3652.23955694558,134.983091543367 PathPoint;PointKind.SMOOTHPOINT 3745.93070561119,135.010593928071 3765.73432339766,134.777311945675 3726.12708782473,135.243875910466 PathPoint;PointKind.SMOOTHPOINT 3800.65083319952,134.40541910528 3817.62614055049,133.592272546086 3783.67552584854,135.218565664474 PathPoint;PointKind.SMOOTHPOINT 3868.3102746951,132.892440637882 3882.1843539887,131.991538656704 3854.43619540149,133.79334261906 PathPoint;PointKind.CORNERPOINT 3914.04874161356,136.228314663477 3914.04874161356,136.228314663477 3914.04874161356,136.228314663477 PathPoint;PointKind.SMOOTHPOINT 3967.78124521545,134.61445992214 3972.79984758005,134.969241099777 3949.30069471577,133.308010238872 PathPoint;PointKind.SMOOTHPOINT 3990.66837190392,133.778710758917 3995.33918342589,133.705545887764 3975.72805170699,134.012740027074 PathPoint;PointKind.SMOOTHPOINT 4009.55490160482,135.918563214365 4016.03730297055,135.794241617379 4004.48234776671,136.015846297958 PathPoint;PointKind.SMOOTHPOINT 4034.43355963956,134.009720036013 4037.31000140732,134.57935678934 4028.5130538469,132.837251420244 PathPoint;PointKind.SMOOTHPOINT 4043.16425110752,133.835465204386 4064.440397912,133.418550352188 4040.28287744221,133.891926907101 PathPoint;PointKind.SMOOTHPOINT 4091.14843828579,133.504986550497 4109.38970290153,134.457307312636 4083.7008853394,133.116172537469 PathPoint;PointKind.SMOOTHPOINT 4480.1079180309,136.32231677265 4548.86333049714,134.040195655661 4411.35250556467,138.604437889638 PathPoint;PointKind.SMOOTHPOINT 4776.5742107859,135.465116906697 4819.25103437602,136.132949329615 4738.77722549318,134.873647107787 PathPoint;PointKind.SMOOTHPOINT 5034.2368764025,135.328379033752 5077.00274163337,133.827612505341 4996.87622726194,136.639462333649 PathPoint;PointKind.SMOOTHPOINT 5225.26351096841,132.705927194711 5278.26325599054,133.345606319437 5172.26376594628,132.066248069985 PathPoint;PointKind.SMOOTHPOINT 5524.72130484946,130.868869202767 5574.69293049233,130.803648857756 5469.38729484316,130.941088250617 PathPoint;PointKind.SMOOTHPOINT 5660.00440138215,132.85028462001 5670.02047740314,133.098338937772 5649.98832536117,132.602230302249 PathPoint;PointKind.SMOOTHPOINT 5701.66354110442,150.177979438766 5711.92389101641,164.231725562154 5690.13167195797,134.382615469456 PathPoint;PointKind.SMOOTHPOINT 5710.35891010653,186.295909406705 5709.21764847321,193.18222398934 5711.81578472823,177.505202123138 PathPoint;PointKind.SMOOTHPOINT 5717.13628946933,212.384683774286 5716.55211051709,236.041969791163 5717.72046842157,188.727397757408 PathPoint;PointKind.SMOOTHPOINT 5712.83508623063,257.422213150098 5726.58912255609,276.235736342906 5708.81487724235,251.923151401885 PathPoint;PointKind.SMOOTHPOINT 5717.46672770836,316.199456372917 5722.48613978677,344.375433379687 5713.67820124483,294.932934944011 PathPoint;PointKind.SMOOTHPOINT 5719.03988225792,363.628945150329 5721.96051423466,375.65528611109 5716.80972240653,354.445774184786 PathPoint;PointKind.SMOOTHPOINT 5719.67679895135,413.709874118874 5721.19965465192,425.827071179139 5718.15394325078,401.592677058609 PathPoint;PointKind.SMOOTHPOINT 5720.48549064543,439.755415797624 5721.53734945434,444.261621300976 5716.92590710899,424.506016557246 PathPoint;PointKind.SMOOTHPOINT 5719.31893436666,463.78359763928 5717.29799226919,476.70845937733 5720.89549757635,453.700744928143 PathPoint;PointKind.SMOOTHPOINT 5713.07826961357,501.796394825958 5710.76097699154,511.447058053084 5715.773238969,490.572848257278 PathPoint;PointKind.CORNERPOINT 5711.96181437665,518.814255374758 5711.96181437665,518.814255374758 5711.96181437665,518.814255374758 PathPoint;PointKind.CORNERPOINT 5706.90202048573,530.795921778963 5706.90202048573,530.795921778963 5706.90202048573,530.795921778963 PathPoint;PointKind.SMOOTHPOINT 5713.85181388329,555.288114233937 5712.93250388757,566.501144663293 5716.21469965461,526.467465945389 PathPoint;PointKind.SMOOTHPOINT 5706.51552673426,584.875543181002 5706.3899075172,593.881566289563 5706.76956683811,566.662636753686 PathPoint;PointKind.SMOOTHPOINT 5714.35926029212,600.95677829264 5714.44610359252,617.780858382213 5714.32909454695,595.11279366392 PathPoint;PointKind.SMOOTHPOINT 5717.03584058365,644.041796864606 5719.23792321973,659.782820448845 5714.83375794757,628.300773280365 PathPoint;PointKind.SMOOTHPOINT 5710.71644562193,693.070813225773 5710.7120284545,705.112611167658 5710.72086278936,681.029015283887 PathPoint;PointKind.SMOOTHPOINT 5715.45416138663,726.155497989933 5717.23230093841,736.83152455738 5713.67602183486,715.479471422487 PathPoint;PointKind.SMOOTHPOINT 5716.78517083972,957.517716998627 5717.23903961085,986.316574902567 5716.33130206858,928.718859094687 PathPoint;PointKind.SMOOTHPOINT 5712.11178843293,1054.63191883566 5711.27711423149,1072.85044168071 5712.94646263437,1036.41339599062 PathPoint;PointKind.CORNERPOINT 5710.98817590432,1072.65125385487 5710.98817590432,1072.65125385487 5710.98817590432,1072.65125385487 PathPoint;PointKind.SMOOTHPOINT 5715.67579062717,1112.74625991189 5715.56935339403,1141.05155580125 5715.78222786031,1084.44096402253 PathPoint;PointKind.SMOOTHPOINT 5715.68286565154,1250.95694227635 5715.46001119643,1269.47590573537 5715.90572010665,1232.43797881733 PathPoint;PointKind.SMOOTHPOINT 5711.15978637033,1327.04018023481 5709.5931219442,1351.72016913879 5712.72645079645,1302.36019133084 PathPoint;PointKind.SMOOTHPOINT 5716.67040737064,1391.17777902976 5718.22237930709,1409.93492046988 5715.1184354342,1372.42063758965 PathPoint;PointKind.SMOOTHPOINT 5714.79527921418,1514.35193344182 5713.57225706035,1546.27678106208 5716.01830136801,1482.42708582156 PathPoint;PointKind.SMOOTHPOINT 5715.43211364029,1703.64501924524 5717.96346043685,1729.97000835911 5712.90076684373,1677.32003013136 PathPoint;PointKind.SMOOTHPOINT 5715.86862616629,1781.76723338521 5711.76413987273,1796.72898216474 5720.11428836689,1766.29086759789 PathPoint;PointKind.SMOOTHPOINT 5718.48794812426,1832.86404772044 5713.25151187008,1855.07391784793 5724.10139061988,1809.05513976396 PathPoint;PointKind.SMOOTHPOINT 5712.03972191205,1899.91960454895 5715.26642896427,1912.77141872993 5708.81301485984,1887.06779036798 PathPoint;PointKind.SMOOTHPOINT 5713.70004905038,1946.001841084 5713.17833467291,1961.10569172962 5714.22176342785,1930.89799043839 PathPoint;PointKind.SMOOTHPOINT 5713.37081363246,1992.06966672278 5713.19825813978,2018.34226091539 5713.54336912514,1965.79707253016 PathPoint;PointKind.SMOOTHPOINT 5711.39548339228,2129.26446372055 5712.72755863432,2161.67477678567 5710.06340815025,2096.85415065544 PathPoint;PointKind.SMOOTHPOINT 5710.62957091372,2375.63438888909 5711.01821134403,2382.0168661565 5709.22132245229,2352.50732054788 PathPoint;PointKind.SMOOTHPOINT 5705.51251868924,2395.62785105656 5706.05899198678,2407.72815616599 5705.17360860227,2388.12352197858 PathPoint;PointKind.SMOOTHPOINT 5711.30943135731,2419.70647103519 5711.45462478201,2425.86142263054 5711.07788125005,2409.89073933075 PathPoint;PointKind.SMOOTHPOINT 5711.15912823174,2440.73743491376 5711.07121596491,2446.15982313705 5711.21105586747,2437.53456220242 PathPoint;PointKind.SMOOTHPOINT 5703.10783321476,2453.69895944396 5702.8907595834,2457.61218741037 5703.3021923104,2450.19521076742 PathPoint;PointKind.SMOOTHPOINT 5709.97110007789,2467.77004016664 5709.90007663887,2469.56410990272 5710.23902143569,2461.00228002469 PathPoint;PointKind.SMOOTHPOINT 5700.96796753295,2474.71551242625 5700.69282637933,2478.465171222 5701.15493965021,2472.16743252306 PathPoint;PointKind.SMOOTHPOINT 5708.54487796403,2487.44284637473 5707.33874299279,2503.0102629572 5708.92426893422,2482.54609980707 PathPoint;PointKind.SMOOTHPOINT 5707.48052710308,2537.85884219893 5709.67048985938,2560.70064354206 5706.04759056863,2522.91299366198 PathPoint;PointKind.SMOOTHPOINT 5704.53188745986,2672.04201033735 5704.74937042237,2699.68567780359 5704.31440449735,2644.3983428711 PathPoint;PointKind.SMOOTHPOINT 5702.57087180307,2807.2338583943 5702.01055048945,2834.28508475558 5703.1311931167,2780.18263203302 PathPoint;PointKind.SMOOTHPOINT 5699.85126549406,2909.36984347966 5700.00111454773,2930.16649103322 5699.70141644039,2888.5731959261 PathPoint;PointKind.SMOOTHPOINT 5698.22664254688,2997.49239142743 5698.31135044991,3015.59805518309 5698.08281157959,2966.74962672269 PathPoint;PointKind.SMOOTHPOINT 5696.81673835052,3055.57070526297 5696.625369291,3059.0107015582 5697.84847339611,3037.02452677722 PathPoint;PointKind.SMOOTHPOINT 5687.77781934711,3067.52354987462 5686.96204693579,3070.54083254764 5690.23962228201,3058.41812385524 PathPoint;PointKind.SMOOTHPOINT 5696.67359251664,3075.60019467113 5696.69676962344,3081.32796216716 5696.66156681317,3072.62827785468 PathPoint;PointKind.SMOOTHPOINT 5696.55191855785,3092.62526066807 5699.64225320029,3117.54393186698 5695.93782169752,3087.6735387618 PathPoint;PointKind.SMOOTHPOINT 5692.13619865204,3153.68638157041 5693.51019968145,3167.12871847434 5687.59667356508,3109.27460581726 PathPoint;PointKind.SMOOTHPOINT 5695.60880998153,3173.65222970594 5696.08924977615,3176.15997896491 5694.66765241479,3168.7396741329 PathPoint;PointKind.SMOOTHPOINT 5687.94235478874,3183.7017938901 5688.40603651333,3191.5715576462 5687.57460887466,3177.46028530223 PathPoint;PointKind.SMOOTHPOINT 5694.9909048764,3207.8344255411 5693.24023678381,3217.59996940388 5696.29083234526,3200.58319455711 PathPoint;PointKind.SMOOTHPOINT 5691.50635698298,3241.81613496632 5692.28325484564,3265.1295756087 5691.04338287207,3227.92303527784 PathPoint;PointKind.SMOOTHPOINT 5689.05157046664,3306.89756464658 5698.5010408564,3340.32688129767 5686.1894816262,3296.7723755953 PathPoint;PointKind.SMOOTHPOINT 5690.46854968737,3387.0299331755 5688.85770887707,3414.05320456845 5692.07939049768,3360.00666178255 PathPoint;PointKind.SMOOTHPOINT 5694.98438940957,3451.16032652232 5695.66305828431,3476.52559421603 5694.30572053483,3425.7950588286 PathPoint;PointKind.SMOOTHPOINT 5673.71464610927,3504.08715904304 5670.96728889104,3512.53552191135 5676.46200332749,3495.63879617472 PathPoint;PointKind.SMOOTHPOINT 5691.29863098921,3549.2832082779 5696.22128955525,3564.24424090122 5680.57371262969,3516.68784312981 PathPoint;PointKind.SMOOTHPOINT 5688.98699030675,3594.33514854999 5692.59379538346,3610.24283384978 5686.11359826971,3581.66215533411 PathPoint;PointKind.SMOOTHPOINT 5691.70651434844,3631.4113202995 5691.69687306228,3645.41551999306 5691.71615563459,3617.40712060594 PathPoint;PointKind.SMOOTHPOINT 5684.52116935909,3662.40659074518 5684.54088105146,3664.33226726615 5684.41402863325,3651.93978879647 PathPoint;PointKind.SMOOTHPOINT 5683.46912974741,3670.41118106031 5683.94149618439,3674.63952414993 5683.19580594404,3667.96454911369 PathPoint;PointKind.SMOOTHPOINT 5685.37280480333,3682.44328560149 5684.30963340547,3689.352795742 5686.05152541783,3678.0323063578 PathPoint;PointKind.CORNERPOINT 5680.30585362071,3695.4264264761 5680.30585362071,3695.4264264761 5680.30585362071,3695.4264264761 PathPoint;PointKind.SMOOTHPOINT 5685.10798501066,3719.49784100659 5685.16680267885,3727.30147042073 5684.96328508227,3700.29978960441 PathPoint;PointKind.SMOOTHPOINT 5677.00658895182,3739.46968682964 5671.66538470615,3748.38209504554 5680.66458745339,3733.36589929417 PathPoint;PointKind.SMOOTHPOINT 5664.9189104888,3760.41418533055 5662.52029955664,3767.42962216108 5666.34253336456,3756.25038526549 PathPoint;PointKind.CORNERPOINT 5666.80111366963,3775.45071328295 5666.80111366963,3775.45071328295 5666.80111366963,3775.45071328295 PathPoint;PointKind.SMOOTHPOINT 5666.75101262778,3782.46103457581 5666.37203164761,3786.08248949325 5667.12999360794,3778.83957965836 PathPoint;PointKind.CORNERPOINT 5663.69509587647,3792.45416293547 5663.69509587647,3792.45416293547 5663.69509587647,3792.45416293547 PathPoint;PointKind.SMOOTHPOINT 5667.63127723879,3798.49183155047 5669.81957804158,3800.7972628608 5665.00315981828,3795.72304209487 PathPoint;PointKind.SMOOTHPOINT 5675.49370519195,3806.56804628829 5676.56567889346,3815.27268244169 5674.25094743949,3796.47661023274 PathPoint;PointKind.SMOOTHPOINT 5671.88879615241,3823.68957875459 5666.66950226405,3827.55279869984 5674.41513728594,3821.81963012469 PathPoint";
	
	mask35mm[1] = "PointKind.CORNERPOINT 5661.40919566154,3828.49957466125 5661.40919566154,3828.49957466125 5661.40919566154,3828.49957466125 PathPoint;PointKind.SMOOTHPOINT 5409.722417593,3827.67817497253 5398.76133441925,3827.85425662994 5474.71743822098,3826.63395881653 PathPoint;PointKind.SMOOTHPOINT 5385.84765672684,3827.50516176224 5369.56588625908,3830.52616596222 5388.19749712944,3827.06920623779 PathPoint;PointKind.SMOOTHPOINT 5357.71259307861,3839.00003671646 5349.73333239555,3838.5081410408 5365.69185376167,3839.49169635773 PathPoint;PointKind.SMOOTHPOINT 5324.12832140923,3833.0673122406 5313.32337498665,3833.30122232437 5334.9332678318,3832.83316612244 PathPoint;PointKind.SMOOTHPOINT 5224.64301109314,3829.35354709625 5204.81683015823,3830.55472612381 5244.46919202805,3828.1523680687 PathPoint;PointKind.SMOOTHPOINT 5193.79768252373,3830.1315164566 5189.68714356422,3828.93600225449 5207.88256287575,3834.22860145569 PathPoint;PointKind.SMOOTHPOINT 5179.00009632111,3824.00005102158 5171.27575278282,3821.15984916687 5182.18337416649,3825.170545578 PathPoint;PointKind.SMOOTHPOINT 5160.03957152367,3820.87330341339 5146.97400569916,3820.33278465271 5169.29200172424,3821.25615119934 PathPoint;PointKind.SMOOTHPOINT 5087.41615533829,3826.34953737259 5065.25040149689,3825.32113552094 5109.58190917969,3827.37770318985 PathPoint;PointKind.SMOOTHPOINT 5018.76909255981,3826.8537068367 4987.11263179779,3827.07675933838 5050.42555332184,3826.63065433502 PathPoint;PointKind.SMOOTHPOINT 4918.99983286858,3824.99989271164 4890.10922312737,3824.49737548828 4947.89079666138,3825.50264596939 PathPoint;PointKind.SMOOTHPOINT 4768.00001621246,3824.99989271164 4716.06135606766,3823.55016946793 4819.93867635727,3826.44985198975 PathPoint;PointKind.SMOOTHPOINT 4671.999989748,3827.00004816055 4660.33823847771,3826.5607881546 4683.6617410183,3827.4393081665 PathPoint;PointKind.SMOOTHPOINT 4649.64446425438,3833.14732789993 4637.69699335098,3833.50185155869 4661.59193515778,3832.79304027557 PathPoint;PointKind.SMOOTHPOINT 4595.95501899719,3828.75236749649 4582.64161705971,3828.36999177933 4609.26842093468,3829.13474321365 PathPoint;PointKind.SMOOTHPOINT 4570.12553930283,3825.58785438538 4555.31697750092,3826.35779857635 4584.93410110474,3824.81814622879 PathPoint;PointKind.SMOOTHPOINT 4495.89437484741,3824.09328460693 4473.05769324303,3823.80343437195 4518.73070240021,3824.38313484192 PathPoint;PointKind.SMOOTHPOINT 3923.50766658783,3823.91673088074 3895.94899892807,3823.50485086441 3951.06633424759,3824.32861089706 PathPoint;PointKind.SMOOTHPOINT 3851.99986696243,3825.9999704361 3837.9401242733,3825.73773622513 3866.05996370316,3826.26220464706 PathPoint;PointKind.SMOOTHPOINT 3819.0698826313,3821.15725278854 3793.98993015289,3821.0035943985 3844.1501891613,3821.3106751442 PathPoint;PointKind.SMOOTHPOINT 3722.13126540184,3821.09730005264 3708.09347391129,3820.50721406937 3736.1690568924,3821.68738603592 PathPoint;PointKind.SMOOTHPOINT 3649.71496939659,3820.09863853455 3626.18222236633,3820.0719666481 3673.24771642685,3820.12531042099 PathPoint;PointKind.SMOOTHPOINT 3456.96963787079,3818.53443861008 3427.96573162079,3818.54033946991 3485.97354412079,3818.52853775024 PathPoint;PointKind.SMOOTHPOINT 3092.86546111107,3817.90021419525 3080.46834468842,3818.09069395065 3105.26257753372,3817.70949840546 PathPoint;PointKind.SMOOTHPOINT 3067.9958152771,3817.72011995316 3053.60361814499,3818.01185846329 3082.38801240921,3817.42814540863 PathPoint;PointKind.SMOOTHPOINT 3046.12498641014,3815.55851697922 3035.06689310074,3815.54600715637 3057.18307971954,3815.57126283646 PathPoint;PointKind.SMOOTHPOINT 3023.00010681152,3819.99997615814 3003.19021224976,3820.76543569565 3042.8096473217,3819.23451662064 PathPoint;PointKind.SMOOTHPOINT 2943.64085912704,3817.8209066391 2926.03351950645,3817.4996638298 2961.24855279922,3818.14214944839 PathPoint;PointKind.SMOOTHPOINT 2798.40287804604,3816.76890134811 2772.95612812042,3819.59281682968 2823.84962797165,3813.94474983215 PathPoint;PointKind.SMOOTHPOINT 2577.55434751511,3816.17079019547 2552.86491394043,3815.64915418625 2602.24378108978,3816.69219017029 PathPoint;PointKind.SMOOTHPOINT 2484.05215501785,3814.49187755585 2476.54059648514,3814.20131921768 2491.56371355057,3814.78243589401 PathPoint;PointKind.SMOOTHPOINT 2423.38470697403,3812.04939365387 2402.57992744446,3813.45922708511 2444.1894865036,3810.63956022263 PathPoint;PointKind.SMOOTHPOINT 2383.57195973396,3814.76567745209 2370.22279858589,3816.67165517807 2396.92147493362,3812.85946369171 PathPoint;PointKind.SMOOTHPOINT 2263.00004482269,3815.99990129471 2248.87232422829,3816.28432273865 2277.1277654171,3815.71571588516 PathPoint;PointKind.SMOOTHPOINT 2238.32689762115,3814.71516609192 2227.95566439629,3814.57283735275 2248.69777679443,3814.85725879669 PathPoint;PointKind.SMOOTHPOINT 2201.50553226471,3816.45143508911 2167.93790102005,3816.87299251556 2235.07316350937,3816.02987766266 PathPoint;PointKind.SMOOTHPOINT 2133.85335445404,3816.96292161942 2116.57386660576,3818.04348707199 2151.13248825073,3815.88235616684 PathPoint;PointKind.SMOOTHPOINT 2078.15997719765,3814.55655097961 2059.82116699219,3814.35214519501 2096.49843335152,3814.76095676422 PathPoint;PointKind.SMOOTHPOINT 1993.60325217247,3813.94404172897 1984.49562907219,3813.61524581909 2022.50058889389,3814.9875497818 PathPoint;PointKind.SMOOTHPOINT 1967.7103972435,3817.76260614395 1960.26575446129,3821.73081636429 1975.15504002571,3813.79439592361 PathPoint;PointKind.SMOOTHPOINT 1941.83913946152,3818.57668876648 1933.39571714401,3818.88140916824 1948.27792167664,3818.34443092346 PathPoint;PointKind.SMOOTHPOINT 1922.95969247818,3815.43530702591 1869.70679283142,3821.10957384109 1932.42313742638,3814.42696809769 PathPoint;PointKind.SMOOTHPOINT 1844.00016903877,3815.99990129471 1830.3050994873,3815.50163269043 1857.69488453865,3816.49816989899 PathPoint;PointKind.SMOOTHPOINT 1778.99983763695,3815.00005960464 1746.36761069298,3814.88298654556 1811.63241863251,3815.11689662933 PathPoint;PointKind.SMOOTHPOINT 1707.07779765129,3815.87480306625 1671.92259907722,3822.30414390564 1742.23299622536,3809.44546222687 PathPoint;PointKind.SMOOTHPOINT 1657.33142495155,3816.51587247849 1629.55253720284,3815.92861890793 1685.11066675186,3817.10336208344 PathPoint;PointKind.SMOOTHPOINT 1587.67531514168,3819.01594877243 1550.06406068802,3816.7129611969 1625.28656959534,3821.31917238235 PathPoint;PointKind.SMOOTHPOINT 1466.31209492683,3818.13695669174 1428.23561668396,3819.54442977905 1504.38821911812,3816.72948360443 PathPoint;PointKind.SMOOTHPOINT 1410.62579870224,3814.72909212112 1408.19063186646,3814.87566947937 1430.36594510078,3813.54042291641 PathPoint;PointKind.SMOOTHPOINT 1390.70154547691,3818.59085083008 1366.14806771278,3821.22145414352 1415.25502324104,3815.96024751663 PathPoint;PointKind.SMOOTHPOINT 1229.5397400856,3818.42491865158 1200.47493696213,3818.01823139191 1258.60489726067,3818.83160591125 PathPoint;PointKind.SMOOTHPOINT 1183.77255320549,3819.09502029419 1181.15009307861,3819.39431190491 1195.00059127808,3817.81406164169 PathPoint;PointKind.SMOOTHPOINT 1173.85344386101,3815.01705408096 1167.60053873062,3813.41910123825 1177.69879817963,3815.99990129471 PathPoint;PointKind.SMOOTHPOINT 1152.03289031982,3812.83609628677 1143.88687133789,3811.11280918121 1160.03551840782,3814.5289349556 PathPoint;PointKind.SMOOTHPOINT 1127.18484163284,3809.65152025223 1106.15169882774,3809.82099294662 1135.31634449959,3809.58590269089 PathPoint;PointKind.SMOOTHPOINT 1059.00017023087,3810.99998474121 1036.41805171967,3811.08944177628 1087.70808935165,3810.88621616364 PathPoint;PointKind.SMOOTHPOINT 1006.78747415543,3812.78558492661 1002.28995680809,3813.85057210922 1012.48203992844,3811.43712043762 PathPoint;PointKind.SMOOTHPOINT 989.776003360748,3819.69289541245 985.385409593582,3819.96079444885 994.31742310524,3819.4157910347 PathPoint;PointKind.SMOOTHPOINT 971.905603408813,3814.55584287643 967.935622930527,3811.60541296005 978.269326686859,3819.28479194641 PathPoint;PointKind.SMOOTHPOINT 956.955420970917,3818.45371484756 941.925576925278,3817.38990783691 961.936218738556,3818.80611419678 PathPoint;PointKind.SMOOTHPOINT 905.226713418961,3818.07889223099 897.102999687195,3818.56748342514 924.381966590881,3816.92704439163 PathPoint;PointKind.SMOOTHPOINT 865.211802721024,3819.50996875763 860.087968111038,3819.72830057144 882.261865139008,3818.78321886063 PathPoint;PointKind.SMOOTHPOINT 832.62206196785,3815.55001974106 828.359280824661,3814.56906080246 843.633774518967,3818.08384895325 PathPoint;PointKind.SMOOTHPOINT 811.717439889908,3817.40170955658 783.198584318161,3817.28534460068 820.49933552742,3817.43758678436 PathPoint;PointKind.SMOOTHPOINT 727.153633832932,3817.79069423676 700.956294536591,3817.9198050499 739.038437604904,3817.73215770721 PathPoint;PointKind.SMOOTHPOINT 643.568780422211,3817.07739830017 639.1197681427,3817.05757141113 665.395706892014,3817.17370033264 PathPoint;PointKind.SMOOTHPOINT 626.635909080505,3819.95937824249 620.68607211113,3820.08848905563 633.164974451065,3819.81752157211 PathPoint;PointKind.SMOOTHPOINT 607.742300033569,3818.82098436356 603.768424987793,3818.70910406113 614.492647647858,3819.01051998138 PathPoint;PointKind.SMOOTHPOINT 592.806279659271,3820.71586847305 584.271157979965,3820.46142339706 596.840697526932,3820.83600997925 PathPoint;PointKind.SMOOTHPOINT 569.962162971497,3815.54270267487 562.354656457901,3812.90643453598 575.687885284424,3817.52680778503 PathPoint;PointKind.SMOOTHPOINT 550.052071809769,3817.40147352219 532.112277746201,3817.5067448616 554.890894889832,3817.37314939499 PathPoint;PointKind.SMOOTHPOINT 509.280552864075,3815.10320663452 492.806178331375,3814.68825817108 542.16698884964,3815.93121528625 PathPoint;PointKind.SMOOTHPOINT 484.475344419479,3805.90966701508 480.197693109512,3804.14176940918 488.769282102585,3807.68440961838 PathPoint;PointKind.SMOOTHPOINT 466.555023193359,3807.78307199478 455.903735160828,3807.99503087997 475.649900436401,3807.60179758072 PathPoint;PointKind.SMOOTHPOINT 442.716021537781,3802.6025891304 437.509692907333,3801.92092180252 450.038870573044,3803.56159687042 PathPoint;PointKind.SMOOTHPOINT 423.800815343857,3804.46867704391 406.231713294983,3803.89440536499 431.101713180542,3804.70730781555 PathPoint;PointKind.SMOOTHPOINT 384.002584218979,3805.1819729805 362.730102539062,3805.7569527626 405.275065898895,3804.60699319839 PathPoint;PointKind.SMOOTHPOINT 343.250184059143,3803.87339830399 338.800817728043,3803.94326448441 350.792899131775,3803.75490903854 PathPoint;PointKind.SMOOTHPOINT 323.304687738419,3810.73963880539 320.49351811409,3811.99982643127 332.522774934769,3806.60691261292 PathPoint;PointKind.SMOOTHPOINT 312.362015247345,3810.66033124924 310.120160579681,3814.25065040588 314.221848249435,3807.68157720566 PathPoint;PointKind.SMOOTHPOINT 300.369225740433,3814.59148406982 297.675955295563,3815.26205778122 304.204312562943,3813.63672494888 PathPoint;PointKind.SMOOTHPOINT 289.383713006973,3820.52114009857 281.704688072205,3819.60509061813 295.778946876526,3821.28376722336 PathPoint;PointKind.SMOOTHPOINT 269.538059234619,3813.36670160294 267.548643350601,3813.23499441147 281.466057300568,3814.15576457977 PathPoint;PointKind.SMOOTHPOINT 261.629962921143,3806.29865169525 258.827644586563,3804.698574543 264.618512392044,3808.0047082901 PathPoint;PointKind.SMOOTHPOINT 255.675523281097,3804.25246953964 254.243030548096,3800.28378725052 256.208724975586,3805.72839260101 PathPoint;PointKind.SMOOTHPOINT 239.816490411758,3796.12533330917 236.609491109848,3794.5965385437 245.525218248367,3798.84680986404 PathPoint;PointKind.SMOOTHPOINT 233.8907289505,3790.07341146469 229.705839157104,3787.54807949066 236.574085950851,3791.6926074028 PathPoint;PointKind.SMOOTHPOINT 220.95155954361,3786.98112487793 219.679452180862,3786.17129087448 225.971302986145,3790.17632246017 PathPoint;PointKind.CORNERPOINT 219.004629850388,3780.95776319504 219.004629850388,3780.95776319504 219.004629850388,3780.95776319504 PathPoint;PointKind.SMOOTHPOINT 220.264345407486,3747.91058778763 219.70458984375,3713.89260292053 220.824100971222,3781.92833662033 PathPoint;PointKind.CORNERPOINT 222.883973121643,3242.15874910355 222.883973121643,3242.15874910355 222.883973121643,3242.15874910355 PathPoint;PointKind.CORNERPOINT 223.252186775208,2358.13701152802 223.252186775208,2358.13701152802 223.252186775208,2358.13701152802 PathPoint;PointKind.CORNERPOINT 220.854549407959,1441.50759458542 220.854549407959,1441.50759458542 220.854549407959,1441.50759458542 PathPoint;PointKind.SMOOTHPOINT 222.250220775604,1246.22005462646 222.282085418701,1228.06735754013 222.218002080917,1264.37298774719 PathPoint;PointKind.CORNERPOINT 223.381061553955,1227.19922304153 223.381061553955,1227.19922304153 223.381061553955,1227.19922304153 PathPoint;PointKind.SMOOTHPOINT 221.98539018631,1144.06248092651 222.940267324448,1116.14197254181 221.030513048172,1171.98275327682 PathPoint;PointKind.SMOOTHPOINT 223.617213964462,915.72634935379 223.601635694504,886.706864833832 223.632792234421,944.745597839355 PathPoint;PointKind.SMOOTHPOINT 225.649824142456,770.519642829895 225.899784564972,734.939818382263 225.39986371994,806.09970331192 PathPoint;PointKind.SMOOTHPOINT 226.64470911026,631.3148188591 227.210129499435,586.01934671402 226.140185594559,671.742317676544 PathPoint;PointKind.SMOOTHPOINT 233.572436571121,497.160422801971 236.882464885712,486.706931591034 224.971107244492,524.324440956116 PathPoint;PointKind.SMOOTHPOINT 229.729206562042,478.103477954865 228.71237039566,469.510645866394 230.746396780014,486.696546077728 PathPoint;PointKind.SMOOTHPOINT 229.278498888016,401.98427438736 227.223937511444,366.357007026672 231.333060264587,437.611541748047 PathPoint;PointKind.SMOOTHPOINT 231.182234287262,135.592081546783 231.294114589691,119.381239414215 231.070708036423,151.802923679352 PathPoint;PointKind.SMOOTHPOINT 246.182692050934,124.68398809433 256.012226343155,123.085327148438 236.353157758713,126.282649040222 PathPoint;PointKind.SMOOTHPOINT 266.078267097473,124.827969074249 281.017473936081,124.843075275421 257.778589725494,124.819707870483 PathPoint;PointKind.CORNERPOINT 295.000033378601,120.999963283539 295.000033378601,120.999963283539 295.000033378601,120.999963283539 PathPoint;PointKind.SMOOTHPOINT 337.99995303154,122.999882698059 356.987031698227,122.091386318207 316.772789955139,124.015774726868 PathPoint;PointKind.SMOOTHPOINT 431.22633934021,124.021203517914 473.019651174545,123.772423267365 389.433027505875,124.270219802856 PathPoint;PointKind.SMOOTHPOINT 771.000090837479,125.000038146973 796.296722888947,124.30538892746 750.324894189835,125.567700862885 PathPoint;PointKind.SMOOTHPOINT 841.104784011841,122.984068393707 852.873458862305,123.425924777985 829.336463212967,122.541975975037 PathPoint;PointKind.SMOOTHPOINT 1126.57870531082,129.057705402374 1168.31147432327,129.067618846893 1084.84558224678,129.048027992249 PathPoint;PointKind.SMOOTHPOINT 1615.02332210541,131.594130992889 1660.07780313492,131.158647537231 1569.9688410759,132.029850482941 PathPoint;PointKind.SMOOTHPOINT 2080.58098196983,134.966354370117 2124.35485839844,133.17343711853 2036.80710554123,136.759271621704 PathPoint;PointKind.SMOOTHPOINT 2151.21746063232,134.476583003998 2161.46123528481,134.991610050201 2140.97404003143,133.961319923401 PathPoint;PointKind.SMOOTHPOINT 2202.99998402596,135.000107288361 2220.1537835598,131.549520492554 2190.02930402756,137.609231472015 PathPoint;PointKind.SMOOTHPOINT 2249.99997854233,134.000029563904 2267.20723986626,130.10617017746 2232.7927172184,137.893652915955 PathPoint;PointKind.SMOOTHPOINT 2303.41928243637,135.578863620758 2318.14676642418,130.869977474213 2288.69144439697,140.287749767303 PathPoint;PointKind.SMOOTHPOINT 2428.76168847084,136.486887931824 2453.79526019096,134.3812251091 2403.72776269913,138.592550754547 PathPoint;PointKind.SMOOTHPOINT 2497.40131616592,136.983976364136 2506.22994661331,138.995225429535 2489.93401408195,135.282640457153 PathPoint;PointKind.SMOOTHPOINT 2534.22268152237,135.247707366943 2542.02350020409,132.569425106049 2524.71427202225,138.512299060822 PathPoint;PointKind.SMOOTHPOINT 2574.9998652935,140.000023841858 2593.5383605957,138.163912296295 2556.46172404289,141.836135387421 PathPoint;PointKind.SMOOTHPOINT 2614.79986667633,135.831184387207 2624.47432637215,135.914976596832 2605.12540698051,135.747628211975 PathPoint;PointKind.SMOOTHPOINT 2652.9999089241,138.999946117401 2665.65017223358,136.654000282288 2640.34964561462,141.345891952515 PathPoint;PointKind.SMOOTHPOINT 2687.41903424263,136.357305049896 2698.82976293564,135.536849498749 2676.00830554962,137.177760601044 PathPoint;PointKind.SMOOTHPOINT 2724.22588348389,136.623787879944 2737.56123661995,139.552738666534 2710.89053034782,133.694837093353 PathPoint;PointKind.SMOOTHPOINT 2751.07786417007,137.819774150848 2766.33819580078,135.41647195816 2735.81717848778,140.22331237793 PathPoint;PointKind.SMOOTHPOINT 2781.91611170769,138.043298721313 2799.31385278702,141.73700094223 2764.51837062836,134.349596500397 PathPoint;PointKind.SMOOTHPOINT 2803.80110263824,138.201677799225 2813.3328795433,137.356910705566 2794.26967978477,139.046680927277 PathPoint;PointKind.SMOOTHPOINT 2859.50191497803,139.606790542603 2892.18618750572,139.193494319916 2833.40371012688,139.936766624451 PathPoint;PointKind.CORNERPOINT 2969.94405984879,137.402229309082 2969.94405984879,137.402229309082 2969.94405984879,137.402229309082 PathPoint;PointKind.SMOOTHPOINT 3037.99985647202,135.000107288361 3051.08701944351,134.774930477142 3024.91304755211,135.225048065186 PathPoint;PointKind.SMOOTHPOINT 3091.30019903183,139.282715320587 3112.61870741844,134.719226360321 3069.98169064522,143.84596824646 PathPoint;PointKind.SMOOTHPOINT 3129.11609530449,137.553527355194 3149.61709856987,128.5134100914 3117.9447054863,142.479565143585 PathPoint;PointKind.SMOOTHPOINT 3171.99988603592,135.999948978424 3191.87705039978,131.376271247864 3152.13617563248,140.620558261871 PathPoint;PointKind.SMOOTHPOINT 3207.72227525711,136.159744262695 3226.61269783974,127.03394651413 3198.70351910591,140.516467094421 PathPoint;PointKind.SMOOTHPOINT 3254.00000452995,135.999948978424 3272.29243397713,128.644409179688 3235.70757508278,143.355724811554 PathPoint;PointKind.SMOOTHPOINT 3330.09064793587,135.003175735474 3368.05276751518,135.780200958252 3295.61239600182,134.297432899475 PathPoint;PointKind.SMOOTHPOINT 3505.18650770187,134.268400669098 3536.87731146812,133.949282169342 3440.84577441216,134.916079044342 PathPoint;PointKind.SMOOTHPOINT 3581.7919421196,133.821587562561 3603.42343211174,132.62300491333 3560.16009807587,135.020406246185 PathPoint;PointKind.SMOOTHPOINT 3681.26981735229,134.542200565338 3703.4320306778,134.205615520477 3652.23971128464,134.983112812042 PathPoint;PointKind.SMOOTHPOINT 3745.93061327934,135.010492801666 3765.73448896408,134.777290821075 3726.12709164619,135.24393081665 PathPoint;PointKind.SMOOTHPOINT 3800.65070271492,134.405536651611 3817.62606024742,133.592162132263 3783.67569923401,135.218675136566 PathPoint;PointKind.SMOOTHPOINT 3864.9999332428,132.000110149384 3878.87415289879,131.099166870117 3851.1260676384,132.900817394257 PathPoint;PointKind.CORNERPOINT 3914.0488243103,136.228430271149 3914.0488243103,136.228430271149 3914.0488243103,136.228430271149 PathPoint;PointKind.SMOOTHPOINT 3967.78110980988,134.614427089691 3972.79979109764,134.969186782837 3949.30067896843,133.307976722717 PathPoint;PointKind.SMOOTHPOINT 3990.66842079163,133.778629302979 3995.33906936646,133.705458641052 3975.72815179825,134.012775421143 PathPoint;PointKind.SMOOTHPOINT 4009.55494880676,135.918517112732 4016.03727936745,135.794126987457 4004.48245167732,136.015763282776 PathPoint;PointKind.SMOOTHPOINT 4034.43344593048,134.00970697403 4037.31011509895,134.579257965088 4028.51299524307,132.837324142456 PathPoint;PointKind.SMOOTHPOINT 4043.16435813904,133.835513591766 4064.44038033485,133.418440818787 4040.28273224831,133.891925811768 PathPoint;PointKind.SMOOTHPOINT 4091.14826202393,133.505065441132 4109.38970804214,134.457228183746 4083.70078682899,133.116080760956 PathPoint;PointKind.SMOOTHPOINT 4480.10792255402,136.322371959686 4548.86332511902,134.040155410767 4411.35251998901,138.604352474213 PathPoint;PointKind.SMOOTHPOINT 4776.57408356667,135.465095043182 4819.25110816956,136.132836341858 4738.77730607986,134.873592853546 PathPoint;PointKind.SMOOTHPOINT 5034.23689842224,135.328431129456 5077.00278997421,133.827724456787 4996.87631249428,136.639366149902 PathPoint;PointKind.SMOOTHPOINT 5225.26366353035,132.705852985382 5278.26341629028,133.345506191254 5172.26391077042,132.06619977951 PathPoint;PointKind.SMOOTHPOINT 5524.72120642662,130.868797302246 5574.69275593758,130.803651809692 5469.38719153404,130.941023826599 PathPoint;PointKind.SMOOTHPOINT 5660.00431895256,132.850306034088 5670.02043843269,133.098378181458 5649.98819947243,132.602233886719 PathPoint;PointKind.SMOOTHPOINT 5701.6634452343,150.178062915802 5708.24136972427,161.081907749176 5691.56164526939,133.431894779205 PathPoint;PointKind.SMOOTHPOINT 5711.99998140335,177.000067234039 5712.94954776764,183.576457500458 5711.22071385384,171.601252555847 PathPoint;PointKind.SMOOTHPOINT 5709.99994397163,189.000055789948 5708.85883569717,195.886359214783 5710.80010056496,184.172444343567 PathPoint;PointKind.SMOOTHPOINT 5717.13620781898,212.384691238403 5716.55202269554,236.041946411133 5717.72039294243,188.727436065674 PathPoint;PointKind.SMOOTHPOINT 5712.83518910408,257.422177791595 5726.58903121948,276.235771179199 5708.81493330002,251.923048496246 PathPoint;PointKind.SMOOTHPOINT 5717.46689200401,316.199462413788 5722.48628139496,344.375360012054 5713.67818593979,294.932999610901 PathPoint;PointKind.SMOOTHPOINT 5719.03994321823,363.628921508789 5721.96051478386,375.655345916748 5716.80977225304,354.445767402649 PathPoint;PointKind.SMOOTHPOINT 5719.67688202858,413.709990978241 5721.19965791702,425.827052593231 5718.15410614014,401.592693328857 PathPoint;PointKind.SMOOTHPOINT 5720.48553586006,439.755442142487 5721.53742313385,444.261574745178 5716.92590117455,424.505968093872 PathPoint;PointKind.SMOOTHPOINT 5719.31893587112,463.783507347107 5717.2980093956,476.708514690399 5720.89552760124,453.70082616806 PathPoint;PointKind.SMOOTHPOINT 5713.07842254639,501.796374320984 5710.76080083847,511.447112560272 5715.77310919762,490.572938919067 PathPoint;PointKind.CORNERPOINT 5712.99982309341,517.000057697296 5712.99982309341,517.000057697296 5712.99982309341,517.000057697296 PathPoint;PointKind.CORNERPOINT 5703.99983167648,530.999965667725 5703.99983167648,530.999965667725 5703.99983167648,530.999965667725 PathPoint;PointKind.SMOOTHPOINT 5713.85167121887,555.288140773773 5712.93255329132,566.501190662384 5716.2146115303,526.467397212982 PathPoint;PointKind.SMOOTHPOINT 5706.51536822319,584.875524044037 5706.39003396034,593.881652355194 5706.76957726479,566.662638187408 PathPoint;PointKind.SMOOTHPOINT 5716.00005626678,605.999894142151 5716.08679890633,622.824189662933 5715.96996188164,600.155918598175 PathPoint;PointKind.SMOOTHPOINT 5717.03601121902,644.041793346405 5719.23785805702,659.782927036285 5714.83381032944,628.300659656525 PathPoint;PointKind.SMOOTHPOINT 5710.71654438972,693.070857524872 5713.90300869942,704.683277606964 5707.48936414719,681.310679912567 PathPoint;PointKind.SMOOTHPOINT 5715.45410871506,726.155562400818 5717.23215579987,736.831634044647 5713.67606163025,715.479490756989 PathPoint;PointKind.SMOOTHPOINT 5716.78534269333,957.517654895782 5717.23888278008,986.316683292389 5716.33144855499,928.718862533569 PathPoint;PointKind.SMOOTHPOINT 5712.11186170578,1054.63188171387 5711.27700805664,1072.85043239594 5712.94636130333,1036.4133310318 PathPoint;PointKind.CORNERPOINT 5710.98810195923,1072.65121936798 5710.98810195923,1072.65121936798 5710.98810195923,1072.65121936798 PathPoint;PointKind.SMOOTHPOINT 5715.67574501038,1112.74614572525 5715.56952953339,1141.05162620544 5715.78231453896,1084.44090127945 PathPoint;PointKind.SMOOTHPOINT 5715.68282604218,1250.95702886581 5715.46012759209,1269.47581529617 5715.90587854385,1232.43800640106 PathPoint;PointKind.SMOOTHPOINT 5711.15981698036,1327.04011917114 5709.59313869476,1351.72011137009 5712.72649526596,1302.3601269722 PathPoint;PointKind.SMOOTHPOINT 5716.67027592659,1391.17774486542 5718.222438097,1409.93492603302 5715.11846780777,1372.42056369781 PathPoint;PointKind.SMOOTHPOINT 5714.79521870613,1514.35182094574 5713.57232451439,1546.27688884735 5716.01846694946,1482.42698907852 PathPoint;PointKind.SMOOTHPOINT 5716.99989795685,1701.00003004074 5719.5313668251,1727.32494592667 5714.46878314018,1674.67511415482 PathPoint;PointKind.SMOOTHPOINT 5715.86870312691,1781.76722288132 5711.76418304443,1796.72897100449 5720.11413574219,1766.29091978073 PathPoint;PointKind.SMOOTHPOINT 5718.48797678947,1832.86394834518 5713.25155377388,1855.07384061813 5724.10146474838,1809.05515909195 PathPoint;PointKind.SMOOTHPOINT 5712.03963518143,1899.91966724396 5715.26646137238,1912.77150392532 5708.81316304207,1887.06783056259 PathPoint;PointKind.SMOOTHPOINT 5713.70013713837,1946.00184202194 5713.17826509476,1961.10568284988 5714.22165513039,1930.898001194 PathPoint;PointKind.SMOOTHPOINT 5713.3708691597,1992.06961870193 5713.1980919838,2018.34237098694 5713.54329228401,1965.79710245132 PathPoint;PointKind.SMOOTHPOINT 5711.39561533928,2129.2643737793 5712.72755742073,2161.67472839355 5710.06331920624,2096.85425519943 PathPoint;PointKind.SMOOTHPOINT 5710.62944769859,2375.63447713852 5711.01819634438,2382.01684713364 5709.2213845253,2352.50735521317 PathPoint;PointKind.SMOOTHPOINT 5705.51269412041,2395.62777042389 5706.05899572372,2407.72807359695 5705.17351269722,2388.12352895737 PathPoint;PointKind.SMOOTHPOINT 5711.30958080292,2419.70658302307 5711.4547419548,2425.86141586304 5711.07803106308,2409.89085674286 PathPoint;PointKind.SMOOTHPOINT 5711.15910887718,2440.73748350143 5711.07130408287,2446.15990161896 5711.21115446091,2437.53449678421 PathPoint;PointKind.SMOOTHPOINT 5705.00002741814,2451.00002288818 5704.78299379349,2454.91323709488 5705.19440174103,2447.49632835388 PathPoint;PointKind.SMOOTHPOINT 5709.97126579285,2467.7700304985 5709.90010142326,2469.56412792206 5710.23892879486,2461.00221633911 PathPoint;PointKind.SMOOTHPOINT 5703.99983167648,2476.99991941452 5703.72473359108,2480.74956178665 5704.18712496758,2474.45192813873 PathPoint;PointKind.SMOOTHPOINT 5709.00010228157,2491.00006341934 5707.79384851456,2506.56747579575 5709.37929153442,2486.10329389572 PathPoint;PointKind.SMOOTHPOINT 5707.48051285744,2537.85879135132 5709.67032194138,2560.70054769516 5706.04766607285,2522.91309356689 PathPoint;PointKind.SMOOTHPOINT 5704.5319712162,2672.04198360443 5704.74935889244,2699.68562364578 5704.31422948837,2644.39834356308 PathPoint;PointKind.SMOOTHPOINT 5702.57087945938,2807.23375082016 5702.01041579247,2834.2851805687 5703.1313431263,2780.18255710602 PathPoint;PointKind.SMOOTHPOINT 5699.85140919685,2909.36984539032 5700.00117301941,2930.16659975052 5699.70129132271,2888.57309103012 PathPoint;PointKind.SMOOTHPOINT 5698.2266664505,2997.49234199524 5698.3112847805,3015.5980682373 5698.08292150497,2966.74957036972 PathPoint;PointKind.SMOOTHPOINT 5698.81687045097,3056.5708065033 5698.6253285408,3060.0107717514 5699.84857678413,3038.02464008331 PathPoint;PointKind.SMOOTHPOINT 5689.77793335915,3068.52358818054 5688.96219849586,3071.54081583023 5692.23965406418,3059.4180893898 PathPoint;PointKind.SMOOTHPOINT 5698.67347955704,3076.60021305084 5698.69684696198,3082.32805967331 5698.66144180298,3073.62830400467 PathPoint;PointKind.SMOOTHPOINT 5698.55203986168,3093.62537384033 5701.6422021389,3118.54399681091 5697.93776035309,3088.67360830307 PathPoint;PointKind.SMOOTHPOINT 5692.13627099991,3153.68644952774 5693.51034522057,3167.12860822678 5687.59662151337,3109.27469015121 PathPoint;PointKind.SMOOTHPOINT 5695.60880899429,3173.65212678909 5696.23123168945,3181.13819360733 5695.19456863403,3168.66755247116 PathPoint;PointKind.SMOOTHPOINT 5687.99988627434,3187.0001077652 5688.46369385719,3194.86973047256 5687.63238072395,3180.75841426849 PathPoint;PointKind.SMOOTHPOINT 5694.9909889698,3207.83439159393 5693.24020385742,3217.60007858276 5696.29071235657,3200.58317899704 PathPoint;PointKind.SMOOTHPOINT 5691.50641322136,3241.81602716446 5692.28320240974,3265.12961626053 5691.04331374168,3227.9230427742 PathPoint;PointKind.SMOOTHPOINT 5689.05141949654,3306.89755439758 5698.50105643272,3340.32686948776 5686.18962049484,3296.77238702774 PathPoint;PointKind.SMOOTHPOINT 5690.46868801117,3387.03005075455 5688.85775327682,3414.05315637589 5692.07926869392,3360.00670909882 PathPoint;PointKind.SMOOTHPOINT 5694.98426198959,3451.16035938263 5695.66297888756,3476.52555942535 5694.30554509163,3425.7951593399 PathPoint;PointKind.SMOOTHPOINT 5678.99989485741,3503.9999628067 5676.25280857086,3512.44834184647 5681.74733519554,3495.55158376694 PathPoint;PointKind.SMOOTHPOINT 5691.29858493805,3549.28316116333 5696.22131824493,3564.24420118332 5680.5736541748,3516.68775558472 PathPoint;PointKind.SMOOTHPOINT 5688.98698210716,3594.33504581451 5692.59370565414,3610.24281978607 5686.113499403,3581.66212320328 PathPoint;PointKind.SMOOTHPOINT 5691.70645236969,3631.41132831573 5691.69689297676,3645.41548490524 5691.71601176262,3617.40717172623 PathPoint;PointKind.SMOOTHPOINT 5684.52132940292,3662.4066567421 5684.54080224037,3664.33222532272 5684.41405177116,3651.93971157074 PathPoint;PointKind.SMOOTHPOINT 5683.46908807755,3670.41129112244 5683.94139289856,3674.6396112442 5683.19576025009,3667.96455860138 PathPoint;PointKind.SMOOTHPOINT 5685.37282347679,3682.44338035583 5684.30960655212,3689.35281515121 5686.05154037476,3678.03236961365 PathPoint;PointKind.CORNERPOINT 5682.99996972084,3694.99993801117 5682.99996972084,3694.99993801117 5682.99996972084,3694.99993801117 PathPoint;PointKind.SMOOTHPOINT 5685.1079928875,3719.49794769287 5685.16676545143,3727.30148077011 5684.9631857872,3700.29985427856 PathPoint;PointKind.SMOOTHPOINT 5677.0065844059,3739.46976184845 5671.66536211967,3748.38218450546 5680.66464543343,3733.36591243744 PathPoint;PointKind.SMOOTHPOINT 5667.91878819466,3757.41427659988 5665.52044272423,3764.42969083786 5669.34242963791,3753.25039386749 PathPoint;PointKind.CORNERPOINT 5669.8012804985,3772.45061159134 5669.8012804985,3772.45061159134 5669.8012804985,3772.45061159134 PathPoint;PointKind.SMOOTHPOINT 5669.75100517273,3779.46106910706 5669.37216997147,3783.08254480362 5670.12984037399,3775.83959341049 PathPoint;PointKind.CORNERPOINT 5666.69518589973,3789.45405721664 5666.69518589973,3789.45405721664 5666.69518589973,3789.45405721664 PathPoint;PointKind.SMOOTHPOINT 5670.63117742538,3795.49181699753 5672.81957030296,3797.79716491699 5668.00305247307,3792.723133564 PathPoint;PointKind.SMOOTHPOINT 5675.49372196198,3806.56796693802 5676.56579017639,3815.27267932892 5674.2510008812,3796.47655248642 PathPoint;PointKind.SMOOTHPOINT 5671.88876867294,3823.68966579437 5666.66934013367,3827.55284070969 5674.41528081894,3821.81956529617 PathPoint";
	
	mask35mm[2] = "PointKind.CORNERPOINT 5661.409306881,3828.49960836333 5661.409306881,3828.49960836333 5661.409306881,3828.49960836333 PathPoint;PointKind.SMOOTHPOINT 5409.72248622482,3827.6781044547 5398.96850722014,3827.81425297427 5474.72046440077,3826.8552110401 PathPoint;PointKind.SMOOTHPOINT 5384,3827 5367.73332660894,3830.10204170416 5392.37474476683,3825.40294282034 PathPoint;PointKind.SMOOTHPOINT 5357.7124982371,3839 5349.73322028774,3838.50822595433 5365.69177618646,3839.49177404567 PathPoint;PointKind.SMOOTHPOINT 5324.12835255629,3833.06728273724 5313.3234547677,3833.3013032445 5334.93325034488,3832.83326222998 PathPoint;PointKind.SMOOTHPOINT 5217,3828 5197.17391429912,3829.20115485782 5236.82608570088,3826.79884514219 PathPoint;PointKind.SMOOTHPOINT 5193.79769053912,3830.13160476034 5189.6871251554,3828.93593406955 5207.88251386424,3834.2285619579 PathPoint;PointKind.SMOOTHPOINT 5176,3827 5168.27583117884,3824.15991448295 5179.1832644755,3828.17044869722 PathPoint;PointKind.SMOOTHPOINT 5160.03954270827,3820.87334928996 5146.97399622954,3820.33274137757 5169.29199321588,3821.25618424919 PathPoint;PointKind.SMOOTHPOINT 5087.41612959356,3826.34942300886 5065.25027667828,3825.32116267996 5109.58198250884,3827.37768333775 PathPoint;PointKind.SMOOTHPOINT 5018.76906411155,3826.85372155771 4987.1126586805,3827.0767733158 5050.4254695426,3826.63066979962 PathPoint;PointKind.SMOOTHPOINT 4919,3825 4890.10915263929,3824.49730658652 4947.89084736071,3825.50269341348 PathPoint;PointKind.SMOOTHPOINT 4777,3824 4725.0612557031,3822.55015478348 4828.9387442969,3825.44984521652 PathPoint;PointKind.SMOOTHPOINT 4672,3827 4660.33810134562,3826.56077472684 4683.66189865439,3827.43922527316 PathPoint;PointKind.SMOOTHPOINT 4649.64454918098,3833.1474040082 4637.69713433178,3833.50179619777 4661.59196403019,3832.79301181864 PathPoint;PointKind.SMOOTHPOINT 4610,3831 4596.68667335825,3830.61767974058 4623.31332664175,3831.38232025942 PathPoint;PointKind.SMOOTHPOINT 4570.12553104587,3825.58790173934 4555.31684119309,3826.35772051443 4584.93422089864,3824.81808296425 PathPoint;PointKind.SMOOTHPOINT 4495.89420393217,3824.0933527536 4473.05765107546,3823.80349740847 4518.73075678887,3824.38320809874 PathPoint;PointKind.SMOOTHPOINT 3923.50771960918,3823.9167108392 3895.94900163453,3823.50491862242 3951.06643758382,3824.32850305597 PathPoint;PointKind.SMOOTHPOINT 3865,3822 3850.99548728345,3820.72513349895 3882.07750538833,3823.55460885943 PathPoint;PointKind.SMOOTHPOINT 3819.06999998991,3821.15718984384 3793.98992878572,3821.00362522547 3844.1500711941,3821.3107544622 PathPoint;PointKind.SMOOTHPOINT 3722.13124122996,3821.09731784493 3708.09350726876,3820.50730070398 3736.16897519116,3821.68733498588 PathPoint;PointKind.SMOOTHPOINT 3649.71496395142,3820.09863954204 3626.18210854276,3820.07196740335 3673.24781936008,3820.12531168073 PathPoint;PointKind.SMOOTHPOINT 3456.96961475404,3818.53440672142 3427.96565255388,3818.54036367891 3485.9735769542,3818.52844976394 PathPoint;PointKind.SMOOTHPOINT 3092.86535237855,3817.90016164355 3080.46824887075,3818.09072981637 3105.26245588635,3817.70959347073 PathPoint;PointKind.SMOOTHPOINT 3067.99582042554,3817.72002544009 3053.60363706264,3818.01182836444 3082.38800378843,3817.42822251574 PathPoint;PointKind.SMOOTHPOINT 3046,3814 3034.94183155682,3813.98736875284 3057.05816844318,3814.01263124716 PathPoint;PointKind.SMOOTHPOINT 3001,3818 2981.1901940602,3818.76551404033 3020.8098059398,3817.23448595967 PathPoint;PointKind.SMOOTHPOINT 2943.64100336878,3817.82081889318 2926.0334472317,3817.49957897821 2961.24855950586,3818.14205880816 PathPoint;PointKind.SMOOTHPOINT 2798.40293676318,3816.76882346496 2772.95615243611,3819.59280329541 2823.84972109026,3813.94484363451 PathPoint;PointKind.SMOOTHPOINT 2577.55433572874,3816.17068844862 2552.86477513535,3815.64909333999 2602.24389632212,3816.69228355726 PathPoint;PointKind.SMOOTHPOINT 2484.0520528771,3814.4919018532 2476.5404821416,3814.20142223784 2491.56362361261,3814.78238146856 PathPoint;PointKind.SMOOTHPOINT 2423.38470949514,3812.04942057593 2402.5799657794,3813.45929097205 2444.18945321088,3810.63955017982 PathPoint;PointKind.SMOOTHPOINT 2383.57198649524,3814.76562606162 2370.22263134998,3816.67173722993 2396.9213416405,3812.8595148933 PathPoint;PointKind.SMOOTHPOINT 2263,3816 2248.87229005551,3816.28423957806 2277.12770994449,3815.71576042194 PathPoint;PointKind.SMOOTHPOINT 2238.32676259795,3814.7151051038 2227.95579578556,3814.57289947962 2248.69772941034,3814.85731072798 PathPoint;PointKind.SMOOTHPOINT 2201.5055407241,3816.4514524635 2167.93776834555,3816.87307295145 2235.07331310266,3816.02983197555 PathPoint;PointKind.SMOOTHPOINT 2133.85325652021,3816.96295646049 2116.57396685885,3818.04346333742 2151.13254618158,3815.88244958355 PathPoint;PointKind.SMOOTHPOINT 2078.15981952885,3814.55650242391 2059.82111878553,3814.35213306097 2096.49852027218,3814.76087178685 PathPoint;PointKind.SMOOTHPOINT 1993.60341088861,3813.94403933214 1984.49566174997,3813.61513483684 2022.50059818719,3814.98759187837 PathPoint;PointKind.SMOOTHPOINT 1967.7104684907,3817.76259556217 1960.2657431058,3821.7308380574 1975.1551938756,3813.79435306694 PathPoint;PointKind.SMOOTHPOINT 1941.83899796787,3818.57672838098 1933.39558010067,3818.8813949089 1948.27798569192,3818.34438834238 PathPoint;PointKind.SMOOTHPOINT 1922.95962555867,3815.43540145512 1869.70694902332,3821.10952519598 1932.4231537893,3814.42705344899 PathPoint;PointKind.SMOOTHPOINT 1844,3816 1830.30522708675,3815.50174498552 1857.69477291325,3816.49825501448 PathPoint;PointKind.SMOOTHPOINT 1779,3815 1746.36763561818,3814.88303956112 1811.63236438182,3815.11696043888 PathPoint;PointKind.SMOOTHPOINT 1707.07777362313,3815.87476814989 1671.9225542359,3822.30410330358 1742.23299301036,3809.44543299619 PathPoint;PointKind.SMOOTHPOINT 1657.33155242541,3816.51597021337 1629.55258038001,3815.92866144918 1685.1105244708,3817.10327897756 PathPoint;PointKind.SMOOTHPOINT 1587.67539108189,3819.0160122549 1550.06418440312,3816.71290706633 1625.28659776066,3821.31911744347 PathPoint;PointKind.SMOOTHPOINT 1466.31207515119,3818.136947582 1428.32025382196,3821.03633777806 1512.03989163478,3814.64717588481 PathPoint;PointKind.SMOOTHPOINT 1410.62579545152,3814.72901907502 1408.19062468361,3814.87563474872 1430.36583427311,3813.54051963643 PathPoint;PointKind.SMOOTHPOINT 1390.70154072234,3818.59080799389 1366.14820258088,3821.22141487183 1415.25487886379,3815.96020111594 PathPoint;PointKind.SMOOTHPOINT 1229.53981637512,3818.42499986586 1200.47478342924,3818.0183484792 1258.604849321,3818.83165125252 PathPoint;PointKind.SMOOTHPOINT 1190,3819 1187.37744663832,3819.29919264341 1201.22797588776,3817.71906217997 PathPoint;PointKind.SMOOTHPOINT 1173.85353667545,3815.01707135888 1167.60060793421,3813.41904011151 1177.69885983639,3815.99980230332 PathPoint;PointKind.SMOOTHPOINT 1152.03276418205,3812.8360293864 1143.88690472767,3811.1127628048 1160.03546492852,3814.52901056735 PathPoint;PointKind.SMOOTHPOINT 1127.18470410412,3809.65146977171 1106.15164502422,3809.82088415664 1135.31630912298,3809.5859723632 PathPoint;PointKind.SMOOTHPOINT 1063,3810 1040.50613327227,3808.00520777317 1091.03039868442,3812.48578077248 PathPoint;PointKind.SMOOTHPOINT 1006.78754028476,3812.78550842858 1002.29003501174,3813.8504982759 1012.48191361901,3811.43710538741 PathPoint;PointKind.SMOOTHPOINT 989.776056472996,3819.6929102757 985.385508222301,3819.96077421806 994.317280908374,3819.41585369622 PathPoint;PointKind.SMOOTHPOINT 971.905779925296,3814.55583985717 967.935463480393,3811.60543976359 978.269445380803,3819.28477252942 PathPoint;PointKind.SMOOTHPOINT 949,3819 933.970172376639,3817.9362640523 953.980641868864,3819.35250489435 PathPoint;PointKind.SMOOTHPOINT 905.226805124447,3818.07897271352 897.103152994175,3818.56747260406 924.381808757392,3816.92712413262 PathPoint;PointKind.SMOOTHPOINT 865.211667326236,3819.50993797863 860.08803715224,3819.72832594113 882.261769106406,3818.78319993125 PathPoint;PointKind.SMOOTHPOINT 833,3812 828.737261536072,3811.01908818793 844.011540402706,3814.53389930944 PathPoint;PointKind.SMOOTHPOINT 810,3819 781.481122132182,3818.88365661093 818.782085286988,3819.03582670995 PathPoint;PointKind.SMOOTHPOINT 727.153799049182,3817.79067196714 700.956166840882,3817.91977152273 739.038435226016,3817.73210555791 PathPoint;PointKind.SMOOTHPOINT 650.568825008411,3817.07733260143 646.119803253488,3817.05767406263 672.395674265067,3817.17377716535 PathPoint;PointKind.SMOOTHPOINT 633.63607140528,3819.9592633943 627.686239141498,3820.08849398985 640.16507695618,3819.81745313171 PathPoint;PointKind.SMOOTHPOINT 614.742384412685,3818.82088540926 610.768434319189,3818.70921975421 621.492582367229,3819.01056199266 PathPoint;PointKind.SMOOTHPOINT 599.806350657489,3820.715752628 591.27117982613,3820.46146847291 603.840817296283,3820.83594951225 PathPoint;PointKind.SMOOTHPOINT 576.962167719187,3815.54265496877 569.354613732454,3812.90635095513 582.687911300311,3817.52684079385 PathPoint;PointKind.SMOOTHPOINT 557.05222757339,3817.40149494682 539.112283494836,3817.50664097227 561.890904175843,3817.37313545969 PathPoint;PointKind.SMOOTHPOINT 509.280509753836,3815.10312263232 492.806287459423,3814.68828490236 542.166991336818,3815.93123780052 PathPoint;PointKind.SMOOTHPOINT 484.475393426068,3805.90971619519 480.197810186283,3804.14174552432 488.769126295872,3807.68436167999 PathPoint;PointKind.SMOOTHPOINT 466.555015836511,3807.78296706951 455.90366963589,3807.99501139565 475.64996280317,3807.60190714859 PathPoint;PointKind.SMOOTHPOINT 442.716051620088,3802.60266396215 437.509593813256,3801.92090571991 450.038992007971,3803.56156445689 PathPoint;PointKind.SMOOTHPOINT 423.800892752411,3804.46870938833 406.231639104751,3803.89451115776 431.101608747904,3804.70731133982 PathPoint;PointKind.SMOOTHPOINT 384.002484335897,3805.1819659332 362.730052676655,3805.7569682398 405.274915995139,3804.6069636266 PathPoint;PointKind.SMOOTHPOINT 343.250299821611,3803.87343922975 338.80066200607,3803.94337717054 350.793029709485,3803.75488508711 PathPoint;PointKind.SMOOTHPOINT 323.304573217343,3810.73965155984 320.493535062276,3811.99987786801 332.52293757671,3806.60693451966 PathPoint;PointKind.SMOOTHPOINT 312.361979158017,3810.66039163031 310.120228395937,3814.25057712958 314.221975361019,3807.6815897449 PathPoint;PointKind.SMOOTHPOINT 300.369284056835,3814.59145299365 297.675849498702,3815.261964555 304.204272855706,3813.63675954488 PathPoint;PointKind.SMOOTHPOINT 289.383746247346,3820.52103988657 281.704567838956,3819.60512004728 295.778924459575,3821.283812971 PathPoint;PointKind.SMOOTHPOINT 269.538221726793,3813.36660963094 267.548574312457,3813.23498860606 281.466087886613,3814.15567303856 PathPoint;PointKind.SMOOTHPOINT 258.630072543686,3809.29864475298 255.827478115545,3807.69859579598 261.618453541918,3811.00476243141 PathPoint;PointKind.SMOOTHPOINT 252.67569945835,3807.25246312333 251.242879089069,3803.28379649811 253.208552446777,3808.72837449132 PathPoint;PointKind.SMOOTHPOINT 239.816457341974,3796.12538018985 236.60956230163,3794.59660917196 245.525349116814,3798.84688749827 PathPoint;PointKind.SMOOTHPOINT 233.890713423414,3790.07330067857 229.70576271058,3787.54798531564 236.57415413415,3791.69256324995 PathPoint;PointKind.SMOOTHPOINT 220.951399516152,3786.98110432318 219.679339628454,3786.17137873761 225.971161122564,3790.1764172526 PathPoint;PointKind.CORNERPOINT 219.004780710075,3780.95784660445 219.004780710075,3780.95784660445 219.004780710075,3780.95784660445 PathPoint;PointKind.SMOOTHPOINT 220.264381780868,3747.91049664749 219.704669267362,3713.89254241452 220.824094294374,3781.92845088046 PathPoint;PointKind.CORNERPOINT 222.884032808137,3242.15868364325 222.884032808137,3242.15868364325 222.884032808137,3242.15868364325 PathPoint;PointKind.CORNERPOINT 223.252243815756,2358.13691411667 223.252243815756,2358.13691411667 223.252243815756,2358.13691411667 PathPoint;PointKind.CORNERPOINT 220.854470780502,1441.50758584943 220.854470780502,1441.50758584943 220.854470780502,1441.50758584943 PathPoint;PointKind.SMOOTHPOINT 222.250142660802,1246.22006411985 222.282171411339,1228.06725201544 222.218113910265,1264.37287622425 PathPoint;PointKind.CORNERPOINT 223.380912481105,1227.19925463023 223.380912481105,1227.19925463023 223.380912481105,1227.19925463023 PathPoint;PointKind.SMOOTHPOINT 221.985405135453,1144.06246269008 222.940438523782,1116.14206724606 221.030371747124,1171.98285813409 PathPoint;PointKind.SMOOTHPOINT 223.617267641649,915.726283437025 223.601587980112,886.706979002639 223.632947303186,944.745587871409 PathPoint;PointKind.SMOOTHPOINT 225.649856215376,770.519690675984 225.899953850634,734.939732138815 225.399758580119,806.099649213153 PathPoint;PointKind.SMOOTHPOINT 226.64471976082,631.314739289254 227.210076859808,586.019258319631 226.140120300868,671.742418142925 PathPoint;PointKind.SMOOTHPOINT 234.572484516518,489.160392943395 237.88245629506,478.707026714429 225.971247693824,516.324334072009 PathPoint;PointKind.SMOOTHPOINT 230.729347946219,470.103556213087 229.712235760575,461.510594165802 231.746460131863,478.696518260372 PathPoint;PointKind.SMOOTHPOINT 229.27852083683,401.984291013931 227.223831347049,366.357119638933 231.333210326611,437.611462388928 PathPoint;PointKind.SMOOTHPOINT 231,151 231.111671369824,134.789151567025 230.888328630176,167.210848432975 PathPoint;PointKind.SMOOTHPOINT 246.182809807833,124.683944432956 255.992317830308,122.967040509411 229.412459349211,127.619166101124 PathPoint;PointKind.SMOOTHPOINT 266.078435370242,124.828053395726 281.017351757478,124.843060620606 257.778485514285,124.819715494185 PathPoint;PointKind.CORNERPOINT 295,121 295,121 295,121 PathPoint;PointKind.SMOOTHPOINT 338,123 356.987036386768,122.091440568341 316.772709708038,124.01575909007 PathPoint;PointKind.SMOOTHPOINT 431.226442121635,124.021208845901 473.019781326066,123.772313843467 389.433102917203,124.270103848335 PathPoint;PointKind.SMOOTHPOINT 771,125 796.296769718001,124.305393121934 750.324958729703,125.567701964747 PathPoint;PointKind.SMOOTHPOINT 841.10495787406,122.983955597329 852.873516374681,123.425864943921 829.336399373438,122.542046250739 PathPoint;PointKind.SMOOTHPOINT 1126.57855552787,129.057817094711 1168.31150546876,129.067716807435 1084.84560558698,129.047917381987 PathPoint;PointKind.SMOOTHPOINT 1615.02332037674,131.594217660306 1660.07782399363,131.158560189094 1569.96881675984,132.029875131517 PathPoint;PointKind.SMOOTHPOINT 2080.58095853713,134.966367389122 2124.35468727165,133.173425873023 2036.80722980262,136.759308905222 PathPoint;PointKind.SMOOTHPOINT 2151.21758657538,134.476479736547 2161.46113535959,134.991593500708 2140.97403779118,133.961365972386 PathPoint;PointKind.SMOOTHPOINT 2203,135 2220.15373532138,131.54948515254 2190.02916372817,137.60911470892 PathPoint;PointKind.SMOOTHPOINT 2250,134 2267.20720895069,130.106276233238 2232.79279104931,137.893723766762 PathPoint;PointKind.SMOOTHPOINT 2303.41912212782,135.578913301738 2318.14666552047,130.870089902251 2288.69157873517,140.287736701224 PathPoint;PointKind.SMOOTHPOINT 2428.76156317101,136.486799767188 2453.79534354978,134.381109115758 2403.72778279224,138.592490418618 PathPoint;PointKind.SMOOTHPOINT 2497.40147136132,136.983975688745 2506.23008262022,138.995327896378 2489.93396746086,135.282713733128 PathPoint;PointKind.SMOOTHPOINT 2534.22269323517,135.247628329053 2542.02340569504,132.569334321892 2524.71439029409,138.512205880959 PathPoint;PointKind.SMOOTHPOINT 2575,140 2593.53843633141,138.163852468059 2556.46156366859,141.836147531941 PathPoint;PointKind.SMOOTHPOINT 2614.79997676293,135.831269628271 2624.47447728666,135.915013044217 2605.1254762392,135.747526212325 PathPoint;PointKind.SMOOTHPOINT 2653,139 2665.65023397812,136.654100497407 2640.34976602188,141.345899502593 PathPoint;PointKind.SMOOTHPOINT 2687.41901006573,136.357267342381 2698.82965400648,135.536794630117 2676.00836612497,137.177740054646 PathPoint;PointKind.SMOOTHPOINT 2724.22591735619,136.623868923506 2737.56138411587,139.552794613973 2710.8904505965,133.694943233039 PathPoint;PointKind.SMOOTHPOINT 2751.07785457375,137.819890493653 2766.33836115612,135.416581476695 2735.81734799137,140.223199510612 PathPoint;PointKind.SMOOTHPOINT 2781.91607419548,138.043259385947 2799.31372119901,141.736937413862 2764.51842719195,134.349581358032 PathPoint;PointKind.SMOOTHPOINT 2803.80126231413,138.201779244994 2813.33296145339,137.356984643304 2794.26956317488,139.046573846684 PathPoint;PointKind.SMOOTHPOINT 2859.50185659719,139.606758811158 2892.18617419939,139.193535505368 2833.40355498866,139.93671602787 PathPoint;PointKind.CORNERPOINT 2969.94405034365,137.402140143307 2969.94405034365,137.402140143307 2969.94405034365,137.402140143307 PathPoint;PointKind.SMOOTHPOINT 3038,135 3051.08702447736,134.774942020394 3024.91297552264,135.225057979606 PathPoint;PointKind.SMOOTHPOINT 3087,141 3108.31852402407,136.43661318428 3065.68147597593,145.563386815721 PathPoint;PointKind.SMOOTHPOINT 3129.11621213462,137.553537375058 3149.61714309546,128.51352151494 3117.94474718719,142.47966587617 PathPoint;PointKind.SMOOTHPOINT 3177,135 3196.8771544437,130.37627042994 3157.13614304043,139.620636372251 PathPoint;PointKind.SMOOTHPOINT 3207.72222005586,136.159685321654 3226.61282919308,127.033963459744 3198.70361306942,140.516416136547 PathPoint;PointKind.SMOOTHPOINT 3254,136 3272.29237189253,128.644392838619 3235.70762810747,143.355607161381 PathPoint;PointKind.SMOOTHPOINT 3330.09065948174,135.003140017403 3368.05263963043,135.78017271679 3295.61234180048,134.29741338899 PathPoint;PointKind.SMOOTHPOINT 3505.18647901434,134.268349948962 3536.87737270546,133.94928319852 3440.84572221403,134.916138439667 PathPoint;PointKind.SMOOTHPOINT 3581.79179472131,133.821694985218 3603.42353302153,132.623053244973 3560.16005642109,135.020336725464 PathPoint;PointKind.SMOOTHPOINT 3681.26992253336,134.542239799068 3703.4318611124,134.205691185856 3652.23955694558,134.983091543367 PathPoint;PointKind.SMOOTHPOINT 3745.93070561119,135.010593928071 3765.73432339766,134.777311945675 3726.12708782473,135.243875910466 PathPoint;PointKind.SMOOTHPOINT 3800.65083319952,134.40541910528 3817.62614055049,133.592272546086 3783.67552584854,135.218565664474 PathPoint;PointKind.SMOOTHPOINT 3865,132 3878.8740792936,131.099098018822 3851.1259207064,132.900901981178 PathPoint;PointKind.CORNERPOINT 3914.04874161356,136.228314663477 3914.04874161356,136.228314663477 3914.04874161356,136.228314663477 PathPoint;PointKind.SMOOTHPOINT 3967.78124521545,134.61445992214 3972.79984758005,134.969241099777 3949.30069471577,133.308010238872 PathPoint;PointKind.SMOOTHPOINT 3990.66837190392,133.778710758917 3995.33918342589,133.705545887764 3975.72805170699,134.012740027074 PathPoint;PointKind.SMOOTHPOINT 4009.55490160482,135.918563214365 4016.03730297055,135.794241617379 4004.48234776671,136.015846297958 PathPoint;PointKind.SMOOTHPOINT 4034.43355963956,134.009720036013 4037.31000140732,134.57935678934 4028.5130538469,132.837251420244 PathPoint;PointKind.SMOOTHPOINT 4043.16425110752,133.835465204386 4064.440397912,133.418550352188 4040.28287744221,133.891926907101 PathPoint;PointKind.SMOOTHPOINT 4091.14843828579,133.504986550497 4109.38970290153,134.457307312636 4083.7008853394,133.116172537469 PathPoint;PointKind.SMOOTHPOINT 4480.1079180309,136.32231677265 4548.86333049714,134.040195655661 4411.35250556467,138.604437889638 PathPoint;PointKind.SMOOTHPOINT 4776.5742107859,135.465116906697 4819.25103437602,136.132949329615 4738.77722549318,134.873647107787 PathPoint;PointKind.SMOOTHPOINT 5034.2368764025,135.328379033752 5077.00274163337,133.827612505341 4996.87622726194,136.639462333649 PathPoint;PointKind.SMOOTHPOINT 5225.26351096841,132.705927194711 5278.26325599054,133.345606319437 5172.26376594628,132.066248069985 PathPoint;PointKind.SMOOTHPOINT 5524.72130484946,130.868869202767 5574.69293049233,130.803648857756 5469.38729484316,130.941088250617 PathPoint;PointKind.SMOOTHPOINT 5660.00440138215,132.85028462001 5670.02047740314,133.098338937772 5649.98832536117,132.602230302249 PathPoint;PointKind.SMOOTHPOINT 5702,154 5708.57767513775,164.904024511537 5691.8982004416,137.253920619569 PathPoint;PointKind.SMOOTHPOINT 5712,177 5712.94946061779,183.576418520642 5711.22056175109,171.601237755683 PathPoint;PointKind.SMOOTHPOINT 5710,189 5708.85873836668,195.886314582635 5710.80007287009,184.172401041464 PathPoint;PointKind.SMOOTHPOINT 5717.13628946933,212.384683774286 5716.55211051709,236.041969791163 5717.72046842157,188.727397757408 PathPoint;PointKind.SMOOTHPOINT 5712.83508623063,257.422213150098 5726.58912255609,276.235736342906 5708.81487724235,251.923151401885 PathPoint;PointKind.SMOOTHPOINT 5717.46672770836,316.199456372917 5722.48613978677,344.375433379687 5713.67820124483,294.932934944011 PathPoint;PointKind.SMOOTHPOINT 5719.03988225792,363.628945150329 5721.96051423466,375.65528611109 5716.80972240653,354.445774184786 PathPoint;PointKind.SMOOTHPOINT 5719.67679895135,413.709874118874 5721.19965465192,425.827071179139 5718.15394325078,401.592677058609 PathPoint;PointKind.SMOOTHPOINT 5720.48549064543,439.755415797624 5721.53734945434,444.261621300976 5716.92590710899,424.506016557246 PathPoint;PointKind.SMOOTHPOINT 5719.31893436666,463.78359763928 5717.29799226919,476.70845937733 5720.89549757635,453.700744928143 PathPoint;PointKind.SMOOTHPOINT 5713.07826961357,501.796394825958 5710.76097699154,511.447058053084 5715.773238969,490.572848257278 PathPoint;PointKind.CORNERPOINT 5713,517 5713,517 5713,517 PathPoint;PointKind.CORNERPOINT 5707,529 5707,529 5707,529 PathPoint;PointKind.SMOOTHPOINT 5713.85181388329,555.288114233937 5712.93250388757,566.501144663293 5716.21469965461,526.467465945389 PathPoint;PointKind.SMOOTHPOINT 5706.51552673426,584.875543181002 5706.3899075172,593.881566289563 5706.76956683811,566.662636753686 PathPoint;PointKind.SMOOTHPOINT 5716,606 5716.0868433004,622.824080089573 5715.96983425483,600.15601537128 PathPoint;PointKind.SMOOTHPOINT 5717.03584058365,644.041796864606 5719.23792321973,659.782820448845 5714.83375794757,628.300773280365 PathPoint;PointKind.SMOOTHPOINT 5710.71644562193,693.070813225773 5713.9031634185,704.683295599047 5707.48920156206,681.310652097038 PathPoint;PointKind.SMOOTHPOINT 5715.45416138663,726.155497989933 5717.23230093841,736.83152455738 5713.67602183486,715.479471422487 PathPoint;PointKind.SMOOTHPOINT 5716.78517083972,957.517716998627 5717.23903961085,986.316574902567 5716.33130206858,928.718859094687 PathPoint;PointKind.SMOOTHPOINT 5712.11178843293,1054.63191883566 5711.27711423149,1072.85044168071 5712.94646263437,1036.41339599062 PathPoint;PointKind.CORNERPOINT 5710.98817590432,1072.65125385487 5710.98817590432,1072.65125385487 5710.98817590432,1072.65125385487 PathPoint;PointKind.SMOOTHPOINT 5715.67579062717,1112.74625991189 5715.56935339403,1141.05155580125 5715.78222786031,1084.44096402253 PathPoint;PointKind.SMOOTHPOINT 5715.68286565154,1250.95694227635 5715.46001119643,1269.47590573537 5715.90572010665,1232.43797881733 PathPoint;PointKind.SMOOTHPOINT 5711.15978637033,1327.04018023481 5709.5931219442,1351.72016913879 5712.72645079645,1302.36019133084 PathPoint;PointKind.SMOOTHPOINT 5716.67040737064,1391.17777902976 5718.22237930709,1409.93492046988 5715.1184354342,1372.42063758965 PathPoint;PointKind.SMOOTHPOINT 5714.79527921418,1514.35193344182 5713.57225706035,1546.27678106208 5716.01830136801,1482.42708582156 PathPoint;PointKind.SMOOTHPOINT 5717,1701 5719.53134679656,1727.32498911388 5714.46865320344,1674.67501088612 PathPoint;PointKind.SMOOTHPOINT 5715.86862616629,1781.76723338521 5711.76413987273,1796.72898216474 5720.11428836689,1766.29086759789 PathPoint;PointKind.SMOOTHPOINT 5718.48794812426,1832.86404772044 5713.25151187008,1855.07391784793 5724.10139061988,1809.05513976396 PathPoint;PointKind.SMOOTHPOINT 5712.03972191205,1899.91960454895 5715.26642896427,1912.77141872993 5708.81301485984,1887.06779036798 PathPoint;PointKind.SMOOTHPOINT 5713.70004905038,1946.001841084 5713.17833467291,1961.10569172962 5714.22176342785,1930.89799043839 PathPoint;PointKind.SMOOTHPOINT 5713.37081363246,1992.06966672278 5713.19825813978,2018.34226091539 5713.54336912514,1965.79707253016 PathPoint;PointKind.SMOOTHPOINT 5711.39548339228,2129.26446372055 5712.72755863432,2161.67477678567 5710.06340815025,2096.85415065544 PathPoint;PointKind.SMOOTHPOINT 5710.62957091372,2375.63438888909 5711.01821134403,2382.0168661565 5709.22132245229,2352.50732054788 PathPoint;PointKind.SMOOTHPOINT 5705.51251868924,2395.62785105656 5706.05899198678,2407.72815616599 5705.17360860227,2388.12352197858 PathPoint;PointKind.SMOOTHPOINT 5711.30943135731,2419.70647103519 5711.45462478201,2425.86142263054 5711.07788125005,2409.89073933075 PathPoint;PointKind.SMOOTHPOINT 5711.15912823174,2440.73743491376 5711.07121596491,2446.15982313705 5711.21105586747,2437.53456220242 PathPoint;PointKind.SMOOTHPOINT 5705,2451 5704.78292636864,2454.91322796642 5705.19435909564,2447.49625132347 PathPoint;PointKind.SMOOTHPOINT 5708,2466 5707.92897656099,2467.79406973608 5708.26792135781,2459.23223985805 PathPoint;PointKind.SMOOTHPOINT 5704,2477 5703.72485884639,2480.74965879575 5704.18697211726,2474.45192009681 PathPoint;PointKind.SMOOTHPOINT 5709,2491 5707.79386502876,2506.56741658247 5709.37939097019,2486.10325343234 PathPoint;PointKind.SMOOTHPOINT 5707.48052710308,2537.85884219893 5709.67048985938,2560.70064354206 5706.04759056863,2522.91299366198 PathPoint;PointKind.SMOOTHPOINT 5704.53188745986,2672.04201033735 5704.74937042237,2699.68567780359 5704.31440449735,2644.3983428711 PathPoint;PointKind.SMOOTHPOINT 5702.57087180307,2807.2338583943 5702.01055048945,2834.28508475558 5703.1311931167,2780.18263203302 PathPoint;PointKind.SMOOTHPOINT 5699.85126549406,2909.36984347966 5700.00111454773,2930.16649103322 5699.70141644039,2888.5731959261 PathPoint;PointKind.SMOOTHPOINT 5698.22664254688,2997.49239142743 5698.31135044991,3015.59805518309 5698.08281157959,2966.74962672269 PathPoint;PointKind.SMOOTHPOINT 5698,3053 5697.80863094048,3056.43999629523 5699.03173504559,3034.45382151425 PathPoint;PointKind.SMOOTHPOINT 5689.77781934711,3068.52354987462 5688.96204693579,3071.54083254764 5692.23962228201,3059.41812385524 PathPoint;PointKind.SMOOTHPOINT 5698.67359251664,3076.60019467113 5698.69676962344,3082.32796216716 5698.66156681317,3073.62827785468 PathPoint;PointKind.SMOOTHPOINT 5698.55191855785,3093.62526066807 5701.64225320029,3118.54393186698 5697.93782169752,3088.6735387618 PathPoint;PointKind.SMOOTHPOINT 5692.13619865204,3153.68638157041 5693.51019968145,3167.12871847434 5687.59667356508,3109.27460581726 PathPoint;PointKind.SMOOTHPOINT 5696,3169 5696.62226818704,3176.48603451013 5695.5856519149,3164.01529384135 PathPoint;PointKind.SMOOTHPOINT 5688,3187 5688.46368172459,3194.8697637561 5687.63225408592,3180.75849141213 PathPoint;PointKind.SMOOTHPOINT 5694.9909048764,3207.8344255411 5693.24023678381,3217.59996940388 5696.29083234526,3200.58319455711 PathPoint;PointKind.SMOOTHPOINT 5691.50635698298,3241.81613496632 5692.28325484564,3265.1295756087 5691.04338287207,3227.92303527784 PathPoint;PointKind.SMOOTHPOINT 5689.05157046664,3306.89756464658 5700.92758364383,3348.68722332933 5686.17528267562,3296.77639997062 PathPoint;PointKind.SMOOTHPOINT 5690.46854968737,3387.0299331755 5688.85770887707,3414.05320456845 5692.07939049768,3360.00666178255 PathPoint;PointKind.SMOOTHPOINT 5694.98438940957,3451.16032652232 5695.66305828431,3476.52559421603 5694.30572053483,3425.7950588286 PathPoint;PointKind.SMOOTHPOINT 5679,3504 5676.25264278177,3512.44836286832 5681.74735721822,3495.55163713168 PathPoint;PointKind.SMOOTHPOINT 5691.29863098921,3549.2832082779 5696.22128955525,3564.24424090122 5680.57371262969,3516.68784312981 PathPoint;PointKind.SMOOTHPOINT 5688.98699030675,3594.33514854999 5692.59379538346,3610.24283384978 5686.11359826971,3581.66215533411 PathPoint;PointKind.SMOOTHPOINT 5691.70651434844,3631.4113202995 5691.69687306228,3645.41551999306 5691.71615563459,3617.40712060594 PathPoint;PointKind.SMOOTHPOINT 5684.52116935909,3662.40659074518 5684.54088105146,3664.33226726615 5684.41402863325,3651.93978879647 PathPoint;PointKind.SMOOTHPOINT 5683.46912974741,3670.41118106031 5683.94149618439,3674.63952414993 5683.19580594404,3667.96454911369 PathPoint;PointKind.SMOOTHPOINT 5685.37280480333,3682.44328560149 5684.30963340547,3689.352795742 5686.05152541783,3678.0323063578 PathPoint;PointKind.CORNERPOINT 5683,3695 5683,3695 5683,3695 PathPoint;PointKind.SMOOTHPOINT 5685.10798501066,3719.49784100659 5685.16680267885,3727.30147042073 5684.96328508227,3700.29978960441 PathPoint;PointKind.SMOOTHPOINT 5677.00658895182,3739.46968682964 5671.66538470615,3748.38209504554 5680.66458745339,3733.36589929417 PathPoint;PointKind.SMOOTHPOINT 5667.9189104888,3757.41418533055 5665.52029955664,3764.42962216108 5669.34253336456,3753.25038526549 PathPoint;PointKind.CORNERPOINT 5669.80111366963,3772.45071328295 5669.80111366963,3772.45071328295 5669.80111366963,3772.45071328295 PathPoint;PointKind.SMOOTHPOINT 5669.75101262778,3779.46103457581 5669.37203164761,3783.08248949325 5670.12999360794,3775.83957965836 PathPoint;PointKind.CORNERPOINT 5666.69509587647,3789.45416293547 5666.69509587647,3789.45416293547 5666.69509587647,3789.45416293547 PathPoint;PointKind.SMOOTHPOINT 5669,3798 5671.18830080279,3800.30543131032 5666.37188257949,3795.2312105444 PathPoint;PointKind.SMOOTHPOINT 5675.49370519195,3806.56804628829 5676.56567889346,3815.27268244169 5674.25094743949,3796.47661023274 PathPoint;PointKind.SMOOTHPOINT 5671.88879615241,3823.68957875459 5666.66950226405,3827.55279869984 5674.41513728594,3821.81963012469 PathPoint";
	
	shadow35mm[0] = "PointKind.CORNERPOINT 5620.18696904182,3815.38904428482 5620.18696904182,3815.38904428482 5620.18696904182,3815.38904428482 PathPoint;PointKind.CORNERPOINT 5673.69018316269,3581.37132883072 5673.69018316269,3581.37132883072 5673.69018316269,3581.37132883072 PathPoint;PointKind.CORNERPOINT 5679.63470935822,3530.36760091782 5679.63470935822,3530.36760091782 5679.63470935822,3530.36760091782 PathPoint;PointKind.SMOOTHPOINT 5713.32201004028,3422.35920667648 5714.71697330475,3393.27764511108 5711.92704677582,3451.44100427628 PathPoint;PointKind.SMOOTHPOINT 5704.4048666954,3353.35407972336 5704.63924884796,3321.33955478668 5704.17048454285,3385.36860466003 PathPoint;PointKind.SMOOTHPOINT 5707.37712979317,3285.34903049469 5707.21462011337,3250.22215604782 5707.53999352455,3320.47566890717 PathPoint;PointKind.SMOOTHPOINT 5715.30363678932,3185.34125804901 5703.78633856773,3171.54079914093 5726.82093501091,3199.14195299149 PathPoint;PointKind.SMOOTHPOINT 5704.4048666954,3099.33480978012 5710.16457796097,3073.94152164459 5698.64515542984,3124.72833395004 PathPoint;PointKind.SMOOTHPOINT 5714.3130004406,3017.32867240906 5713.27421307564,2985.09581565857 5714.63306307793,3027.2704410553 PathPoint;PointKind.SMOOTHPOINT 5736.11054062843,2923.32160234451 5737.5901222229,2891.03233337402 5735.86589097977,2928.65881204605 PathPoint;PointKind.SMOOTHPOINT 5734.12891387939,2728.30668210983 5737.78201818466,2642.08190202713 5730.47580957413,2814.53146219254 PathPoint;PointKind.CORNERPOINT 5738.09216737747,2518.29083204269 5738.09216737747,2518.29083204269 5738.09216737747,2518.29083204269 PathPoint;PointKind.CORNERPOINT 5679.63470935822,2471.28717899323 5679.63470935822,2471.28717899323 5679.63470935822,2471.28717899323 PathPoint;PointKind.SMOOTHPOINT 5734.12891387939,2422.28360652924 5750.61638832092,2422.32467651367 5717.64143943787,2422.2425365448 PathPoint;PointKind.SMOOTHPOINT 5742.05506682396,2294.27389383316 5743.47127318382,2280.94078302383 5738.21219086647,2330.45749425888 PathPoint;PointKind.SMOOTHPOINT 5745.60230970383,2105.39893627167 5745.68621993065,2096.73954248428 5744.6647810936,2202.29695558548 PathPoint;PointKind.SMOOTHPOINT 5735.11955022812,2085.25788545609 5735.19460916519,2076.85152053833 5735.03988862038,2094.17526483536 PathPoint;PointKind.SMOOTHPOINT 5746.06753349304,2053.52636575699 5746.60144329071,1989.40597057343 5745.99601507187,2062.10409164429 PathPoint;PointKind.SMOOTHPOINT 5747.34920024872,1860.91994047165 5747.3920404911,1852.81215906143 5747.03126192093,1921.28620862961 PathPoint;PointKind.SMOOTHPOINT 5740.07344007492,1836.23900413513 5740.11769652367,1827.32846975327 5740.03484845161,1844.03852462769 PathPoint;PointKind.SMOOTHPOINT 5747.59562015533,1811.01448059082 5747.88842082024,1747.40250349045 5747.55702853203,1819.44326877594 PathPoint;PointKind.SMOOTHPOINT 5747.99994707108,1683.22758436203 5747.91532874107,1635.38034439087 5748.02756309509,1698.72300624847 PathPoint;PointKind.SMOOTHPOINT 5739.54908967018,909.287095069885 5739.32886958122,882.175476551056 5741.41352534294,1138.54352474213 PathPoint;PointKind.SMOOTHPOINT 5739.10050630569,840.363636016846 5746.68676972389,829.182922840118 5726.58761501312,858.805947303772 PathPoint;PointKind.SMOOTHPOINT 5739.0828037262,808.161227703094 5739.81993913651,677.45151758194 5739.03890132904,815.921566486359 PathPoint;PointKind.SMOOTHPOINT 5740.07344007492,588.144600391388 5739.37666654587,514.905960559845 5740.61620116234,645.171217918396 PathPoint;PointKind.SMOOTHPOINT 5739.0828037262,372.128047943115 5739.13520336151,365.698707103729 5738.80664348602,406.098117828369 PathPoint;PointKind.SMOOTHPOINT 5729.37612533569,328.874981403351 5728.18261742592,292.274544239044 5729.8944568634,344.766232967377 PathPoint;PointKind.SMOOTHPOINT 5728.18403363228,228.117327690125 5718.86893630028,196.837105751038 5734.25601840019,248.507158756256 PathPoint;PointKind.SMOOTHPOINT 5699.4509768486,163.112275600433 5636.07220172882,127.552750110626 5710.24034500122,169.165849685669 PathPoint;PointKind.SMOOTHPOINT 5483.65794897079,133.65683555603 5479.86393213272,133.688228130341 5527.32454776764,133.296883106232 PathPoint;PointKind.SMOOTHPOINT 5440.21511077881,124.509086608887 5391.62117600441,124.912469387054 5467.82228350639,124.280133247375 PathPoint;PointKind.SMOOTHPOINT 5205.85455536842,126.452593803406 5169.9533700943,126.749997138977 5309.5251095295,125.593664646149 PathPoint;PointKind.SMOOTHPOINT 5079.41175699234,130.65660238266 5040.91183304787,130.975484848022 5119.99244213104,130.320725440979 PathPoint;PointKind.SMOOTHPOINT 4970.15780925751,128.403418064117 4950.52812695503,128.565573692322 5012.00068831444,128.057391643524 PathPoint;PointKind.SMOOTHPOINT 4910.34822821617,128.89767408371 4366.80574893951,133.389172554016 4930.57696580887,128.730561733246 PathPoint;PointKind.SMOOTHPOINT 3525.63723564148,140.110487937927 3372.21464395523,141.071619987488 3622.8137755394,139.501991271973 PathPoint;PointKind.SMOOTHPOINT 638.448132276535,149.111187458038 574.366210699081,150.593483448029 702.529699802399,147.628891468048 PathPoint;PointKind.CORNERPOINT 308.511704206467,155.111653804779 308.511704206467,155.111653804779 308.511704206467,155.111653804779 PathPoint;PointKind.CORNERPOINT 245.100710391998,247.11856842041 245.100710391998,247.11856842041 245.100710391998,247.11856842041 PathPoint;PointKind.CORNERPOINT 232.220313549042,696.152758598328 232.220313549042,696.152758598328 232.220313549042,696.152758598328 PathPoint;PointKind.SMOOTHPOINT 237,786 239.156259370823,816.430739657322 234.284034691546,747.670272909543 PathPoint;PointKind.SMOOTHPOINT 233.286286326389,985.73915028795 228.688619676819,1052.36673311308 241.110822736186,872.349035813093 PathPoint;PointKind.SMOOTHPOINT 230,1607 229.970613718033,1617.49928188324 230.195082426071,1536.7061252594 PathPoint;PointKind.SMOOTHPOINT 194.569759368896,1724.23053503036 192.87880897522,1761.49116039276 197.179473638535,1666.73751354218 PathPoint;PointKind.SMOOTHPOINT 191.996512413025,1857.78327941895 191.956858634949,1870.08397579193 192.160792350769,1806.64666414261 PathPoint;PointKind.SMOOTHPOINT 206.459519863129,1895.24358987808 211.784455776215,1918.2451415062 203.536469936371,1882.61740207672 PathPoint;PointKind.SMOOTHPOINT 192.061303853989,1927.74646997452 192.161500453949,1951.42567634583 192.015277147293,1916.86410427094 PathPoint;PointKind.SMOOTHPOINT 192.529360055923,2001.4035987854 192.626016139984,2013.5872220993 192.328258752823,1976.02636098862 PathPoint;PointKind.SMOOTHPOINT 214.386026859283,2038.25446844101 217.576385736465,2071.80298089981 212.298892736435,2016.31200313568 PathPoint;PointKind.SMOOTHPOINT 193.310751914978,2091.7146062851 193.942379951477,2163.18157196045 193.151428699493,2073.68110656738 PathPoint;PointKind.SMOOTHPOINT 194.569759368896,2316.27536773682 194.573299884796,2341.4092540741 194.559491872787,2238.93350601196 PathPoint;PointKind.SMOOTHPOINT 227,2407 227.046734809875,2749.50337123871 226.9964594841,2381.8387336731 PathPoint;PointKind.SMOOTHPOINT 228,3129 228.900373412307,3751.11545571113 227.927522525598,3078.92149212762 PathPoint;PointKind.SMOOTHPOINT 263,3767 297.935017345621,3799.76918013535 268.893055023718,3772.52775986423 PathPoint;PointKind.CORNERPOINT 965.41158914566,3803.38811159134 965.41158914566,3803.38811159134 965.41158914566,3803.38811159134 PathPoint;PointKind.SMOOTHPOINT 1026.84131026268,3822.38958835602 1045.9753203392,3825.37825584412 979.18915271759,3814.94624376297 PathPoint;PointKind.SMOOTHPOINT 1111.9999229908,3824.99989271164 1122.39416956902,3827.77140855789 1094.85886931419,3820.42955875397 PathPoint;PointKind.SMOOTHPOINT 1191.31385207176,3834.3905210495 1212.42948889732,3830.47683477402 1188.05693149567,3834.99429702759 PathPoint;PointKind.SMOOTHPOINT 1256.70682668686,3815.38904428482 1289.34648871422,3808.74467611313 1224.06681060791,3822.03341245651 PathPoint;PointKind.SMOOTHPOINT 1714.45587873459,3824.38974380493 1718.98773908615,3824.40626621246 1667.47535705566,3824.2179107666 PathPoint;PointKind.SMOOTHPOINT 1786.00014567375,3818.99989843369 1800.43199658394,3818.95387172699 1738.06403875351,3819.15355682373 PathPoint;PointKind.SMOOTHPOINT 1843.91979932785,3824.01633739471 2007.05508828163,3823.47086191177 1826.10179901123,3824.07605409622 PathPoint;PointKind.SMOOTHPOINT 2623.99989724159,3815.00005960464 2645.58182001114,3814.92027997971 2285.00151872635,3816.2505698204 PathPoint;PointKind.SMOOTHPOINT 2710.99108099937,3820.89572668076 3475.59770822525,3818.06921482086 2689.11600351334,3820.97668647766 PathPoint;PointKind.SMOOTHPOINT 4423.30140709877,3814.38896656036 4456.06038451195,3814.14278268814 4403.9184987545,3814.53459978104 PathPoint;PointKind.SMOOTHPOINT 4513.46418499947,3823.38966608047 4549.19507145882,3823.124127388 4477.73294448853,3823.65544080734 PathPoint;PointKind.SMOOTHPOINT 4586.78331255913,3821.38951063156 4638.10840129852,3808.30045938492 4535.45786976814,3834.4787979126 PathPoint;PointKind.SMOOTHPOINT 4753.23748111725,3812.38881111145 4828.45609545708,3801.9039273262 4678.01886677742,3822.8736948967 PathPoint;PointKind.SMOOTHPOINT 5114.87922906876,3811.38873338699 5148.02376866341,3810.89848995209 5081.73468947411,3811.87921285629 PathPoint";
	
	shadow35mm[1] = "PointKind.CORNERPOINT 5620.71804642677,3815.93593597412 5620.71804642677,3815.93593597412 5620.71804642677,3815.93593597412 PathPoint;PointKind.CORNERPOINT 5674.22126054764,3581.91822052002 5674.22126054764,3581.91822052002 5674.22126054764,3581.91822052002 PathPoint;PointKind.CORNERPOINT 5680.16614079475,3530.91425657272 5680.16614079475,3530.91425657272 5680.16614079475,3530.91425657272 PathPoint;PointKind.SMOOTHPOINT 5713.85344147682,3422.90609836578 5715.2480506897,3393.82453680038 5712.45847821236,3451.98789596558 PathPoint;PointKind.SMOOTHPOINT 5704.93594408035,3353.90097141266 5705.1706802845,3321.88644647598 5704.7015619278,3385.91549634933 PathPoint;PointKind.SMOOTHPOINT 5707.90856122971,3285.89592218399 5707.74569749832,3250.76904773712 5708.0710709095,3321.02256059647 PathPoint;PointKind.SMOOTHPOINT 5715.83471417427,3185.88814973831 5704.31741595268,3172.08769083023 5727.35236644745,3199.68884468079 PathPoint;PointKind.SMOOTHPOINT 5704.93594408035,3099.88170146942 5710.69565534592,3074.48841333389 5699.17658686638,3125.27522563934 PathPoint;PointKind.SMOOTHPOINT 5714.84407782555,3017.87556409836 5713.80529046059,2985.64270734787 5715.16449451447,3027.8173327446 PathPoint;PointKind.SMOOTHPOINT 5712.53141283989,2923.54677915573 5714.01099443436,2891.25774621964 5712.28676319122,2928.88422489166 PathPoint;PointKind.SMOOTHPOINT 5716.66000843048,2727.85349607468 5720.31311273575,2641.62871599197 5713.00690412521,2814.07851219177 PathPoint;PointKind.CORNERPOINT 5720.62326192856,2517.83764600754 5720.62326192856,2517.83764600754 5720.62326192856,2517.83764600754 PathPoint;PointKind.SMOOTHPOINT 5725.99988937378,2421.99989318848 5723.37707519531,2405.72248935699 5728.15570950508,2435.37690639496 PathPoint;PointKind.SMOOTHPOINT 5724.58651542664,2293.820707798 5726.00236773491,2280.48783302307 5720.74363946915,2330.00430822372 PathPoint;PointKind.SMOOTHPOINT 5728.1337583065,2104.94575023651 5728.21731448174,2096.28635644913 5727.19587564468,2201.84376955032 PathPoint;PointKind.SMOOTHPOINT 5717.6509988308,2084.80493545532 5717.72605776787,2076.39833450317 5717.57133722305,2093.72231483459 PathPoint;PointKind.SMOOTHPOINT 5728.59862804413,2053.07317972183 5729.1325378418,1988.95278453827 5728.52710962296,2061.65090560913 PathPoint;PointKind.SMOOTHPOINT 5729.88064885139,1860.46675443649 5729.92313504219,1852.35920906067 5729.56271052361,1920.83325862885 PathPoint;PointKind.SMOOTHPOINT 5722.6048886776,1835.78605413437 5722.64914512634,1826.87528371811 5722.56629705429,1843.58557462692 PathPoint;PointKind.SMOOTHPOINT 5730.12706875801,1810.56129455566 5730.41951537132,1746.94931745529 5730.08812308311,1818.99008274078 PathPoint;PointKind.SMOOTHPOINT 5730.53139567375,1682.77439832687 5730.44642329216,1634.92715835571 5730.55865764618,1698.26982021332 PathPoint;PointKind.SMOOTHPOINT 5722.08053827286,908.833909034729 5721.85996413231,881.7222905159 5723.94461989403,1138.09057474136 PathPoint;PointKind.SMOOTHPOINT 5721.63195490837,839.910686016083 5729.21786427498,828.729972839355 5709.1190636158,858.352761268616 PathPoint;PointKind.SMOOTHPOINT 5721.61389827728,807.708041667938 5722.35138773918,676.998331546783 5721.57034993172,815.468380451202 PathPoint;PointKind.SMOOTHPOINT 5722.6048886776,587.691414356232 5721.90811514854,514.453010559082 5723.14729571342,644.71803188324 PathPoint;PointKind.SMOOTHPOINT 5721.61389827728,371.675097942352 5721.6662979126,365.245521068573 5721.3380920887,405.645167827606 PathPoint;PointKind.SMOOTHPOINT 5729.90720272064,329.421637058258 5728.71369481087,292.821435928345 5730.42553424835,345.313124656677 PathPoint;PointKind.SMOOTHPOINT 5728.71511101723,228.664219379425 5719.40036773682,197.383997440338 5734.78709578514,249.054050445557 PathPoint;PointKind.SMOOTHPOINT 5699.98205423355,163.659167289734 5636.60363316536,128.099641799927 5710.77142238617,169.712741374969 PathPoint;PointKind.SMOOTHPOINT 5484.18902635574,134.203727245331 5480.39500951767,134.235119819641 5527.85562515259,133.843774795532 PathPoint;PointKind.SMOOTHPOINT 5440.74654221535,125.055978298187 5392.15225338936,125.459361076355 5468.35371494293,124.826788902283 PathPoint;PointKind.SMOOTHPOINT 5206.38598680496,126.999485492706 5170.48444747925,127.296888828278 5310.05654096603,126.140556335449 PathPoint;PointKind.SMOOTHPOINT 5079.94283437729,131.20349407196 5041.44291043282,131.52214050293 5120.52351951599,130.86761713028 PathPoint;PointKind.SMOOTHPOINT 4970.68924069405,128.950309753418 4951.05955839157,129.112465381622 5012.53211975098,128.604283332825 PathPoint;PointKind.SMOOTHPOINT 4910.87965965271,129.44456577301 4367.33718037605,133.936064243317 4931.10839724541,129.277453422546 PathPoint;PointKind.SMOOTHPOINT 3526.16831302643,140.657379627228 3372.74572134018,141.618275642395 3623.34520697594,140.048882961273 PathPoint;PointKind.SMOOTHPOINT 638.979209661484,149.658079147339 574.89728808403,151.140375137329 703.061131238937,148.175783157349 PathPoint;PointKind.CORNERPOINT 309.043135643005,155.65854549408 309.043135643005,155.65854549408 309.043135643005,155.65854549408 PathPoint;PointKind.CORNERPOINT 245.631787776947,247.665460109711 245.631787776947,247.665460109711 245.631787776947,247.665460109711 PathPoint;PointKind.SMOOTHPOINT 230,1613 229.970967769623,1623.49928188324 231.6443129075,1020.50621221021 PathPoint;PointKind.SMOOTHPOINT 211.101136207581,1724.77742671967 209.409831762314,1762.03805208206 213.710850477219,1667.28440523148 PathPoint;PointKind.SMOOTHPOINT 208.527535200119,1858.33017110825 211.177965402603,1868.57878446579 204.9926841259,1844.66000318527 PathPoint;PointKind.SMOOTHPOINT 208.592326641083,1928.29336166382 208.692877292633,1951.97256803513 208.52045416832,1911.33193016052 PathPoint;PointKind.SMOOTHPOINT 209.671829938889,1995.77960729599 211.014393568039,2006.43726825714 206.500235795975,1970.60040235519 PathPoint;PointKind.SMOOTHPOINT 209.842128753662,2092.2614979744 212.256052494049,2163.69046211243 209.279894828796,2075.62414169312 PathPoint;PointKind.SMOOTHPOINT 216.531225442886,2316.54680728912 216.534765958786,2341.6806936264 216.520603895187,2239.20470952988 PathPoint;PointKind.SMOOTHPOINT 240,2418 240.044265420322,2744.88244543932 239.9964594841,2392.8387336731 PathPoint;PointKind.SMOOTHPOINT 241,3659 250.097001552582,3714.15486478806 228.295668245568,3581.97132527091 PathPoint;PointKind.SMOOTHPOINT 275,3791 282.436154231347,3790.96282109058 267.563845768653,3791.03717890942 PathPoint;PointKind.CORNERPOINT 965.943020582199,3803.93500328064 965.943020582199,3803.93500328064 965.943020582199,3803.93500328064 PathPoint;PointKind.SMOOTHPOINT 1027.37238764763,3822.93648004532 1046.50639772415,3825.92514753342 979.720230102539,3815.49313545227 PathPoint;PointKind.SMOOTHPOINT 1112.53135442734,3825.54678440094 1122.92560100555,3828.31830024719 1095.39030075073,3820.97645044327 PathPoint;PointKind.SMOOTHPOINT 1191.8452835083,3834.9374127388 1212.96056628227,3831.02372646332 1188.58800888062,3835.54118871689 PathPoint;PointKind.SMOOTHPOINT 1257.23790407181,3815.93593597412 1289.87792015076,3809.29156780243 1224.59824204445,3822.58030414581 PathPoint;PointKind.SMOOTHPOINT 1714.98731017113,3824.93663549423 1719.51917052269,3824.95315790176 1668.00643444061,3824.7648024559 PathPoint;PointKind.SMOOTHPOINT 1786.5312230587,3819.54679012299 1800.96307396889,3819.5005273819 1738.59547019005,3819.70044851303 PathPoint;PointKind.SMOOTHPOINT 1844.4508767128,3824.56322908401 2007.58616566658,3824.01775360107 1826.63287639618,3824.62294578552 PathPoint;PointKind.SMOOTHPOINT 2624.53132867813,3815.54695129395 2646.11325144768,3815.46717166901 2285.5325961113,3816.7974615097 PathPoint;PointKind.SMOOTHPOINT 2711.52251243591,3821.44261837006 3476.1287856102,3818.61610651016 2689.64743494987,3821.52357816696 PathPoint;PointKind.SMOOTHPOINT 4423.83248448372,3814.93585824966 4456.59181594849,3814.68967437744 4404.44957613945,3815.08149147034 PathPoint;PointKind.SMOOTHPOINT 4513.99526238441,3823.93655776978 4549.72650289536,3823.6710190773 4478.26402187347,3824.20233249664 PathPoint;PointKind.SMOOTHPOINT 4587.31438994408,3821.93640232086 4638.63983273506,3808.84735107422 4535.98894715309,3835.0256896019 PathPoint;PointKind.SMOOTHPOINT 4753.76891255379,3812.93570280075 4828.98717284203,3802.4508190155 4678.55029821396,3823.420586586 PathPoint;PointKind.SMOOTHPOINT 5115.41066050529,3811.93562507629 5148.55484604836,3811.44538164139 5082.26612091064,3812.42610454559 PathPoint";
	
	shadow35mm[2] = "PointKind.CORNERPOINT 5621.18681073189,3814.98282909393 5621.18681073189,3814.98282909393 5621.18681073189,3814.98282909393 PathPoint;PointKind.CORNERPOINT 5674.69002485275,3580.96511363983 5674.69002485275,3580.96511363983 5674.69002485275,3580.96511363983 PathPoint;PointKind.CORNERPOINT 5680.63490509987,3529.96114969254 5680.63490509987,3529.96114969254 5680.63490509987,3529.96114969254 PathPoint;PointKind.SMOOTHPOINT 5666.46859288216,3505.04677534103 5667.86355614662,3475.96521377563 5665.07362961769,3534.12857294083 PathPoint;PointKind.SMOOTHPOINT 5686.46861314774,3345.04684925079 5686.70334935188,3313.03232431412 5686.23423099518,3377.06137418747 PathPoint;PointKind.SMOOTHPOINT 5708.37732553482,3284.94257926941 5708.21446180344,3249.81594085693 5708.53983521461,3320.06945371628 PathPoint;PointKind.SMOOTHPOINT 5716.30347847939,3184.93504285812 5704.7861802578,3171.13458395004 5727.82113075256,3198.7357378006 PathPoint;PointKind.SMOOTHPOINT 5705.40470838547,3098.92859458923 5711.16441965103,3073.53507041931 5699.6449971199,3124.32188272476 PathPoint;PointKind.SMOOTHPOINT 5715.31284213066,3016.92245721817 5714.2740547657,2984.68960046768 5715.63325881958,3026.86422586441 PathPoint;PointKind.SMOOTHPOINT 5712.99982309341,2922.59367227554 5714.47975873947,2890.30463933945 5712.75552749634,2927.93111801147 PathPoint;PointKind.SMOOTHPOINT 5717.1287727356,2726.90038919449 5720.78187704086,2640.67560911179 5713.47566843033,2813.12540531158 PathPoint;PointKind.CORNERPOINT 5721.09202623367,2516.88453912735 5721.09202623367,2516.88453912735 5721.09202623367,2516.88453912735 PathPoint;PointKind.CORNERPOINT 5680.63490509987,2470.88096380234 5680.63490509987,2470.88096380234 5680.63490509987,2470.88096380234 PathPoint;PointKind.SMOOTHPOINT 5717.1287727356,2420.87731361389 5733.61624717712,2420.91838359833 5700.64129829407,2420.83624362946 PathPoint;PointKind.SMOOTHPOINT 5725.05527973175,2292.86760091782 5726.47113204002,2279.53472614288 5721.21240377426,2329.05120134354 PathPoint;PointKind.SMOOTHPOINT 5728.60252261162,2103.99264335632 5728.68607878685,2095.33324956894 5727.6646399498,2200.89066267014 PathPoint;PointKind.SMOOTHPOINT 5700.46887516975,2086.04694843292 5700.54393410683,2077.64034748077 5700.38921356201,2094.96432781219 PathPoint;PointKind.SMOOTHPOINT 5729.06739234924,2052.12007284164 5729.60130214691,1987.99967765808 5728.99587392807,2060.69779872894 PathPoint;PointKind.SMOOTHPOINT 5730.34941315651,1859.5136475563 5730.39189934731,1851.40586614609 5730.03147482872,1919.88015174866 PathPoint;PointKind.SMOOTHPOINT 5710.46870827675,1837.04694986343 5710.51296472549,1828.13617944717 5710.43011665344,1844.84647035599 PathPoint;PointKind.SMOOTHPOINT 5730.59583306313,1809.60818767548 5730.88827967644,1745.9962105751 5730.55688738823,1818.0369758606 PathPoint;PointKind.SMOOTHPOINT 5731.00015997887,1681.82129144669 5730.91518759727,1633.97405147552 5731.02742195129,1697.31671333313 PathPoint;PointKind.SMOOTHPOINT 5722.54930257797,907.880802154541 5722.32872843742,880.769183635712 5724.41338419914,1137.13746786118 PathPoint;PointKind.SMOOTHPOINT 5722.10071921349,838.957343101501 5729.68662858009,827.776629924774 5709.58782792091,857.399654388428 PathPoint;PointKind.SMOOTHPOINT 5722.0826625824,806.75493478775 5722.8201520443,676.045224666595 5722.03911423683,814.515273571014 PathPoint;PointKind.SMOOTHPOINT 5723.07365298271,586.738307476044 5722.37687945366,513.499667644501 5723.61606001854,643.764925003052 PathPoint;PointKind.SMOOTHPOINT 5722.0826625824,370.721991062164 5722.13506221771,364.292414188385 5721.80685639381,404.692060947418 PathPoint;PointKind.SMOOTHPOINT 5703.46875429153,338.046805858612 5702.27524638176,301.446604728699 5703.98708581924,353.938293457031 PathPoint;PointKind.SMOOTHPOINT 5703.46875429153,259.046802520752 5694.15365695953,227.766816616058 5709.54073905945,279.436869621277 PathPoint;PointKind.SMOOTHPOINT 5700.45081853867,162.706060409546 5637.07239747047,127.146534919739 5711.24018669128,168.759634494781 PathPoint;PointKind.SMOOTHPOINT 5484.65779066086,133.250620365143 5480.86377382278,133.282012939453 5528.3243894577,132.890667915344 PathPoint;PointKind.SMOOTHPOINT 5427.06067800522,137.534880638123 5383.18660497665,133.459038734436 5454.55065965652,140.088772773743 PathPoint;PointKind.SMOOTHPOINT 5206.85475111008,126.046378612518 5170.95285773277,126.26683473587 5310.28915286064,125.41121006012 PathPoint;PointKind.SMOOTHPOINT 5080.4115986824,130.250387191772 5041.91167473793,130.569033622742 5120.99228382111,129.914510250092 PathPoint;PointKind.SMOOTHPOINT 4971.15800499916,127.99720287323 4951.52832269669,128.159358501434 5013.00088405609,127.651176452637 PathPoint;PointKind.SMOOTHPOINT 4911.34842395782,128.491458892822 4367.80594468117,132.982957363129 4931.57716155052,128.324346542358 PathPoint;PointKind.SMOOTHPOINT 3526.63707733154,139.70427274704 3373.21448564529,140.665168762207 3623.81361722946,139.095540046692 PathPoint;PointKind.SMOOTHPOINT 639.447973966599,148.704972267151 575.366052389145,150.187268257141 703.529895544052,147.222676277161 PathPoint;PointKind.CORNERPOINT 309.51189994812,154.705438613892 309.51189994812,154.705438613892 309.51189994812,154.705438613892 PathPoint;PointKind.CORNERPOINT 246.100552082062,246.712353229523 246.100552082062,246.712353229523 246.100552082062,246.712353229523 PathPoint;PointKind.SMOOTHPOINT 227,1603 226.970967769623,1613.49928188324 228.614282741717,1021.32695477779 PathPoint;PointKind.SMOOTHPOINT 211.569900512695,1723.82431983948 209.878596067429,1761.08494520187 214.179614782333,1666.33129835129 PathPoint;PointKind.SMOOTHPOINT 208.996299505234,1857.37706422806 208.956999778748,1869.67776060104 209.160933494568,1806.24021291733 PathPoint;PointKind.SMOOTHPOINT 214.468874931335,1891.04689836502 219.793810844421,1914.04844999313 211.545825004578,1878.42071056366 PathPoint;PointKind.SMOOTHPOINT 209.061090946198,1927.34025478363 209.161641597748,1951.01946115494 209.015064239502,1916.45788908005 PathPoint;PointKind.SMOOTHPOINT 209.529501199722,2000.99738359451 209.625803232193,2013.18100690842 209.328399896622,1975.62014579773 PathPoint;PointKind.SMOOTHPOINT 231.385813951492,2037.84825325012 234.576526880264,2071.39676570892 229.299033880234,2015.90578794479 PathPoint;PointKind.SMOOTHPOINT 210.310893058777,2091.30839109421 210.942167043686,2162.77535676956 210.151215791702,2073.2746553421 PathPoint;PointKind.SMOOTHPOINT 216.999989748001,2315.59370040894 217.003530263901,2340.72758674622 216.989368200302,2238.25160264969 PathPoint;PointKind.SMOOTHPOINT 229,2415 229.043888928998,2739.10220741614 228.9964594841,2389.8387336731 PathPoint;PointKind.SMOOTHPOINT 243,3678 252.097001552582,3733.15486478806 230.590038030939,3602.75614283438 PathPoint;PointKind.SMOOTHPOINT 268.099547624588,3805.52894353867 277.893322706223,3814.7158741951 248.860738277435,3787.48269796371 PathPoint;PointKind.SMOOTHPOINT 307,3818 313.804871559143,3817.59520101547 280.756279945374,3819.56065940857 PathPoint;PointKind.SMOOTHPOINT 344,3808 360.211062872076,3807.79751040913 325.527004241943,3808.23060560226 PathPoint;PointKind.SMOOTHPOINT 438,3808 444.357641111766,3806.66973370709 400.127531439566,3815.9243964026 PathPoint;PointKind.SMOOTHPOINT 481,3813 506.415947437286,3813.27427196503 471.423646778333,3812.89671979808 PathPoint;PointKind.SMOOTHPOINT 559.999859333038,3824.59367752075 583.119428157806,3824.13742303848 550.704234838486,3824.77731227875 PathPoint;PointKind.CORNERPOINT 966.411784887314,3802.98189640045 966.411784887314,3802.98189640045 966.411784887314,3802.98189640045 PathPoint;PointKind.SMOOTHPOINT 1027.84115195274,3821.98337316513 1046.97516202927,3824.97204065323 980.188994407654,3814.54002857208 PathPoint;PointKind.SMOOTHPOINT 1122.4688744545,3813.046875 1132.86312103271,3815.81839084625 1105.32782077789,3808.47654104233 PathPoint;PointKind.SMOOTHPOINT 1192.31404781342,3833.98430585861 1213.42933058739,3830.07061958313 1189.05677318573,3834.5880818367 PathPoint;PointKind.SMOOTHPOINT 1257.70666837692,3814.98282909393 1290.34668445587,3808.33846092224 1225.06700634956,3821.62719726562 PathPoint;PointKind.SMOOTHPOINT 1715.45607447624,3823.98352861404 1719.9879348278,3824.00005102158 1668.47519874573,3823.81169557571 PathPoint;PointKind.SMOOTHPOINT 1786.99998736382,3818.5936832428 1801.431838274,3818.54742050171 1739.06423449516,3818.74734163284 PathPoint;PointKind.SMOOTHPOINT 1844.91964101791,3823.61012220383 2008.05492997169,3823.06464672089 1827.10164070129,3823.66983890533 PathPoint;PointKind.SMOOTHPOINT 2625.00009298325,3814.59384441376 2646.58201575279,3814.51406478882 2286.00136041641,3815.84435462952 PathPoint;PointKind.SMOOTHPOINT 2711.99127674103,3820.48951148987 3476.59754991531,3817.66299962997 2690.11619925499,3820.57047128677 PathPoint;PointKind.SMOOTHPOINT 4424.30124878883,3813.98275136948 4457.0605802536,3813.73656749725 4404.91834044456,3814.12838459015 PathPoint;PointKind.SMOOTHPOINT 4514.46402668953,3822.98345088959 4550.19526720047,3822.71791219711 4478.73278617859,3823.24898958206 PathPoint;PointKind.SMOOTHPOINT 4587.78315424919,3820.98329544067 4639.10859704018,3807.89424419403 4536.45771145821,3834.07258272171 PathPoint;PointKind.SMOOTHPOINT 4754.23732280731,3811.98259592056 4829.45593714714,3801.49771213531 4679.01906251907,3822.46747970581 PathPoint;PointKind.SMOOTHPOINT 5115.87907075882,3810.98251819611 5149.02361035347,3810.4922747612 5082.73488521576,3811.47276163101 PathPoint";
	
	subshadow35mm[0] = "PointKind.SMOOTHPOINT 219.763716459274,153.127548694611 220.404549837112,147.381999492645 219.670954942703,153.957917690277 PathPoint;PointKind.SMOOTHPOINT 237.975422143936,125.593900680542 240.302603244781,123.443863391876 231.660203933716,131.428670883179 PathPoint;PointKind.SMOOTHPOINT 1909.01395440102,124.965577125549 1919.76189851761,124.980211257935 977.890491485596,123.693115711212 PathPoint;PointKind.SMOOTHPOINT 1941.33461594582,125.009951591492 1955.95128178596,132.86328792572 1931.82195782661,119.899098873138 PathPoint;PointKind.SMOOTHPOINT 1980.56282401085,125.06471157074 2044.93719220161,125.155348777771 1967.45123147964,125.046300888062 PathPoint;PointKind.SMOOTHPOINT 2176.03718519211,125.350077152252 2182.21396923065,125.359282493591 2110.15314102173,125.250706672668 PathPoint;PointKind.SMOOTHPOINT 2194.58559393883,125.378165245056 2204.19632434845,133.756914138794 2189.92061018944,121.311292648315 PathPoint;PointKind.SMOOTHPOINT 2221.37986421585,125.418999195099 2360.74235916138,125.632138252258 2212.4368751049,125.405309200287 PathPoint;PointKind.SMOOTHPOINT 2646.20601296425,126.108927726746 2652.65152215958,126.120021343231 2502.89159417152,125.863687992096 PathPoint;PointKind.SMOOTHPOINT 2665.54997563362,126.142208576202 2671.72746777534,135.023946762085 2661.86677694321,120.84677696228 PathPoint;PointKind.SMOOTHPOINT 2685.64027905464,126.176905632019 2879.63187217712,126.51207447052 2678.9412689209,126.165339946747 PathPoint;PointKind.SMOOTHPOINT 3269.18279886246,127.246849536896 3278.89939069748,127.265732288361 3075.48081994057,126.872026920319 PathPoint;PointKind.SMOOTHPOINT 3298.31522583961,127.303261756897 3318.48271250725,117.929863929749 3289.51421141624,131.393973827362 PathPoint;PointKind.SMOOTHPOINT 3337.61778473854,127.379972934723 3709.6491765976,128.108375072479 3324.5284974575,127.354481220245 PathPoint;PointKind.SMOOTHPOINT 4395.93392729759,129.642598628998 4405.04898548126,129.663841724396 4071.96114420891,128.886580467224 PathPoint;PointKind.SMOOTHPOINT 4423.1874024868,129.706327915192 4441.62216067314,123.468647003174 4414.61121082306,132.608134746552 PathPoint;PointKind.SMOOTHPOINT 4454.35279369354,129.779498577118 5161.34708404541,131.446845531464 4444.00599002838,129.755187034607 PathPoint;PointKind.SMOOTHPOINT 5674.76048111916,133.594522476196 5677.03632473946,134.063522815704 5671.78644776344,132.981777191162 PathPoint;PointKind.SMOOTHPOINT 5700.53649902344,147.576019763947 5707.50104784966,153.327233791351 5689.90787029266,138.798608779907 PathPoint;PointKind.SMOOTHPOINT 5714.00001883507,168.999917507172 5714.80831861496,175.267102718353 5713.19171905518,162.732968330383 PathPoint;PointKind.SMOOTHPOINT 5725.94359517097,209.219706058502 5725.87809562683,264.308953285217 5725.97404360771,193.939547538757 PathPoint;PointKind.SMOOTHPOINT 5725.52652239799,520.887544155121 5725.50457119942,536.430881023407 5725.73647499084,373.570454120636 PathPoint;PointKind.SMOOTHPOINT 5725.45783638954,568.769245147705 5716.89509868622,583.907074928284 5733.51852893829,554.519376754761 PathPoint;PointKind.SMOOTHPOINT 5725.39198279381,614.078643321991 5725.3746342659,625.941023826599 5725.41464209557,598.654975891113 PathPoint;PointKind.SMOOTHPOINT 5725.33887505531,650.219521522522 5725.32223463058,661.540911197662 5725.3569316864,637.990107536316 PathPoint;PointKind.SMOOTHPOINT 5725.28789162636,684.643013477325 5721.33738398552,695.512397289276 5729.259288311,673.716509342194 PathPoint;PointKind.SMOOTHPOINT 5725.23867845535,717.639677524567 5725.07652282715,825.564043521881 5725.25531888008,706.512780189514 PathPoint;PointKind.SMOOTHPOINT 5724.68069314957,1073.42635631561 5724.65767979622,1087.42508411407 5724.88993763924,945.408854484558 PathPoint;PointKind.SMOOTHPOINT 5724.61129903793,1115.71097373962 5724.52349424362,1168.94782304764 5724.63466644287,1101.52176618576 PathPoint;PointKind.SMOOTHPOINT 5725.99988937378,1247.99998998642 5725.26594042778,1268.1094121933 5728.02825093269,1192.44551897049 PathPoint;PointKind.SMOOTHPOINT 5724.23777461052,1336.32004737854 5721.71303272247,1349.81318950653 5727.76873111725,1317.45334625244 PathPoint;PointKind.SMOOTHPOINT 5724.1609454155,1380.40914773941 5723.29104065895,1876.34077548981 5724.18679118156,1365.65109729767 PathPoint;PointKind.SMOOTHPOINT 5720.82507133484,2899.96623516083 5720.78683376312,2913.15725326538 5722.14993238449,2440.40325880051 PathPoint;PointKind.SMOOTHPOINT 5720.71035861969,2939.27705526352 5715.70867180824,2951.42409324646 5725.66566467285,2927.24236965179 PathPoint;PointKind.SMOOTHPOINT 5720.40693640709,2977.31140136719 5720.05394697189,3006.24992609024 5720.57192444801,2963.78899097443 PathPoint;PointKind.SMOOTHPOINT 5718.57719779015,3073.96842956543 5718.46319317818,3078.72829914093 5719.41948652267,3038.86869907379 PathPoint;PointKind.SMOOTHPOINT 5718.22350025177,3088.38163375854 5712.53636956215,3094.14889812469 5721.62841439247,3084.92845058441 PathPoint;PointKind.SMOOTHPOINT 5717.77385473251,3105.8595085144 5717.11213231087,3131.02856397629 5717.92857527733,3099.97658729553 PathPoint;PointKind.SMOOTHPOINT 5715.54651618004,3184.00978803635 5715.02358198166,3201.18506669998 5716.36154294014,3157.21020698547 PathPoint;PointKind.SMOOTHPOINT 5713.90584111214,3236.1936879158 5695.89205026627,3274.26745176315 5715.54120540619,3232.73743629456 PathPoint;PointKind.SMOOTHPOINT 5711.0844039917,3320.19644021988 5708.99797797203,3380.41329860687 5712.05875396729,3292.09324121475 PathPoint;PointKind.SMOOTHPOINT 5704.7224509716,3496.35952949524 5703.72331738472,3523.29624652863 5706.79436087608,3440.47413825989 PathPoint;PointKind.SMOOTHPOINT 5701.84401154518,3573.80949497223 5688.72321367264,3589.92167472839 5703.17382931709,3572.17660903931 PathPoint;PointKind.SMOOTHPOINT 5699.20632719994,3645.68952083588 5696.80412665574,3677.30737437516 5700.30707359314,3631.19984149933 PathPoint;PointKind.SMOOTHPOINT 5690,3735 5688.78647484905,3741.73097755262 5691.21352515095,3728.26902244738 PathPoint;PointKind.SMOOTHPOINT 5685,3758 5684.60288033257,3762.42249869745 5685.40719643816,3753.46528196645 PathPoint;PointKind.SMOOTHPOINT 5684.3775984306,3769.34912453476 5682.71915629268,3773.54782947708 5685.58131050207,3766.30166709985 PathPoint;PointKind.SMOOTHPOINT 5684,3780 5683.91445635725,3781.13550344488 5684.2606713823,3776.53985681388 PathPoint;PointKind.SMOOTHPOINT 5683.29797342017,3788.7585976495 5682.61969361244,3791.05716754749 5684.62369837468,3784.26595104744 PathPoint;PointKind.SMOOTHPOINT 5682,3796 5679.56569950089,3805.3996002276 5682.59993655591,3793.68345617577 PathPoint;PointKind.SMOOTHPOINT 5677,3818 5669.10110902786,3829.63507938385 5679.00715588339,3815.04373377582 PathPoint;PointKind.SMOOTHPOINT 5655.91396093369,3827.93757677078 5643.08100700378,3828.7379693985 5658.68760108948,3827.76456356049 PathPoint;PointKind.SMOOTHPOINT 399,3821 391.032423019409,3820.98701810837 1167.22645068169,3822.25924348831 PathPoint;PointKind.SMOOTHPOINT 383,3815 368.344742536545,3820.15805959702 389.755304336548,3812.62242555618 PathPoint;PointKind.SMOOTHPOINT 347,3820 305.884696960449,3819.93249416351 354.927923202515,3820.01298189163 PathPoint;PointKind.CORNERPOINT 290.999958515167,3819.99997615814 290.999958515167,3819.99997615814 290.999958515167,3819.99997615814 PathPoint;PointKind.CORNERPOINT 266.999863386154,3818.00005674362 266.999863386154,3818.00005674362 266.999863386154,3818.00005674362 PathPoint;PointKind.SMOOTHPOINT 245.000159740448,3806.00006818771 237.769364118576,3802.96513795853 252.23060131073,3809.03476238251 PathPoint;PointKind.SMOOTHPOINT 221.000064611435,3790.00000476837 215.944916009903,3781.56083106995 224.67334985733,3796.13288640976 PathPoint;PointKind.SMOOTHPOINT 210.100940465927,3767.50262260437 210.114040374756,3766.86580181122 210.038627386093,3770.53424835205 PathPoint;PointKind.SMOOTHPOINT 211.442087888718,3242.62680530548 211.490592956543,3223.49267721176 210.640515089035,3558.72453689575 PathPoint;PointKind.SMOOTHPOINT 211.590789556503,3184.05935525894 219.036494493484,3165.68313360214 203.242961168289,3204.66208934784 PathPoint;PointKind.SMOOTHPOINT 211.744447946548,3123.48726511002 211.987681388855,3027.60891437531 211.692402362823,3144.0340590477 PathPoint;PointKind.SMOOTHPOINT 212.527610063553,2815.28393983841 212.573990821838,2796.93320989609 212.25038766861,2924.13521289825 PathPoint;PointKind.SMOOTHPOINT 212.668522596359,2759.78375673294 218.729531764984,2734.71666812897 208.30660700798,2777.82504558563 PathPoint;PointKind.SMOOTHPOINT 212.86785364151,2681.62781238556 214.825758934021,1913.3792924881 212.800583839417,2707.93313741684 PathPoint;PointKind.SMOOTHPOINT 218.741569519043,453.145201206207 218.793615102768,435.15914440155 217.342711687088,937.076132297516 PathPoint;PointKind.SMOOTHPOINT 218.892749547958,401.263189315796 225.556354522705,389.010171890259 209.870806932449,417.853102684021 PathPoint;PointKind.SMOOTHPOINT 219.012418985367,360.959844589233 219.403291940689,230.567836761475 218.973827362061,373.873994350433 PathPoint";
	
} else {
	
	mask35mm[0] = "PointKind.CORNERPOINT 273.750064796937,131.080404299288 273.750064796937,131.080404299288 273.750064796937,131.080404299288 PathPoint;PointKind.SMOOTHPOINT 284.683359235861,130.096714450665 286.338718062628,129.946226629517 276.630022918657,130.829430181888 PathPoint;PointKind.SMOOTHPOINT 292.637996823297,128.093162491585 317.22590344219,127.877500878644 290.800746630041,128.10937891397 PathPoint;PointKind.SMOOTHPOINT 417.843090075814,128.420856670034 422.286839306184,128.458290500826 363.745520115209,127.964372414968 PathPoint;PointKind.SMOOTHPOINT 431.749737428596,130.481625277593 439.582827885089,130.959897710978 427.226398283361,130.205540726451 PathPoint;PointKind.SMOOTHPOINT 447.65140914122,129.511177880203 460.606747722323,129.552014046255 443.276554956898,129.497338550438 PathPoint;PointKind.SMOOTHPOINT 486.597066691249,129.718233671065 553.930038865847,130.210075164706 473.625685923807,129.62335954118 PathPoint;PointKind.SMOOTHPOINT 658.314220631109,130.06253705536 662.95735694616,130.136330771841 609.05855851124,129.279697488382 PathPoint;PointKind.SMOOTHPOINT 672.295396311645,130.265178991746 679.32888673012,128.560972431864 666.460967604937,131.679129735686 PathPoint;PointKind.SMOOTHPOINT 694.084453074635,131.168223217735 702.635736085753,130.120958167038 686.689623640228,132.07396825384 PathPoint;PointKind.SMOOTHPOINT 716.939272867458,131.228040204417 721.091786754752,130.029255166388 707.987811618763,133.812904316994 PathPoint;PointKind.SMOOTHPOINT 731.96652045242,130.717614902834 735.723144718366,130.628056136718 726.787749014416,130.840723100756 PathPoint;PointKind.SMOOTHPOINT 751.715969832471,132.331364947204 795.075980686954,131.844442736374 747.771591644001,132.375754225253 PathPoint;PointKind.SMOOTHPOINT 914.678716426107,133.770185803851 1045.76148624845,136.722750393084 841.857535553584,132.129825802672 PathPoint;PointKind.SMOOTHPOINT 1300.23640773879,132.754679979511 1401.62406441967,133.036045410667 1198.8491022503,132.47355438777 PathPoint;PointKind.SMOOTHPOINT 1479.09587455162,135.247411786677 1492.23135235118,135.554159825302 1412.77047319109,133.697879282299 PathPoint;PointKind.SMOOTHPOINT 1514.2233973352,135.790431056264 1518.28916881529,135.068781657214 1502.70857965075,137.834599434304 PathPoint;PointKind.SMOOTHPOINT 1526.45783708033,135.838220492604 1531.06948875869,135.843600613152 1522.40206017882,135.833578479652 PathPoint;PointKind.SMOOTHPOINT 1540.42165024402,135.819337911861 1542.87292889889,135.227258308575 1535.81340142328,136.932352403745 PathPoint;PointKind.SMOOTHPOINT 1547.19419403975,135.283963027541 1549.68228434455,135.412802174459 1545.06033968824,135.173253266166 PathPoint;PointKind.SMOOTHPOINT 1554.77294928979,135.750340547864 1578.40123086637,135.614833755165 1552.09731298054,135.765557297766 PathPoint;PointKind.SMOOTHPOINT 1652.31618838236,135.522300812179 1669.48455349682,135.573207879544 1607.05762178102,135.387839756741 PathPoint;PointKind.SMOOTHPOINT 1711.61997098173,135.855987610312 1859.6004122503,137.034116816036 1689.04164463015,135.676239550645 PathPoint;PointKind.SMOOTHPOINT 2023.63916926041,136.672622718232 2043.8700795382,137.012754398288 1951.21092014713,135.454985368593 PathPoint;PointKind.SMOOTHPOINT 2082.42020251462,137.119145226983 2088.65340847875,137.119690405725 2062.81253535518,137.117522293019 PathPoint;PointKind.SMOOTHPOINT 2105.11939310788,137.89794377477 2110.81998123086,137.883715420393 2098.68877201741,137.914084167725 PathPoint;PointKind.SMOOTHPOINT 2118.83702074451,137.039328932679 2136.34448355281,136.977875306471 2112.88838132354,137.06031460038 PathPoint;PointKind.SMOOTHPOINT 2176.26336989695,136.880943604177 2182.89379811427,136.875121888649 2155.11502660051,136.899658187315 PathPoint;PointKind.SMOOTHPOINT 2198.52644562096,138.142414239506 2204.31739721661,138.14896953155 2191.39400525016,138.134498205945 PathPoint;PointKind.SMOOTHPOINT 2214.81226210605,136.91995570017 2228.63800289349,136.961636412857 2208.64911555069,136.901435945798 PathPoint;PointKind.SMOOTHPOINT 2259.44290697419,137.158853914214 2266.40002228801,137.211944845067 2243.44558841384,137.036468660113 PathPoint;PointKind.SMOOTHPOINT 2279.01543414044,138.353074782795 2283.71493523903,138.398823430619 2271.59150289806,138.280843054667 PathPoint;PointKind.SMOOTHPOINT 2295.25070538575,137.488864333601 2322.14702473525,137.765686071016 2290.45516665653,137.439519446859 PathPoint;PointKind.SMOOTHPOINT 2379.35064446868,138.423347228098 2387.2143060126,138.512976421624 2350.47546991246,138.094517944077 PathPoint;PointKind.SMOOTHPOINT 2402.23045390064,139.687865536899 2410.03009077474,139.774937958736 2394.30381312726,139.599505031929 PathPoint;PointKind.SMOOTHPOINT 2426.49183723539,138.94787505265 2441.82058587671,139.112471812629 2418.66580522679,138.864078431453 PathPoint;PointKind.SMOOTHPOINT 2472.40604177771,139.410417148678 2475.38131711087,139.43803459636 2457.16800154237,139.269233060687 PathPoint;PointKind.SMOOTHPOINT 2482.72509755013,137.87416957388 2491.27906726414,137.95007566632 2479.75896636299,137.847770660063 PathPoint;PointKind.SMOOTHPOINT 2506.83022960896,139.702162863839 2514.43996034092,139.759828901419 2498.38388562241,139.638245548237 PathPoint;PointKind.SMOOTHPOINT 2529.48320528067,139.857736434273 2533.81545565285,139.884365952506 2521.99658028096,139.812099688716 PathPoint;PointKind.SMOOTHPOINT 2543.3428746217,137.020516893035 2547.16254076627,137.040070759415 2539.06057055455,136.998557582042 PathPoint;PointKind.SMOOTHPOINT 2559.23128774206,141.111082522725 2561.62716091232,141.120936947551 2555.45629313179,141.095229377129 PathPoint;PointKind.SMOOTHPOINT 2569.17599882181,138.10043398799 2576.07905241534,138.108227497411 2566.82689933289,138.097630669359 PathPoint;PointKind.SMOOTHPOINT 2589.12033235931,138.246290217173 2594.09209324587,138.310909378683 2582.71178500617,138.162858637142 PathPoint;PointKind.SMOOTHPOINT 2605.9348139986,141.233317755093 2608.81643118351,141.289121585286 2601.21186062282,141.141873958178 PathPoint;PointKind.SMOOTHPOINT 2623.82921117236,138.243475609186 2647.27545816659,138.296956145772 2621.07271236202,138.237216818411 PathPoint;PointKind.SMOOTHPOINT 2682.45426340871,139.408978758243 2797.86956188028,138.003009614811 2661.08997264853,139.669393287872 PathPoint;PointKind.SMOOTHPOINT 3016.3350984459,140.282831435441 3126.04141125585,139.813539766317 2907.98682802208,140.746598483824 PathPoint;PointKind.SMOOTHPOINT 3347.2346252887,141.148881256429 3352.4374931793,141.094167317648 3273.97825250178,141.92191032631 PathPoint;PointKind.SMOOTHPOINT 3364.03460655093,141.076019157521 3369.74675460493,141.080934678752 3358.05648199153,141.071124267602 PathPoint;PointKind.SMOOTHPOINT 3380.02354891192,142.24700348121 3383.90123190136,142.27937196614 3373.70569056163,142.19439105024 PathPoint;PointKind.SMOOTHPOINT 3394.04049499109,141.285002802564 3409.46213412622,141.042961489462 3389.96518844823,141.348879788212 PathPoint;PointKind.SMOOTHPOINT 3443.89211099014,140.602192859028 3447.3897840255,140.919793223023 3440.3940861365,140.284591574234 PathPoint;PointKind.SMOOTHPOINT 3452.27695744491,140.504678048589 3460.85876299039,142.578985994242 3449.54082186742,139.843114298535 PathPoint;PointKind.SMOOTHPOINT 3470.94262728821,140.303859279325 3538.95771201154,139.612919421819 3464.65999776846,140.367693214753 PathPoint;PointKind.SMOOTHPOINT 3659.25912687911,139.941158937241 3703.06660662735,140.546556665858 3613.04668739806,139.302707737326 PathPoint;PointKind.SMOOTHPOINT 3885.09523613586,141.173731445557 3890.95618642728,141.18548726765 3792.77867135767,140.988978090159 PathPoint;PointKind.SMOOTHPOINT 3902.69850060778,141.20594637622 3910.33747998517,140.171106646184 3896.87908024707,141.994204257177 PathPoint;PointKind.SMOOTHPOINT 3920.14487102159,141.231299827628 3945.61765959346,141.264042041118 3914.33703402571,141.223983581355 PathPoint;PointKind.SMOOTHPOINT 3994.99639454775,141.265695572654 3999.52925770623,141.263701875623 3970.87166976479,141.276142353545 PathPoint;PointKind.SMOOTHPOINT 4009.04128243655,139.844324377635 4014.20109517746,139.840387766346 4004.59425918552,139.847976261471 PathPoint;PointKind.SMOOTHPOINT 4023.75357836078,141.241569750269 4048.02400974405,141.210957179519 4018.72709911883,141.24800561216 PathPoint;PointKind.SMOOTHPOINT 4090.5215056581,141.069884352789 4113.38025548077,140.972502098625 4070.63391512743,141.15449575906 PathPoint;PointKind.SMOOTHPOINT 4158.06642356252,140.698822767466 4161.94636642761,140.674334146762 4135.77962199839,140.839035162295 PathPoint;PointKind.SMOOTHPOINT 4169.69816096301,140.625096808347 4178.9455412523,140.443111420504 4165.82371136871,140.701445501357 PathPoint;PointKind.SMOOTHPOINT 4190.15230036752,140.495617678147 4196.70119874978,140.454461300656 4183.33249626835,140.538215307447 PathPoint;PointKind.SMOOTHPOINT 4209.82115255573,140.375073579437 4212.32017357947,140.360350262572 4203.25431707381,140.414032728608 PathPoint;PointKind.SMOOTHPOINT 4217.32419591201,140.331158201053 4224.31456927443,138.835655094153 4214.87415046965,140.855387680004 PathPoint;PointKind.SMOOTHPOINT 4230.92015235422,140.255883345139 4242.53074873601,140.194286987421 4226.3784355291,140.280073453398 PathPoint;PointKind.SMOOTHPOINT 4266.01187199969,140.095905523066 4270.15706394913,140.08047333683 4254.2120430688,140.139565431659 PathPoint;PointKind.SMOOTHPOINT 4278.49387659603,140.054031044988 4281.63187971012,141.35336906191 4274.0657386771,138.220674528066 PathPoint;PointKind.SMOOTHPOINT 4288.69041512281,140.02696097193 4299.65638212882,140.001187931854 4285.27984417449,140.034997961833 PathPoint;PointKind.SMOOTHPOINT 4322.0005514136,139.987275577025 4325.87620799076,139.987384524096 4310.74721521035,139.986970950571 PathPoint;PointKind.SMOOTHPOINT 4333.68696466623,139.993014242918 4341.207731011,135.601274478404 4330.28986446066,141.976718064799 PathPoint;PointKind.SMOOTHPOINT 4345.84865688952,140.010509328208 4387.81467252804,140.09191375731 4341.77177965327,140.002467206664 PathPoint;PointKind.SMOOTHPOINT 4481.04527471987,141.079681154729 4600.62762067036,140.179183179107 4432.27950066328,141.446852330233 PathPoint;PointKind.SMOOTHPOINT 4789.19944314928,139.451364175203 4797.87507934267,139.417207543272 4696.61582098239,139.813517082252 PathPoint;PointKind.SMOOTHPOINT 4815.1531722732,139.349180590312 4826.77577251257,138.062910430756 4806.57118524855,140.298646896998 PathPoint;PointKind.SMOOTHPOINT 4839.64085642894,139.250088673134 4852.57990553192,139.196986545804 4831.4809908568,139.283683848426 PathPoint;PointKind.SMOOTHPOINT 4878.53014651647,139.083325659384 4901.65911156352,138.979483020892 4865.52423754242,139.141747962932 PathPoint;PointKind.SMOOTHPOINT 4951.06944894194,139.273179813845 4962.47589563574,139.381638204428 4927.8463423125,139.052561275523 PathPoint;PointKind.SMOOTHPOINT 4981.87660617168,138.341743935109 4984.42344005805,138.340286370836 4970.88711866459,138.347863955157 PathPoint;PointKind.SMOOTHPOINT 4992.24302207596,139.408895395343 4995.75456988094,139.399211326016 4989.71376470826,139.415894127749 PathPoint;PointKind.SMOOTHPOINT 5002.7470082281,137.384062072521 5014.82695023856,137.316048665844 4999.26569113392,137.403620993844 PathPoint;PointKind.SMOOTHPOINT 5038.55495681591,138.999702768625 5042.85049785324,138.937835715248 5026.72102034649,139.170378983772 PathPoint;PointKind.SMOOTHPOINT 5051.43230087813,139.535855408405 5056.16942582044,139.455313713519 5047.15256224624,139.608993072684 PathPoint;PointKind.SMOOTHPOINT 5065.61294072985,138.536772679 5071.54001590197,138.420879231463 5060.882820858,138.629278720643 PathPoint;PointKind.SMOOTHPOINT 5083.40407974906,138.165226257253 5087.27046130715,138.079777478472 5077.46640997016,138.296382872178 PathPoint;PointKind.SMOOTHPOINT 5095.15487075857,139.650288705362 5098.48400200247,139.572512772899 5091.27545815377,139.740959624092 PathPoint;PointKind.SMOOTHPOINT 5105.02829651111,137.66274904386 5112.72415876485,137.476464010958 5101.68508377289,137.74383300495 PathPoint;PointKind.SMOOTHPOINT 5134.91055287254,136.717663207934 5179.35725064421,135.59256209847 5127.10278173295,136.915362438695 PathPoint;PointKind.SMOOTHPOINT 5273.04166539921,134.042511707858 5277.02299890406,133.992723985621 5219.39112300934,134.712511833422 PathPoint;PointKind.SMOOTHPOINT 5284.95823925967,137.110376891073 5290.99918526148,137.039937400906 5281.15951446941,137.154908461561 PathPoint;PointKind.SMOOTHPOINT 5302.85263643343,134.120534745165 5312.42065656212,134.022771723327 5297.24938993954,134.177784593177 PathPoint;PointKind.SMOOTHPOINT 5326.69833911004,135.195250242914 5331.08703250416,135.163969865581 5318.2879088134,135.254948693767 PathPoint;PointKind.SMOOTHPOINT 5342.59470751094,136.249160272632 5346.72584175053,136.227957207645 5338.49066390564,136.270195320578 PathPoint;PointKind.SMOOTHPOINT 5359.49291848919,134.268777042769 5442.32761394669,134.031389507296 5355.6281388614,134.279925815403 PathPoint;PointKind.SMOOTHPOINT 5537.36115059993,135.74660941807 5546.0450695157,135.639603786875 5464.82288156422,136.63954455677 PathPoint;PointKind.SMOOTHPOINT 5560.94417649547,135.427493424896 5568.02730466369,135.322987876534 5553.86773287477,135.532016468451 PathPoint;PointKind.SMOOTHPOINT 5580.06465719941,135.127996347596 5589.07382939968,133.075597604163 5574.49904952954,136.396192550512 PathPoint;PointKind.SMOOTHPOINT 5593.17195487706,134.910718515784 5629.69991115038,134.307957743548 5589.20465341987,134.976072779999 PathPoint;PointKind.SMOOTHPOINT 5659.58263550753,137.07879983397 5674.17351161826,138.626247179141 5634.08623826462,134.374150636444 PathPoint;PointKind.SMOOTHPOINT 5693.30762990126,155.414123399454 5697.99974941793,160.560561218085 5685.26349429362,146.591486595933 PathPoint;PointKind.SMOOTHPOINT 5701.22762443564,171.603302387647 5703.43667684502,175.37494508477 5698.51770635943,166.977403490546 PathPoint;PointKind.SMOOTHPOINT 5709.15574421264,179.722015401342 5711.80100386725,185.258747996897 5708.15537491151,177.627889277153 PathPoint;PointKind.SMOOTHPOINT 5714.48655185625,254.382539044129 5714.64988176933,261.199122430736 5713.48936804011,212.798248249964 PathPoint;PointKind.SMOOTHPOINT 5712.86806300188,279.942053394796 5709.93689447241,483.994258853339 5712.9764654538,272.40559771789 PathPoint;PointKind.SMOOTHPOINT 5712.14095523,936.875279176224 5713.38106393416,955.430682540371 5711.15949662907,922.190821951626 PathPoint;PointKind.SMOOTHPOINT 5700.07323103931,991.503870392458 5698.87067198807,1018.10807700617 5702.16649089918,945.199914115618 PathPoint;PointKind.SMOOTHPOINT 5706.79924708879,1098.7965142261 5706.76112573744,1126.64328674981 5706.85062373508,1061.18964512236 PathPoint;PointKind.SMOOTHPOINT 5706.62953422867,1163.57857999835 5706.73251077022,1179.86914915376 5706.55497865889,1151.74896527964 PathPoint;PointKind.SMOOTHPOINT 5705.46858666647,1227.34574633874 5703.90518525103,1245.03847768306 5707.50150105217,1204.34519688023 PathPoint;PointKind.SMOOTHPOINT 5711.30091477955,1276.96013890275 5711.48885259624,1291.03613967462 5711.16652332021,1266.88643144067 PathPoint;PointKind.SMOOTHPOINT 5707.07150275533,1374.12271490741 5704.39940924483,1401.92771128634 5710.74146172701,1335.93805058853 PathPoint;PointKind.SMOOTHPOINT 5698.91267921681,1454.06725321149 5698.72975287881,1473.66659743538 5699.10360495803,1433.56313892439 PathPoint;PointKind.SMOOTHPOINT 5699.39707548906,1648.41605086644 5699.64279218899,1662.3271089655 5697.89160979006,1563.14792307284 PathPoint;PointKind.SMOOTHPOINT 5703.28706241896,1680.81736748768 5704.92705749561,1740.65254748243 5702.91969130722,1667.41465220703 PathPoint;PointKind.SMOOTHPOINT 5702.88664579733,1833.6626845777 5701.1535946611,1904.42967268106 5703.53828494543,1807.04652357267 PathPoint;PointKind.SMOOTHPOINT 5702.06194796426,2148.46280772043 5700.51910035343,2186.2432910064 5703.60514739339,2110.68232535525 PathPoint;PointKind.SMOOTHPOINT 5701.56606797618,2337.7479920101 5703.3074946556,2372.29468433388 5699.82429010437,2303.20105984691 PathPoint;PointKind.SMOOTHPOINT 5691.38764997371,2429.83395019605 5690.21479104496,2442.68383447339 5693.27407374809,2409.1672682096 PathPoint;PointKind.SMOOTHPOINT 5695.150352415,2510.82175641682 5694.37939960475,2529.53221180182 5696.80946237153,2470.56230194977 PathPoint;PointKind.SMOOTHPOINT 5699.99710095601,2557.39689304266 5699.07913713786,2575.14817668477 5700.92471653091,2539.45306493745 PathPoint;PointKind.SMOOTHPOINT 5700.78379788871,2636.35277789873 5701.78388753751,2654.66911065788 5699.21063925495,2607.54347910122 PathPoint;PointKind.SMOOTHPOINT 5704.62605313538,2686.97402811978 5704.9707234262,2702.32722893544 5704.19250068499,2667.67721589374 PathPoint;PointKind.SMOOTHPOINT 5701.52541573291,2732.51605926314 5701.86976532547,2747.4544936795 5701.19751050978,2718.28391615507 PathPoint;PointKind.SMOOTHPOINT 5701.41669314828,2774.01717840849 5698.35293716742,2841.06929649572 5702.02540999172,2760.69633932712 PathPoint;PointKind.SMOOTHPOINT 5699.03451075907,2924.83269847638 5697.63483112551,2953.62418193502 5700.58519921122,2892.92274525876 PathPoint;PointKind.SMOOTHPOINT 5709.78448192733,2993.69208650628 5710.71695357118,3003.30533314042 5707.88324171917,2974.08537611636 PathPoint;PointKind.SMOOTHPOINT 5707.68338632577,3037.21236240233 5706.01478890747,3069.67821337159 5709.35233618827,3004.74627343526 PathPoint;PointKind.SMOOTHPOINT 5707.06022184907,3275.08403629154 5704.17846225892,3326.11487743623 5709.94233325751,3224.05319606765 PathPoint;PointKind.SMOOTHPOINT 5704.65647376877,3433.99722406568 5703.72775285117,3458.1376849707 5705.9891732892,3399.34795744956 PathPoint;PointKind.SMOOTHPOINT 5713.22844787299,3575.7313847371 5713.73831738645,3597.99339704966 5712.05716180385,3524.59341193911 PathPoint;PointKind.SMOOTHPOINT 5708.12182641713,3628.35382365605 5704.54613693913,3671.64876108283 5709.20641201114,3615.22249920624 PathPoint;PointKind.SMOOTHPOINT 5703.83973059034,3745.76093052706 5698.05010200223,3780.8376676305 5708.8882765621,3715.17252106116 PathPoint;PointKind.SMOOTHPOINT 5629.12438005897,3817.43331008103 5585.23969697249,3819.97572355036 5673.00906251955,3814.89113553031 PathPoint;PointKind.SMOOTHPOINT 5116.31756724452,3820.16108302485 5054.38237860562,3820.01475132116 5178.25240406513,3820.30741380774 PathPoint;PointKind.SMOOTHPOINT 4492.28147083767,3817.51551371535 4413.74944080244,3817.12027235838 4570.81385206528,3817.91099491173 PathPoint;PointKind.SMOOTHPOINT 4033.18528711689,3820.36292155333 4024.13955009093,3820.6601164155 4083.57316266051,3818.70767618706 PathPoint;PointKind.SMOOTHPOINT 4012.3016264682,3826.381616443 3989.82576983737,3827.24191751604 4019.7117133182,3826.09805967942 PathPoint;PointKind.SMOOTHPOINT 3952.68533952977,3824.20121386208 3943.91841676749,3824.83553817025 3969.98271684594,3822.9496264459 PathPoint;PointKind.SMOOTHPOINT 3925.84772140941,3827.16764928095 3919.75840730685,3827.30247064769 3937.30226125537,3826.91379151933 PathPoint;PointKind.SMOOTHPOINT 3896.79911944692,3827.36829121455 3885.05638835379,3827.37267872117 3909.7060266522,3827.36336685474 PathPoint;PointKind.SMOOTHPOINT 3859.27828701669,3823.95674339734 3852.3739004991,3822.17472459739 3871.60795131448,3827.13869902516 PathPoint;PointKind.SMOOTHPOINT 3833.07409716125,3827.13413080415 3749.86841275033,3826.63061134053 3840.75246250342,3827.18050830413 PathPoint;PointKind.SMOOTHPOINT 3599.91957625332,3825.30230574052 3541.10569877509,3825.03775450303 3638.67709551536,3825.47661489051 PathPoint;PointKind.SMOOTHPOINT 3462.7899538598,3824.94340197883 3459.26031554947,3824.875150698 3497.73840181783,3825.61998682535 PathPoint;PointKind.SMOOTHPOINT 3437.94771254348,3824.87838339494 3433.93810837698,3823.4986372493 3446.6537585495,3827.87453192753 PathPoint;PointKind.SMOOTHPOINT 3426.04174593236,3817.76156443889 3422.51407519902,3817.74803104575 3432.09687050255,3817.78505771731 PathPoint;PointKind.SMOOTHPOINT 3413.10812319597,3823.80106663819 3404.95379593543,3826.68953441682 3418.06002120781,3822.04697284435 PathPoint;PointKind.SMOOTHPOINT 3389.25411279462,3825.76324473822 3378.84979173904,3825.73553609303 3396.66551627812,3825.78288122221 PathPoint;PointKind.SMOOTHPOINT 3353.48653294582,3823.64502148437 3344.69245059011,3819.73978989382 3362.99468387048,3827.86749671195 PathPoint;PointKind.SMOOTHPOINT 3325.67359005854,3819.52348519005 3320.57780323926,3819.5295007358 3338.53971325612,3819.50818051702 PathPoint;PointKind.SMOOTHPOINT 3303.14811874603,3825.75864534987 3292.23037212668,3825.77642130658 3308.40328676183,3825.75017990298 PathPoint;PointKind.SMOOTHPOINT 3278.96476049028,3821.4256073848 3272.08125247799,3822.01468782428 3292.99957219879,3820.22449429146 PathPoint;PointKind.SMOOTHPOINT 3251.14686610957,3819.32842943839 3245.7115502295,3819.34287423847 3259.27362946703,3819.30669363869 PathPoint;PointKind.SMOOTHPOINT 3229.00039778333,3825.93132413625 3222.23448322152,3825.9506486236 3234.50608107697,3825.9156299844 PathPoint;PointKind.SMOOTHPOINT 3208.5766962649,3825.99159605679 3204.64471746588,3826.00328571254 3215.42177432344,3825.97080631905 PathPoint;PointKind.SMOOTHPOINT 3198.47842393962,3820.20264866864 3190.8836085857,3820.22625455464 3202.42869854155,3820.19052905725 PathPoint;PointKind.SMOOTHPOINT 3166.67242791965,3823.1560805549 3163.48731804166,3823.18549369691 3174.31767596693,3823.08577829467 PathPoint;PointKind.SMOOTHPOINT 3156.74592692559,3819.08135771465 3153.3950981146,3819.11511553232 3159.92013732154,3819.04928792309 PathPoint;PointKind.SMOOTHPOINT 3146.7932605653,3825.12866184935 3139.48217104428,3825.22611991693 3150.12863753733,3825.08411217881 PathPoint;PointKind.SMOOTHPOINT 3124.99266880766,3825.40561456495 3120.91458527291,3825.45514906728 3132.21085076005,3825.31842582533 PathPoint;PointKind.SMOOTHPOINT 3112.02982219255,3818.96432407949 3110.09334359367,3818.98625380175 3116.07165968067,3818.9180395954 PathPoint;PointKind.SMOOTHPOINT 3098.10231278526,3825.00122501978 3091.56066676523,3825.09424607357 3100.02895486786,3824.97377438697 PathPoint;PointKind.SMOOTHPOINT 3078.79369128969,3825.26893113067 3075.47273886758,3825.313518554 3085.12352141794,3825.1834789884 PathPoint;PointKind.SMOOTHPOINT 3069.29583567128,3820.87684946864 3066.5188199886,3820.913064785 3072.55732516912,3820.83425669771 PathPoint;PointKind.SMOOTHPOINT 3056.36981639713,3823.87969514717 3048.25259350184,3824.01996036242 3059.10393904009,3823.83237723695 PathPoint;PointKind.SMOOTHPOINT 3024.57973093824,3820.75981583348 3013.54395500323,3820.97654236824 3032.19704069756,3820.61035784762 PathPoint;PointKind.SMOOTHPOINT 2985.82023564569,3822.68274349625 2978.41648618152,3822.15876638985 2996.47948192141,3823.43719799697 PathPoint;PointKind.SMOOTHPOINT 2970.92570857031,3818.59501804418 2962.13659616099,3819.10456790401 2976.93712675511,3818.24639809708 PathPoint;PointKind.SMOOTHPOINT 2948.05197505522,3825.62057059089 2949.06181947342,3825.84373700936 2945.23833367548,3824.99918151089 PathPoint;PointKind.SMOOTHPOINT 2938.84229958543,3826.18253786496 2937.08942006166,3826.22406173386 2945.0811721382,3826.034489477 PathPoint;PointKind.SMOOTHPOINT 2933.15744797984,3821.53284513882 2928.80206716366,3821.6062626684 2935.20619103831,3821.4980686278 PathPoint;PointKind.SMOOTHPOINT 2923.20708177008,3826.56785017986 2915.83584630166,3828.00238748831 2928.05271598704,3825.62485144676 PathPoint;PointKind.SMOOTHPOINT 2899.35837530636,3826.50543193417 2894.29471223347,3826.47019835225 2904.43259292797,3826.54069314009 PathPoint;PointKind.SMOOTHPOINT 2890.43636823255,3818.38435658009 2863.50574537712,3818.17505949323 2895.14539283537,3818.42081226351 PathPoint;PointKind.SMOOTHPOINT 2821.65228900049,3817.96827760759 2818.87888914224,3817.96723082797 2840.97778099139,3817.97561286285 PathPoint;PointKind.SMOOTHPOINT 2814.90515098923,3822.23541442364 2811.44145047178,3822.24522372172 2817.55051027056,3822.22800279927 PathPoint;PointKind.SMOOTHPOINT 2803.44716301107,3818.03077231148 2788.56061001984,3818.15117015318 2806.70509176432,3818.00441679838 PathPoint;PointKind.SMOOTHPOINT 2764.23508878452,3819.06612131769 2757.53725371167,3819.42035126175 2775.74297902797,3818.45760661155 PathPoint;PointKind.SMOOTHPOINT 2745.4584252071,3820.54057237883 2741.52126319513,3820.91922997802 2751.43067940736,3819.96607028995 PathPoint;PointKind.SMOOTHPOINT 2736.39562871272,3825.06661107753 2732.50181107801,3825.41838413155 2740.34645405455,3824.70996990213 PathPoint;PointKind.SMOOTHPOINT 2721.67423261434,3822.57699848873 2718.4003969876,3822.76625598225 2725.83373445579,3822.33677979672 PathPoint;PointKind.SMOOTHPOINT 2712.546922249,3825.00419283184 2708.83466964936,3825.07762115288 2716.12406786236,3824.93375578436 PathPoint;PointKind.SMOOTHPOINT 2699.63451338541,3822.94602640409 2694.43458579004,3822.81845188502 2703.80754222584,3823.04845475915 PathPoint;PointKind.SMOOTHPOINT 2685.71991075209,3823.9219133965 2680.99860875327,3823.73729502283 2690.48413082691,3824.10807761942 PathPoint;PointKind.SMOOTHPOINT 2671.1205638546,3821.84762472229 2666.7867339679,3821.6181477749 2675.45967101566,3822.07711548167 PathPoint;PointKind.SMOOTHPOINT 2658.63497750807,3821.10798167705 2654.62350205437,3820.84542173877 2662.63238273378,3821.36954910888 PathPoint;PointKind.SMOOTHPOINT 2645.95892532639,3828.87889632104 2641.04602312988,3828.50574624055 2649.67693049773,3829.16123531332 PathPoint;PointKind.SMOOTHPOINT 2632.06058507244,3823.78147303431 2626.82533759777,3822.90072943517 2636.50634348189,3824.52922203707 PathPoint;PointKind.SMOOTHPOINT 2616.156261391,3825.76421860456 2612.848642095,3825.15109346647 2620.93659091644,3826.65022241236 PathPoint;PointKind.SMOOTHPOINT 2600.27315158236,3819.64929554776 2587.714857855,3816.17812587134 2603.38345726587,3820.50894780703 PathPoint;PointKind.SMOOTHPOINT 2569.47925294488,3815.51971839942 2566.99952184003,3815.55742854733 2582.66460984363,3815.31960820681 PathPoint;PointKind.SMOOTHPOINT 2562.51284627242,3819.55046704242 2558.32726794169,3819.80662514248 2564.70855918728,3819.41620652368 PathPoint;PointKind.SMOOTHPOINT 2541.64509618481,3819.49585073215 2526.12802674134,3821.38260822422 2545.01414864407,3819.08631905185 PathPoint;PointKind.SMOOTHPOINT 2514.79952278391,3825.49894175099 2510.19232650531,3825.6730024017 2526.8361484076,3825.04424200407 PathPoint;PointKind.SMOOTHPOINT 2491.95000630281,3823.4147673372 2482.03003939723,3823.15776832779 2500.29005365509,3823.63083756865 PathPoint;PointKind.SMOOTHPOINT 2466.12448556494,3819.29819372148 2456.65826501021,3818.27449258936 2473.91229366015,3820.14022318515 PathPoint;PointKind.SMOOTHPOINT 2442.2734789507,3820.24807456945 2434.89077413249,3821.22600525536 2448.06927365791,3819.48030199583 PathPoint;PointKind.SMOOTHPOINT 2422.38105363,3827.28142997237 2420.49695020674,3827.18666477012 2434.26610299555,3827.87877722742 PathPoint;PointKind.SMOOTHPOINT 2408.49066865658,3819.14735108567 2401.97965762496,3818.96163238343 2413.012281825,3819.27649516363 PathPoint;PointKind.SMOOTHPOINT 2385.93604941126,3826.30227793347 2382.07151513909,3826.21977060892 2397.10221428554,3826.54055790262 PathPoint;PointKind.SMOOTHPOINT 2374.6915959831,3824.11993788103 2369.90814050175,3824.02427409011 2379.03635345921,3824.20704695771 PathPoint;PointKind.SMOOTHPOINT 2358.45114107426,3825.75417474001 2352.4258052075,3825.64068649081 2363.7658346635,3825.85409596178 PathPoint;PointKind.SMOOTHPOINT 2337.93048065578,3821.99935320759 2332.3295723344,3822.10415430563 2344.59604995974,3821.87488009944 PathPoint;PointKind.SMOOTHPOINT 2322.02085303671,3826.00669512356 2314.68360303795,3825.88356132848 2327.97656393274,3826.10662161198 PathPoint;PointKind.SMOOTHPOINT 2304.14501839285,3821.91092789667 2294.15985267398,3822.23385662038 2311.79495205685,3821.66359799212 PathPoint;PointKind.SMOOTHPOINT 2268.35852419586,3826.87831309482 2254.98497312806,3826.66412085558 2279.26802570571,3827.05332420303 PathPoint;PointKind.SMOOTHPOINT 2221.65499793932,3826.75607786245 2110.63386807371,3831.27831637719 2235.74445756793,3826.18227346212 PathPoint;PointKind.SMOOTHPOINT 1921.55732501453,3826.98294958984 1797.32870445028,3829.0075917859 1979.3678043098,3826.04095551723 PathPoint;PointKind.SMOOTHPOINT 1499.2275599328,3829.92658467415 1475.97333266941,3830.30437991989 1595.65164568138,3828.36005160748 PathPoint;PointKind.SMOOTHPOINT 1391.57545415136,3830.69273544464 1389.71043096809,3830.70099480955 1426.44621188132,3830.53982475607 PathPoint;PointKind.SMOOTHPOINT 1375.01335018998,3830.61355008815 1354.69075208588,3826.59500113585 1376.75607034625,3830.95833367934 PathPoint;PointKind.SMOOTHPOINT 1353.41713231199,3830.90346155634 1356.46535488984,3831.01943149938 1352.31006342622,3830.86114222833 PathPoint;PointKind.SMOOTHPOINT 1279.48941533458,3830.76325277767 1271.58655174268,3830.73086184305 1304.72946674784,3830.86610625271 PathPoint;PointKind.SMOOTHPOINT 1255.6746173709,3830.64979434509 1250.81246619624,3832.39146025622 1264.50234349994,3827.48737505336 PathPoint;PointKind.SMOOTHPOINT 1240.18770891178,3830.55860999818 1188.09483217653,3830.22922187409 1245.35692435683,3830.59149171523 PathPoint;PointKind.SMOOTHPOINT 1086.84550971792,3828.84727397167 1024.59992312695,3829.40757274648 1135.44329802242,3828.40965949966 PathPoint;PointKind.SMOOTHPOINT 890.441388396748,3829.86901287311 885.128160348485,3829.8811490859 957.768663588504,3829.71527693153 PathPoint;PointKind.SMOOTHPOINT 871.21432032842,3828.2829112639 863.929132610133,3828.29681503451 876.531765188912,3828.27269744962 PathPoint;PointKind.SMOOTHPOINT 852.638068053633,3829.93994408647 840.139589336546,3829.95836126267 859.921840361964,3829.92914257466 PathPoint;PointKind.SMOOTHPOINT 815.197198788218,3829.98195889656 810.161226711501,3829.98598071071 827.650973423834,3829.97226476757 PathPoint;PointKind.SMOOTHPOINT 799.668552755553,3828.09565744764 796.265738083215,3828.09750281114 804.691151981785,3828.0930341548 PathPoint;PointKind.SMOOTHPOINT 789.911103050835,3829.99653367627 777.866861179044,3830.00108773205 793.306175843059,3829.99538481103 PathPoint;PointKind.SMOOTHPOINT 753.953258039893,3830.00037998059 742.02724463914,3829.99855370382 765.872938711415,3830.00218968296 PathPoint;PointKind.SMOOTHPOINT 715.202069846168,3828.88665296419 708.197283809105,3828.90033493765 726.87026177883,3828.86439027051 PathPoint;PointKind.SMOOTHPOINT 691.133347421977,3831.82760322599 687.435707144408,3831.82939371523 698.003006443725,3831.82455792176 PathPoint;PointKind.SMOOTHPOINT 677.439112567419,3829.80012263171 661.168828763244,3829.79385496075 681.093822250836,3829.80156466553 PathPoint;PointKind.SMOOTHPOINT 632.717352704364,3831.70744550286 510.100637823167,3831.09838795581 648.000596553573,3831.78352267124 PathPoint;PointKind.SMOOTHPOINT 396.244240843414,3831.0780642112 392.781457396897,3831.00640410307 460.477589702136,3832.40733196415 PathPoint;PointKind.SMOOTHPOINT 382.337945308922,3829.01729652444 379.481675940432,3828.95510818921 385.853840799173,3829.09387404562 PathPoint;PointKind.SMOOTHPOINT 367.424504511273,3832.01494060576 360.534577669812,3831.83109722567 370.307121445311,3832.09201095511 PathPoint;PointKind.SMOOTHPOINT 349.540714586872,3830.95582897883 343.996871322303,3830.49668871259 356.918201041411,3831.56694324063 PathPoint;PointKind.SMOOTHPOINT 333.646997528879,3828.88985969486 325.774503323921,3829.62018169372 337.30682220136,3828.5503759143 PathPoint;PointKind.SMOOTHPOINT 322.713703089955,3829.87354954349 316.656897783602,3830.08873319932 328.299024943886,3829.67505091227 PathPoint;PointKind.SMOOTHPOINT 307.522140798565,3827.70357630826 294.723324837347,3828.61715837438 311.705719631034,3827.40488516988 PathPoint;PointKind.SMOOTHPOINT 277.006715473123,3828.74161739726 270.397638403999,3828.25221330893 288.672234097682,3829.60550292679 PathPoint;PointKind.SMOOTHPOINT 260.127067024773,3823.63639125432 258.577408484099,3821.31074729379 265.279978855985,3831.36986898865 PathPoint;PointKind.SMOOTHPOINT 256.197304318092,3806.41811371433 254.204967552878,3803.99168140447 258.063388957027,3808.69058986669 PathPoint;PointKind.SMOOTHPOINT 249.252111518431,3802.35119373028 246.704776129572,3799.32099088631 251.278266027137,3804.76122905245 PathPoint;PointKind.SMOOTHPOINT 241.895334789179,3793.16337441383 240.334710537199,3791.12894554211 244.220315385225,3796.19514557996 PathPoint;PointKind.SMOOTHPOINT 241.350508925947,3784.11045466243 238.068471418773,3783.13304309204 243.575798086436,3784.77307059755 PathPoint;PointKind.SMOOTHPOINT 236.389734488588,3781.06079460904 229.192794450391,3777.06847561706 238.315265878129,3782.12879043121 PathPoint;PointKind.CORNERPOINT 227.467728040686,3772.93948033634 227.467728040686,3772.93948033634 227.467728040686,3772.93948033634 PathPoint;PointKind.SMOOTHPOINT 228.234236575789,1963.08066712896 229.536497092184,1930.24687585183 226.139386353577,2015.900691315 PathPoint;PointKind.SMOOTHPOINT 225.540712311618,1843.64140181623 225.568696607532,1841.55426772449 224.992692886929,1884.28818698292 PathPoint;PointKind.SMOOTHPOINT 229.536769857326,1835.55389746498 229.978168816168,1819.0874742533 229.47946446911,1837.68682750449 PathPoint;PointKind.SMOOTHPOINT 229.632233223784,1799.11403026533 229.702912405118,1794.83061402745 229.457889315919,1809.66261991151 PathPoint;PointKind.SMOOTHPOINT 227.689891414697,1781.90119324116 227.749028950179,1779.33749477994 227.619643015881,1784.94580909251 PathPoint;PointKind.SMOOTHPOINT 228.707292108917,1772.79382677945 228.761928845629,1770.73949451877 228.568334926116,1778.02677232346 PathPoint;PointKind.SMOOTHPOINT 230.715927505217,1764.70135974961 230.60279345126,1761.68875709331 230.832703104242,1767.80117782927 PathPoint;PointKind.SMOOTHPOINT 228.373777905118,1755.86808205414 228.610911526411,1747.13640635194 228.301733936902,1758.52373103345 PathPoint;PointKind.SMOOTHPOINT 229.207364249876,1725.33601645797 229.423761597621,1717.40204120975 228.894473820322,1736.79763562083 PathPoint;PointKind.SMOOTHPOINT 233.856341936284,1703.97581168778 233.714140007194,1701.71812095414 235.044881867069,1722.8772755303 PathPoint;PointKind.SMOOTHPOINT 230.078861145322,1693.22526504893 230.16068762646,1690.19286443334 230.016523329349,1695.53331046303 PathPoint;PointKind.SMOOTHPOINT 234.905563752657,1682.72182282619 235.071913899885,1678.85055550093 234.707748722518,1687.32290917391 PathPoint;PointKind.SMOOTHPOINT 229.963703037573,1672.58679323941 230.066328382979,1668.73280030833 229.893077608849,1675.23814536685 PathPoint;PointKind.SMOOTHPOINT 232.973829192923,1661.46003202919 233.119033297225,1656.12556172729 232.867548590933,1665.36633892902 PathPoint;PointKind.SMOOTHPOINT 231.026184072113,1646.27155243213 231.471493114723,1626.96963388653 230.901939473425,1651.66317953105 PathPoint;PointKind.SMOOTHPOINT 232.432666619435,1588.82996458929 232.54137159379,1584.53541862286 231.963229536659,1607.40406889363 PathPoint;PointKind.SMOOTHPOINT 236.172230112375,1578.46583459252 237.277223489907,1534.71430495627 236.067010089401,1582.63877927099 PathPoint;PointKind.SMOOTHPOINT 234.42912276094,1485.33636957126 234.012639386258,1470.93913965635 234.741359939424,1496.14856716451 PathPoint;PointKind.SMOOTHPOINT 236.609771167882,1411.44953767551 232.09823197967,1383.03321763954 240.955873298133,1438.82253781363 PathPoint;PointKind.SMOOTHPOINT 225.859448181336,1342.5901487248 225.911294063822,1337.43796915385 225.678631425857,1360.57845920119 PathPoint;PointKind.SMOOTHPOINT 227.907860606234,1319.31416477649 228.114158765944,1314.83232183777 227.257588245294,1333.45630292755 PathPoint;PointKind.SMOOTHPOINT 227.653531304442,1298.34991933472 228.130880615887,1288.57359623052 227.400729580056,1303.52737633952 PathPoint;PointKind.SMOOTHPOINT 232.009988141847,1270.73807837137 232.674612405988,1257.96666327683 231.399075815788,1282.47964883145 PathPoint;PointKind.SMOOTHPOINT 231.460650982735,1225.13297616185 235.363861218519,1152.70519915968 230.691843456229,1239.39856476695 PathPoint;PointKind.SMOOTHPOINT 237.636002983214,1019.72072636064 237.98511575788,1005.57899459815 236.50312175792,1065.65686980447 PathPoint;PointKind.SMOOTHPOINT 239.708281249727,987.334775612418 239.938359243482,976.058819665114 239.637224237249,990.822347497264 PathPoint;PointKind.SMOOTHPOINT 238.781039984335,962.0268712202 235.286970153469,952.813323570786 241.97496965643,970.4488072862 PathPoint;PointKind.SMOOTHPOINT 226.933412305804,932.641164891495 227.06114245727,929.947912257318 226.538665166816,940.969130690492 PathPoint;PointKind.SMOOTHPOINT 228.751366281536,899.433379599673 229.140874285028,892.43379669753 227.726473153837,917.846909242807 PathPoint;PointKind.SMOOTHPOINT 234.032758596889,877.999570142643 235.190043516009,854.844775653713 233.599856844882,886.656429270093 PathPoint;PointKind.SMOOTHPOINT 231.839789736532,844.183986592691 236.570969045006,759.752394945421 231.204611161702,855.519090190646 PathPoint;PointKind.SMOOTHPOINT 239.780754615145,580.420085959496 239.988394508758,561.996532984478 239.076240031286,642.932204210783 PathPoint;PointKind.SMOOTHPOINT 238.900893840599,536.892008128038 239.769785570749,518.399465425439 238.653863974147,542.149279603927 PathPoint;PointKind.SMOOTHPOINT 244.530595946446,392.440744242454 244.860117867163,384.434194393263 242.014722373119,453.546615491239 PathPoint;PointKind.SMOOTHPOINT 241.30994585853,375.954224008171 240.386267260685,369.430717104973 242.286133184009,382.847239052109 PathPoint;PointKind.SMOOTHPOINT 241.376239445743,350.648919954157 241.546687541275,346.959242746886 241.056206136812,357.585131902171 PathPoint;PointKind.SMOOTHPOINT 247.000799831273,336.41252561025 248.2282965129,310.89857738115 246.830766086309,339.944038694218 PathPoint;PointKind.SMOOTHPOINT 246.530592584834,279.806547435382 250.568546903241,237.999381692291 245.46016709872,290.890123453781 PathPoint;PointKind.SMOOTHPOINT 252.816020496203,156.331330961643 255.58251785362,134.525391384986 249.756728694802,180.450685794008 PathPoint";
	
	mask35mm[1] = "PointKind.CORNERPOINT 272.909338474274,131.080520153046 272.909338474274,131.080520153046 272.909338474274,131.080520153046 PathPoint;PointKind.SMOOTHPOINT 283.843159675598,130.096728801727 285.499058961868,129.946138858795 275.789548158646,130.829379558563 PathPoint;PointKind.SMOOTHPOINT 291.79869890213,128.093268871307 316.387935876846,127.877533435822 289.960817098618,128.109319210052 PathPoint;PointKind.SMOOTHPOINT 417.011522054672,128.420884609222 421.455577611923,128.458178043365 362.910314798355,127.96439409256 PathPoint;PointKind.SMOOTHPOINT 434.169570207596,129.99995470047 442.00296163559,130.478160381317 429.645853042603,129.72403049469 PathPoint;PointKind.SMOOTHPOINT 446.821603775024,129.511127471924 459.777413606644,129.551961421967 442.446234226227,129.497437477112 PathPoint;PointKind.SMOOTHPOINT 485.769757032394,129.718129634857 553.106828927994,130.210025310516 472.797660827637,129.623243808746 PathPoint;PointKind.SMOOTHPOINT 650.497215986252,130.062503814697 655.140602588654,130.136382579803 601.238372325897,129.279813766479 PathPoint;PointKind.SMOOTHPOINT 664.479421377182,130.265257358551 671.513010263443,128.561089038849 658.644651174545,131.679103374481 PathPoint;PointKind.SMOOTHPOINT 693.270188570023,131.168324947357 701.821596622467,130.121040344238 685.874758958817,132.07398891449 PathPoint;PointKind.SMOOTHPOINT 716.126343011856,131.228041648865 720.279368162155,130.02922296524 707.17414855957,133.812854290009 PathPoint;PointKind.SMOOTHPOINT 731.154416799545,130.717499256134 734.911258220673,130.628042221069 725.975704193115,130.840709209442 PathPoint;PointKind.SMOOTHPOINT 759.189637899399,132.000110149384 802.552460432053,131.513171195984 755.24514913559,132.044484615326 PathPoint;PointKind.SMOOTHPOINT 913.878318071365,133.770132064819 1051.20784878731,135.062656402588 841.037160158157,133.084688186646 PathPoint;PointKind.SMOOTHPOINT 1302.22369909286,134.000029563904 1403.61770153046,134.28138256073 1200.83040475845,133.718912601471 PathPoint;PointKind.SMOOTHPOINT 1478.33073019981,135.24747133255 1491.46710634232,135.55408000946 1412.00128912926,133.697905540466 PathPoint;PointKind.SMOOTHPOINT 1510.23679733276,135.000107288361 1514.30272579193,134.278314113617 1498.72126936913,137.04416513443 PathPoint;PointKind.SMOOTHPOINT 1525.69539785385,135.838265419006 1530.30762791634,135.843694210052 1521.6393828392,135.83354473114 PathPoint;PointKind.SMOOTHPOINT 1539.66025471687,135.819382667542 1542.1117079258,135.227172374725 1535.05191922188,136.932284832001 PathPoint;PointKind.SMOOTHPOINT 1546.43326163292,135.284056663513 1548.9215362072,135.412695407867 1544.29903864861,135.173356533051 PathPoint;PointKind.SMOOTHPOINT 1560.23985743523,135.000107288361 1583.86961460114,134.864387512207 1557.56428956985,135.015213489532 PathPoint;PointKind.SMOOTHPOINT 1651.56180024147,135.522215366364 1668.73117804527,135.573198795319 1606.30019903183,135.38791179657 PathPoint;PointKind.SMOOTHPOINT 1710.86933612823,135.855967998505 1858.85900616646,137.034015655518 1688.28969597816,135.676345825195 PathPoint;PointKind.SMOOTHPOINT 2022.90810227394,136.672646999359 2043.14002633095,137.01277256012 1950.47516584396,135.45494556427 PathPoint;PointKind.SMOOTHPOINT 2081.69270396233,137.119224071503 2087.92613625526,137.119696140289 2062.08391070366,137.11757183075 PathPoint;PointKind.SMOOTHPOINT 2102.27372288704,138.999946117401 2107.97466158867,138.985784053802 2095.8427298069,139.01623249054 PathPoint;PointKind.SMOOTHPOINT 2118.11186671257,137.039444446564 2135.62042593956,136.97783946991 2112.16309189796,137.060215473175 PathPoint;PointKind.SMOOTHPOINT 2175.54186701775,136.880829334259 2182.17254519463,136.87516450882 2154.39188718796,136.899712085724 PathPoint;PointKind.SMOOTHPOINT 2196.27973079681,138.999946117401 2202.07130670547,139.006555080414 2189.14665341377,138.992156982422 PathPoint;PointKind.SMOOTHPOINT 2214.09312844276,136.920011043549 2227.91955113411,136.961553096771 2207.92979836464,136.901364326477 PathPoint;PointKind.SMOOTHPOINT 2258.72664213181,137.158877849579 2265.68410992622,137.211985588074 2242.72811293602,137.036375999451 PathPoint;PointKind.SMOOTHPOINT 2278.30038428307,138.352975845337 2283.00006508827,138.398766517639 2270.87592244148,138.280749320984 PathPoint;PointKind.SMOOTHPOINT 2294.53648209572,137.488853931427 2321.43484354019,137.76572227478 2289.74085330963,137.439522743225 PathPoint;PointKind.SMOOTHPOINT 2378.64179134369,138.423314094543 2386.50598526001,138.513007164001 2349.76498961449,138.094518184662 PathPoint;PointKind.SMOOTHPOINT 2401.52308344841,139.687750339508 2409.32319402695,139.77484703064 2393.59586834908,139.59947347641 PathPoint;PointKind.SMOOTHPOINT 2425.78588485718,138.947782516479 2441.11561059952,139.11253452301 2417.95957446098,138.863990306854 PathPoint;PointKind.SMOOTHPOINT 2471.70283555984,139.410409927368 2474.67863917351,139.438025951385 2456.46410107613,139.269261360168 PathPoint;PointKind.SMOOTHPOINT 2482.02273130417,137.87406206131 2490.57732582092,137.950065135956 2479.05648708344,137.847862243652 PathPoint;PointKind.SMOOTHPOINT 2506.12904191017,139.7021484375 2513.73973488808,139.759740829468 2497.68243312836,139.638183116913 PathPoint;PointKind.SMOOTHPOINT 2524.30038571358,140.000023841858 2528.6325609684,140.026695728302 2516.81290268898,139.954469203949 PathPoint;PointKind.SMOOTHPOINT 2542.30143070221,138.000104427338 2546.12129330635,138.019459247589 2538.01882266998,137.97815322876 PathPoint;PointKind.SMOOTHPOINT 2558.53363394737,141.111037731171 2560.92985510826,141.12095117569 2554.75838184357,141.095223426819 PathPoint;PointKind.SMOOTHPOINT 2568.47894310951,138.100419044495 2575.38259506226,138.108208179474 2566.12981081009,138.097586631775 PathPoint;PointKind.SMOOTHPOINT 2588.42479348183,138.246288299561 2593.39673995972,138.310961723328 2582.01575160027,138.162968158722 PathPoint;PointKind.SMOOTHPOINT 2604.30542349815,138.999946117401 2607.18704938889,139.055886268616 2599.58202123642,138.90860080719 PathPoint;PointKind.SMOOTHPOINT 2623.13565731049,138.243455886841 2646.58343195915,138.297035694122 2620.37901163101,138.237318992615 PathPoint;PointKind.SMOOTHPOINT 2681.7641222477,139.408993721008 2797.18706488609,138.002936840057 2660.39887905121,139.66933965683 PathPoint;PointKind.SMOOTHPOINT 3015.66628217697,140.282793045044 3125.37943482399,139.813556671143 2907.31091737747,140.746600627899 PathPoint;PointKind.SMOOTHPOINT 3346.58626556396,141.1488032341 3351.7894077301,141.094279289246 3273.32555651665,141.921815872192 PathPoint;PointKind.SMOOTHPOINT 3363.3874297142,141.076104640961 3369.1000521183,141.080825328827 3357.40891456604,141.071147918701 PathPoint;PointKind.SMOOTHPOINT 3379.37746167183,142.247071266174 3383.25538873672,142.279407978058 3373.0590569973,142.194435596466 PathPoint;PointKind.SMOOTHPOINT 3393.39507222176,141.284995079041 3408.81791353226,141.043059825897 3389.31958436966,141.348960399628 PathPoint;PointKind.SMOOTHPOINT 3443.24978470802,140.602147579193 3446.74781441689,140.919849872589 3439.75175499916,140.28468132019 PathPoint;PointKind.SMOOTHPOINT 3451.63549661636,140.504665374756 3460.21770715714,142.578935623169 3448.89903187752,139.843060970306 PathPoint;PointKind.SMOOTHPOINT 3470.30215859413,140.303800106049 3538.32148790359,139.612927436829 3464.0191590786,140.367765426636 PathPoint;PointKind.SMOOTHPOINT 3658.63034248352,139.941251277924 3702.44068622589,140.546443462372 3612.41492629051,139.302778244019 PathPoint;PointKind.SMOOTHPOINT 3884.4805598259,141.173822879791 3890.34188389778,141.185388565063 3792.158421278,140.989007949829 PathPoint;PointKind.SMOOTHPOINT 3902.08506703377,141.205923557281 3909.72479224205,140.171148777008 3896.26516699791,141.994278430939 PathPoint;PointKind.SMOOTHPOINT 3919.53237533569,141.231415271759 3945.00709533691,141.263988018036 3913.7241590023,141.224098205566 PathPoint;PointKind.SMOOTHPOINT 3995.38899064064,143.265795707703 3999.92191314697,143.263671398163 3971.2628531456,143.276181221008 PathPoint;PointKind.SMOOTHPOINT 4009.43457126617,141.844396591187 4014.59451913834,141.8403840065 4004.98732924461,141.847937107086 PathPoint;PointKind.SMOOTHPOINT 4024.14789319038,143.241484165192 4048.4195458889,143.211035728455 4019.12106871605,143.248093128204 PathPoint;PointKind.SMOOTHPOINT 4089.92005705833,141.069967746735 4112.78010606766,140.972485542297 4070.03085494041,141.15446805954 PathPoint;PointKind.SMOOTHPOINT 4157.46885180473,140.69892168045 4161.34925723076,140.674374103546 4135.18095016479,140.839126110077 PathPoint;PointKind.SMOOTHPOINT 4169.10157084465,140.625042915344 4178.34939837456,140.443060398102 4165.22683024406,140.701518058777 PathPoint;PointKind.SMOOTHPOINT 4189.55690145493,140.49569606781 4196.10614776611,140.454390048981 4182.73645162582,140.538182258606 PathPoint;PointKind.SMOOTHPOINT 4209.22694563866,140.375082492828 4211.72619581223,140.360448360443 4202.65964269638,140.414028167725 PathPoint;PointKind.SMOOTHPOINT 4216.7303609848,140.331180095673 4223.72110962868,138.835666179657 4214.28032398224,140.855412483215 PathPoint;PointKind.SMOOTHPOINT 4230.32700419426,140.255885124207 4241.93848013878,140.194280147552 4225.78523039818,140.279960632324 PathPoint;PointKind.SMOOTHPOINT 4265.42130589485,140.095853805542 4269.56654191017,140.080511569977 4253.6204123497,140.139520168304 PathPoint;PointKind.SMOOTHPOINT 4277.90410280228,140.054075717926 4281.04206204414,141.353445053101 4273.47562551498,138.22056055069 PathPoint;PointKind.SMOOTHPOINT 4288.10114264488,140.026931762695 4299.06789064407,140.001204013824 4284.69020962715,140.034956932068 PathPoint;PointKind.SMOOTHPOINT 4321.41314864159,139.987277984619 4325.28930544853,139.987277984619 4310.15926480293,139.987041950226 PathPoint;PointKind.SMOOTHPOINT 4333.10074567795,139.992942810059 4340.62186360359,135.601286888123 4329.70326662064,141.976811885834 PathPoint;PointKind.SMOOTHPOINT 4351.41477227211,140.000023841858 4393.38333964348,140.08145570755 4347.33751416206,139.991998672485 PathPoint;PointKind.SMOOTHPOINT 4480.4683470726,141.07964515686 4600.05812287331,140.179173946381 4431.69915676117,141.446914672852 PathPoint;PointKind.SMOOTHPOINT 4788.64157795906,139.451479911804 4797.31796622276,139.417254924774 4696.05213046074,139.813556671143 PathPoint;PointKind.SMOOTHPOINT 4814.59710001945,139.349277019501 4826.22025966644,138.062889575958 4806.0141813755,140.298607349396 PathPoint;PointKind.SMOOTHPOINT 4839.08614039421,139.25014257431 4852.02566385269,139.197034835815 4830.92595934868,139.28365945816 PathPoint;PointKind.SMOOTHPOINT 4877.97799944878,139.08326625824 4901.10818982124,138.979411125183 4864.9712061882,139.141802787781 PathPoint;PointKind.SMOOTHPOINT 4950.52175402641,139.273273944855 4961.92894220352,139.381613731384 4927.29703187943,139.052581787109 PathPoint;PointKind.SMOOTHPOINT 4981.33061528206,138.341646194458 4983.87801647186,138.340229988098 4970.34049987793,138.347783088684 PathPoint;PointKind.SMOOTHPOINT 4991.69795393944,139.408993721008 4995.20979166031,139.399316310883 4989.16860938072,139.415838718414 PathPoint;PointKind.SMOOTHPOINT 5002.20231056213,137.384054660797 5014.28325891495,137.316076755524 4998.720921278,137.403645515442 PathPoint;PointKind.SMOOTHPOINT 5038.01250457764,138.999710083008 5042.30856657028,138.93786907196 5026.17797613144,139.170362949371 PathPoint;PointKind.SMOOTHPOINT 5050.89113116264,139.535744190216 5055.6279873848,139.455256462097 5046.61100149155,139.608914852142 PathPoint;PointKind.SMOOTHPOINT 5065.07231354713,138.536846637726 5070.99984526634,138.42095375061 5060.3418302536,138.629372119904 PathPoint;PointKind.SMOOTHPOINT 5082.86446809769,138.165328502655 5086.7310655117,138.079884052277 5076.92631483078,138.296327590942 PathPoint;PointKind.SMOOTHPOINT 5094.61614847183,139.650220870972 5097.94564962387,139.572565555573 5090.73645114899,139.740858078003 PathPoint;PointKind.SMOOTHPOINT 5104.49029326439,137.662811279297 5112.18631267548,137.476580142975 5101.14663004875,137.743771076202 PathPoint;PointKind.SMOOTHPOINT 5134.37401771545,136.717729568481 5178.8237786293,135.59255361557 5126.56611800194,136.915290355682 PathPoint;PointKind.SMOOTHPOINT 5266.47208213806,134.000029563904 5270.45339226723,133.950226306915 5212.81804203987,134.669895172119 PathPoint;PointKind.SMOOTHPOINT 5284.43134903908,137.11049079895 5290.47288537025,137.03991651535 5280.63237547874,137.154865264893 PathPoint;PointKind.SMOOTHPOINT 5302.3268866539,134.120643138885 5311.89548492432,134.022688865662 5296.72331213951,134.177763462067 PathPoint;PointKind.SMOOTHPOINT 5326.17403149605,135.195307731628 5330.56320905685,135.163915157318 5317.76318192482,135.255024433136 PathPoint;PointKind.SMOOTHPOINT 5342.0713019371,136.24920129776 5346.203083992,136.227958202362 5337.96713590622,136.270208358765 PathPoint;PointKind.SMOOTHPOINT 5368.47859382629,134.000029563904 5451.31816864014,133.762578964233 5364.61341261864,134.011123180389 PathPoint;PointKind.SMOOTHPOINT 5536.84995174408,135.746684074402 5545.53448319435,135.639524459839 5464.30725932121,136.639602184296 PathPoint;PointKind.SMOOTHPOINT 5560.43474435806,135.427565574646 5567.51825451851,135.323002338409 5553.35760712624,135.532128810883 PathPoint;PointKind.SMOOTHPOINT 5579.55636262894,135.128037929535 5588.56626749039,133.075482845306 5573.99031758308,136.396250724792 PathPoint;PointKind.SMOOTHPOINT 5592.66441464424,134.910650253296 5629.19474959373,134.308054447174 5588.69691252708,134.976031780243 PathPoint;PointKind.SMOOTHPOINT 5659.07918214798,137.078862190247 5673.67106437683,138.626303672791 5633.58144879341,134.374144077301 PathPoint;PointKind.SMOOTHPOINT 5692.80613660812,155.41401386261 5697.49873638153,160.560507774353 5684.76173043251,146.591520309448 PathPoint;PointKind.SMOOTHPOINT 5700.72662472725,171.603376865387 5704.75466966629,173.301644325256 5696.61042094231,169.868052005768 PathPoint;PointKind.SMOOTHPOINT 5708.65561008453,179.722015857697 5711.30072951317,185.258674621582 5707.65506029129,177.627918720245 PathPoint;PointKind.SMOOTHPOINT 5713.98656487465,254.382526874542 5714.15013670921,261.199200153351 5712.98955559731,212.798223495483 PathPoint;PointKind.SMOOTHPOINT 5711.49970650673,289.000039100647 5708.5685133934,493.052244186401 5711.60804629326,281.463460922241 PathPoint;PointKind.SMOOTHPOINT 5711.64061903954,936.875267028809 5712.52256155014,950.066049098969 5710.65918803215,922.19085931778 PathPoint;PointKind.SMOOTHPOINT 5704.49939846992,967.999942302704 5702.89094209671,973.997812271118 5708.45521688461,953.251805305481 PathPoint;PointKind.SMOOTHPOINT 5699.57241654396,991.503775119781 5699.19499754906,999.848299026489 5700.17749071121,978.117084503174 PathPoint;PointKind.SMOOTHPOINT 5700.61970114708,1020.72318077087 5705.646879673,1044.14227724075 5698.9007806778,1012.71642208099 PathPoint;PointKind.SMOOTHPOINT 5706.29868865013,1098.7965130806 5706.26045107841,1126.64337873459 5706.33373975754,1072.98520803452 PathPoint;PointKind.SMOOTHPOINT 5706.12874388695,1163.57851266861 5706.23177289963,1179.86913442612 5706.05439305305,1151.74894094467 PathPoint;PointKind.SMOOTHPOINT 5704.96780872345,1227.34580039978 5703.40467095375,1245.03846645355 5707.00112700462,1204.34519290924 PathPoint;PointKind.SMOOTHPOINT 5710.80080866814,1276.96022987366 5710.91056466103,1285.20491123199 5710.66626906395,1266.88651800156 PathPoint;PointKind.SMOOTHPOINT 5710.49986481667,1323.9999961853 5709.08047199249,1339.40383672714 5711.50891184807,1313.04634809494 PathPoint;PointKind.SMOOTHPOINT 5706.57095432281,1374.12260770798 5703.89892697334,1401.92769527435 5708.09160590172,1358.30405473709 PathPoint;PointKind.SMOOTHPOINT 5700.41187286377,1454.06722068787 5700.31592488289,1464.32149887085 5700.60270667076,1433.56314897537 PathPoint;PointKind.SMOOTHPOINT 5700.01604318619,1531.60593509674 5700.01073241234,1539.70498323441 5700.04082679749,1493.70494842529 PathPoint;PointKind.SMOOTHPOINT 5700.03834843636,1556.96617841721 5701.62874817848,1568.91659975052 5698.88166189194,1548.26949119568 PathPoint;PointKind.SMOOTHPOINT 5700.13819098473,1581.30840539932 5700.26423335075,1603.06039094925 5700.09039402008,1573.01297664642 PathPoint;PointKind.SMOOTHPOINT 5698.89617800713,1648.41605186462 5699.14188981056,1662.32721090317 5698.49822402,1625.88538885117 PathPoint;PointKind.SMOOTHPOINT 5702.78649687767,1680.81743717194 5704.42646384239,1740.65262794495 5702.41899132729,1667.41469621658 PathPoint;PointKind.SMOOTHPOINT 5702.38606452942,1833.66268873215 5700.65262794495,1904.42957639694 5703.03751945496,1807.04650640488 PathPoint;PointKind.SMOOTHPOINT 5701.56147837639,2148.462703228 5700.01816749573,2186.24331235886 5703.10443520546,2110.68233013153 PathPoint;PointKind.SMOOTHPOINT 5701.06545209885,2337.74788856506 5702.80703186989,2372.29459047318 5699.32316422462,2303.20095062256 PathPoint;PointKind.SMOOTHPOINT 5692.88650631905,2429.83387470245 5691.71353340149,2442.68382310867 5694.77289319038,2409.16717529297 PathPoint;PointKind.SMOOTHPOINT 5696.6493666172,2510.82175970078 5695.87859630585,2529.5322060585 5698.30845236778,2470.56231737137 PathPoint;PointKind.SMOOTHPOINT 5699.49594140053,2557.39701032639 5698.57823967934,2575.1482129097 5700.42355656624,2539.45296764374 PathPoint;PointKind.SMOOTHPOINT 5700.28264403343,2636.3528752327 5701.28319382668,2654.66914415359 5698.70959281921,2607.54346132278 PathPoint;PointKind.SMOOTHPOINT 5704.12551999092,2686.97399139404 5704.47001218796,2702.32732057571 5703.69180679321,2667.67723560333 PathPoint;PointKind.SMOOTHPOINT 5701.024736166,2732.51611948013 5701.36922836304,2747.45450019836 5700.6965303421,2718.28395366669 PathPoint;PointKind.SMOOTHPOINT 5700.91568827629,2774.01710271835 5697.85207986832,2841.06928110123 5701.52465701103,2760.69626569748 PathPoint;PointKind.SMOOTHPOINT 5698.533629179,2924.83269453049 5697.13370919228,2953.62416982651 5700.08437514305,2892.92273283005 PathPoint;PointKind.SMOOTHPOINT 5709.28405165672,2993.69218826294 5710.21662354469,3003.30539703369 5707.38279461861,2974.08528327942 PathPoint;PointKind.SMOOTHPOINT 5707.18310952187,3037.21244573593 5705.51411032677,3069.67826843262 5708.85210871696,3004.74638700485 PathPoint;PointKind.SMOOTHPOINT 5706.55962467194,3275.08413076401 5705.42949199677,3295.09725093842 5709.44195866585,3224.05325889587 PathPoint;PointKind.SMOOTHPOINT 5704.86194729805,3341.70106172562 5704.83928799629,3344.98288393021 5705.02127051353,3318.52484464645 PathPoint;PointKind.SMOOTHPOINT 5704.80777740479,3351.5212726593 5703.38130354881,3358.31764698029 5705.477643013,3348.32937955856 PathPoint;PointKind.SMOOTHPOINT 5704.75927233696,3369.61897373199 5704.71926450729,3395.18102645874 5704.7684776783,3363.68624925613 PathPoint;PointKind.SMOOTHPOINT 5704.15596842766,3433.99711847305 5703.71446609497,3445.47806739807 5704.75360751152,3418.46558332443 PathPoint;PointKind.SMOOTHPOINT 5707.3477435112,3490.95316171646 5707.66638994217,3494.88573074341 5705.36682486534,3466.52997493744 PathPoint;PointKind.SMOOTHPOINT 5708.32244753838,3502.98713922501 5705.76938152313,3508.35739374161 5710.08031368256,3499.28918838501 PathPoint;PointKind.SMOOTHPOINT 5709.22457098961,3514.36635732651 5710.82382202148,3534.93722677231 5708.92681360245,3510.5348110199 PathPoint;PointKind.SMOOTHPOINT 5712.7286195755,3575.73128700256 5713.23845386505,3597.99334287643 5712.28676319122,3556.4257979393 PathPoint;PointKind.SMOOTHPOINT 5707.62142539024,3628.35373878479 5704.04550433159,3671.64881944656 5708.7062394619,3615.22243738174 PathPoint;PointKind.SMOOTHPOINT 5703.33917140961,3745.76102256775 5701.43331170082,3757.30758905411 5708.38794708252,3715.17261743546 PathPoint;PointKind.SMOOTHPOINT 5691.37718439102,3778.98050308228 5687.79630661011,3785.02628803253 5697.44102597237,3768.74321937561 PathPoint;PointKind.SMOOTHPOINT 5678.46952557564,3795.63981056213 5673.30072641373,3798.00723552704 5685.38238286972,3792.47411727905 PathPoint;PointKind.SMOOTHPOINT 5664.97307896614,3806.29652738571 5654.79692816734,3812.57315397263 5669.93511199951,3803.23586940765 PathPoint;PointKind.SMOOTHPOINT 5628.61906170845,3817.43333816528 5584.73153471947,3819.97566461563 5642.67420172691,3816.61925554276 PathPoint;PointKind.SMOOTHPOINT 5115.78029036522,3820.16118764877 5053.84108901024,3820.01484632492 5177.71878361702,3820.30752897263 PathPoint;PointKind.SMOOTHPOINT 4491.70523643494,3817.51547813416 4413.16809654236,3817.12035655975 4570.24202227592,3817.91107177734 PathPoint;PointKind.SMOOTHPOINT 4032.57998585701,3820.36299705505 4023.53361368179,3820.66016435623 4082.97108650208,3818.70768785477 PathPoint;PointKind.SMOOTHPOINT 4005.3934264183,3825.9999704361 3982.91610717773,3826.86031579971 4012.80372619629,3825.71649312973 PathPoint;PointKind.SMOOTHPOINT 3952.0750272274,3824.20115232468 3943.30764770508,3824.8356127739 3969.37327980995,3822.94969797134 PathPoint;PointKind.SMOOTHPOINT 3925.23543834686,3827.1676325798 3919.14575099945,3827.30240821838 3936.69077754021,3826.91389560699 PathPoint;PointKind.SMOOTHPOINT 3896.18515133858,3827.36826181412 3884.441614151,3827.37274646759 3909.09316420555,3827.36330509186 PathPoint;PointKind.SMOOTHPOINT 3861.38400435448,3824.99989271164 3854.47893619537,3823.21783304214 3873.71420502663,3828.18163633347 PathPoint;PointKind.SMOOTHPOINT 3832.45621919632,3827.13411569595 3749.2452442646,3826.63065433502 3840.1348900795,3827.18061447144 PathPoint;PointKind.SMOOTHPOINT 3599.28740143776,3825.30225276947 3540.46951889992,3825.03765821457 3638.04719924927,3825.47668218613 PathPoint;PointKind.SMOOTHPOINT 3462.14870452881,3824.94348049164 3458.61916422844,3824.87526655197 3497.09961533546,3825.61995506287 PathPoint;PointKind.SMOOTHPOINT 3437.3052585125,3824.87833499908 3433.29527020454,3823.49871397018 3446.01174116135,3827.87455558777 PathPoint;PointKind.SMOOTHPOINT 3424.35688376427,3819.99997615814 3420.82875967026,3819.98628616333 3430.41222810745,3820.02334356308 PathPoint;PointKind.SMOOTHPOINT 3412.46393680573,3823.80107402802 3404.30906653404,3826.68942689896 3417.41641044617,3822.04686641693 PathPoint;PointKind.SMOOTHPOINT 3388.60829472542,3825.76322793961 3378.20378065109,3825.73561191559 3396.02036476135,3825.78281879425 PathPoint;PointKind.SMOOTHPOINT 3352.83846259117,3823.64505529404 3344.04417514801,3819.73986625671 3362.34758019447,3827.86747455597 PathPoint;PointKind.SMOOTHPOINT 3325.02381563187,3819.52342271805 3319.9275970459,3819.52955961227 3337.89111256599,3819.50808048248 PathPoint;PointKind.SMOOTHPOINT 3304.3493270874,3822.99997329712 3293.43108415604,3823.01767587662 3309.60486888885,3822.99147605896 PathPoint;PointKind.SMOOTHPOINT 3278.31237316132,3821.42562389374 3271.42854809761,3822.01476573944 3292.34768629074,3820.22444486618 PathPoint;PointKind.SMOOTHPOINT 3250.49241542816,3819.32845830917 3245.05701541901,3819.34285640717 3258.61966967583,3819.30674314499 PathPoint;PointKind.SMOOTHPOINT 3228.34471821785,3825.93128442764 3221.57843828201,3825.95063924789 3233.85057449341,3825.91570615768 PathPoint;PointKind.SMOOTHPOINT 3207.91983604431,3825.99170923233 3203.98773908615,3826.0032749176 3214.7654235363,3825.97070217133 PathPoint;PointKind.SMOOTHPOINT 3197.82086849213,3820.202729702 3190.22539973259,3820.22633314133 3201.77137613297,3820.19045591354 PathPoint;PointKind.SMOOTHPOINT 3166.0128736496,3823.1559920311 3162.82782554626,3823.18549633026 3173.65826368332,3823.08588981628 PathPoint;PointKind.SMOOTHPOINT 3155.33998847008,3821.0000538826 3151.98924422264,3821.03380680084 3158.51441502571,3820.96795320511 PathPoint;PointKind.SMOOTHPOINT 3146.13252282143,3825.12876749039 3138.82064938545,3825.22601366043 3149.46804285049,3825.08415699005 PathPoint;PointKind.SMOOTHPOINT 3124.33073401451,3825.40563583374 3120.2520596981,3825.45520305634 3131.54913783073,3825.31853914261 PathPoint;PointKind.SMOOTHPOINT 3111.33704066277,3821.99989557266 3109.40037846565,3822.02184677124 3115.37924766541,3821.95363283157 PathPoint;PointKind.SMOOTHPOINT 3097.43839144707,3825.001308918 3090.89658021927,3825.09430646896 3099.36514019966,3824.97369289398 PathPoint;PointKind.SMOOTHPOINT 3078.12877178192,3825.26897192001 3074.80741381645,3825.31358242035 3084.45886015892,3825.18352746964 PathPoint;PointKind.SMOOTHPOINT 3068.63027572632,3820.87684392929 3065.85274100304,3820.91295719147 3071.89179897308,3820.83435773849 PathPoint;PointKind.SMOOTHPOINT 3055.70349812508,3823.87967348099 3047.58544921875,3824.01987791061 3058.43748450279,3823.83246660233 PathPoint;PointKind.SMOOTHPOINT 3023.9114356041,3820.75977087021 3012.87493944168,3820.97645044327 3031.52885556221,3820.61036109924 PathPoint;PointKind.SMOOTHPOINT 2985.14915943146,3822.68274307251 2977.74523258209,3822.15874671936 2995.80929875374,3823.43710899353 PathPoint;PointKind.SMOOTHPOINT 2970.25385499001,3818.59509944916 2961.46417021751,3819.10446166992 2976.26600503922,3818.24647665024 PathPoint;PointKind.SMOOTHPOINT 2947.37858176231,3825.62066316605 2948.38869094849,3825.84371566772 2944.56493377686,3824.99918460846 PathPoint;PointKind.SMOOTHPOINT 2938.16863775253,3826.18242502213 2936.41572833061,3826.22396707535 2944.40773487091,3826.03443145752 PathPoint;PointKind.SMOOTHPOINT 2932.48327732086,3821.5327835083 2928.1277346611,3821.60619020462 2934.53217387199,3821.49808645248 PathPoint;PointKind.SMOOTHPOINT 2922.53230333328,3826.5678691864 2915.1605951786,3828.00248622894 2927.37820744514,3825.62491178513 PathPoint;PointKind.SMOOTHPOINT 2898.68197202682,3826.50532007217 2893.61797213554,3826.47015094757 2903.75659346581,3826.54072523117 PathPoint;PointKind.SMOOTHPOINT 2882.32301831245,3818.00005674362 2855.39066791534,3817.79069423676 2887.03225851059,3818.03664207458 PathPoint;PointKind.SMOOTHPOINT 2820.97118854523,3817.96819210052 2818.19754838943,3817.96724796295 2840.29815673828,3817.97550916672 PathPoint;PointKind.SMOOTHPOINT 2814.22367334366,3822.23545789719 2810.75963258743,3822.24513530731 2816.86879277229,3822.2279047966 PathPoint;PointKind.SMOOTHPOINT 2797.31770992279,3818.99989843369 2782.43019461632,3819.12027597427 2800.57569265366,3818.97346258163 PathPoint;PointKind.SMOOTHPOINT 2763.55039358139,3819.06622409821 2756.85209155083,3819.42027568817 2775.05884051323,3818.45749139786 PathPoint;PointKind.SMOOTHPOINT 2744.77255940437,3820.54049491882 2740.83515167236,3820.91933012009 2750.7454097271,3819.96598720551 PathPoint;PointKind.SMOOTHPOINT 2735.70919275284,3825.06669044495 2731.8149793148,3825.41838169098 2739.66040849686,3824.71004247665 PathPoint;PointKind.SMOOTHPOINT 2720.98666548729,3822.57699966431 2717.71275043488,3822.76629924774 2725.1464176178,3822.33671665192 PathPoint;PointKind.SMOOTHPOINT 2711.85886144638,3825.00414133072 2708.146276474,3825.07754802704 2715.4361987114,3824.93380308151 PathPoint;PointKind.SMOOTHPOINT 2698.94553780556,3822.94592142105 2693.74558210373,3822.81846284866 2703.11874389648,3823.04836034775 PathPoint;PointKind.SMOOTHPOINT 2685.03024816513,3823.92192363739 2680.30861616135,3823.73734474182 2689.7947204113,3824.10815477371 PathPoint;PointKind.SMOOTHPOINT 2670.42986869812,3821.84765338898 2666.09592318535,3821.61822795868 2674.76912498474,3822.07707881927 PathPoint;PointKind.SMOOTHPOINT 2659.3087542057,3822.99997329712 2655.29734969139,3822.73750305176 2663.30635070801,3823.26149940491 PathPoint;PointKind.SMOOTHPOINT 2645.26671409607,3828.8788819313 2640.35354018211,3828.50571155548 2648.98496389389,3829.1611790657 PathPoint;PointKind.SMOOTHPOINT 2631.36771082878,3823.78148317337 2626.13199591637,3822.90083885193 2635.81353664398,3824.52924013138 PathPoint;PointKind.SMOOTHPOINT 2612.30592727661,3825.9999704361 2608.99837732315,3825.38698911667 2617.08668589592,3826.88604354858 PathPoint;PointKind.SMOOTHPOINT 2595.30472397804,3818.99989843369 2582.74580597878,3815.52877664566 2598.41542124748,3819.85953569412 PathPoint;PointKind.SMOOTHPOINT 2568.78201127052,3815.51980733871 2566.3022339344,3815.55733680725 2581.9686627388,3815.31965017319 PathPoint;PointKind.SMOOTHPOINT 2561.81533813477,3819.55056667328 2557.62974023819,3819.80666399002 2564.01152014732,3819.41626310349 PathPoint;PointKind.SMOOTHPOINT 2540.94647526741,3819.49580669403 2525.42839407921,3821.38266563416 2544.31563019753,3819.08628702164 PathPoint;PointKind.SMOOTHPOINT 2514.09909725189,3825.4988694191 2509.49182391167,3825.67306280136 2526.13649725914,3825.04426717758 PathPoint;PointKind.SMOOTHPOINT 2491.24825358391,3823.41468572617 2481.32772803307,3823.15788030624 2499.58864688873,3823.63089323044 PathPoint;PointKind.SMOOTHPOINT 2465.42089819908,3819.29824590683 2455.95426678658,3818.27456474304 2473.20932507515,3820.14018058777 PathPoint;PointKind.SMOOTHPOINT 2441.56844258308,3820.24804830551 2434.18540477753,3821.225938797 2447.36462116241,3819.48022842407 PathPoint;PointKind.SMOOTHPOINT 2421.67463779449,3827.28140115738 2419.79072928429,3827.18675136566 2433.56085777283,3827.87880420685 PathPoint;PointKind.SMOOTHPOINT 2404.29282903671,3819.99997615814 2397.78146624565,3819.81421709061 2408.81477594376,3820.12908697128 PathPoint;PointKind.SMOOTHPOINT 2388.29217553139,3824.00005102158 2384.42734837532,3823.91743898392 2399.45896267891,3824.23820972443 PathPoint;PointKind.SMOOTHPOINT 2373.98247241974,3824.11995649338 2369.19852733612,3824.02436256409 2378.3273935318,3824.20705318451 PathPoint;PointKind.SMOOTHPOINT 2357.74106383324,3825.75425863266 2351.71510577202,3825.64072608948 2363.0560863018,3825.85410118103 PathPoint;PointKind.SMOOTHPOINT 2341.2889945507,3819.99997615814 2335.68789839745,3820.10477542877 2347.95507788658,3819.87534999847 PathPoint;PointKind.SMOOTHPOINT 2321.30844712257,3826.00657939911 2313.97037386894,3825.88360548019 2327.26465702057,3826.10665798187 PathPoint;PointKind.SMOOTHPOINT 2298.28624248505,3821.99989557266 2288.30021739006,3822.32279062271 2305.93658924103,3821.75253152847 PathPoint;PointKind.SMOOTHPOINT 2267.64272332191,3826.8782544136 2254.26842451096,3826.66417121887 2278.55282306671,3827.05339193344 PathPoint;PointKind.SMOOTHPOINT 2220.93623757362,3826.75598859787 2109.90813732147,3831.2784075737 2235.02642869949,3826.18218898773 PathPoint;PointKind.SMOOTHPOINT 1920.81980466843,3826.98305368423 1796.58345580101,3829.00752067566 1978.63395094872,3826.04104042053 PathPoint;PointKind.SMOOTHPOINT 1498.46351981163,3829.92663860321 1475.20799517632,3830.30429363251 1594.8937189579,3828.36007833481 PathPoint;PointKind.SMOOTHPOINT 1390.80457448959,3830.6928062439 1388.93978476524,3830.70106744766 1425.67759394646,3830.53985595703 PathPoint;PointKind.SMOOTHPOINT 1374.2416870594,3830.61349868774 1353.917709589,3826.59501314163 1375.98432898521,3830.95834493637 PathPoint;PointKind.SMOOTHPOINT 1352.64383196831,3830.90334892273 1355.6925702095,3831.01947784424 1351.53671264648,3830.86109876633 PathPoint;PointKind.SMOOTHPOINT 1278.71148705482,3830.7631444931 1270.80834746361,3830.73080778122 1303.95324110985,3830.86605548859 PathPoint;PointKind.SMOOTHPOINT 1257.22090959549,3828.99996757507 1252.35871911049,3830.74166536331 1266.04918599129,3825.8375787735 PathPoint;PointKind.SMOOTHPOINT 1239.40751194954,3830.5585026741 1187.3112988472,3830.22923469543 1244.57701921463,3830.59154748917 PathPoint;PointKind.SMOOTHPOINT 1086.05573058128,3828.8472533226 1023.8060259819,3829.40759897232 1134.65674638748,3828.4096455574 PathPoint;PointKind.SMOOTHPOINT 889.639238119125,3829.86904621124 884.325985908508,3829.8810839653 956.970645189285,3829.7153878212 PathPoint;PointKind.SMOOTHPOINT 870.411050319672,3828.2828950882 863.125376701355,3828.2968211174 875.728905200958,3828.27274560928 PathPoint;PointKind.SMOOTHPOINT 851.833609342575,3829.93985652924 839.334526062012,3829.95826721191 859.117866754532,3829.92923498154 PathPoint;PointKind.SMOOTHPOINT 814.39017534256,3829.98187065125 809.354145526886,3829.98588323593 826.844648122787,3829.97219324112 PathPoint;PointKind.SMOOTHPOINT 798.860764503479,3828.0957198143 795.590744018555,3829.03726100922 805.908515453339,3826.0670042038 PathPoint;PointKind.SMOOTHPOINT 789.102748632431,3829.99650478363 777.057913541794,3830.0009894371 792.497749328613,3829.99532461166 PathPoint;PointKind.SMOOTHPOINT 753.142436742783,3830.00028133392 741.215854883194,3829.99862909317 765.062999725342,3830.00216960907 PathPoint;PointKind.SMOOTHPOINT 714.388657808304,3828.88667106628 707.38374710083,3828.9003610611 726.058198213577,3828.86448383331 PathPoint;PointKind.SMOOTHPOINT 690.318814516068,3831.82765960693 686.621099710464,3831.82931184769 697.188831567764,3831.82459115982 PathPoint;PointKind.SMOOTHPOINT 673.184487819672,3828.99996757507 662.101610898972,3829.91011619568 676.82697057724,3828.70091199875 PathPoint;PointKind.SMOOTHPOINT 631.899240016937,3831.70751810074 509.274533987045,3831.0983133316 647.183293104172,3831.78352117538 PathPoint;PointKind.SMOOTHPOINT 395.411188602448,3831.07801437378 391.947855949402,3831.00649595261 459.648538827896,3832.4073600769 PathPoint;PointKind.SMOOTHPOINT 385.166351795197,3828.99996757507 382.310217618942,3828.93789052963 388.682792186737,3829.0766787529 PathPoint;PointKind.SMOOTHPOINT 366.58961892128,3832.01483488083 359.699420928955,3831.83120012283 369.472306966782,3832.09201812744 PathPoint;PointKind.SMOOTHPOINT 348.704702854156,3830.95574855804 343.160609006882,3830.49666166306 356.082783937454,3831.56684160233 PathPoint;PointKind.SMOOTHPOINT 332.809910774231,3828.88997554779 324.937219619751,3829.62026596069 336.470096111298,3828.55032205582 PathPoint;PointKind.SMOOTHPOINT 321.876089572906,3829.87353086472 315.818974971771,3830.08879423141 327.461607456207,3829.67502593994 PathPoint;PointKind.SMOOTHPOINT 301.160885095596,3828.99996757507 288.361212015152,3829.91342067719 305.344712734222,3828.70114803314 PathPoint;PointKind.SMOOTHPOINT 276.166259050369,3828.7415099144 269.556823968887,3828.25221061707 287.832258939743,3829.60539579391 PathPoint;PointKind.SMOOTHPOINT 259.285433292389,3823.63632202148 257.735749483109,3821.3106751442 264.438654184341,3831.36975288391 PathPoint;PointKind.SMOOTHPOINT 255.158253908157,3806.99990987778 253.16565155983,3804.57347631454 257.024459838867,3809.27244901657 PathPoint;PointKind.SMOOTHPOINT 248.157945871353,3803.00007104874 245.610898733139,3799.96986150742 250.184183120728,3805.40998220444 PathPoint;PointKind.SMOOTHPOINT 241.052838563919,3793.16333770752 239.49182510376,3791.12895727158 243.377541303635,3796.19519948959 PathPoint;PointKind.SMOOTHPOINT 240.157442092896,3785.00008821487 236.875029802322,3784.02266979218 242.382656335831,3785.6626367569 PathPoint;PointKind.SMOOTHPOINT 234.156975746155,3782.0000910759 227.933456897736,3776.99427366257 235.873063802719,3783.3797121048 PathPoint;PointKind.CORNERPOINT 226.624174118042,3772.93943881989 226.624174118042,3772.93943881989 226.624174118042,3772.93943881989 PathPoint;PointKind.SMOOTHPOINT 226.268352270126,2439.08831119537 226.269414424896,2436.54952526093 226.02157831192,2975.66647768021 PathPoint;PointKind.SMOOTHPOINT 227.156313657761,2431.99996232986 226.344827413559,2430.43174982071 227.98656463623,2433.6040520668 PathPoint;PointKind.SMOOTHPOINT 226.274371147156,2426.20083332062 226.398643255234,2172.5582742691 226.273663043976,2427.96094179153 PathPoint;PointKind.SMOOTHPOINT 227.390695810318,1963.08058261871 228.693251609802,1930.24678230286 226.718351840973,1980.03422498703 PathPoint;PointKind.SMOOTHPOINT 225.156276226044,1847.00004816055 225.184246301651,1844.91279602051 224.608204364777,1887.64682292938 PathPoint;PointKind.SMOOTHPOINT 228.693251609802,1835.55379629135 229.13475394249,1819.08756494522 228.636249303818,1837.6868391037 PathPoint;PointKind.SMOOTHPOINT 228.788845539093,1799.11409854889 228.859655857086,1794.83054637909 228.61465215683,1809.66271162033 PathPoint;PointKind.SMOOTHPOINT 226.846164464951,1781.90129041672 226.905291080475,1779.33748483658 226.776062250137,1784.94589805603 PathPoint;PointKind.SMOOTHPOINT 227.863708734512,1772.79390335083 227.918232679367,1770.73945999146 227.724566459656,1778.02678585052 PathPoint;PointKind.SMOOTHPOINT 230.156900882721,1763.99996995926 230.043604373932,1760.98722696304 230.27373790741,1767.09957361221 PathPoint;PointKind.SMOOTHPOINT 227.530192136765,1755.86811304092 227.767052650452,1747.13649272919 227.457965612411,1758.52373600006 PathPoint;PointKind.SMOOTHPOINT 228.363629579544,1725.33612012863 228.580309152603,1717.40206003189 228.050647974014,1736.7977142334 PathPoint;PointKind.SMOOTHPOINT 233.013035058975,1703.97571563721 232.870706319809,1701.71804666519 234.20194029808,1722.87734985352 PathPoint;PointKind.SMOOTHPOINT 230.156900882721,1693.00011634827 230.238686800003,1689.96778249741 230.094587802887,1695.30806064606 PathPoint;PointKind.SMOOTHPOINT 234.062443971634,1682.72176265717 233.269014358521,1678.92892599106 234.774087667465,1686.12349033356 PathPoint;PointKind.SMOOTHPOINT 230.156900882721,1672.99997806549 230.259575843811,1669.14600849152 230.086444616318,1675.65135240555 PathPoint;PointKind.SMOOTHPOINT 232.13038444519,1661.46002054214 232.275545597076,1656.12564325333 232.024168968201,1665.36638975143 PathPoint;PointKind.SMOOTHPOINT 230.182746648788,1646.271443367 230.628143548965,1626.96973085403 230.05847454071,1651.6631770134 PathPoint;PointKind.SMOOTHPOINT 231.156742572784,1590.99997758865 231.265436410904,1586.70556783676 230.68727016449,1609.57423210144 PathPoint;PointKind.SMOOTHPOINT 235.157171487808,1577.00006961823 236.262166500092,1533.24849843979 235.052018165588,1581.17292165756 PathPoint;PointKind.SMOOTHPOINT 233.58589053154,1485.33634901047 233.319289684296,1476.12510681152 233.89816403389,1496.14861249924 PathPoint;PointKind.SMOOTHPOINT 236.940529346466,1441.82506084442 237.017712593079,1440.25141954422 236.06602191925,1459.66029167175 PathPoint;PointKind.SMOOTHPOINT 236.157013177872,1437.00004577637 235.577076673508,1434.57951307297 236.528059244156,1438.5479593277 PathPoint;PointKind.SMOOTHPOINT 237.202527523041,1432.08061695099 237.218459844589,1425.13908147812 237.198987007141,1433.74985218048 PathPoint;PointKind.SMOOTHPOINT 235.766848325729,1411.44955873489 231.254814863205,1383.03314208984 236.831127405167,1418.15222740173 PathPoint;PointKind.SMOOTHPOINT 225.015717744827,1342.59006500244 225.067763328552,1337.43790626526 224.834797382355,1360.57848215103 PathPoint;PointKind.SMOOTHPOINT 227.06426024437,1319.3142414093 227.27031826973,1314.83242034912 226.413867473602,1333.4562420845 PathPoint;PointKind.SMOOTHPOINT 226.156471967697,1300.00001907349 226.634087562561,1290.22371053696 225.903679132462,1305.17743349075 PathPoint;PointKind.SMOOTHPOINT 231.166656017303,1270.7381272316 231.831210851669,1257.96677827835 230.555562973022,1282.47965812683 PathPoint;PointKind.SMOOTHPOINT 230.617167949677,1225.13297796249 234.52094078064,1152.70511627197 229.848521947861,1239.39866065979 PathPoint;PointKind.SMOOTHPOINT 236.79288983345,1019.72074270248 237.141984701157,1005.57897806168 235.66027879715,1065.65681219101 PathPoint;PointKind.SMOOTHPOINT 238.86515378952,987.334699630737 239.095287322998,976.058864593506 238.794343471527,990.822343826294 PathPoint;PointKind.SMOOTHPOINT 238.157050609589,964.999945163727 234.663269519806,955.78634262085 241.35165810585,973.42188835144 PathPoint;PointKind.SMOOTHPOINT 226.089556217194,932.641282081604 226.217368841171,929.947893619537 225.694788694382,940.969047546387 PathPoint;PointKind.SMOOTHPOINT 227.907611131668,899.43336725235 227.89061665535,892.422909736633 227.949389219284,916.512107849121 PathPoint;PointKind.SMOOTHPOINT 233.189352750778,877.999556064606 234.347101449966,854.844818115234 232.75634765625,886.656353473663 PathPoint;PointKind.SMOOTHPOINT 230.99635720253,844.18408870697 233.518620729446,799.177522659302 230.361188650131,855.519168376923 PathPoint;PointKind.SMOOTHPOINT 236.729868650436,694.686276912689 236.773416996002,693.018929958344 235.408194065094,744.967503547668 PathPoint;PointKind.SMOOTHPOINT 236.859451532364,689.697926044464 237.694659233093,687.63710975647 236.236320734024,691.235218048096 PathPoint;PointKind.SMOOTHPOINT 237.018066644669,683.42059135437 238.008348941803,643.686797618866 236.966021060944,685.504539012909 PathPoint;PointKind.SMOOTHPOINT 238.937734365463,580.420138835907 239.145562648773,561.996474266052 238.637144565582,607.105243206024 PathPoint;PointKind.SMOOTHPOINT 238.057916164398,536.892092227936 238.926758766174,518.399505615234 237.810788154602,542.149286270142 PathPoint;PointKind.SMOOTHPOINT 242.157479524612,393.00009727478 242.487101554871,384.993574619293 239.641234874725,454.106097221375 PathPoint;PointKind.SMOOTHPOINT 240.467237234116,375.954165458679 239.543162584305,369.430646896362 241.443357467651,382.84731388092 PathPoint;PointKind.SMOOTHPOINT 243.157321214676,347.000062465668 243.327974081039,343.310372829437 242.837258577347,353.936169147491 PathPoint;PointKind.SMOOTHPOINT 246.158616542816,329.412431716919 247.386113405228,303.898530006409 245.988317728043,332.943978309631 PathPoint;PointKind.SMOOTHPOINT 245.688436031342,279.806499481201 249.726394414902,237.999379634857 244.617429971695,290.890202522278 PathPoint;PointKind.SMOOTHPOINT 251.973913908005,156.331243515015 254.740473031998,134.525442123413 248.91455411911,180.450654029846 PathPoint";
	
	mask35mm[2] = "PointKind.CORNERPOINT 273,133 273,133 273,133 PathPoint;PointKind.SMOOTHPOINT 284.495824098587,130.096728801727 286.151369333267,129.946138858795 276.442566633224,130.829379558563 PathPoint;PointKind.SMOOTHPOINT 292.450655221939,128.093268871307 317.038475990295,127.877533435822 290.613127470016,128.109319210052 PathPoint;PointKind.SMOOTHPOINT 417.655689239502,128.420884609222 422.099390745163,128.458178043365 363.558022499084,127.96439409256 PathPoint;PointKind.SMOOTHPOINT 434.812675237656,129.99995470047 442.645712614059,130.478160381317 430.289312124252,129.72403049469 PathPoint;PointKind.SMOOTHPOINT 447.464000701904,129.511127471924 460.419102430344,129.551961421967 443.088985204697,129.497437477112 PathPoint;PointKind.SMOOTHPOINT 486.409675598145,129.718129634857 553.742498874664,130.210025310516 473.438287496567,129.623243808746 PathPoint;PointKind.SMOOTHPOINT 651.126867055893,130.062503814697 655.769899606705,130.136382579803 601.871209859848,129.279813766479 PathPoint;PointKind.SMOOTHPOINT 666,132 673.033234834671,130.295831680298 660.165583848953,133.41384601593 PathPoint;PointKind.SMOOTHPOINT 693.897007226944,131.168324947357 702.448061227798,130.121040344238 686.502285718918,132.07398891449 PathPoint;PointKind.SMOOTHPOINT 716.751745462418,131.228041648865 720.904416561127,130.02922296524 707.800259113312,133.812854290009 PathPoint;PointKind.SMOOTHPOINT 731.779111146927,130.717499256134 735.535598516464,130.628042221069 726.600398540497,130.840709209442 PathPoint;PointKind.SMOOTHPOINT 759.812561988831,132.000110149384 803.172552108765,131.513171195984 755.868073225021,132.044484615326 PathPoint;PointKind.SMOOTHPOINT 914.491328716278,133.770132064819 1051.81236219406,135.062656402588 841.65477347374,133.084688186646 PathPoint;PointKind.SMOOTHPOINT 1302.81263422966,134.000029563904 1404.20026373863,134.28138256073 1201.42535877228,133.718912601471 PathPoint;PointKind.SMOOTHPOINT 1478.90833568573,135.24747133255 1492.04400372505,135.55408000946 1412.58314323425,133.697905540466 PathPoint;PointKind.SMOOTHPOINT 1509,136 1513.06557440758,135.278206825256 1497.48518013954,138.044057846069 PathPoint;PointKind.SMOOTHPOINT 1526.27017092705,135.838265419006 1530.88204693794,135.843694210052 1522.21450996399,135.83354473114 PathPoint;PointKind.SMOOTHPOINT 1540.23431968689,135.819382667542 1542.68541884422,135.227172374725 1535.62598419189,136.932284832001 PathPoint;PointKind.SMOOTHPOINT 1547.00661849976,135.284056663513 1549.49489307404,135.412695407867 1544.87274956703,135.173356533051 PathPoint;PointKind.SMOOTHPOINT 1560.81250619888,135.000107288361 1584.44084715843,134.864387512207 1558.13693833351,135.015213489532 PathPoint;PointKind.SMOOTHPOINT 1652.12878417969,135.522215366364 1669.29709982872,135.573198795319 1606.87001538277,135.38791179657 PathPoint;PointKind.SMOOTHPOINT 1711.43242549896,135.855967998505 1859.41289019585,137.034015655518 1688.85420155525,135.676345825195 PathPoint;PointKind.SMOOTHPOINT 2023.45171880722,136.672646999359 2043.68258070946,137.01277256012 1951.02338504791,135.45494556427 PathPoint;PointKind.SMOOTHPOINT 2082.23277997971,137.119224071503 2088.46585822105,137.119696140289 2062.62504887581,137.11757183075 PathPoint;PointKind.SMOOTHPOINT 2101,138 2106.70058465004,137.985837936401 2094.56936097145,138.016286373138 PathPoint;PointKind.SMOOTHPOINT 2118.64946436882,137.039444446564 2136.15696144104,136.97783946991 2112.7010436058,137.060215473175 PathPoint;PointKind.SMOOTHPOINT 2176.0759241581,136.880829334259 2182.70624828339,136.87516450882 2154.92736053467,136.899712085724 PathPoint;PointKind.SMOOTHPOINT 2196,139 2201.79122185707,139.006608963013 2188.86763072014,138.992210865021 PathPoint;PointKind.SMOOTHPOINT 2214.62470722198,136.920011043549 2228.45042181015,136.961553096771 2208.46173119545,136.901364326477 PathPoint;PointKind.SMOOTHPOINT 2259.25538849831,137.158877849579 2266.21250224113,137.211985588074 2243.25792145729,137.036375999451 PathPoint;PointKind.SMOOTHPOINT 2278.8280684948,138.352975845337 2283.52739524841,138.398766517639 2271.4039607048,138.280749320984 PathPoint;PointKind.SMOOTHPOINT 2295.06310415268,137.488853931427 2321.9596953392,137.76572227478 2290.26782941818,137.439522743225 PathPoint;PointKind.SMOOTHPOINT 2379.1631026268,138.423314094543 2387.02694249153,138.513007164001 2350.28807115555,138.094518184662 PathPoint;PointKind.SMOOTHPOINT 2402.04297852516,139.687750339508 2409.84273505211,139.77484703064 2394.11647152901,139.59947347641 PathPoint;PointKind.SMOOTHPOINT 2426.30436372757,138.947782516479 2441.63302731514,139.11253452301 2418.47840738297,138.863990306854 PathPoint;PointKind.SMOOTHPOINT 2472.21848201752,139.410409927368 2475.19393157959,139.438025951385 2456.98045563698,139.269261360168 PathPoint;PointKind.SMOOTHPOINT 2482.53766965866,137.87406206131 2491.09155607224,137.950065135956 2479.57142543793,137.847862243652 PathPoint;PointKind.SMOOTHPOINT 2506.6425640583,139.7021484375 2514.25254893303,139.759740829468 2498.19630932808,139.638183116913 PathPoint;PointKind.SMOOTHPOINT 2524.81249165535,140.000023841858 2529.14466691017,140.026695728302 2517.32571673393,139.954469203949 PathPoint;PointKind.SMOOTHPOINT 2542.81247448921,138.000104427338 2546.63233709335,138.019459247589 2538.53022050858,137.97815322876 PathPoint;PointKind.SMOOTHPOINT 2559.04361557961,141.111037731171 2561.43983674049,141.12095117569 2555.26871752739,141.095223426819 PathPoint;PointKind.SMOOTHPOINT 2568.98857069016,138.100419044495 2575.89151453972,138.108208179474 2566.63943839073,138.097586631775 PathPoint;PointKind.SMOOTHPOINT 2588.93300485611,138.246288299561 2593.90459728241,138.310961723328 2582.52431702614,138.162968158722 PathPoint;PointKind.SMOOTHPOINT 2606,141 2608.88162589073,141.055940151215 2601.27695178986,140.908654689789 PathPoint;PointKind.SMOOTHPOINT 2623.64174437523,138.243455886841 2647.08810281754,138.297035694122 2620.88509869576,138.237318992615 PathPoint;PointKind.SMOOTHPOINT 2682.26666879654,139.408993721008 2797.68217635155,138.002936840057 2660.90248775482,139.66933965683 PathPoint;PointKind.SMOOTHPOINT 3016.14758563042,140.282793045044 3125.85401129723,139.813556671143 2907.79930186272,140.746600627899 PathPoint;PointKind.SMOOTHPOINT 3347.04703402519,141.1488032341 3352.24982213974,141.094279289246 3273.79092764854,141.921815872192 PathPoint;PointKind.SMOOTHPOINT 3363.84713602066,141.076104640961 3369.55940437317,141.080825328827 3357.86897492409,141.071147918701 PathPoint;PointKind.SMOOTHPOINT 3379.83610582352,142.247071266174 3383.71367883682,142.279407978058 3373.51805520058,142.194435596466 PathPoint;PointKind.SMOOTHPOINT 3393.85300827026,141.284995079041 3409.27478742599,141.043059825897 3389.77752041817,141.348960399628 PathPoint;PointKind.SMOOTHPOINT 3443.70453429222,140.602147579193 3447.20220994949,140.919849872589 3440.20650458336,140.28468132019 PathPoint;PointKind.SMOOTHPOINT 3452.08953809738,140.504665374756 3460.67139458656,142.578935623169 3449.35342741013,139.843060970306 PathPoint;PointKind.SMOOTHPOINT 3470.75513792038,140.303800106049 3538.77021861076,139.612927436829 3464.47249245644,140.367765426636 PathPoint;PointKind.SMOOTHPOINT 3659.0716381073,139.941251277924 3702.87914943695,140.546443462372 3612.85905432701,139.302778244019 PathPoint;PointKind.SMOOTHPOINT 3884.90769338608,141.173822879791 3890.76866340637,141.185388565063 3792.59121966362,140.989007949829 PathPoint;PointKind.SMOOTHPOINT 3902.51113843918,141.205923557281 3910.15015554428,140.171148777008 3896.69159245491,141.994278430939 PathPoint;PointKind.SMOOTHPOINT 3919.95738458633,141.231415271759 3945.43033432961,141.263988018036 3914.14952230453,141.224098205566 PathPoint;PointKind.SMOOTHPOINT 3995.80904316902,143.265795707703 4000.34161162376,143.263671398163 3971.68432188034,143.276181221008 PathPoint;PointKind.SMOOTHPOINT 4009.85391569138,141.844396591187 4015.01350951195,141.8403840065 4005.40667366982,141.847937107086 PathPoint;PointKind.SMOOTHPOINT 4024.56617546082,143.241484165192 4048.83641195297,143.211035728455 4019.53970503807,143.248093128204 PathPoint;PointKind.SMOOTHPOINT 4090.33409070969,141.069967746735 4113.19272351265,140.972485542297 4070.44630479813,141.15446805954 PathPoint;PointKind.SMOOTHPOINT 4157.8789908886,140.69892168045 4161.75904226303,140.674374103546 4135.59215140343,140.839126110077 PathPoint;PointKind.SMOOTHPOINT 4169.51064777374,140.625042915344 4178.75812125206,140.443060398102 4165.63626122475,140.701518058777 PathPoint;PointKind.SMOOTHPOINT 4189.96491622925,140.49569606781 4196.51380848885,140.454390048981 4183.14482045174,140.538182258606 PathPoint;PointKind.SMOOTHPOINT 4209.63354420662,140.375082492828 4212.13279438019,140.360448360443 4203.06694936752,140.414028167725 PathPoint;PointKind.SMOOTHPOINT 4217.13660550117,140.331180095673 4224.12700009346,138.835666179657 4214.68656849861,140.855412483215 PathPoint;PointKind.SMOOTHPOINT 4230.73254060745,140.255885124207 4242.34330844879,140.194280147552 4226.19076681137,140.279960632324 PathPoint;PointKind.SMOOTHPOINT 4265.82436394691,140.095853805542 4269.96959996223,140.080511569977 4254.02453255653,140.139520168304 PathPoint;PointKind.SMOOTHPOINT 4278.30645275116,140.054075717926 4281.44441199303,141.353445053101 4273.87832951546,138.22056055069 PathPoint;PointKind.SMOOTHPOINT 4288.50278449059,140.026931762695 4299.4688243866,140.001204013824 4285.09220552444,140.034956932068 PathPoint;PointKind.SMOOTHPOINT 4321.81302022934,139.987277984619 4325.6888229847,139.987277984619 4310.55984449387,139.987041950226 PathPoint;PointKind.SMOOTHPOINT 4333.49955511093,139.992942810059 4341.02031898499,135.601286888123 4330.10243010521,141.976811885834 PathPoint;PointKind.SMOOTHPOINT 4357,140 4398.96608901024,140.081431865692 4352.92309594154,139.991974830627 PathPoint;PointKind.SMOOTHPOINT 4480.85795116425,141.07964515686 4600.44029188156,140.179173946381 4432.09194731712,141.446914672852 PathPoint;PointKind.SMOOTHPOINT 4789.01206326485,139.451479911804 4797.68774342537,139.417254924774 4696.42828059196,139.813556671143 PathPoint;PointKind.SMOOTHPOINT 4814.96581506729,139.349277019501 4826.5882666111,138.062889575958 4806.38360452652,140.298607349396 PathPoint;PointKind.SMOOTHPOINT 4839.45343923569,139.25014257431 4852.39225459099,139.197034835815 4831.29361224174,139.28365945816 PathPoint;PointKind.SMOOTHPOINT 4878.34281992912,139.08326625824 4901.47159409523,138.979411125183 4865.33673477173,139.141802787781 PathPoint;PointKind.SMOOTHPOINT 4950.88197183609,139.273273944855 4962.28845191002,139.381613731384 4927.65866589546,139.052581787109 PathPoint;PointKind.SMOOTHPOINT 4977,138 4979.54704713821,137.99858379364 4966.01059269905,138.006136894226 PathPoint;PointKind.SMOOTHPOINT 4992.05569338799,139.408993721008 4995.56717705727,139.399316310883 4989.52634882927,139.415838718414 PathPoint;PointKind.SMOOTHPOINT 5002.5593419075,137.384054660797 5014.63958215714,137.316076755524 4999.07830667496,137.403645515442 PathPoint;PointKind.SMOOTHPOINT 5038.36741161346,138.999710083008 5042.66311955452,138.93786907196 5026.53359127045,139.170362949371 PathPoint;PointKind.SMOOTHPOINT 5051.2449760437,139.535744190216 5055.98183226585,139.455256462097 5046.96520042419,139.608914852142 PathPoint;PointKind.SMOOTHPOINT 5065.42545032501,138.536846637726 5071.35262799263,138.42095375061 5060.69532108307,138.629372119904 PathPoint;PointKind.SMOOTHPOINT 5083.21654272079,138.165328502655 5087.08278608322,138.079884052277 5077.27874350548,138.296327590942 PathPoint;PointKind.SMOOTHPOINT 5094.96751499176,139.650220870972 5098.29666209221,139.572565555573 5091.08781766891,139.740858078003 PathPoint;PointKind.SMOOTHPOINT 5110,138 5117.6956653595,137.813768863678 5106.65669083595,138.080959796906 PathPoint;PointKind.SMOOTHPOINT 5134.72290587425,136.717729568481 5179.16983437538,135.59255361557 5126.91536021233,136.915290355682 PathPoint;PointKind.SMOOTHPOINT 5266.8124730587,134.000029563904 5270.79378318787,133.950226306915 5213.16197347641,134.669895172119 PathPoint;PointKind.SMOOTHPOINT 5287,138 5293.04118227959,137.9294257164 5283.20138049126,138.044374465942 PathPoint;PointKind.SMOOTHPOINT 5302.665153265,134.120643138885 5312.23304343224,134.022688865662 5297.0619328022,134.177763462067 PathPoint;PointKind.SMOOTHPOINT 5326.51088190079,135.195307731628 5330.89970541,135.163915157318 5318.10038638115,135.255024433136 PathPoint;PointKind.SMOOTHPOINT 5344,137 5348.13142800331,136.978756904602 5339.89618802071,137.021007061005 PathPoint;PointKind.SMOOTHPOINT 5368.81261181831,134.000029563904 5451.6472299099,133.762578964233 5364.94778466225,134.011123180389 PathPoint;PointKind.SMOOTHPOINT 5537.17370223999,135.746684074402 5545.85752558708,135.639524459839 5464.6352584362,136.639602184296 PathPoint;PointKind.SMOOTHPOINT 5560.75672459602,135.427565574646 5567.83988070488,135.323002338409 5553.68029546738,135.532128810883 PathPoint;PointKind.SMOOTHPOINT 5577,135 5586.00919675827,132.947444915771 5571.43430900574,136.268212795258 PathPoint;PointKind.SMOOTHPOINT 5592.98462462425,134.910650253296 5629.51248121262,134.308054447174 5589.0171225071,134.976031780243 PathPoint;PointKind.SMOOTHPOINT 5659.39514350891,137.078862190247 5673.98596358299,138.626303672791 5633.8988263607,134.374144077301 PathPoint;PointKind.SMOOTHPOINT 5693.11997365952,155.41401386261 5697.81221938133,160.560507774353 5685.07592153549,146.591520309448 PathPoint;PointKind.SMOOTHPOINT 5702,173 5706.02769088745,174.698267459869 5697.88379621506,171.264675140381 PathPoint;PointKind.SMOOTHPOINT 5710,182 5712.64511942863,187.536658763885 5708.99945020676,179.905902862549 PathPoint;PointKind.SMOOTHPOINT 5714.29898571968,254.382526874542 5714.46255755424,261.199200153351 5713.30197644234,212.798223495483 PathPoint;PointKind.SMOOTHPOINT 5713,292 5710.06880688667,496.052205085754 5713.10833978653,284.463421821594 PathPoint;PointKind.SMOOTHPOINT 5711.95339393616,936.875267028809 5712.83498239517,950.066049098969 5710.97196292877,922.19085931778 PathPoint;PointKind.SMOOTHPOINT 5704,966 5702.39154362679,971.997869968414 5707.9554643631,951.251863002777 PathPoint;PointKind.SMOOTHPOINT 5699.88589954376,991.503775119781 5699.50848054886,999.848299026489 5700.49097371101,978.117084503174 PathPoint;PointKind.SMOOTHPOINT 5700.93318414688,1020.72318077087 5705.96000862122,1044.14227724075 5699.2142636776,1012.71642208099 PathPoint;PointKind.SMOOTHPOINT 5706.61181759834,1098.7965130806 5706.57358002663,1126.64337873459 5706.64686870575,1072.98520803452 PathPoint;PointKind.SMOOTHPOINT 5706.44187283516,1163.57851266861 5706.54490184784,1179.86913442612 5706.36752200127,1151.74894094467 PathPoint;PointKind.SMOOTHPOINT 5705.28093767166,1227.34580039978 5703.71779990196,1245.03846645355 5707.31390190125,1204.34519290924 PathPoint;PointKind.SMOOTHPOINT 5711.11358356476,1276.96022987366 5711.22333955765,1285.20491123199 5710.97904396057,1266.88651800156 PathPoint;PointKind.SMOOTHPOINT 5710.81263971329,1323.9999961853 5709.39324688911,1339.40383672714 5711.82168674469,1313.04634809494 PathPoint;PointKind.SMOOTHPOINT 5706.88408327103,1374.12260770798 5704.21205592155,1401.92769527435 5708.40438079834,1358.30405473709 PathPoint;PointKind.SMOOTHPOINT 5700.72531843185,1454.06722068787 5700.62937045097,1464.32149887085 5700.91615223885,1433.56314897537 PathPoint;PointKind.SMOOTHPOINT 5698,1532 5697.99468922615,1540.09904813766 5698.0247836113,1494.09901332855 PathPoint;PointKind.SMOOTHPOINT 5700.35179400444,1556.96617841721 5701.94183969498,1568.91659975052 5699.19510746002,1548.26949119568 PathPoint;PointKind.SMOOTHPOINT 5700.45163655281,1581.30840539932 5700.57767891884,1603.06039094925 5700.40383958817,1573.01297664642 PathPoint;PointKind.SMOOTHPOINT 5699.20966100693,1648.41605186462 5699.45537281036,1662.32721090317 5698.81170701981,1625.88538885117 PathPoint;PointKind.SMOOTHPOINT 5703.09962582588,1680.81743717194 5704.7395927906,1740.65262794495 5702.7321202755,1667.41469621658 PathPoint;PointKind.SMOOTHPOINT 5702.69919347763,1833.66268873215 5700.96611094475,1904.42957639694 5703.35064840317,1807.04650640488 PathPoint;PointKind.SMOOTHPOINT 5701.8746073246,2148.462703228 5700.33165049553,2186.24331235886 5703.41756415367,2110.68233013153 PathPoint;PointKind.SMOOTHPOINT 5701.37858104706,2337.74788856506 5703.1201608181,2372.29459047318 5699.63664722443,2303.20095062256 PathPoint;PointKind.SMOOTHPOINT 5693.20030593872,2429.83387470245 5692.88786242047,2443.87497783929 5693.66186351393,2409.08639571065 PathPoint;PointKind.SMOOTHPOINT 5696.96281218529,2510.82175970078 5693.141098426,2529.15395525178 5698.99727847698,2501.06346717426 PathPoint;PointKind.SMOOTHPOINT 5699.80942440033,2557.39701032639 5698.89172267914,2575.1482129097 5700.73703956604,2539.45296764374 PathPoint;PointKind.SMOOTHPOINT 5700.59612703323,2636.3528752327 5701.59632277489,2654.66914415359 5699.02307581902,2607.54346132278 PathPoint;PointKind.SMOOTHPOINT 5704.43864893913,2686.97399139404 5704.78314113617,2702.32732057571 5704.00493574142,2667.67723560333 PathPoint;PointKind.SMOOTHPOINT 5701.33786511421,2732.51611948013 5701.68235731125,2747.45450019836 5701.0100133419,2718.28395366669 PathPoint;PointKind.SMOOTHPOINT 5701.22917127609,2774.01710271835 5698.16556286812,2841.06928110123 5701.83778595924,2760.69626569748 PathPoint;PointKind.SMOOTHPOINT 5698.8471121788,2924.83269453049 5697.44719219208,2953.62416982651 5700.39785814285,2892.92273283005 PathPoint;PointKind.SMOOTHPOINT 5709.59682655334,2993.69218826294 5710.52939844131,3003.30539703369 5707.69556951523,2974.08528327942 PathPoint;PointKind.SMOOTHPOINT 5707.49588441849,3037.21244573593 5705.82723927498,3069.67826843262 5709.16488361359,3004.74638700485 PathPoint;PointKind.SMOOTHPOINT 5706.87275362015,3275.08413076401 5705.74264809987,3295.09713919942 5709.75473356247,3224.05325889587 PathPoint;PointKind.SMOOTHPOINT 5705.17485178991,3341.7010709281 5705.15228393956,3344.98298516214 5705.33422070988,3318.52495451256 PathPoint;PointKind.SMOOTHPOINT 5705.12078907397,3351.52126042301 5703.69429128351,3358.3177089349 5705.79073055372,3348.32937130583 PathPoint;PointKind.SMOOTHPOINT 5705.07218001775,3369.61887591552 5705.03224644008,3395.18108381943 5705.08144808884,3363.6862153848 PathPoint;PointKind.SMOOTHPOINT 5704.46909737587,3433.99711847305 5704.02743147983,3445.47807442264 5705.06646368881,3418.46548853307 PathPoint;PointKind.SMOOTHPOINT 5707.66025737039,3490.95318348236 5707.97914930871,3494.88575899779 5705.67978009245,3466.52993687066 PathPoint;PointKind.SMOOTHPOINT 5708.63508310062,3502.98725579941 5706.08246956553,3508.35732888846 5710.39297534175,3499.28908148207 PathPoint;PointKind.SMOOTHPOINT 5709.53727377301,3514.36635050257 5711.13654445091,3534.93718288153 5709.23939140048,3510.53479875935 PathPoint;PointKind.SMOOTHPOINT 5713.04104042053,3575.73128700256 5713.55087471008,3597.99334287643 5712.59888910535,3556.42579505576 PathPoint;PointKind.SMOOTHPOINT 5707.93420028687,3628.35373878479 5704.3586332798,3671.64881944656 5709.01901435852,3615.22243738174 PathPoint;PointKind.SMOOTHPOINT 5703.65230035782,3745.76102256775 5701.74641133167,3757.30754232552 5708.70072197914,3715.17261743546 PathPoint;PointKind.SMOOTHPOINT 5691.69101393956,3778.98051367553 5688.11017548449,3785.02625980463 5697.7544705498,3768.74321316887 PathPoint;PointKind.SMOOTHPOINT 5678.78409570446,3795.63992336117 5675.2103807132,3801.61186413488 5682.68809642092,3789.11605083179 PathPoint;PointKind.SMOOTHPOINT 5665.28861475916,3806.29643932421 5655.11297783053,3812.57308808768 5670.2503323789,3803.23589785825 PathPoint;PointKind.SMOOTHPOINT 5628.93679332733,3817.43333816528 5585.05209875107,3819.97566461563 5642.99124208916,3816.61921196835 PathPoint;PointKind.SMOOTHPOINT 5116.13024067879,3820.16118764877 5054.1949338913,3820.01484632492 5178.0648393631,3820.30752897263 PathPoint;PointKind.SMOOTHPOINT 4492.0941324234,3817.51547813416 4413.56194925308,3817.12035655975 4570.62631559372,3817.91107177734 PathPoint;PointKind.SMOOTHPOINT 4032.99791407585,3820.36299705505 4023.95189595222,3820.66016435623 4083.38582825661,3818.70768785477 PathPoint;PointKind.SMOOTHPOINT 4002,3826 3979.52409696579,3826.86034536362 4009.40994572639,3825.71652269363 PathPoint;PointKind.SMOOTHPOINT 3952.4979121685,3824.20115232468 3943.73088669777,3824.8356127739 3969.79510259628,3822.94969797134 PathPoint;PointKind.SMOOTHPOINT 3925.66009354591,3827.1676325798 3919.57076025009,3827.30240821838 3937.11472463608,3826.91389560699 PathPoint;PointKind.SMOOTHPOINT 3896.61157679558,3827.36826181412 3884.86874771118,3827.37274646759 3909.51852750778,3827.36330509186 PathPoint;PointKind.SMOOTHPOINT 3861.8125,3825 3854.90778589249,3823.21794033051 3874.14199256897,3828.18174362183 PathPoint;PointKind.SMOOTHPOINT 3832.88653922081,3827.13411569595 3749.68087506294,3826.63065433502 3840.5648560524,3827.18061447144 PathPoint;PointKind.SMOOTHPOINT 3599.73223757744,3825.30225276947 3540.91824960709,3825.03765821457 3638.48955702782,3825.47668218613 PathPoint;PointKind.SMOOTHPOINT 3462.60239195824,3824.94348049164 3459.07285165787,3824.87526655197 3497.55082440376,3825.61995506287 PathPoint;PointKind.SMOOTHPOINT 3437.76036214828,3824.87833499908 3433.75072789192,3823.49871397018 3446.46613669395,3827.87455558777 PathPoint;PointKind.SMOOTHPOINT 3425,3818 3421.59243681604,3818.91316046535 3433.80190854735,3815.6410579437 PathPoint;PointKind.SMOOTHPOINT 3412.92045664787,3823.80107402802 3404.76629447937,3826.68942689896 3417.87257623672,3822.04686641693 PathPoint;PointKind.SMOOTHPOINT 3389.06658482552,3825.76322793961 3378.66242480278,3825.73561191559 3396.47794675827,3825.78281879425 PathPoint;PointKind.SMOOTHPOINT 3353.29887700081,3823.64505529404 3344.50494360924,3819.73986625671 3362.80728650093,3827.86747455597 PathPoint;PointKind.SMOOTHPOINT 3325.48600029945,3819.52342271805 3320.39013576508,3819.52955961227 3338.35223507881,3819.50808048248 PathPoint;PointKind.SMOOTHPOINT 3304,3825 3295.06642586566,3827.72388687648 3309.0267343315,3823.46735116551 PathPoint;PointKind.SMOOTHPOINT 3278.77739024162,3821.42562389374 3271.89391922951,3822.01476573944 3292.81199526787,3820.22444486618 PathPoint;PointKind.SMOOTHPOINT 3250.95920276642,3819.32845830917 3245.52415680885,3819.34285640717 3259.08610296249,3819.30674314499 PathPoint;PointKind.SMOOTHPOINT 3228.81292176247,3825.93128442764 3222.04699587822,3825.95063924789 3234.31842398643,3825.91570615768 PathPoint;PointKind.SMOOTHPOINT 3208.3891017437,3825.99170923233 3204.45735883713,3826.0032749176 3215.2343351841,3825.97070217133 PathPoint;PointKind.SMOOTHPOINT 3198.29084229469,3820.202729702 3190.69608163834,3820.22633314133 3202.24134993553,3820.19045591354 PathPoint;PointKind.SMOOTHPOINT 3166.4849717617,3823.1559920311 3163.29992365837,3823.18549633026 3174.13000774384,3823.08588981628 PathPoint;PointKind.SMOOTHPOINT 3157,3819 3153.64925575256,3819.03375291824 3160.17407250404,3818.96789932251 PathPoint;PointKind.SMOOTHPOINT 3146.6056830883,3825.12876749039 3139.29451775551,3825.22601366043 3149.94120311737,3825.08415699005 PathPoint;PointKind.SMOOTHPOINT 3124.80531048775,3825.40563583374 3120.72699022293,3825.45520305634 3132.02336025238,3825.31853914261 PathPoint;PointKind.SMOOTHPOINT 3112,3820 3110.06333780289,3820.02195119858 3116.04185295105,3819.95373725891 PathPoint;PointKind.SMOOTHPOINT 3097.91473817825,3825.001308918 3091.37328100204,3825.09430646896 3099.84148693085,3824.97369289398 PathPoint;PointKind.SMOOTHPOINT 3078.60618066788,3825.26897192001 3075.285176754,3825.31358242035 3084.93591499329,3825.18352746964 PathPoint;PointKind.SMOOTHPOINT 3069.10839271545,3820.87684392929 3066.33121204376,3820.91295719147 3072.36991596222,3820.83435773849 PathPoint;PointKind.SMOOTHPOINT 3056.18232321739,3823.87967348099 3048.06498241425,3824.01987791061 3058.91630959511,3823.83246660233 PathPoint;PointKind.SMOOTHPOINT 3024.39238500595,3820.75977087021 3013.35659694672,3820.97645044327 3032.00945091248,3820.61036109924 PathPoint;PointKind.SMOOTHPOINT 2985.63258719444,3822.68274307251 2978.22901439667,3822.15874671936 2996.29201841354,3823.43710899353 PathPoint;PointKind.SMOOTHPOINT 2970.73834490776,3818.59509944916 2961.94901418686,3819.10446166992 2976.74978685379,3818.24647665024 PathPoint;PointKind.SMOOTHPOINT 2947.86448788643,3825.62066316605 2948.87424302101,3825.84371566772 2945.05083990097,3824.99918460846 PathPoint;PointKind.SMOOTHPOINT 2938.65489792824,3826.18242502213 2936.90198850632,3826.22396707535 2944.89364099503,3826.03443145752 PathPoint;PointKind.SMOOTHPOINT 2932.96989154816,3821.5327835083 2928.61470293999,3821.60619020462 2935.01878809929,3821.49808645248 PathPoint;PointKind.SMOOTHPOINT 2923.01962566376,3826.5678691864 2915.64827156067,3828.00248622894 2927.86517572403,3825.62491178513 PathPoint;PointKind.SMOOTHPOINT 2899.17071056366,3826.50532007217 2894.10706472397,3826.47015094757 2904.24497795105,3826.54072523117 PathPoint;PointKind.SMOOTHPOINT 2889,3818 2862.06941986084,3817.79063749313 2893.70888614655,3818.03658533096 PathPoint;PointKind.SMOOTHPOINT 2821.46488380432,3817.96819210052 2818.69124364853,3817.96724796295 2840.79043579102,3817.97550916672 PathPoint;PointKind.SMOOTHPOINT 2814.71772265434,3822.23545789719 2811.25403594971,3822.24513530731 2817.36284208298,3822.2279047966 PathPoint;PointKind.SMOOTHPOINT 2801,3818 2786.1135468483,3818.12037754059 2804.25798273087,3817.97356414795 PathPoint;PointKind.SMOOTHPOINT 2764.04762935638,3819.06622409821 2757.34968137741,3819.42027568817 2775.55536818504,3818.45749139786 PathPoint;PointKind.SMOOTHPOINT 2745.27085733414,3820.54049491882 2741.33380365372,3820.91933012009 2751.24335360527,3819.96598720551 PathPoint;PointKind.SMOOTHPOINT 2736.20819878578,3825.06669044495 2732.31433939934,3825.41838169098 2740.15906047821,3824.71004247665 PathPoint;PointKind.SMOOTHPOINT 2721.486733675,3822.57699966431 2718.21281862259,3822.76629924774 2725.64613175392,3822.33671665192 PathPoint;PointKind.SMOOTHPOINT 2712.35928368568,3825.00414133072 2708.64705276489,3825.07754802704 2715.9366209507,3824.93380308151 PathPoint;PointKind.SMOOTHPOINT 2699.44702219963,3822.94592142105 2694.2470664978,3822.81846284866 2703.61987423897,3823.04836034775 PathPoint;PointKind.SMOOTHPOINT 2685.53244066238,3823.92192363739 2680.81116271019,3823.73734474182 2690.29655885696,3824.10815477371 PathPoint;PointKind.SMOOTHPOINT 2670.93312335014,3821.84765338898 2666.59917783737,3821.61822795868 2675.27202558517,3822.07707881927 PathPoint;PointKind.SMOOTHPOINT 2659.8125,3823 2655.80109548569,3822.73752975464 2663.80974245071,3823.26152610779 PathPoint;PointKind.SMOOTHPOINT 2645.77138495445,3828.8788819313 2640.85856509209,3828.50571155548 2649.48928070068,3829.1611790657 PathPoint;PointKind.SMOOTHPOINT 2631.87308979034,3823.78148317337 2626.63772892952,3822.90083885193 2636.31891560555,3824.52924013138 PathPoint;PointKind.SMOOTHPOINT 2612.8125,3826 2609.50495004654,3825.38701868057 2617.59290456772,3826.88607311249 PathPoint;PointKind.SMOOTHPOINT 2595.8125,3819 2583.25429010391,3815.52887821198 2598.92284321785,3819.85963726044 PathPoint;PointKind.SMOOTHPOINT 2569.29163885117,3815.51980733871 2566.81186151505,3815.55733680725 2582.47722816467,3815.31965017319 PathPoint;PointKind.SMOOTHPOINT 2562.325319767,3819.55056667328 2558.13972187042,3819.80666399002 2564.52114772797,3819.41626310349 PathPoint;PointKind.SMOOTHPOINT 2541.45751905441,3819.49580669403 2525.94050002098,3821.38266563416 2544.82667398453,3819.08628702164 PathPoint;PointKind.SMOOTHPOINT 2514.61191129684,3825.4988694191 2510.00499200821,3825.67306280136 2526.64860320091,3825.04426717758 PathPoint;PointKind.SMOOTHPOINT 2491.76248383522,3823.41468572617 2481.84266638756,3823.15788030624 2500.10252308846,3823.63089323044 PathPoint;PointKind.SMOOTHPOINT 2465.93689870834,3819.29824590683 2456.47062134743,3818.27456474304 2473.72461748123,3820.14018058777 PathPoint;PointKind.SMOOTHPOINT 2442.08585929871,3820.24804830551 2434.70317554474,3821.225938797 2447.88168382645,3819.48022842407 PathPoint;PointKind.SMOOTHPOINT 2422.19347071648,3827.28140115738 2420.30956220627,3827.18675136566 2434.07862854004,3827.87880420685 PathPoint;PointKind.SMOOTHPOINT 2404.8125,3820 2398.30149126053,3819.81424093246 2409.33409285545,3820.12911081314 PathPoint;PointKind.SMOOTHPOINT 2388,3826 2384.13552689552,3825.91738796234 2399.16607904434,3826.23815870285 PathPoint;PointKind.SMOOTHPOINT 2374.50413775444,3824.11995649338 2369.72054672241,3824.02436256409 2378.84870481491,3824.20705318451 PathPoint;PointKind.SMOOTHPOINT 2358.26379132271,3825.75425863266 2352.23818731308,3825.64072608948 2363.57845973969,3825.85410118103 PathPoint;PointKind.SMOOTHPOINT 2339,3821 2333.39925789833,3821.10479927063 2345.66572928429,3820.87537384033 PathPoint;PointKind.SMOOTHPOINT 2321.83329892159,3826.00657939911 2314.49593377113,3825.88360548019 2327.78915476799,3826.10665798187 PathPoint;PointKind.SMOOTHPOINT 2298.8125,3822 2288.82718300819,3822.32289505005 2306.46249270439,3821.75263595581 PathPoint;PointKind.SMOOTHPOINT 2268.17111563683,3826.8782544136 2254.79752492905,3826.66417121887 2279.08050727844,3827.05339193344 PathPoint;PointKind.SMOOTHPOINT 2221.46746230125,3826.75598859787 2110.4464430809,3831.2784075737 2235.55694532394,3826.18218898773 PathPoint;PointKind.SMOOTHPOINT 1921.36979413033,3826.98305368423 1797.14123439789,3829.00752067566 1979.18039989471,3826.04104042053 PathPoint;PointKind.SMOOTHPOINT 1499.04006314278,3829.92663860321 1475.78595471382,3830.30429363251 1595.46424341202,3828.36007833481 PathPoint;PointKind.SMOOTHPOINT 1391.38784480095,3830.6928062439 1389.5230550766,3830.70106744766 1426.25873994827,3830.53985595703 PathPoint;PointKind.SMOOTHPOINT 1374.82601952553,3830.61349868774 1354.5031042099,3826.59501314163 1376.56866145134,3830.95834493637 PathPoint;PointKind.SMOOTHPOINT 1353.22958064079,3830.90334892273 1356.2779648304,3831.01947784424 1352.12246131897,3830.86109876633 PathPoint;PointKind.SMOOTHPOINT 1279.30183839798,3830.7631444931 1271.39905285835,3830.73080778122 1304.54182219505,3830.86605548859 PathPoint;PointKind.SMOOTHPOINT 1257.8125,3829 1252.950309515,3830.74169778824 1266.64006829262,3825.83761119843 PathPoint;PointKind.SMOOTHPOINT 1240.00034165382,3830.5585026741 1187.90731501579,3830.22923469543 1245.16949486732,3830.59154748917 PathPoint;PointKind.SMOOTHPOINT 1086.6581196785,3828.8472533226 1024.41230964661,3829.40759897232 1135.25594902039,3828.4096455574 PathPoint;PointKind.SMOOTHPOINT 890.254019021988,3829.86904621124 884.940766811371,3829.8810839653 957.581177473068,3829.7153878212 PathPoint;PointKind.SMOOTHPOINT 871.026893377304,3828.2828950882 863.741573810577,3828.2968211174 876.344394207001,3828.27274560928 PathPoint;PointKind.SMOOTHPOINT 852.450514554977,3829.93985652924 839.952139377594,3829.95826721191 859.734417915344,3829.92923498154 PathPoint;PointKind.SMOOTHPOINT 815.009558916092,3829.98187065125 809.973883152008,3829.98588323593 827.46332359314,3829.97219324112 PathPoint;PointKind.SMOOTHPOINT 799.481210231781,3828.0957198143 796.210932201517,3829.03735321274 806.528157431773,3826.06693374662 PathPoint;PointKind.SMOOTHPOINT 789.723548412323,3829.99650478363 777.679421424866,3830.0009894371 793.118549108505,3829.99532461166 PathPoint;PointKind.SMOOTHPOINT 753.765714883804,3830.00028133392 741.839841127396,3829.99862909317 765.685569763184,3830.00216960907 PathPoint;PointKind.SMOOTHPOINT 715.014414310455,3828.88667106628 708.009857654572,3828.9003610611 726.682892560959,3828.86448383331 PathPoint;PointKind.SMOOTHPOINT 690.945987224579,3831.82765960693 687.248272418976,3831.82931184769 697.815650224686,3831.82459115982 PathPoint;PointKind.SMOOTHPOINT 673.8125,3829 662.730324034507,3829.91005965565 677.454759261954,3828.7008852323 PathPoint;PointKind.SMOOTHPOINT 632.529953241348,3831.70751810074 509.913036346436,3831.0983133316 647.812944173813,3831.78352117538 PathPoint;PointKind.SMOOTHPOINT 396.056771993637,3831.07801437378 392.593793392181,3831.00649595261 460.290227651596,3832.4073600769 PathPoint;PointKind.SMOOTHPOINT 385.8125,3829 382.956365823746,3828.93792295456 389.328586339951,3829.07671117783 PathPoint;PointKind.SMOOTHPOINT 367.236972570419,3832.01483488083 360.347128629684,3831.83120012283 370.119660615921,3832.09201812744 PathPoint;PointKind.SMOOTHPOINT 349.353118658066,3830.95574855804 343.809378862381,3830.49666166306 356.730845689774,3831.56684160233 PathPoint;PointKind.SMOOTHPOINT 333.45938873291,3828.88997554779 325.58705163002,3829.62026596069 337.119220018387,3828.55032205582 PathPoint;PointKind.SMOOTHPOINT 322.526275634766,3829.87353086472 316.46951508522,3830.08879423141 328.111439466476,3829.67502593994 PathPoint;PointKind.SMOOTHPOINT 305,3828 292.201035022736,3828.91345310211 309.183473587036,3827.70118045807 PathPoint;PointKind.SMOOTHPOINT 276.819277524948,3828.7415099144 270.210196495056,3828.25221061707 288.484569311142,3829.60539579391 PathPoint;PointKind.SMOOTHPOINT 259.939513921738,3823.63632202148 258.389830112457,3821.3106751442 265.0923807621,3831.36975288391 PathPoint;PointKind.SMOOTHPOINT 255.8125,3807 253.819897651672,3804.57356643677 257.67835187912,3809.27253913879 PathPoint;PointKind.SMOOTHPOINT 248.8125,3803 246.265452861786,3799.96979045868 250.838737249374,3805.4099111557 PathPoint;PointKind.SMOOTHPOINT 241.707981348038,3793.16333770752 240.147321939468,3791.12895727158 244.032684087753,3796.19519948959 PathPoint;PointKind.SMOOTHPOINT 240.8125,3785 237.530441761017,3784.0225815773 243.037714242935,3785.66254854202 PathPoint;PointKind.SMOOTHPOINT 234.8125,3782 228.589441133928,3776.99418737599 236.528497044939,3783.37980495107 PathPoint;PointKind.CORNERPOINT 227.280379056931,3772.93943881989 227.280379056931,3772.93943881989 227.280379056931,3772.93943881989 PathPoint;PointKind.SMOOTHPOINT 226.924467196043,2439.08826032343 226.925635179253,2436.54954692634 226.677604251809,2975.66640480218 PathPoint;PointKind.SMOOTHPOINT 227.8125,2432 227.000789098952,2430.43171727709 228.642686080167,2433.6039780723 PathPoint;PointKind.SMOOTHPOINT 226.930585236256,2426.2008070646 227.05476465153,2172.55821463709 226.929723544863,2427.96085431832 PathPoint;PointKind.SMOOTHPOINT 228.046900749207,1963.08058261871 229.349102497101,1930.24678230286 227.374495392522,1980.03416755749 PathPoint;PointKind.SMOOTHPOINT 225.8125,1847 225.840470075607,1844.91274785995 225.264428138733,1887.64677476883 PathPoint;PointKind.SMOOTHPOINT 229.349102497101,1835.55379629135 229.790604829788,1819.08756494522 229.292100191116,1837.6868391037 PathPoint;PointKind.SMOOTHPOINT 229.444696426392,1799.11409854889 229.515506744385,1794.83054637909 229.270503044128,1809.66271162033 PathPoint;PointKind.SMOOTHPOINT 227.502369403839,1781.90129041672 227.561496019363,1779.33748483658 227.432267189026,1784.94589805603 PathPoint;PointKind.SMOOTHPOINT 228.519913673401,1772.79390335083 228.574437618256,1770.73945999146 228.380771398544,1778.02678585052 PathPoint;PointKind.SMOOTHPOINT 230.8125,1764 230.699203491211,1760.98725700378 230.929337024689,1767.09960365295 PathPoint;PointKind.SMOOTHPOINT 228.186397075653,1755.86811304092 228.42325758934,1747.13649272919 228.1141705513,1758.52373600006 PathPoint;PointKind.SMOOTHPOINT 229.019834518433,1725.33612012863 229.236160039902,1717.40206003189 228.706852912903,1736.7977142334 PathPoint;PointKind.SMOOTHPOINT 233.668885946274,1703.97571563721 233.526557207108,1701.71804666519 234.857437133789,1722.87734985352 PathPoint;PointKind.SMOOTHPOINT 230.8125,1693 230.894285917282,1689.96766614914 230.750186920166,1695.30794429779 PathPoint;PointKind.SMOOTHPOINT 234,1683 233.206889675862,1679.20726266624 234.711535861034,1686.40181094707 PathPoint;PointKind.SMOOTHPOINT 230.8125,1673 230.91517496109,1669.14603042603 230.742043733597,1675.65137434006 PathPoint;PointKind.SMOOTHPOINT 232.786235332489,1661.46002054214 232.931396484375,1656.12564325333 232.680019855499,1665.36638975143 PathPoint;PointKind.SMOOTHPOINT 230.838597536087,1646.271443367 231.283994436264,1626.96973085403 230.714325428009,1651.6631770134 PathPoint;PointKind.SMOOTHPOINT 231.8125,1591 231.92119383812,1586.70559024811 231.343027591705,1609.57425451279 PathPoint;PointKind.SMOOTHPOINT 235.8125,1577 236.917495012283,1533.24842882156 235.70734667778,1581.17285203934 PathPoint;PointKind.SMOOTHPOINT 234.241741418839,1485.33634901047 233.975123722248,1476.12501339945 234.554014921188,1496.14861249924 PathPoint;PointKind.SMOOTHPOINT 237.596024554077,1441.82515833005 237.673211729641,1440.25134069184 236.721312094974,1459.6602181888 PathPoint;PointKind.SMOOTHPOINT 236.8125,1437 236.232322527148,1434.57943801593 237.183511654593,1438.54789999401 PathPoint;PointKind.SMOOTHPOINT 237.858010545009,1432.08072386502 237.873798092449,1425.13910245023 237.854214331388,1433.74987975322 PathPoint;PointKind.SMOOTHPOINT 236.422345161438,1411.44955873489 231.910665750504,1383.03314208984 237.486507231641,1418.15211815276 PathPoint;PointKind.SMOOTHPOINT 225.671922683716,1342.59006500244 225.723968267441,1337.43790626526 225.491002321243,1360.57848215103 PathPoint;PointKind.SMOOTHPOINT 227.720465183258,1319.3142414093 227.926523208618,1314.83242034912 227.070072412491,1333.4562420845 PathPoint;PointKind.SMOOTHPOINT 226.8125,1300 227.290115594864,1290.22369146347 226.559707164764,1305.17741441727 PathPoint;PointKind.SMOOTHPOINT 231.822506904602,1270.7381272316 232.487061738968,1257.96677827835 231.211413860321,1282.47965812683 PathPoint;PointKind.SMOOTHPOINT 231.273018836975,1225.13297796249 235.176437616348,1152.70511627197 230.504372835159,1239.39866065979 PathPoint;PointKind.SMOOTHPOINT 237.448386669159,1019.72074270248 237.797481536865,1005.57897806168 236.315775632858,1065.65681219101 PathPoint;PointKind.SMOOTHPOINT 239.520650625229,987.334699630737 239.750784158707,976.058864593506 239.449840307236,990.822343826294 PathPoint;PointKind.SMOOTHPOINT 238.8125,965 235.318718910217,955.786397457123 242.006753444672,973.421943187714 PathPoint;PointKind.SMOOTHPOINT 228,939 228.127812623978,936.306611537933 227.605232477188,947.327765464783 PathPoint;PointKind.SMOOTHPOINT 228.563816070557,899.43336725235 228.546553733398,892.422962285315 228.605450510471,916.511996603837 PathPoint;PointKind.SMOOTHPOINT 233.845203638077,877.999556064606 235.002598285675,854.844818115234 233.412198543549,886.656353473663 PathPoint;PointKind.SMOOTHPOINT 231.652208089828,844.18408870697 234.174191322147,799.177423534512 231.01703953743,855.519168376923 PathPoint;PointKind.SMOOTHPOINT 237.385094836979,694.686292366122 237.428911802846,693.019001084786 236.063684990506,744.967617704992 PathPoint;PointKind.SMOOTHPOINT 237.514674196649,689.697855817727 238.349927906022,687.637042229803 236.891620020976,691.235111500436 PathPoint;PointKind.SMOOTHPOINT 237.673459195087,683.420493914699 238.663569686334,643.686690273591 237.621526213293,685.504599597192 PathPoint;PointKind.SMOOTHPOINT 239.593231201172,580.420138835907 239.801059484482,561.996474266052 239.292468062525,607.105234959414 PathPoint;PointKind.SMOOTHPOINT 238.713413000107,536.892092227936 239.582255601883,518.399505615234 238.466284990311,542.149286270142 PathPoint;PointKind.SMOOTHPOINT 244,399 244.329622030258,390.993477344513 241.484109401703,460.105999946594 PathPoint;PointKind.SMOOTHPOINT 241.122380018234,375.954165458679 240.198659420013,369.430646896362 242.09850025177,382.84731388092 PathPoint;PointKind.SMOOTHPOINT 240,352 240.170652866364,348.31031036377 239.679937362671,358.936106681824 PathPoint;PointKind.SMOOTHPOINT 247,334 248.227496862411,308.48609828949 246.829701185226,337.531546592712 PathPoint;PointKind.SMOOTHPOINT 246.34322476387,279.806499481201 250.38118314743,237.999379634857 245.272572755814,290.890202522278 PathPoint;PointKind.SMOOTHPOINT 252.628348588943,156.331243515015 255.394907712936,134.525442123413 249.569342851639,180.450654029846 PathPoint";
	
	shadow35mm[0] = "PointKind.SMOOTHPOINT 224.203499794006,3748.59997272491 224.203499794006,3748.59997272491 225.223876476288,3755.03804683685 PathPoint;PointKind.SMOOTHPOINT 223.313414096832,2765.39021015167 223.312705993652,2760.61665058136 223.418567419052,3322.71792411804 PathPoint;PointKind.SMOOTHPOINT 232.4532558918,2718.34383487701 232.420329093933,2704.1562795639 232.516277074814,2745.5805516243 PathPoint;PointKind.SMOOTHPOINT 223.094256162643,2665.93593835831 222.797560930252,2543.04227113724 223.137804508209,2683.94559860229 PathPoint;PointKind.SMOOTHPOINT 222.30401301384,2331.98338508606 222.30153465271,2299.74415540695 222.30507516861,2349.28258180618 PathPoint;PointKind.SMOOTHPOINT 223.453264474869,2232.34382629395 223.457159042358,2183.74222040176 223.450432062149,2265.29328346252 PathPoint;PointKind.SMOOTHPOINT 223.329700469971,2117.7868938446 223.308811426163,2110.45188903809 223.410424232483,2146.58096551895 PathPoint;PointKind.SMOOTHPOINT 231.453060150146,2094.34372186661 224.863806009293,2077.73445367813 233.776346683502,2100.19949913025 PathPoint;PointKind.SMOOTHPOINT 223.009991884232,2054.68475103378 222.648151159286,2012.75748968124 223.105585813522,2065.75854063034 PathPoint;PointKind.SMOOTHPOINT 221.820378541946,1986.40472173691 221.697522640228,1977.27302312851 222.145751953125,2010.57275533676 PathPoint;PointKind.SMOOTHPOINT 230.453218460083,1946.34378433228 229.736618041992,1943.12592744827 234.52516579628,1964.63385343552 PathPoint;PointKind.SMOOTHPOINT 221.497483491898,1916.30038261414 221.495005130768,1910.88056087494 221.503502368927,1927.84222841263 PathPoint;PointKind.SMOOTHPOINT 221.496421337128,1898.91149282455 221.506688833237,1868.4205698967 221.494297027588,1905.0951218605 PathPoint;PointKind.SMOOTHPOINT 221.727262973785,1774.47132825851 221.748506069183,1766.8502497673 221.57679104805,1828.24444770813 PathPoint;PointKind.SMOOTHPOINT 223.290754795074,1750.72343587875 224.403538942337,1744.0318608284 221.824981212616,1759.53554391861 PathPoint;PointKind.SMOOTHPOINT 221.847640514374,1731.32400512695 221.924115657806,1703.97989273071 221.828875780106,1738.08757066727 PathPoint;PointKind.SMOOTHPOINT 222.453068733215,1638.34368467331 223.85759139061,1604.10170316696 220.469671726227,1686.70123100281 PathPoint;PointKind.SMOOTHPOINT 225.417188644409,1521.87062501907 225.528714895248,1514.14403915405 224.803617238998,1564.37617063522 PathPoint;PointKind.SMOOTHPOINT 236.452976703644,1500.34381628036 236.524849176407,1494.08866882324 236.362693548203,1508.23775053024 PathPoint;PointKind.SMOOTHPOINT 225.915339231491,1479.53195571899 227.511757850647,1308.20237874985 225.856212615967,1485.87396383286 PathPoint;PointKind.SMOOTHPOINT 224.88717341423,1038.55857610703 224.917621850967,1027.4484372139 224.694923400879,1108.1157875061 PathPoint;PointKind.SMOOTHPOINT 227.58115196228,1007.35435724258 229.854871273041,996.166799068451 225.396653652191,1018.10005903244 PathPoint;PointKind.SMOOTHPOINT 225.046850681305,980.613548755646 225.650862693787,761.440508365631 225.024191379547,988.845720291138 PathPoint;PointKind.SMOOTHPOINT 226.527140378952,432.063009738922 226.54519701004,425.082528591156 226.165653705597,571.362247467041 PathPoint;PointKind.SMOOTHPOINT 234.353450775146,414.258935451508 236.428901195526,397.290422916412 233.514702558517,421.119039058685 PathPoint;PointKind.SMOOTHPOINT 226.629815340042,392.179806232452 226.715849876404,358.679444789886 226.613883018494,398.496322631836 PathPoint;PointKind.SMOOTHPOINT 226.85428404808,302.762188911438 226.864551544189,298.532452583313 226.790908813477,328.746979236603 PathPoint;PointKind.SMOOTHPOINT 226.884024381638,290.388321876526 225.570138931274,286.289348602295 228.501686096191,295.434501171112 PathPoint;PointKind.SMOOTHPOINT 226.914118766785,277.820434570312 226.941380739212,266.232798099518 226.904559373856,281.886126995087 PathPoint;PointKind.SMOOTHPOINT 226.987053394318,246.134469509125 227.007588386536,236.893723011017 226.96581029892,255.655152797699 PathPoint;PointKind.SMOOTHPOINT 229.008333921432,217.21081495285 229.024620294571,209.922308921814 228.992401599884,224.405851364136 PathPoint;PointKind.SMOOTHPOINT 227.083709478378,202.85425901413 227.108493089676,191.695733070374 227.072379827499,207.954254150391 PathPoint;PointKind.CORNERPOINT 227.121592998505,185.882205963135 227.121592998505,185.882205963135 227.121592998505,185.882205963135 PathPoint;PointKind.SMOOTHPOINT 246.029010057449,162.700324058533 251.588682174683,155.983021259308 236.996445894241,173.613846302032 PathPoint;PointKind.SMOOTHPOINT 265.001218557358,132.430565357208 266.414592504501,130.602242946625 260.93918466568,137.685399055481 PathPoint;PointKind.SMOOTHPOINT 421.716490030289,129.864871501923 428.460818767548,129.799489974976 325.205921173096,130.800511837006 PathPoint;PointKind.SMOOTHPOINT 446.498331069946,130.951337814331 453.456506967545,130.89138507843 439.344364643097,131.012706756592 PathPoint;PointKind.SMOOTHPOINT 480.205458641052,131.054484844208 542.441001176834,130.578875541687 472.866323232651,131.110424995422 PathPoint;PointKind.SMOOTHPOINT 705.42015337944,131.154799461365 719.003342628479,131.226789951324 618.179717302322,130.692172050476 PathPoint;PointKind.SMOOTHPOINT 737.970594406128,130.833084583282 748.41476225853,130.898230075836 723.837563037872,130.745043754578 PathPoint;PointKind.SMOOTHPOINT 778.772207736969,131.602556705475 870.068658828735,132.223091125488 768.034885168076,131.529622077942 PathPoint;PointKind.SMOOTHPOINT 1082.25460910797,134.058022499084 1093.07655000687,134.150547981262 971.854596376419,133.116245269775 PathPoint;PointKind.SMOOTHPOINT 1117.67109775543,133.005781173706 1130.07564926147,133.110816478729 1106.68558502197,132.912783622742 PathPoint;PointKind.SMOOTHPOINT 1152.48711490631,134.652121067047 1262.92996788025,135.575487613678 1139.87862968445,134.546849727631 PathPoint;PointKind.SMOOTHPOINT 1505.29633784294,137.223715782166 1558.59030747414,137.533864974976 1381.10247516632,136.500742435455 PathPoint;PointKind.SMOOTHPOINT 1668.36966776848,138.044879436493 1682.53881239891,138.10601234436 1612.99281263351,137.805540561676 PathPoint;PointKind.SMOOTHPOINT 1712.50042819977,136.847476959229 1723.34502840042,136.890907287598 1698.20594930649,136.790356636047 PathPoint;PointKind.SMOOTHPOINT 1743.70547318459,138.34912776947 2070.97730898857,139.582171440125 1732.79112482071,138.308057785034 PathPoint;PointKind.SMOOTHPOINT 2789.76718211174,139.390275478363 2799.06351470947,139.404909610748 2427.19250822067,138.828041553497 PathPoint;PointKind.SMOOTHPOINT 2820.85716032982,140.256993770599 2828.7440135479,140.269503593445 2811.55551695824,140.242123603821 PathPoint;PointKind.SMOOTHPOINT 2841.33019351959,139.472651481628 2883.71795797348,139.542045593262 2833.4401538372,139.459669589996 PathPoint;PointKind.SMOOTHPOINT 2968.57775115967,139.69877243042 3123.28165555,139.997591972351 2926.14785456657,139.616868495941 PathPoint;PointKind.SMOOTHPOINT 3424.6401014328,142.294678688049 3440.09339118004,142.305300235748 3271.98580169678,142.18917131424 PathPoint;PointKind.SMOOTHPOINT 3472.15347075462,143.25864315033 3485.84960246086,143.266668319702 3456.74443745613,143.249673843384 PathPoint;PointKind.SMOOTHPOINT 3511.96657204628,142.345662117004 3740.82197928429,142.45589017868 3498.30867791176,142.339053153992 PathPoint;PointKind.SMOOTHPOINT 4176.8538608551,141.185081005096 4186.36156225204,141.176347732544 3966.12660312653,141.378629207611 PathPoint;PointKind.SMOOTHPOINT 4205.80465936661,143.488068580627 4213.07440066338,143.480987548828 4196.3486495018,143.497273921967 PathPoint;PointKind.SMOOTHPOINT 4227.06156277657,141.136693954468 4369.92456579208,140.991768836975 4219.82297801971,141.14401102066 PathPoint;PointKind.SMOOTHPOINT 4632.92223000526,141.568872928619 4645.09629392624,141.547393798828 4504.62951207161,141.794993877411 PathPoint;PointKind.SMOOTHPOINT 4671.74788141251,143.899712562561 4680.14492297173,143.884370326996 4659.72747588158,143.921663761139 PathPoint;PointKind.SMOOTHPOINT 4694.2914083004,141.457464694977 4810.90467238426,141.239368915558 4685.9711959362,141.473042964935 PathPoint;PointKind.SMOOTHPOINT 5023.60010290146,136.755187511444 5030.66909694672,136.737957000732 4923.94343161583,136.999247074127 PathPoint;PointKind.SMOOTHPOINT 5045.54669880867,138.000504970551 5053.57800507545,137.980442047119 5038.57294464111,138.017735481262 PathPoint;PointKind.SMOOTHPOINT 5068.56642508507,136.643307209015 5428.11254167557,135.734338760376 5060.66328549385,136.663370132446 PathPoint;PointKind.CORNERPOINT 5644.26564002037,133.328204154968 5644.26564002037,133.328204154968 5644.26564002037,133.328204154968 PathPoint;PointKind.SMOOTHPOINT 5682.95002484322,153.057610988617 5685.86457753181,155.565948486328 5667.94956707954,140.148417949677 PathPoint;PointKind.SMOOTHPOINT 5692.38514566422,164.551305770874 5697.36169481277,167.534308433533 5687.63058686256,161.701426506042 PathPoint;PointKind.SMOOTHPOINT 5699.73242425919,176.348540782928 5705.98285102844,187.244124412537 5697.79399180412,172.969472408295 PathPoint;PointKind.SMOOTHPOINT 5707.57395887375,205.674870014191 5707.51766467094,207.495639324188 5707.9074754715,194.890222549438 PathPoint;PointKind.SMOOTHPOINT 5706.65307068825,298.788785934448 5706.58509278297,315.274136066437 5706.79716968536,264.040274620056 PathPoint;PointKind.SMOOTHPOINT 5704.23171186447,325.904417037964 5705.23721837997,321.254067420959 5703.90810871124,327.400875091553 PathPoint;PointKind.SMOOTHPOINT 5706.90019869804,342.332174777985 5706.72777557373,384.57643032074 5706.92356610298,336.532809734344 PathPoint;PointKind.SMOOTHPOINT 5706.34150528908,487.447772026062 5706.31176495552,495.58340549469 5706.53694176674,434.150025844574 PathPoint;PointKind.SMOOTHPOINT 5704.64170360565,515.864424705505 5704.61373353004,523.638453483582 5704.67144393921,507.568051815033 PathPoint;PointKind.SMOOTHPOINT 5706.1676659584,535.608229637146 5705.45035743713,737.143836021423 5706.19563603401,527.715003490448 PathPoint;PointKind.SMOOTHPOINT 5709,1059 5709.00106215477,1069.09967565536 5708.99114871025,962.180344104767 PathPoint;PointKind.SMOOTHPOINT 5704.87254524231,1094.81878995895 5709.68198204041,1106.58888101578 5701.44001507759,1086.4192700386 PathPoint;PointKind.SMOOTHPOINT 5718,1117 5719.0972058773,1111.56459999084 5717.90192770958,1117.48599481583 PathPoint;PointKind.SMOOTHPOINT 5718.60585236549,1243.41754674911 5718.58142280579,1251.74554824829 5718.73012447357,1201.05126142502 PathPoint;PointKind.SMOOTHPOINT 5700.45327329636,1267.34364509583 5700.43592476845,1273.24592113495 5700.47805690765,1258.96300792694 PathPoint;PointKind.SMOOTHPOINT 5718.47945594788,1286.22592449188 5718.28685188293,1350.99470615387 5718.49715852737,1280.29839277267 PathPoint;PointKind.SMOOTHPOINT 5705.87097072601,1498.56222867966 5705.83308720589,1510.43806314468 5706.08410978317,1431.24923229218 PathPoint;PointKind.SMOOTHPOINT 5717.45306038857,1535.34370422363 5718.6338224411,1543.99814128876 5715.84035539627,1523.51838111877 PathPoint;PointKind.SMOOTHPOINT 5705.67093157768,1560.98695278168 5705.59020781517,1585.93696832657 5705.69996380806,1552.07028150558 PathPoint;PointKind.SMOOTHPOINT 5708.45306897163,1681.34372234344 5715.13473057747,1713.29593420029 5698.82959270477,1635.32315254211 PathPoint;PointKind.SMOOTHPOINT 5713.24834370613,1761.78046703339 5713.21187639236,1772.46999263763 5713.30782437325,1744.20534610748 PathPoint;PointKind.SMOOTHPOINT 5697.45304012299,1795.34384965897 5695.66224718094,1802.5794839859 5700.02557897568,1784.94913101196 PathPoint;PointKind.SMOOTHPOINT 5713.0624666214,1816.11204385757 5712.80861163139,1889.54682826996 5713.08795833588,1808.70009183884 PathPoint;PointKind.SMOOTHPOINT 5716.39798665047,1957.4612402916 5716.46808886528,1965.41843175888 5715.88000917435,1898.78096580505 PathPoint;PointKind.SMOOTHPOINT 5716.4532186985,1984.34366941452 5715.91222786903,2126.18287324905 5716.49145627022,1974.2848277092 PathPoint;PointKind.SMOOTHPOINT 5716.88480758667,2201.26494169235 5716.85506725311,2209.96044874191 5717.36100697517,2062.64029026031 PathPoint;PointKind.SMOOTHPOINT 5707.45322728157,2223.34383487701 5707.42915177345,2230.48316717148 5707.48225951195,2214.67594385147 PathPoint;PointKind.SMOOTHPOINT 5716.72442221642,2248.69864940643 5716.61360406876,2282.00805902481 5716.74814367294,2241.57914400101 PathPoint;PointKind.SMOOTHPOINT 5705.40503883362,2342.90870904922 5705.38946056366,2347.9869890213 5705.50735974312,2310.0949716568 PathPoint;PointKind.SMOOTHPOINT 5703.40712571144,2357.92474508286 5703.38836097717,2364.03898000717 5703.4227039814,2352.85944700241 PathPoint;PointKind.SMOOTHPOINT 5720,2378 5718.23186635971,2959.10251426697 5720.01841068268,2371.90559196472 PathPoint;PointKind.SMOOTHPOINT 5708.70232129097,3747.954890728 5708.64638113976,3764.76030349731 5709.08682131767,3632.67781734467 PathPoint;PointKind.CORNERPOINT 5700.68907165527,3772.56737709045 5700.68907165527,3772.56737709045 5700.68907165527,3772.56737709045 PathPoint;PointKind.SMOOTHPOINT 5695.67322278023,3791.7501282692 5692.93888235092,3796.92825078964 5697.94340157509,3787.45123386383 PathPoint;PointKind.SMOOTHPOINT 5682.76662611961,3797.7730178833 5677.49586009979,3801.87246322632 5690.07779145241,3792.08671331406 PathPoint;PointKind.SMOOTHPOINT 5668.7801721096,3810.83516120911 5660.59697771072,3813.79385232925 5674.56148052216,3808.74507665634 PathPoint;PointKind.SMOOTHPOINT 5647.01768302917,3816.86159133911 5646.28550434113,3817.0667052269 5652.64320874214,3815.28653383255 PathPoint;PointKind.SMOOTHPOINT 5623.26861047745,3817.32091426849 5616.81247973442,3817.36552476883 5638.18586611748,3817.21776723862 PathPoint;PointKind.SMOOTHPOINT 5590.46041989326,3822.66827344894 5579.97022533417,3820.82626104355 5598.79762673378,3824.13215875626 PathPoint;PointKind.SMOOTHPOINT 5555.77398562431,3818.5204410553 5550.82257413864,3817.89494991302 5571.43050098419,3820.49793720245 PathPoint;PointKind.SMOOTHPOINT 5537.92907738686,3827.49399662018 5507.75503063202,3827.4930524826 5543.32234525681,3827.49423265457 PathPoint;PointKind.SMOOTHPOINT 5429.1594722271,3827.37031459808 5421.44858264923,3827.35591650009 5471.31179237366,3827.45009422302 PathPoint;PointKind.SMOOTHPOINT 5398.1300368309,3822.07960367203 5390.05447411537,3822.06260919571 5406.21976161003,3822.09636211395 PathPoint;PointKind.SMOOTHPOINT 5380.67210698128,3827.26881980896 5341.6361489296,3827.17983484268 5389.1183617115,3827.28793859482 PathPoint;PointKind.SMOOTHPOINT 5252.13934206963,3826.93176269531 5244.50669789314,3826.90957546234 5298.67942357063,3827.0663022995 PathPoint;PointKind.SMOOTHPOINT 5230.57547593117,3824.59785461426 5226.07087755203,3824.58440065384 5238.39930796623,3824.6209859848 PathPoint;PointKind.SMOOTHPOINT 5215.34523868561,3826.82318687439 5141.07760691643,3826.60013437271 5219.91285824776,3826.8368768692 PathPoint;PointKind.SMOOTHPOINT 4969.03437995911,3826.02444648743 4957.95044088364,3825.9866809845 5058.56694602966,3826.32987499237 PathPoint;PointKind.SMOOTHPOINT 4941.08873391151,3823.71154546738 4932.05015087128,3823.68062496185 4952.38581204414,3823.75049114227 PathPoint;PointKind.SMOOTHPOINT 4908.14494156837,3825.81508398056 4716.823959589,3825.15324354172 4917.31735610962,3825.84694862366 PathPoint;PointKind.SMOOTHPOINT 4258.50488448143,3823.52791070938 4246.88703560829,3823.48754882812 4496.68919706345,3824.35403108597 PathPoint;PointKind.SMOOTHPOINT 4229.26588797569,3822.5429391861 4223.19036269188,3822.52216815948 4240.96835517883,3822.58353710175 PathPoint;PointKind.SMOOTHPOINT 4205.26331448555,3823.3438038826 4015.46369218826,3822.68975257874 4211.36114501953,3823.3648109436 PathPoint;PointKind.SMOOTHPOINT 3599.98096489906,3825.4008436203 3589.20646691322,3825.36827087402 3805.94587469101,3826.02421045303 PathPoint;PointKind.SMOOTHPOINT 3568.92391347885,3823.53876829147 3559.44949293137,3822.4088716507 3581.69030570984,3825.06119012833 PathPoint;PointKind.SMOOTHPOINT 3538.96371388435,3825.21791696548 3480.2980735302,3825.04395961761 3548.5241689682,3825.24647712708 PathPoint;PointKind.SMOOTHPOINT 3368.89928126335,3824.70831871033 3359.74563145638,3824.68282699585 3428.23655748367,3824.87354278564 PathPoint;PointKind.SMOOTHPOINT 3341.95524716377,3822.82240390778 3336.37043738365,3822.80706167221 3351.12164282799,3822.84765958786 PathPoint;PointKind.SMOOTHPOINT 3324.65841078758,3824.58628892899 3299.59191226959,3824.51760292053 3330.24782323837,3824.60139513016 PathPoint;PointKind.SMOOTHPOINT 3249.33641338348,3824.38353538513 3243.86065149307,3824.36890125275 3274.48151135445,3824.45009708405 PathPoint;PointKind.SMOOTHPOINT 3234.88792204857,3821.4843249321 3229.0860786438,3821.46898269653 3240.36687040329,3821.49872303009 PathPoint;PointKind.SMOOTHPOINT 3215.49333000183,3824.29455041885 3191.36542224884,3824.23176527023 3221.2987139225,3824.30965662003 PathPoint;PointKind.SMOOTHPOINT 3143.03313159943,3824.10902738571 3132.40237855911,3824.08235549927 3167.20954442024,3824.16968822479 PathPoint;PointKind.SMOOTHPOINT 3111.95519113541,3821.10808610916 3104.66491484642,3821.08991146088 3122.59302520752,3821.13428592682 PathPoint;PointKind.SMOOTHPOINT 3089.25446534157,3823.97566795349 3073.9962580204,3823.93837451935 3096.54757404327,3823.99337053299 PathPoint;PointKind.SMOOTHPOINT 3043.46426510811,3823.86520385742 3030.81081533432,3823.83499145508 3058.7320318222,3823.90155315399 PathPoint;PointKind.SMOOTHPOINT 3005.87000513077,3822.8039932251 2989.4721057415,3822.76599168777 3018.52770352364,3822.83349752426 PathPoint;PointKind.SMOOTHPOINT 2958.29750919342,3826.66268348694 2926.58829474449,3826.59116506577 2974.69788694382,3826.69974088669 PathPoint;PointKind.SMOOTHPOINT 2862.47344636917,3826.45450115204 2851.75382637978,3826.43184185028 2894.63407659531,3826.52177095413 PathPoint;PointKind.SMOOTHPOINT 2836.36214160919,3824.26858663559 2830.34645104408,3824.25631284714 2847.12637209892,3824.29053783417 PathPoint;PointKind.SMOOTHPOINT 2812.17935585976,3826.35111808777 2729.9965467453,3826.18565797806 2818.20850038528,3826.36339187622 PathPoint;PointKind.SMOOTHPOINT 2562.63777637482,3825.89415550232 2554.64329147339,3825.88093757629 2646.60819196701,3826.03365182877 PathPoint;PointKind.SMOOTHPOINT 2533.98438119888,3824.35355901718 2523.43187355995,3824.33632850647 2541.98877954483,3824.36654090881 PathPoint;PointKind.SMOOTHPOINT 2506.95820713043,3825.80351829529 2367.40381622314,3825.58117389679 2517.52593898773,3825.82027673721 PathPoint;PointKind.SMOOTHPOINT 2093.47551727295,3826.23192071915 2083.92426753044,3826.22106313705 2232.62947583199,3826.3921880722 PathPoint;PointKind.SMOOTHPOINT 2064.84513545036,3826.19934797287 2057.1976211071,3828.04254055023 2078.00310873985,3823.02822589874 PathPoint;PointKind.SMOOTHPOINT 2041.28866696358,3826.17314815521 2027.06181192398,3826.15756988525 2049.13480424881,3826.18188142776 PathPoint;PointKind.SMOOTHPOINT 1994.67317247391,3830.12696027756 1986.15362906456,3830.11775493622 2008.85541701317,3830.14206647873 PathPoint;PointKind.SMOOTHPOINT 1968.9017572403,3829.6383690834 1959.94000339508,3829.62892770767 1977.40324401855,3829.64710235596 PathPoint;PointKind.SMOOTHPOINT 1942.28805327415,3830.0724363327 1704.91735124588,3829.83026504517 1951.22820997238,3830.08140563965 PathPoint;PointKind.SMOOTHPOINT 1262.17583799362,3828.56394052505 1715.2964656106,3828.79153211325 1469.35797715187,3828.66873979568 PathPoint;PointKind.SMOOTHPOINT 264.453125,3829.34375 246.297814175413,3827.43402777778 282.608435824587,3831.25347222222 PathPoint;PointKind.SMOOTHPOINT 229.453125,3799.34375 226.876283047183,3792.1281441015 235.177069673185,3815.37053057514 PathPoint;PointKind.SMOOTHPOINT 225.453125,3771.34375 224.496123552322,3760.70733213425 226.153439044952,3779.12462377548 PathPoint";
	
	shadow35mm[1] = "PointKind.SMOOTHPOINT 227.70359826088,3746.25622272491 227.70359826088,3746.25622272491 228.723974943161,3752.69429683685 PathPoint;PointKind.SMOOTHPOINT 228.227240562439,1452.12749004364 228.248483657837,1444.50641155243 225.361546993256,2475.96396446228 PathPoint;PointKind.SMOOTHPOINT 229.790732383728,1428.37959766388 230.903516530991,1421.68802261353 228.32495880127,1437.19170570374 PathPoint;PointKind.SMOOTHPOINT 228.347618103027,1408.98016691208 228.711229085922,1278.95188808441 228.328853368759,1415.74373245239 PathPoint;PointKind.SMOOTHPOINT 222.984375,1038 223.014823436737,1026.88986110687 222.657939434052,1156.09060335159 PathPoint;PointKind.SMOOTHPOINT 240,1009 242.27371931076,997.812441825867 237.815501689911,1019.74570178986 PathPoint;PointKind.SMOOTHPOINT 228.546949148178,978.269798755646 229.15096116066,759.096758365631 228.52428984642,986.501970291138 PathPoint;PointKind.SMOOTHPOINT 223.027238845825,435.719259738922 223.045295476913,428.738778591156 222.66575217247,575.018497467041 PathPoint;PointKind.SMOOTHPOINT 235,412 237.07545042038,395.031487464905 234.161251783371,418.860103607178 PathPoint;PointKind.SMOOTHPOINT 223.129913806915,395.836056232452 223.215948343277,362.335694789886 223.113981485367,402.152572631836 PathPoint;PointKind.SMOOTHPOINT 223.354382514954,306.418438911438 223.364650011063,302.188702583313 223.29100728035,332.403229236603 PathPoint;PointKind.SMOOTHPOINT 223.384122848511,294.044571876526 222.070237398148,289.945598602295 225.001784563065,299.090751171112 PathPoint;PointKind.SMOOTHPOINT 223.414217233658,281.476684570312 223.441479206085,269.889048099518 223.404657840729,285.542376995087 PathPoint;PointKind.SMOOTHPOINT 223.487151861191,249.790719509125 223.507686853409,240.549973011017 223.465908765793,259.311402797699 PathPoint;PointKind.SMOOTHPOINT 229,227 229.016286373138,219.711493968964 228.984067678452,234.195036411285 PathPoint;PointKind.SMOOTHPOINT 223.583807945251,206.51050901413 223.608591556549,195.351983070374 223.572478294373,211.610504150391 PathPoint;PointKind.CORNERPOINT 223.621691465378,189.538455963135 223.621691465378,189.538455963135 223.621691465378,189.538455963135 PathPoint;PointKind.SMOOTHPOINT 249.529108524323,160.356574058533 255.088780641556,153.639271259308 240.496544361115,171.270096302032 PathPoint;PointKind.SMOOTHPOINT 268.501317024231,130.086815357208 269.914690971375,128.258492946625 264.439283132553,135.341649055481 PathPoint;PointKind.SMOOTHPOINT 425.216588497162,127.521121501923 431.960917234421,127.455739974976 328.706019639969,128.456761837006 PathPoint;PointKind.SMOOTHPOINT 449.998429536819,128.607587814331 456.956605434418,128.54763507843 442.84446310997,128.668956756592 PathPoint;PointKind.SMOOTHPOINT 483.705557107925,128.710734844208 545.941099643707,128.235125541687 476.366421699524,128.766674995422 PathPoint;PointKind.SMOOTHPOINT 708.920251846313,128.811049461365 722.503441095352,128.883039951324 621.679815769196,128.348422050476 PathPoint;PointKind.SMOOTHPOINT 741.470692873001,128.489334583282 751.914860725403,128.554480075836 727.337661504745,128.401293754578 PathPoint;PointKind.SMOOTHPOINT 782.272306203842,129.258806705475 873.568757295609,129.879341125488 771.534983634949,129.185872077942 PathPoint;PointKind.SMOOTHPOINT 1085.75470757484,131.714272499084 1096.57664847374,131.806797981262 975.354694843292,130.772495269775 PathPoint;PointKind.SMOOTHPOINT 1121.17119622231,130.662031173706 1133.57574772835,130.767066478729 1110.18568348885,130.569033622742 PathPoint;PointKind.SMOOTHPOINT 1155.98721337318,132.308371067047 1266.43006634712,133.231737613678 1143.37872815132,132.203099727631 PathPoint;PointKind.SMOOTHPOINT 1508.79643630981,134.879965782166 1562.09040594101,135.190114974976 1384.60257363319,134.156992435455 PathPoint;PointKind.SMOOTHPOINT 1671.86976623535,135.701129436493 1686.03891086578,135.76226234436 1616.49291110039,135.461790561676 PathPoint;PointKind.SMOOTHPOINT 1716.00052666664,134.503726959229 1726.84512686729,134.547157287598 1701.70604777336,134.446606636047 PathPoint;PointKind.SMOOTHPOINT 1747.20557165146,136.00537776947 2074.47740745544,137.238421440125 1736.29122328758,135.964307785034 PathPoint;PointKind.SMOOTHPOINT 2793.26728057861,137.046525478363 2802.56361317635,137.061159610748 2430.69260668755,136.484291553497 PathPoint;PointKind.SMOOTHPOINT 2824.35725879669,137.913243770599 2832.24411201477,137.925753593445 2815.05561542511,137.898373603821 PathPoint;PointKind.SMOOTHPOINT 2844.83029198647,137.128901481628 2887.21805644035,137.198295593262 2836.94025230408,137.115919589996 PathPoint;PointKind.SMOOTHPOINT 2972.07784962654,137.35502243042 3126.78175401688,137.653841972351 2929.64795303345,137.273118495941 PathPoint;PointKind.SMOOTHPOINT 3428.14019989967,139.950928688049 3443.59348964691,139.961550235748 3275.48590016365,139.84542131424 PathPoint;PointKind.SMOOTHPOINT 3475.6535692215,140.91489315033 3489.34970092773,140.922918319702 3460.244535923,140.905923843384 PathPoint;PointKind.SMOOTHPOINT 3515.46667051315,140.001912117004 3744.32207775116,140.11214017868 3501.80877637863,139.995303153992 PathPoint;PointKind.SMOOTHPOINT 4180.35395932198,138.841331005096 4189.86166071892,138.832597732544 3969.6267015934,139.034879207611 PathPoint;PointKind.SMOOTHPOINT 4209.30475783348,141.144318580627 4216.57449913025,141.137237548828 4199.84874796867,141.153523921967 PathPoint;PointKind.SMOOTHPOINT 4230.56166124344,138.792943954468 4373.42466425896,138.648018836975 4223.32307648659,138.80026102066 PathPoint;PointKind.SMOOTHPOINT 4636.42232847214,139.225122928619 4648.59639239311,139.203643798828 4508.12961053848,139.451243877411 PathPoint;PointKind.SMOOTHPOINT 4675.24797987938,141.555962562561 4683.6450214386,141.540620326996 4663.22757434845,141.577913761139 PathPoint;PointKind.SMOOTHPOINT 4697.79150676727,139.113714694977 4814.40477085114,138.895618915558 4689.47129440308,139.129292964935 PathPoint;PointKind.SMOOTHPOINT 5027.10020136833,134.411437511444 5034.16919541359,134.394207000732 4927.4435300827,134.655497074127 PathPoint;PointKind.SMOOTHPOINT 5049.04679727554,135.656754970551 5057.07810354233,135.636692047119 5042.07304310799,135.673985481262 PathPoint;PointKind.SMOOTHPOINT 5072.06652355194,134.299557209015 5431.61264014244,133.390588760376 5064.16338396072,134.319620132446 PathPoint;PointKind.CORNERPOINT 5647.76573848724,130.984454154968 5647.76573848724,130.984454154968 5647.76573848724,130.984454154968 PathPoint;PointKind.SMOOTHPOINT 5686.45012331009,150.713860988617 5689.36467599869,153.222198486328 5671.44966554642,137.804667949677 PathPoint;PointKind.SMOOTHPOINT 5695.88524413109,162.207555770874 5700.86179327965,165.190558433533 5691.13068532944,159.357676506042 PathPoint;PointKind.SMOOTHPOINT 5703.23252272606,174.004790782928 5709.48294949532,184.900374412537 5701.294090271,170.625722408295 PathPoint;PointKind.SMOOTHPOINT 5711.07405734062,203.331120014191 5711.01776313782,205.151889324188 5711.40757393837,192.546472549438 PathPoint;PointKind.SMOOTHPOINT 5710.15316915512,296.445035934448 5710.08519124985,312.930386066437 5710.29726815224,261.696524620056 PathPoint;PointKind.SMOOTHPOINT 5707.73181033134,323.560667037964 5708.73731684685,318.910317420959 5707.40820717812,325.057125091553 PathPoint;PointKind.SMOOTHPOINT 5710.40029716492,339.988424777985 5710.2278740406,382.23268032074 5710.42366456985,334.189059734344 PathPoint;PointKind.SMOOTHPOINT 5709.84160375595,485.104022026062 5709.81186342239,493.23965549469 5710.03704023361,431.806275844574 PathPoint;PointKind.SMOOTHPOINT 5708.14180207253,513.520674705505 5708.11383199692,521.294703483582 5708.17154240608,505.224301815033 PathPoint;PointKind.SMOOTHPOINT 5709.66776442528,533.264479637146 5708.95045590401,734.800086021423 5709.69573450089,525.371253490448 PathPoint;PointKind.SMOOTHPOINT 5710.24486851692,1069.60613965988 5710.24593067169,1079.70581531525 5710.23601722717,972.786483764648 PathPoint;PointKind.SMOOTHPOINT 5708.37264370918,1092.47503995895 5713.18208050728,1104.24513101578 5704.94011354446,1084.0755200386 PathPoint;PointKind.SMOOTHPOINT 5710.46544265747,1114.1699051857 5711.56264853477,1108.73450517654 5710.36737036705,1114.65590000153 PathPoint;PointKind.SMOOTHPOINT 5710.10572624207,1239.07387733459 5710.08129668236,1247.40187883377 5710.22999835014,1196.7075920105 PathPoint;PointKind.SMOOTHPOINT 5708.84105396271,1263.23742628098 5708.8237054348,1269.1397023201 5708.86583757401,1254.85678911209 PathPoint;PointKind.SMOOTHPOINT 5709.97932982445,1281.88225507736 5709.78672575951,1346.65103673935 5709.99703240395,1275.95472335815 PathPoint;PointKind.SMOOTHPOINT 5709.37106919289,1480.21841526031 5709.33318567276,1492.09424972534 5709.58420825005,1412.90541887283 PathPoint;PointKind.SMOOTHPOINT 5709.05914974213,1515.84285020828 5710.23991179466,1524.49728727341 5707.44644474983,1504.01752710342 PathPoint;PointKind.SMOOTHPOINT 5709.17103004456,1542.64313936234 5709.03436613083,1584.91619110107 5709.20006227493,1533.72646808624 PathPoint;PointKind.SMOOTHPOINT 5708.74829244614,1670.43664455414 5708.71182513237,1681.12617015839 5708.89345359802,1627.54825115204 PathPoint;PointKind.SMOOTHPOINT 5707.49247145653,1703.77603054047 5705.70167851448,1711.0116648674 5710.06501030922,1693.38131189346 PathPoint;PointKind.SMOOTHPOINT 5708.5624153614,1724.76822137833 5708.27421736717,1808.16106081009 5708.58790707588,1717.35626935959 PathPoint;PointKind.SMOOTHPOINT 5705.64892482758,1975.5894613266 5705.10793399811,2117.42866516113 5705.97004961967,1891.35043859482 PathPoint;PointKind.SMOOTHPOINT 5707.38483977318,2396.92123889923 5707.35509943962,2405.61674594879 5707.86103916168,2258.29658746719 PathPoint;PointKind.SMOOTHPOINT 5705.3341729641,2419.14434909821 5705.31009745598,2426.28368139267 5705.36320519447,2410.47645807266 PathPoint;PointKind.SMOOTHPOINT 5707.22445440292,2444.35494661331 5707.11363625526,2477.66435623169 5707.24817585945,2437.23544120789 PathPoint;PointKind.SMOOTHPOINT 5709.90497899055,2542.56484508514 5709.8894007206,2547.64312505722 5710.00729990005,2509.75110769272 PathPoint;PointKind.SMOOTHPOINT 5707.90706586838,2557.58088111877 5707.88830113411,2563.69511604309 5707.92264413834,2552.51558303833 PathPoint;PointKind.SMOOTHPOINT 5709.80194997787,2576.0937666893 5708.03381633759,3157.19628095627 5709.82036066055,2569.99935865402 PathPoint;PointKind.SMOOTHPOINT 5717.20241975784,3743.611140728 5717.14647960663,3760.41655349731 5717.58691978455,3628.33406734467 PathPoint;PointKind.CORNERPOINT 5709.18917012215,3768.22362709045 5709.18917012215,3768.22362709045 5709.18917012215,3768.22362709045 PathPoint;PointKind.SMOOTHPOINT 5704.1733212471,3787.4063782692 5701.43898081779,3792.58450078964 5706.44350004196,3783.10748386383 PathPoint;PointKind.SMOOTHPOINT 5686.26672458649,3795.4292678833 5680.99595856667,3799.52871322632 5693.57788991928,3789.74296331406 PathPoint;PointKind.SMOOTHPOINT 5672.28027057648,3808.49141120911 5664.0970761776,3811.45010232925 5678.06157898903,3806.40132665634 PathPoint;PointKind.SMOOTHPOINT 5650.51778149605,3814.51784133911 5649.785602808,3814.7229552269 5656.14330720901,3812.94278383255 PathPoint;PointKind.SMOOTHPOINT 5626.76870894432,3814.97716426849 5620.31257820129,3815.02177476883 5641.68596458435,3814.87401723862 PathPoint;PointKind.SMOOTHPOINT 5593.96051836014,3820.32452344894 5583.47032380104,3818.48251104355 5602.29772520065,3821.78840875626 PathPoint;PointKind.SMOOTHPOINT 5559.27408409119,3816.1766910553 5554.32267260551,3815.55119991302 5574.93059945107,3818.15418720245 PathPoint;PointKind.SMOOTHPOINT 5541.42917585373,3825.15024662018 5511.25512909889,3825.1493024826 5546.82244372368,3825.15048265457 PathPoint;PointKind.SMOOTHPOINT 5432.65957069397,3825.02656459808 5424.9486811161,3825.01216650009 5474.81189084053,3825.10634422302 PathPoint;PointKind.SMOOTHPOINT 5401.63013529778,3819.73585367203 5393.55457258224,3819.71885919571 5409.7198600769,3819.75261211395 PathPoint;PointKind.SMOOTHPOINT 5384.17220544815,3824.92506980896 5345.13624739647,3824.83608484268 5392.61846017838,3824.94418859482 PathPoint;PointKind.SMOOTHPOINT 5255.6394405365,3824.58801269531 5248.00679636002,3824.56582546234 5302.17952203751,3824.7225522995 PathPoint;PointKind.SMOOTHPOINT 5234.07557439804,3822.25410461426 5229.57097601891,3822.24065065384 5241.89940643311,3822.2772359848 PathPoint;PointKind.SMOOTHPOINT 5218.84533715248,3824.47943687439 5144.5777053833,3824.25638437271 5223.41295671463,3824.4931268692 PathPoint;PointKind.SMOOTHPOINT 4972.53447842598,3823.68069648743 4961.45053935051,3823.6429309845 5062.06704449654,3823.98612499237 PathPoint;PointKind.SMOOTHPOINT 4944.58883237839,3821.36779546738 4935.55024933815,3821.33687496185 4955.88591051102,3821.40674114227 PathPoint;PointKind.SMOOTHPOINT 4911.64504003525,3823.47133398056 4720.32405805588,3822.80949354172 4920.81745457649,3823.50319862366 PathPoint;PointKind.SMOOTHPOINT 4262.0049829483,3821.18416070938 4250.38713407516,3821.14379882812 4500.18929553032,3822.01028108597 PathPoint;PointKind.SMOOTHPOINT 4232.76598644257,3820.1991891861 4226.69046115875,3820.17841815948 4244.46845364571,3820.23978710175 PathPoint;PointKind.SMOOTHPOINT 4208.76341295242,3821.0000538826 4018.96379065514,3820.34600257874 4214.8612434864,3821.0210609436 PathPoint;PointKind.SMOOTHPOINT 3603.48106336594,3823.0570936203 3592.7065653801,3823.02452087402 3809.44597315788,3823.68046045303 PathPoint;PointKind.SMOOTHPOINT 3572.42401194572,3821.19501829147 3562.94959139824,3820.0651216507 3585.19040417671,3822.71744012833 PathPoint;PointKind.SMOOTHPOINT 3542.46381235123,3822.87416696548 3483.79817199707,3822.70020961761 3552.02426743507,3822.90272712708 PathPoint;PointKind.SMOOTHPOINT 3372.39937973022,3822.36456871033 3363.24572992325,3822.33907699585 3431.73665595055,3822.52979278564 PathPoint;PointKind.SMOOTHPOINT 3345.45534563065,3820.47865390778 3339.87053585052,3820.46331167221 3354.62174129486,3820.50390958786 PathPoint;PointKind.SMOOTHPOINT 3328.15850925446,3822.24253892899 3303.09201073647,3822.17385292053 3333.74792170525,3822.25764513016 PathPoint;PointKind.SMOOTHPOINT 3252.83651185036,3822.03978538513 3247.36074995995,3822.02515125275 3277.98160982132,3822.10634708405 PathPoint;PointKind.SMOOTHPOINT 3238.38802051544,3819.1405749321 3232.58617711067,3819.12523269653 3243.86696887016,3819.15497303009 PathPoint;PointKind.SMOOTHPOINT 3218.9934284687,3821.95080041885 3194.86552071571,3821.88801527023 3224.79881238937,3821.96590662003 PathPoint;PointKind.SMOOTHPOINT 3147.5332300663,3826.76527738571 3136.90247702599,3826.73860549927 3171.70964288712,3826.82593822479 PathPoint;PointKind.SMOOTHPOINT 3116.45528960228,3823.76433610916 3109.16501331329,3823.74616146088 3127.09312367439,3823.79053592682 PathPoint;PointKind.SMOOTHPOINT 3093.75456380844,3826.63191795349 3078.49635648727,3826.59462451935 3101.04767251015,3826.64962053299 PathPoint;PointKind.SMOOTHPOINT 3046.96436357498,3821.52145385742 3034.31091380119,3821.49124145508 3062.23213028908,3821.55780315399 PathPoint;PointKind.SMOOTHPOINT 3009.37010359764,3820.4602432251 2992.97220420837,3820.42224168777 3022.02780199051,3820.48974752426 PathPoint;PointKind.SMOOTHPOINT 2957.984375,3828 2926.27516055107,3827.92848157883 2974.3847527504,3828.03705739975 PathPoint;PointKind.SMOOTHPOINT 2865.97354483604,3824.11075115204 2855.25392484665,3824.08809185028 2898.13417506218,3824.17802095413 PathPoint;PointKind.SMOOTHPOINT 2839.86224007607,3821.92483663559 2833.84654951096,3821.91256284714 2850.6264705658,3821.94678783417 PathPoint;PointKind.SMOOTHPOINT 2786.984375,3827 2704.80156588554,3826.83453989029 2793.01351952553,3827.01227378845 PathPoint;PointKind.SMOOTHPOINT 2574.984375,3828 2566.98989009857,3827.98678207397 2658.95479059219,3828.13949632645 PathPoint;PointKind.SMOOTHPOINT 2537.48447966576,3822.00980901718 2526.93197202682,3821.99257850647 2545.4888780117,3822.02279090881 PathPoint;PointKind.SMOOTHPOINT 2499.984375,3828 2360.42998409271,3827.7776556015 2510.5521068573,3828.01675844193 PathPoint;PointKind.SMOOTHPOINT 2096.97561573982,3823.88817071915 2087.42436599731,3823.87731313705 2236.12957429886,3824.0484380722 PathPoint;PointKind.SMOOTHPOINT 2068.34523391724,3823.85559797287 2060.69771957397,3825.69879055023 2081.50320720673,3820.68447589874 PathPoint;PointKind.SMOOTHPOINT 2044.78876543045,3823.82939815521 2030.56191039085,3823.81381988525 2052.63490271568,3823.83813142776 PathPoint;PointKind.SMOOTHPOINT 1998.17327094078,3827.78321027756 1989.65372753143,3827.77400493622 2012.35551548004,3827.79831647873 PathPoint;PointKind.SMOOTHPOINT 1972.40185570717,3827.2946190834 1963.44010186195,3827.28517770767 1980.90334248543,3827.30335235596 PathPoint;PointKind.SMOOTHPOINT 1945.78815174103,3827.7286863327 1708.41744971275,3827.48651504517 1954.72830843925,3827.73765563965 PathPoint;PointKind.SMOOTHPOINT 1265.67593646049,3826.22019052505 1254.39762306213,3826.21452569962 1472.85807561874,3826.32498979568 PathPoint;PointKind.SMOOTHPOINT 1232.0424516201,3826.20366811752 1226.24308657646,3827.42278575897 1243.33634328842,3823.82939815521 PathPoint;PointKind.SMOOTHPOINT 1214.33703970909,3826.19517087936 1135.61048221588,3826.15811347961 1220.21925282478,3826.19800329208 PathPoint;PointKind.SMOOTHPOINT 989.610228061676,3826.10760211945 978.730930805206,3826.10406160355 1060.41983795166,3826.12955331802 PathPoint;PointKind.SMOOTHPOINT 956.156955480576,3828.25409889221 945.805549144745,3828.25126647949 966.826654195786,3828.25716733932 PathPoint;PointKind.SMOOTHPOINT 926.533812999725,3826.08942747116 890.84718298912,3826.07998609543 936.682347774506,3826.09202384949 PathPoint;PointKind.SMOOTHPOINT 826.4182908535,3829.0660572052 809.709888219833,3829.06298875809 859.435017824173,3829.07219409943 PathPoint;PointKind.SMOOTHPOINT 786.657943248749,3829.71562385559 779.846344709396,3829.71467971802 802.635583400726,3829.71798419952 PathPoint;PointKind.SMOOTHPOINT 757.150929689407,3829.05519962311 673.090939044952,3829.04457807541 763.825864315033,3829.05614376068 PathPoint;PointKind.SMOOTHPOINT 540.273795843124,3829.05024290085 532.151498317719,3829.05095100403 599.98424243927,3829.04410600662 PathPoint;PointKind.SMOOTHPOINT 518.97582244873,3830.91703891754 513.629643440247,3830.91774702072 526.596074819565,3830.91609477997 PathPoint;PointKind.SMOOTHPOINT 500.996020555496,3829.05519962311 450.112080097198,3829.06369686127 506.090114831924,3829.05449151993 PathPoint;PointKind.SMOOTHPOINT 393.473031044006,3830.11735439301 380.160337209702,3828.42994451523 416.689255952835,3833.0602312088 PathPoint;PointKind.SMOOTHPOINT 370.260700702667,3832.48265504837 363.81342124939,3825.8517408371 370.558812141418,3832.78949975967 PathPoint;PointKind.SMOOTHPOINT 353.639040708542,3830.15818834305 307.676417350769,3830.17848730087 357.823222398758,3830.1563000679 PathPoint;PointKind.CORNERPOINT 278.070269346237,3825.16912937164 278.070269346237,3825.16912937164 278.070269346237,3825.16912937164 PathPoint;PointKind.SMOOTHPOINT 261.238302707672,3818.04466724396 255.323870897293,3814.22657489777 272.489000082016,3825.30744552612 PathPoint;PointKind.SMOOTHPOINT 241.443986415863,3791.76719427109 237.089151859283,3785.46318769455 245.561960458755,3797.72800683975 PathPoint;PointKind.SMOOTHPOINT 230.612840175629,3767.4839758873 229.655838727951,3756.84755802155 231.313154220581,3775.26484966278 PathPoint";
	
	shadow35mm[2] = "PointKind.SMOOTHPOINT 230.609732866287,3746.4436340332 230.609732866287,3746.4436340332 231.630109548569,3752.88170814514 PathPoint;PointKind.SMOOTHPOINT 231.133375167847,1452.31490135193 231.154618263245,1444.69382286072 228.267681598663,2476.15137577057 PathPoint;PointKind.SMOOTHPOINT 232.696866989136,1428.56700897217 233.809651136398,1421.87543392181 231.231093406677,1437.37911701202 PathPoint;PointKind.SMOOTHPOINT 231.253752708435,1409.16757822037 231.61736369133,1279.1392993927 231.234987974167,1415.93114376068 PathPoint;PointKind.SMOOTHPOINT 225.890579223633,1038.18760156631 225.92102766037,1027.07746267319 225.564143657684,1156.27820491791 PathPoint;PointKind.SMOOTHPOINT 242.90629863739,1009.18747186661 245.180017948151,997.999913692474 240.721800327301,1019.93317365646 PathPoint;PointKind.SMOOTHPOINT 231.453083753586,978.457210063934 232.057095766068,759.28416967392 231.430424451828,986.689381599426 PathPoint;PointKind.SMOOTHPOINT 226,438 226.018056631088,431.019518852234 225.638513326645,577.299237728119 PathPoint;PointKind.SMOOTHPOINT 247.906215190887,414.187488555908 249.981665611267,397.218976020813 247.067466974258,421.047592163086 PathPoint;PointKind.SMOOTHPOINT 236.036281585693,398.023617267609 236.122316122055,364.523255825043 236.020349264145,404.340133666992 PathPoint;PointKind.SMOOTHPOINT 236.260750293732,308.605999946594 236.271017789841,304.376263618469 236.197375059128,334.590790271759 PathPoint;PointKind.SMOOTHPOINT 236.290490627289,296.232132911682 234.976605176926,292.133159637451 237.908152341843,301.278312206268 PathPoint;PointKind.SMOOTHPOINT 236.320585012436,283.664245605469 236.347846984863,272.076609134674 236.311025619507,287.729938030243 PathPoint;PointKind.SMOOTHPOINT 236.393519639969,251.978280544281 236.414054632187,242.737534046173 236.372276544571,261.498963832855 PathPoint;PointKind.SMOOTHPOINT 241.906102895737,229.187507629395 241.922389268875,221.899001598358 241.890170574188,236.38254404068 PathPoint;PointKind.SMOOTHPOINT 236.49017572403,208.698070049286 236.514959335327,197.53954410553 236.478846073151,213.798065185547 PathPoint;PointKind.CORNERPOINT 236.528059244156,191.726016998291 236.528059244156,191.726016998291 236.528059244156,191.726016998291 PathPoint;PointKind.SMOOTHPOINT 262.435430288315,162.544140815735 267.995102405548,155.82683801651 253.402866125107,173.457663059235 PathPoint;PointKind.SMOOTHPOINT 272.0157122612,137.187438011169 273.429086208344,135.359115600586 267.953678369522,142.442271709442 PathPoint;PointKind.SMOOTHPOINT 427.122881412506,133.708527088165 433.867210149765,133.643145561218 330.612312555313,134.644167423248 PathPoint;PointKind.SMOOTHPOINT 451.904722452164,134.794993400574 458.862898349762,134.735040664673 444.750756025314,134.856362342834 PathPoint;PointKind.SMOOTHPOINT 486.611691713333,128.898146152496 548.847234249115,128.422536849976 479.272556304932,128.954086303711 PathPoint;PointKind.SMOOTHPOINT 710.826544761658,135.998532772064 724.409734010696,136.070523262024 623.58610868454,135.535905361176 PathPoint;PointKind.SMOOTHPOINT 743.376985788345,135.676817893982 753.821153640747,135.741963386536 729.24395442009,135.588777065277 PathPoint;PointKind.SMOOTHPOINT 784.178599119186,136.446290016174 875.475050210953,137.066824436188 773.441276550293,136.373355388641 PathPoint;PointKind.SMOOTHPOINT 1089.66103792191,140.901675224304 1100.4829788208,140.994200706482 979.261025190353,139.959897994995 PathPoint;PointKind.SMOOTHPOINT 1125.07752656937,139.849433898926 1137.48207807541,139.954469203949 1114.09201383591,139.756436347961 PathPoint;PointKind.SMOOTHPOINT 1159.89354372025,141.495773792267 1270.33639669418,142.419140338898 1147.28505849838,141.39050245285 PathPoint;PointKind.SMOOTHPOINT 1511.70257091522,135.067377090454 1564.99654054642,135.377526283264 1387.5087082386,134.344403743744 PathPoint;PointKind.SMOOTHPOINT 1674.77590084076,135.888540744781 1688.94504547119,135.949673652649 1619.3990457058,135.649201869965 PathPoint;PointKind.SMOOTHPOINT 1718.90666127205,134.691138267517 1729.7512614727,134.734568595886 1704.61218237877,134.634017944336 PathPoint;PointKind.SMOOTHPOINT 1750.11170625687,136.192789077759 2077.38354206085,137.425832748413 1739.19735789299,136.151719093323 PathPoint;PointKind.SMOOTHPOINT 2794.1733777523,144.234008789062 2803.46971035004,144.248642921448 2431.59870386124,143.671774864197 PathPoint;PointKind.SMOOTHPOINT 2825.26335597038,145.100727081299 2833.15020918846,145.113236904144 2815.9617125988,145.08585691452 PathPoint;PointKind.SMOOTHPOINT 2845.73638916016,144.316384792328 2888.12415361404,144.385778903961 2837.84634947777,144.303402900696 PathPoint;PointKind.SMOOTHPOINT 2974.98398423195,137.542433738708 3129.68788862228,137.84125328064 2932.55408763885,137.46052980423 PathPoint;PointKind.SMOOTHPOINT 3431.04633450508,140.138339996338 3446.49962425232,140.148961544037 3278.39203476906,140.032832622528 PathPoint;PointKind.SMOOTHPOINT 3478.5597038269,141.102304458618 3492.25583553314,141.110329627991 3463.15067052841,141.093335151672 PathPoint;PointKind.SMOOTHPOINT 3518.37280511856,140.189323425293 3747.22821235657,140.299551486969 3504.71491098404,140.18271446228 PathPoint;PointKind.SMOOTHPOINT 4183.26009392738,139.028742313385 4192.76779532433,139.020009040833 3972.53283619881,139.2222905159 PathPoint;PointKind.SMOOTHPOINT 4212.21089243889,141.331729888916 4219.48063373566,141.324648857117 4202.75488257408,141.340935230255 PathPoint;PointKind.SMOOTHPOINT 4233.46779584885,138.980355262756 4376.33079886436,138.835430145264 4226.229211092,138.987672328949 PathPoint;PointKind.SMOOTHPOINT 4639.32846307755,139.412534236908 4651.50252699852,139.391055107117 4511.03574514389,139.638655185699 PathPoint;PointKind.SMOOTHPOINT 4678.15411448479,141.74337387085 4686.55115604401,141.728031635284 4666.13370895386,141.765325069427 PathPoint;PointKind.SMOOTHPOINT 4700.69764137268,139.301126003265 4817.31090545654,139.083030223846 4692.37742900848,139.316704273224 PathPoint;PointKind.SMOOTHPOINT 5026.0066151619,142.5989985466 5033.07560920715,142.581768035889 4926.34994387627,142.843058109283 PathPoint;PointKind.SMOOTHPOINT 5047.95321106911,143.844316005707 5055.98451733589,143.824253082275 5040.97945690155,143.861546516418 PathPoint;PointKind.SMOOTHPOINT 5070.9729373455,142.487118244171 5430.519053936,141.578149795532 5063.06979775429,142.507181167603 PathPoint;PointKind.CORNERPOINT 5648.67183566093,140.171856880188 5648.67183566093,140.171856880188 5648.67183566093,140.171856880188 PathPoint;PointKind.SMOOTHPOINT 5687.35622048378,159.901263713837 5690.27077317238,162.409601211548 5672.35576272011,146.992070674896 PathPoint;PointKind.SMOOTHPOINT 5696.79134130478,171.394958496094 5701.76789045334,174.377961158752 5692.03678250313,168.545079231262 PathPoint;PointKind.SMOOTHPOINT 5704.13861989975,183.192193508148 5710.38904666901,194.087777137756 5702.20018744469,179.813125133514 PathPoint;PointKind.SMOOTHPOINT 5711.98015451431,212.51852273941 5711.92386031151,214.339292049408 5712.31367111206,201.733875274658 PathPoint;PointKind.SMOOTHPOINT 5713.05930376053,296.632447242737 5712.99132585526,313.117797374725 5713.20340275764,261.883935928345 PathPoint;PointKind.SMOOTHPOINT 5710.63794493675,323.748078346252 5711.64345145226,319.097728729248 5710.31434178352,325.244536399841 PathPoint;PointKind.SMOOTHPOINT 5713.30643177032,340.175836086273 5713.13400864601,382.420091629028 5713.32979917526,334.376471042633 PathPoint;PointKind.SMOOTHPOINT 5712.74773836136,485.291433334351 5712.7179980278,493.427066802979 5712.94317483902,431.993687152863 PathPoint;PointKind.SMOOTHPOINT 5711.04793667793,513.708086013794 5711.01996660233,521.48211479187 5711.07767701149,505.411713123322 PathPoint;PointKind.SMOOTHPOINT 5712.57389903069,533.451890945435 5711.85659050941,734.987497329712 5712.60186910629,525.558664798737 PathPoint;PointKind.SMOOTHPOINT 5713.15100312233,1069.79355096817 5713.1520652771,1079.89322662354 5713.14215183258,972.973895072937 PathPoint;PointKind.SMOOTHPOINT 5711.27877831459,1092.66245126724 5716.08821511269,1104.43254232407 5707.84624814987,1084.26293134689 PathPoint;PointKind.SMOOTHPOINT 5713.37157726288,1114.35731649399 5714.46878314018,1108.92191648483 5713.27350497246,1114.84331130981 PathPoint;PointKind.SMOOTHPOINT 5713.01186084747,1239.26128864288 5712.98743128777,1247.58929014206 5713.13613295555,1196.89500331879 PathPoint;PointKind.SMOOTHPOINT 5711.74718856812,1263.42483758926 5711.72984004021,1269.32711362839 5711.77197217941,1255.04420042038 PathPoint;PointKind.SMOOTHPOINT 5712.88546442986,1282.06966638565 5712.69286036491,1346.83844804764 5712.90316700935,1276.14213466644 PathPoint;PointKind.SMOOTHPOINT 5712.27720379829,1480.4058265686 5712.23932027817,1492.28166103363 5712.49034285545,1413.09283018112 PathPoint;PointKind.SMOOTHPOINT 5696,1516 5700.44815050553,1523.51714287606 5685.5556366228,1498.34731347789 PathPoint;PointKind.SMOOTHPOINT 5715,1551 5714.86333608627,1593.27305173874 5715.02903223038,1542.08332872391 PathPoint;PointKind.SMOOTHPOINT 5711.65442705154,1670.62405586243 5711.61795973778,1681.31358146667 5711.79958820343,1627.73566246033 PathPoint;PointKind.SMOOTHPOINT 5710.39860606194,1703.96344184875 5708.60781311989,1711.19907617569 5712.97114491463,1693.56872320175 PathPoint;PointKind.SMOOTHPOINT 5711.46854996681,1724.95563268661 5711.18035197258,1808.34847211838 5711.49404168129,1717.54368066788 PathPoint;PointKind.SMOOTHPOINT 5708.55505943298,1975.77687263489 5708.01406860352,2117.61607646942 5708.87618422508,1891.53784990311 PathPoint;PointKind.SMOOTHPOINT 5718,2395 5717.97025966644,2403.69550704956 5718.4761993885,2256.37534856796 PathPoint;PointKind.SMOOTHPOINT 5681,2419 5680.97592449188,2426.13933229446 5681.02903223038,2410.33210897446 PathPoint;PointKind.SMOOTHPOINT 5710.13058900833,2444.5423579216 5710.01977086067,2477.85176753998 5710.15431046486,2437.42285251617 PathPoint;PointKind.SMOOTHPOINT 5712.81111359596,2542.75225639343 5712.795535326,2547.83053636551 5712.91343450546,2509.93851900101 PathPoint;PointKind.SMOOTHPOINT 5695,2558 5694.98123526573,2564.11423492432 5695.01557826996,2552.93470191956 PathPoint;PointKind.SMOOTHPOINT 5712.70808458328,2576.28117799759 5710.93995094299,3157.38369226456 5712.72649526596,2570.18676996231 PathPoint;PointKind.SMOOTHPOINT 5714.01559710503,3734.84372377396 5713.95965695381,3751.64913654327 5714.40009713173,3619.56665039062 PathPoint;PointKind.CORNERPOINT 5706.09546303749,3768.41111898422 5706.09546303749,3768.41111898422 5706.09546303749,3768.41111898422 PathPoint;PointKind.SMOOTHPOINT 5693.01573514938,3785.84367513657 5678.21798427733,3813.86672823605 5695.28591394424,3781.5447807312 PathPoint;PointKind.SMOOTHPOINT 5653.42391610146,3814.7052526474 5672.37878940923,3809.39519948671 5673.46587912408,3809.09382254901 PathPoint;PointKind.SMOOTHPOINT 5596.86665296555,3820.51193475723 5536.028314426,3820.27802957302 5603.84784043648,3820.53871363491 PathPoint;PointKind.SMOOTHPOINT 5222.75166749954,3818.66685390472 5148.48403573036,3818.44380140305 5202.99065908545,3818.60762653279 PathPoint;PointKind.SMOOTHPOINT 4975.44061303139,3823.86810779572 4967.25893486368,3823.8402309562 5064.97317910194,3824.17353630066 PathPoint;PointKind.SMOOTHPOINT 4914.55117464066,3823.65874528885 4723.23019266129,3822.99690485001 4927.12874177838,3823.70243931141 PathPoint;PointKind.SMOOTHPOINT 4264.91111755371,3821.37157201767 4253.29326868057,3821.33121013641 4503.09543013573,3822.19769239426 PathPoint;PointKind.SMOOTHPOINT 4235.67212104797,3820.38660049438 4229.59659576416,3820.36582946777 4247.37458825111,3820.42719841003 PathPoint;PointKind.SMOOTHPOINT 4211.66954755783,3821.18746519089 4021.86992526054,3820.53341388702 4217.76737809181,3821.20847225189 PathPoint;PointKind.SMOOTHPOINT 3606.38719797134,3823.24450492859 3595.6126999855,3823.21193218231 3812.35210776329,3823.86787176132 PathPoint;PointKind.SMOOTHPOINT 3575.33014655113,3821.38242959976 3565.85572600365,3820.25253295898 3588.09653878212,3822.90485143661 PathPoint;PointKind.SMOOTHPOINT 3545.36994695663,3823.06157827377 3486.70430660248,3822.8876209259 3554.93040204048,3823.09013843536 PathPoint;PointKind.SMOOTHPOINT 3375.30551433563,3822.55198001862 3366.15186452866,3822.52648830414 3434.64279055595,3822.71720409393 PathPoint;PointKind.SMOOTHPOINT 3348.36148023605,3820.66606521606 3342.77667045593,3820.6507229805 3357.52787590027,3820.69132089615 PathPoint;PointKind.SMOOTHPOINT 3331.06464385986,3822.42995023727 3305.99814534187,3822.36126422882 3336.65405631065,3822.44505643845 PathPoint;PointKind.SMOOTHPOINT 3255.74264645576,3822.22719669342 3250.26688456535,3822.21256256104 3280.88774442673,3822.29375839233 PathPoint;PointKind.SMOOTHPOINT 3241.29415512085,3819.32798624039 3235.49231171608,3819.31264400482 3246.77310347557,3819.34238433838 PathPoint;PointKind.SMOOTHPOINT 3221.89956307411,3822.13821172714 3197.77165532112,3822.07542657852 3227.70494699478,3822.15331792831 PathPoint;PointKind.SMOOTHPOINT 3150.43956041336,3826.95284128189 3139.80880737305,3826.92616939545 3174.61597323418,3827.01350212097 PathPoint;PointKind.SMOOTHPOINT 3119.36161994934,3823.95190000534 3112.07134366035,3823.93372535706 3129.99945402145,3823.978099823 PathPoint;PointKind.SMOOTHPOINT 3096.6608941555,3826.81948184967 3081.40268683434,3826.78218841553 3103.95400285721,3826.83718442917 PathPoint;PointKind.SMOOTHPOINT 3049.87049818039,3821.70886516571 3037.2170484066,3821.67865276337 3065.13826489449,3821.74521446228 PathPoint;PointKind.SMOOTHPOINT 3012.27623820305,3820.64765453339 2995.87833881378,3820.60965299606 3024.93393659592,3820.67715883255 PathPoint;PointKind.SMOOTHPOINT 2960.89060664177,3828.1875371933 2929.18139219284,3828.11601877213 2977.29098439217,3828.22459459305 PathPoint;PointKind.SMOOTHPOINT 2868.87967944145,3824.29816246033 2858.16005945206,3824.27550315857 2901.04030966759,3824.36543226242 PathPoint;PointKind.SMOOTHPOINT 2842.76837468147,3822.11224794388 2836.75268411636,3822.09997415543 2853.5326051712,3822.13419914246 PathPoint;PointKind.SMOOTHPOINT 2789.89076972008,3827.18745946884 2707.70796060562,3827.02199935913 2795.91991424561,3827.19973325729 PathPoint;PointKind.SMOOTHPOINT 2577.89069652557,3828.1875371933 2569.89621162415,3828.17431926727 2661.86111211777,3828.32703351974 PathPoint;PointKind.SMOOTHPOINT 2540.39061427116,3822.19722032547 2529.83810663223,3822.17998981476 2548.39501261711,3822.2102022171 PathPoint;PointKind.SMOOTHPOINT 2502.89053201675,3828.1875371933 2363.33614110947,3827.9651927948 2513.45826387405,3828.20429563522 PathPoint;PointKind.SMOOTHPOINT 2099.88175034523,3824.07558202744 2090.33050060272,3824.06472444534 2239.03570890427,3824.23584938049 PathPoint;PointKind.SMOOTHPOINT 2071.25136852264,3824.04300928116 2063.60385417938,3825.88620185852 2084.40934181213,3820.87188720703 PathPoint;PointKind.SMOOTHPOINT 2047.69490003586,3824.0168094635 2033.46804499626,3824.00123119354 2055.54103732109,3824.02554273605 PathPoint;PointKind.SMOOTHPOINT 2001.07940554619,3827.97062158585 1992.55986213684,3827.96141624451 2015.26165008545,3827.98572778702 PathPoint;PointKind.SMOOTHPOINT 1975.30799031258,3827.48203039169 1966.34623646736,3827.47258901596 1983.80947709084,3827.49076366425 PathPoint;PointKind.SMOOTHPOINT 1948.69428634644,3827.91609764099 1711.32358431816,3827.67392635345 1957.63444304466,3827.92506694794 PathPoint;PointKind.SMOOTHPOINT 1268.5820710659,3826.40760183334 1317.96066407627,3826.43240351246 1475.76421022415,3826.51240110397 PathPoint;PointKind.SMOOTHPOINT 992.516362667084,3826.29501342773 1273.78539519083,3826.38654852033 1129.92338275086,3826.33761002993 PathPoint;PointKind.CORNERPOINT 287.976357936859,3820.35662412643 287.976357936859,3820.35662412643 287.976357936859,3820.35662412643 PathPoint;PointKind.SMOOTHPOINT 254.015729427338,3819.62491750717 248.101297616959,3815.80682516098 265.266426801682,3826.88769578934 PathPoint;PointKind.SMOOTHPOINT 238.015784025192,3797.62509584427 233.660949468613,3791.32108926773 242.133758068085,3803.58590841293 PathPoint;PointKind.SMOOTHPOINT 233.518974781036,3767.67138719559 232.561973333359,3757.03496932983 234.219288825989,3775.45226097107 PathPoint";
	
	subshadow35mm[0] = "PointKind.SMOOTHPOINT 245.000159740448,158.999848365784 245.974863767624,157.158308029175 244.35578584671,160.217785835266 PathPoint;PointKind.SMOOTHPOINT 248.632375001907,155.143754482269 255.02300620079,143.715913295746 247.846026420593,156.5505194664 PathPoint;PointKind.SMOOTHPOINT 259.000067710876,143.000020980835 265.830076932907,135.506873130798 255.112227201462,147.264926433563 PathPoint;PointKind.SMOOTHPOINT 288.99992108345,131.000032424927 313.091007471085,130.847790241241 273.305168151855,131.09940290451 PathPoint;PointKind.SMOOTHPOINT 399.657683372498,129.233787059784 409.461017847061,129.218208789825 342.748492956161,129.324188232422 PathPoint;PointKind.SMOOTHPOINT 429.000062942505,132.000110149384 444.288010597229,124.477458000183 419.400662183762,136.723394393921 PathPoint;PointKind.SMOOTHPOINT 459.986304044724,129.154951572418 475.315675735474,129.13866519928 449.785723686218,129.166045188904 PathPoint;PointKind.SMOOTHPOINT 508.259822130203,129.110105037689 515.420869588852,129.10444021225 491.416171789169,129.123558998108 PathPoint;PointKind.SMOOTHPOINT 527.000126838684,129.99995470047 531.348942518234,126.997833251953 518.768073320389,135.682482719421 PathPoint;PointKind.SMOOTHPOINT 546.197866201401,129.082961082458 643.98868560791,129.020884037018 540.780522823334,129.086501598358 PathPoint;PointKind.SMOOTHPOINT 899.794145822525,129.018051624298 904.09693479538,129.018523693085 763.340892791748,129.001293182373 PathPoint;PointKind.SMOOTHPOINT 914.000111818314,132.000110149384 924.712296724319,127.252750396729 910.035088062286,133.756914138794 PathPoint;PointKind.SMOOTHPOINT 939.243636131287,129.023716449738 1025.08663058281,129.038114547729 930.345257520676,129.022300243378 PathPoint;PointKind.SMOOTHPOINT 1214.63523030281,129.105620384216 1220.06142497063,129.107980728149 1117.228910923,129.06596660614 PathPoint;PointKind.SMOOTHPOINT 1227.99996972084,129.99995470047 1233.83509397507,130.002551078796 1222.54084825516,129.99783039093 PathPoint;PointKind.SMOOTHPOINT 1248.52434039116,129.120018482208 1521.79799795151,129.237563610077 1242.65239477158,129.117422103882 PathPoint;PointKind.SMOOTHPOINT 2164.8381793499,129.710576534271 2172.42585897446,129.716713428497 1834.58345890045,129.44527387619 PathPoint;PointKind.SMOOTHPOINT 2182.99996376038,131.000032424927 2186.97525501251,130.048341751099 2170.6779062748,133.949990272522 PathPoint;PointKind.SMOOTHPOINT 2199.89884614944,129.738900661469 2323.13924789429,129.838979244232 2195.80636382103,129.735596179962 PathPoint;PointKind.SMOOTHPOINT 2575.40879487991,130.061087608337 2580.02704381943,130.065336227417 2448.68664979935,129.947082996368 PathPoint;PointKind.SMOOTHPOINT 2585.99989414215,131.000032424927 2587.61543154716,131.001448631287 2581.37845873833,130.995783805847 PathPoint;PointKind.SMOOTHPOINT 2594.11546468735,130.078082084656 2645.81195354462,130.124816894531 2592.49957323074,130.076665878296 PathPoint;PointKind.SMOOTHPOINT 2744.99986052513,132.000110149384 2754.40453290939,132.008843421936 2693.00809264183,131.951251029968 PathPoint;PointKind.SMOOTHPOINT 2777.91037201881,130.247790813446 3056.41053915024,130.510025024414 2768.49932670593,130.2388215065 PathPoint;PointKind.SMOOTHPOINT 3609.83211994171,131.092557907104 3615.67892789841,131.098930835724 3337.64008998871,130.797278881073 PathPoint;PointKind.SMOOTHPOINT 3625.00004410744,134.000029563904 3629.99783635139,134.00545835495 3619.1617333889,133.993656635284 PathPoint;PointKind.SMOOTHPOINT 3642.34432339668,131.127963066101 3904.43986415863,131.413564682007 3637.35255002975,131.122534275055 PathPoint;PointKind.SMOOTHPOINT 4391.45305037498,131.989252567291 4393.65206480026,131.992084980011 4157.67313957214,131.705775260925 PathPoint;PointKind.SMOOTHPOINT 4399.99985575676,132.999951839447 4407.82864451408,131.265099048615 4397.85642743111,133.475089073181 PathPoint;PointKind.SMOOTHPOINT 4423.00010919571,135.000107288361 4454.6225810051,135.03858089447 4415.39118647575,134.990665912628 PathPoint;PointKind.SMOOTHPOINT 4516.7161488533,135.091216564178 4518.52110385895,135.092396736145 4485.87011218071,135.068557262421 PathPoint;PointKind.SMOOTHPOINT 4524.00005221367,134.000029563904 4528.822234869,134.00333404541 4522.19757556915,133.998849391937 PathPoint;PointKind.SMOOTHPOINT 4536.56357288361,135.104670524597 4549.8341345787,135.112931728363 4531.76121711731,135.101602077484 PathPoint;PointKind.SMOOTHPOINT 4576.14441633224,135.125441551208 5102.07318305969,135.351326465607 4563.02822113037,135.119776725769 PathPoint;PointKind.SMOOTHPOINT 5639.65839028358,133.760690689087 5673.16795706749,133.835277557373 5502.13731765747,133.454082012177 PathPoint;PointKind.SMOOTHPOINT 5682.00012803078,141.000101566315 5693.26817393303,147.690496444702 5670.73172807693,134.309470653534 PathPoint;PointKind.SMOOTHPOINT 5707.99990653992,166.999998092651 5709.15128231049,174.880242347717 5706.84853076935,159.119753837585 PathPoint;PointKind.SMOOTHPOINT 5721.00174307823,193.137266635895 5720.97058653831,234.285850524902 5721.01307272911,177.992355823517 PathPoint;PointKind.SMOOTHPOINT 5720.70575594902,459.293661117554 5720.69902896881,464.92874622345 5720.86791157722,327.879860401154 PathPoint;PointKind.SMOOTHPOINT 5718.0000936985,475.999939441681 5717.99796938896,477.578301429749 5718.0071747303,470.227010250092 PathPoint;PointKind.SMOOTHPOINT 5720.67884802818,481.156346797943 5720.51987886429,608.898868560791 5720.68061828613,479.568071365356 PathPoint;PointKind.SMOOTHPOINT 5720.05465507507,950.839533805847 5720.04792809486,955.584297180176 5720.30851006508,769.544584751129 PathPoint;PointKind.SMOOTHPOINT 5716.00005626678,969.000020027161 5715.99085092545,975.596237182617 5716.00678324699,964.226932525635 PathPoint;PointKind.SMOOTHPOINT 5720.00650405884,984.984505176544 5719.83231067657,1108.46400976181 5720.01570940018,978.335652351379 PathPoint;PointKind.SMOOTHPOINT 5719.42975401878,1378.62685203552 5719.42125678062,1384.20387268066 5719.63899850845,1240.91636180878 PathPoint;PointKind.SMOOTHPOINT 5718.0000936985,1395.99992752075 5714.912763834,1400.40196895599 5721.21204972267,1391.42015218735 PathPoint;PointKind.SMOOTHPOINT 5718.0000936985,1408.99999380112 5714.09809112549,1414.54231739044 5720.47491431236,1405.48473358154 PathPoint;PointKind.SMOOTHPOINT 5718.0000936985,1425.00005722046 5715.94801068306,1429.5503282547 5720.28478860855,1419.93334293365 PathPoint;PointKind.SMOOTHPOINT 5719.33876276016,1438.29658269882 5719.26582813263,1485.7798576355 5719.34548974037,1433.83152008057 PathPoint;PointKind.SMOOTHPOINT 5719.11429405212,1582.24900245667 5719.10650491714,1587.26260900497 5719.19076919556,1533.81309270859 PathPoint;PointKind.SMOOTHPOINT 5716.99989795685,1598.00004959106 5715.5373108387,1602.01711893082 5718.94647359848,1592.65481472015 PathPoint;PointKind.SMOOTHPOINT 5719.07039165497,1610.13741016388 5718.86858224869,1737.07694292068 5719.07711863518,1605.85621833801 PathPoint;PointKind.SMOOTHPOINT 5718.43309879303,1995.98849773407 5718.42141509056,2002.75914430618 5718.65579724312,1866.57154798508 PathPoint;PointKind.SMOOTHPOINT 5714.99986052513,2014.99988794327 5713.34466934204,2020.0725030899 5717.26579070091,2008.05646419525 PathPoint;PointKind.SMOOTHPOINT 5718.37043166161,2032.30522155762 5718.24970006943,2102.1022439003 5718.37963700294,2026.97060823441 PathPoint;PointKind.SMOOTHPOINT 5718.0000936985,2240.9999871254 5717.9437994957,2271.87257766724 5718.12613606453,2171.80485248566 PathPoint;PointKind.SMOOTHPOINT 5714.99986052513,2337.99997329712 5714.98853087425,2345.05527734756 5715.05013585091,2307.37781524658 PathPoint;PointKind.SMOOTHPOINT 5717.74694681168,2359.86761569977 5717.71416060248,2379.85329400669 5717.75863051414,2352.82812595367 PathPoint;PointKind.SMOOTHPOINT 5713,2423 5712.88509098996,2492.73084528132 5713.03270130477,2403.15569342411 PathPoint;PointKind.SMOOTHPOINT 5717.30650663376,2625.54816484451 5717.29942560196,2629.84163045883 5717.41950906371,2558.14249099492 PathPoint;PointKind.SMOOTHPOINT 5714.99986052513,2639.00000095367 5714.99242544174,2643.46577167511 5715.00729560852,2634.71810102463 PathPoint;PointKind.SMOOTHPOINT 5716,2678 5715.87077116966,2754.94083929062 5716.00743508339,2673.5469751358 PathPoint;PointKind.SMOOTHPOINT 5710.88129067421,2873.21220588684 5710.87279343605,2878.13257884979 5711.00591683388,2800.76522541046 PathPoint;PointKind.SMOOTHPOINT 5708.99986052513,2887.99999666214 5706.96441793442,2892.24672746658 5711.12310791016,2883.57104730606 PathPoint;PointKind.SMOOTHPOINT 5716.83172345161,2905.03200531006 5716.58742785454,3046.44422292709 5716.83951258659,2900.34530639648 PathPoint;PointKind.SMOOTHPOINT 5716.14238500595,3292.82565593719 5716.1335337162,3297.61030912399 5716.35517001152,3177.44944810867 PathPoint;PointKind.SMOOTHPOINT 5714.99986052513,3303.9999961853 5714.99667406082,3305.85923910141 5715.00871181488,3299.26939487457 PathPoint;PointKind.SMOOTHPOINT 5716.10591769218,3312.66411066055 5716.02129936218,3358.11843395233 5716.10910415649,3310.81312894821 PathPoint;PointKind.SMOOTHPOINT 5711,3440 5710.99114871025,3444.53209638596 5711.07718324661,3399.98579740524 PathPoint;PointKind.SMOOTHPOINT 5714.99986052513,3454.99993085861 5717.83758401871,3458.14792156219 5711.22496247292,3450.81173658371 PathPoint;PointKind.SMOOTHPOINT 5715.81205487251,3467.13091850281 5715.55359721184,3599.41922664642 5715.82019805908,3462.96089887619 PathPoint;PointKind.SMOOTHPOINT 5711,3739 5711.01347726192,3748.09638799179 5710.92667163835,3689.20294365725 PathPoint;PointKind.SMOOTHPOINT 5695,3783 5691.3585793972,3792.92146968842 5698.6414206028,3773.07853031158 PathPoint;PointKind.SMOOTHPOINT 5678.99989485741,3801.99999332428 5674.20745253563,3804.75994348526 5683.79269123077,3799.2400431633 PathPoint;PointKind.SMOOTHPOINT 5635.15945672989,3822.28526115417 5161.23945236206,3825.35842895508 5651.15975618362,3822.18140602112 PathPoint;PointKind.SMOOTHPOINT 272.294704914093,3829.97667789459 253.065809011459,3829.99603271484 678.143688440323,3829.56904649734 PathPoint;PointKind.SMOOTHPOINT 245.000159740448,3812.00006246567 238.506145477295,3799.71069574356 252.149877548218,3825.5304980278 PathPoint;PointKind.SMOOTHPOINT 228.000018596649,3795.99999904633 224.345852136612,3785.22620916367 231.654185056686,3806.77378892899 PathPoint;PointKind.SMOOTHPOINT 219.041805267334,3756.34574890137 219.072961807251,3738.65119457245 218.995778560638,3782.72117614746 PathPoint;PointKind.SMOOTHPOINT 219.245384931564,3687.40033864975 219.255298376083,3684.69491243362 219.143064022064,3715.49692869186 PathPoint;PointKind.SMOOTHPOINT 221.000064611435,3679.00011062622 221.006437540054,3677.31812953949 220.989443063736,3681.79664611816 PathPoint;PointKind.SMOOTHPOINT 219.29495215416,3674.05212163925 219.627760648727,3586.12317323685 219.28857922554,3675.76667547226 PathPoint;PointKind.SMOOTHPOINT 220.926775932312,3295.17608642578 220.941292047501,3291.82935476303 220.233896970749,3455.31149625778 PathPoint;PointKind.SMOOTHPOINT 223.999943733215,3280.00001907349 224.027913808823,3273.54282617569 223.985427618027,3283.37224245071 PathPoint;PointKind.SMOOTHPOINT 221.05458855629,3265.58705091476 221.965563297272,3053.47568750381 221.026264429092,3272.13653326035 PathPoint;PointKind.SMOOTHPOINT 223.761312961578,2515.16266822815 223.766269683838,2513.34992408752 223.003288507462,2793.49418878555 PathPoint;PointKind.SMOOTHPOINT 221.999906301498,2509.0000462532 222.008757591248,2505.75339317322 221.994949579239,2510.81444263458 PathPoint;PointKind.SMOOTHPOINT 223.802382946014,2499.9745631218 223.870714902878,2474.45782899857 223.793531656265,2503.22593688965 PathPoint;PointKind.SMOOTHPOINT 223.999943733215,2422.99997091293 224.018000364304,2415.72633504868 223.936568498611,2448.79215717316 PathPoint;PointKind.SMOOTHPOINT 222.207734584808,2400.5637216568 222.212337255478,2398.61667394638 222.18967795372,2407.85671234131 PathPoint;PointKind.SMOOTHPOINT 223.000102043152,2391.99992179871 223.007183074951,2389.02045965195 222.995145320892,2393.94838571548 PathPoint;PointKind.SMOOTHPOINT 222.243847846985,2385.77758312225 222.549394369125,2261.49414539337 222.236766815186,2388.76011371613 PathPoint;PointKind.SMOOTHPOINT 223.179606199265,2007.50815629959 223.182438611984,2006.47172927856 222.863438129425,2134.57019090652 PathPoint;PointKind.SMOOTHPOINT 223.999943733215,2002.0000576973 224.010565280914,1997.80596256256 223.997465372086,2003.03648471832 PathPoint;PointKind.SMOOTHPOINT 223.218905925751,1991.81635379791 223.377521038055,1928.16448688507 223.208284378052,1996.01044893265 PathPoint;PointKind.SMOOTHPOINT 223.695459365845,1801.14942312241 223.701478242874,1798.80819797516 223.53649020195,1864.50412273407 PathPoint;PointKind.SMOOTHPOINT 223.713161945343,1794.12716388702 223.509228229523,1792.8858590126 224.196442365646,1797.07027673721 PathPoint;PointKind.SMOOTHPOINT 223.722367286682,1790.35391807556 223.725199699402,1789.24408435822 223.719534873962,1791.61150932312 PathPoint;PointKind.SMOOTHPOINT 223.730864524841,1787.02441692352 223.11870932579,1785.99459886551 224.426575899124,1788.19467544556 PathPoint;PointKind.SMOOTHPOINT 223.74006986618,1783.43032121658 223.825750350952,1749.22681331635 223.736883401871,1784.62819576263 PathPoint;PointKind.SMOOTHPOINT 223.997111320496,1681.16346359253 224.004900455475,1678.09242010117 223.911430835724,1715.12125968933 PathPoint;PointKind.SMOOTHPOINT 225.000139474869,1668.99990320206 225.008636713028,1665.50753831863 224.99235033989,1672.06858634949 PathPoint;PointKind.SMOOTHPOINT 224.046678543091,1661.48126363754 224.357181787491,1538.35675477982 224.037827253342,1664.97056007385 PathPoint;PointKind.SMOOTHPOINT 224.963318109512,1300.70434570312 224.974293708801,1296.37004613876 224.664498567581,1417.30486392975 PathPoint;PointKind.SMOOTHPOINT 225.999981164932,1286.00011110306 226.009540557861,1282.26510286331 225.989005565643,1290.32190084457 PathPoint;PointKind.SMOOTHPOINT 225.025277137756,1276.52946710587 225.09290099144,1250.06104230881 225.015717744827,1280.25503396988 PathPoint;PointKind.SMOOTHPOINT 225.227086544037,1197.87383794785 225.228856801987,1197.2792673111 225.160524845123,1223.83313655853 PathPoint;PointKind.SMOOTHPOINT 225.231689214706,1196.09059810638 225.235937833786,1194.45086717606 225.230273008347,1196.68493270874 PathPoint;PointKind.SMOOTHPOINT 225.999981164932,1189.9999666214 226.004937887192,1188.04300546646 225.995732545853,1191.63780927658 PathPoint;PointKind.SMOOTHPOINT 225.259659290314,1185.30807495117 225.319494009018,1162.09031581879 225.254702568054,1187.261967659 PathPoint;PointKind.SMOOTHPOINT 225.437747240067,1116.33528470993 225.440933704376,1115.08855104446 225.378620624542,1139.09254074097 PathPoint;PointKind.SMOOTHPOINT 225.999981164932,1110.99996328354 225.430666208267,1112.52285718918 226.742427349091,1109.01373386383 PathPoint;PointKind.SMOOTHPOINT 225.459698438644,1107.72404193878 225.539714097977,1076.81297779083 225.455803871155,1109.34748649597 PathPoint;PointKind.SMOOTHPOINT 227.000176906586,1018.00005197525 227.004779577255,1016.09667062759 226.921931505203,1047.95753717422 PathPoint;PointKind.SMOOTHPOINT 227.000176906586,1009.00006055832 225.70930480957,1007.11178541183 228.071891069412,1010.56803703308 PathPoint;PointKind.SMOOTHPOINT 225.726299285889,1005.03326654434 226.295968294144,786.295001506805 225.721342563629,1006.91729307175 PathPoint;PointKind.SMOOTHPOINT 227.210129499435,451.315226554871 227.216502428055,449.063694477081 226.807218790054,594.935781955719 PathPoint;PointKind.SMOOTHPOINT 228.999860286713,444.999890327454 229.735933542252,443.915312290192 227.488059997559,447.228055000305 PathPoint;PointKind.SMOOTHPOINT 227.240223884583,440.675504207611 227.249783277512,437.277789115906 227.236683368683,441.978414058685 PathPoint;PointKind.SMOOTHPOINT 227.26854801178,430.566387176514 227.277753353119,427.334368228912 227.259342670441,433.908162117004 PathPoint;PointKind.SMOOTHPOINT 228.999860286713,420.999913215637 227.985856533051,418.337209224701 231.171966791153,426.70250415802 PathPoint;PointKind.SMOOTHPOINT 227.319885492325,412.466089725494 227.454425096512,365.14261007309 227.312096357346,415.272302627563 PathPoint;PointKind.SMOOTHPOINT 227.67924785614,289.79948759079 227.694118022919,284.887375831604 227.5748026371,323.958621025085 PathPoint;PointKind.SMOOTHPOINT 228.999860286713,272.999975681305 231.549739837646,268.90855550766 226.556904315948,276.920034885406 PathPoint;PointKind.SMOOTHPOINT 227.761033773422,263.359858989716 227.796084880829,252.22918510437 227.748641967773,267.285346984863 PathPoint;PointKind.SMOOTHPOINT 237.999851703644,232.000093460083 238.009411096573,229.169096946716 237.969403266907,241.118574142456 PathPoint;PointKind.SMOOTHPOINT 237.999851703644,223.999943733215 240.017945766449,219.818594455719 236.856265068054,226.369729042053 PathPoint;PointKind.SMOOTHPOINT 236.928137540817,212.991535663605 236.954691410065,205.594453811646 236.915037631989,216.660690307617 PathPoint;PointKind.SMOOTHPOINT 237.999851703644,192.000052928925 238.044816255569,181.013360023499 237.978608608246,197.249457836151 PathPoint;PointKind.SMOOTHPOINT 244.172387123108,163.434934616089 244.747012853622,162.359797954559 236.820505857468,177.193851470947 PathPoint";
	
}



// 645

var negative645 = [];
var mask645 = [];
var shadow645 = [];
var subshadow645 = [];

// Negative shapes

if (fancy == true && mask_variant_645 == 4) {

	negative645[0] = "PointKind.CORNERPOINT 274.48228263855,3769.92693185806 274.48228263855,3769.92693185806 274.48228263855,3769.92693185806 PathPoint;PointKind.CORNERPOINT 180.404638290405,3770.57579040527 180.404638290405,3770.57579040527 180.404638290405,3770.57579040527 PathPoint;PointKind.CORNERPOINT 199.878419876099,198.821682929993 199.878419876099,198.821682929993 199.878419876099,198.821682929993 PathPoint;PointKind.CORNERPOINT 280.882591247559,193.235692977905 280.882591247559,193.235692977905 280.882591247559,193.235692977905 PathPoint;PointKind.SMOOTHPOINT 924.918483734131,189.023423194885 949.197296142578,189.169056415558 900.639671325684,188.877789974213 PathPoint;PointKind.SMOOTHPOINT 2030.75251960754,187.492032051086 2062.52809906006,187.043330669403 1998.9766254425,187.941205501556 PathPoint;PointKind.SMOOTHPOINT 2451.90113449097,185.133576393127 2466.70363807678,184.737274646759 2431.12821960449,185.688965320587 PathPoint;PointKind.SMOOTHPOINT 2999.82602500916,185.672442913055 3000.71288490295,185.674095153809 2797.57602119446,185.314378738403 PathPoint;PointKind.SMOOTHPOINT 3002.48093986511,185.676927566528 3003.1201210022,185.896439552307 3000.73397064209,185.078108310699 PathPoint;PointKind.SMOOTHPOINT 3004.50045013428,185.680704116821 3035.61041259766,185.735464096069 3003.82853889465,185.679523944855 PathPoint;PointKind.SMOOTHPOINT 3086.59761810303,185.824685096741 3087.26606750488,185.825865268707 3063.53233718872,185.785267353058 PathPoint;PointKind.SMOOTHPOINT 3088.59069252014,185.827989578247 3089.24844169617,185.969610214233 3087.78565788269,185.655448436737 PathPoint;PointKind.SMOOTHPOINT 3090.59635543823,185.831530094147 3124.05187034607,185.888414382935 3089.93168258667,185.830585956573 PathPoint;PointKind.SMOOTHPOINT 3152.59503746033,185.920042991638 3176.89430618286,185.908005237579 3146.54846572876,185.923111438751 PathPoint;PointKind.SMOOTHPOINT 4472.55255126953,188.359458446503 4472.96262168884,188.359930515289 3948.14298057556,187.424762248993 PathPoint;PointKind.SMOOTHPOINT 4473.28520202637,188.663234710693 4473.61313247681,188.664178848267 4472.87544631958,188.662762641907 PathPoint;PointKind.SMOOTHPOINT 4474.76686859131,188.363234996796 4656.05544471741,188.685894012451 4474.43862342834,188.362526893616 PathPoint;PointKind.SMOOTHPOINT 4888.17387008667,189.034044742584 4888.69440460205,189.034516811371 4807.59865188599,188.938686847687 PathPoint;PointKind.SMOOTHPOINT 4889.72477340698,189.035696983337 4890.0394859314,188.904225826263 4888.66261863708,189.481093883514 PathPoint;PointKind.SMOOTHPOINT 4890.74098014832,189.036877155304 4927.25959205627,189.0793633461 4890.40360832214,189.036641120911 PathPoint;PointKind.SMOOTHPOINT 4950.51275634766,189.053635597229 4969.17111778259,188.732392787933 4948.53762054443,189.088096618652 PathPoint;PointKind.CORNERPOINT 5092.22308540344,190.919959545135 5092.22308540344,190.919959545135 5092.22308540344,190.919959545135 PathPoint;PointKind.CORNERPOINT 5099.609375,3746 5099.609375,3746 5099.609375,3746 PathPoint;PointKind.CORNERPOINT 5054.93940734863,3764.1778421402 5054.93940734863,3764.1778421402 5054.93940734863,3764.1778421402 PathPoint;PointKind.SMOOTHPOINT 4489.19927024841,3770.49270629883 4483.01863098145,3770.53684473038 4830.28564834595,3768.0412530899 PathPoint;PointKind.SMOOTHPOINT 4472.18402290344,3769.79333639145 4459.47089576721,3772.15226411819 4478.33854103088,3768.6518740654 PathPoint;PointKind.SMOOTHPOINT 4453.31574821472,3770.97421646118 4442.7709903717,3770.43157339096 4460.05940818787,3771.32095098495 PathPoint;PointKind.SMOOTHPOINT 4425.68650627136,3770.92276096344 4126.7404499054,3772.82661437988 4433.9898815155,3770.87012529373 PathPoint;PointKind.SMOOTHPOINT 3358.03024673462,3773.64305734634 2743.68968391418,3775.045337677 3750.14694595337,3772.74754285812 PathPoint;PointKind.SMOOTHPOINT 1652.87278556824,3774.81213569641 1649.63942909241,3774.80977535248 2093.387550354,3775.07295370102 PathPoint;PointKind.SMOOTHPOINT 1644.37397384644,3774.85910654068 1643.31339263916,3775.18436193466 1645.9126033783,3774.38750982285 PathPoint;PointKind.SMOOTHPOINT 1636.28963851929,3774.8019862175 1327.27498435974,3774.61174249649 1638.59018707275,3774.80340242386 PathPoint;PointKind.SMOOTHPOINT 1119.26385307312,3774.20316696167 1091.00896263123,3773.8493514061 1125.60342216492,3774.28247451782 PathPoint;PointKind.SMOOTHPOINT 567.570909500122,3771.75147771835 557.883428573608,3771.53031349182 609.292978286743,3772.70364046097 PathPoint;PointKind.SMOOTHPOINT 499.344066619873,3771.07004642487 498.603548049927,3771.065325737 531.979125976562,3771.29522323608 PathPoint;PointKind.SMOOTHPOINT 497.112754821777,3771.05494022369 496.640686035156,3770.71363449097 497.288993835449,3771.18216276169 PathPoint;PointKind.SMOOTHPOINT 495.369876861572,3771.04290246964 407.310794830322,3770.44715166092 495.952409744263,3771.04667901993 PathPoint";
			
	negative645[1] = "PointKind.CORNERPOINT 274.482192993164,3769.92693185806 274.482192993164,3769.92693185806 274.482192993164,3769.92693185806 PathPoint;PointKind.CORNERPOINT 180.40454864502,3770.57579040527 180.40454864502,3770.57579040527 180.40454864502,3770.57579040527 PathPoint;PointKind.CORNERPOINT 199.878330230713,198.821682929993 199.878330230713,198.821682929993 199.878330230713,198.821682929993 PathPoint;PointKind.CORNERPOINT 280.882501602173,193.235692977905 280.882501602173,193.235692977905 280.882501602173,193.235692977905 PathPoint;PointKind.SMOOTHPOINT 519.018443921226,191.584682414175 521.721287900547,191.566169980933 390.318087788389,192.466182334006 PathPoint;PointKind.SMOOTHPOINT 528,195 531.324599325049,192.652648527146 525.778791881096,196.568296098161 PathPoint;PointKind.SMOOTHPOINT 536.101359496971,191.467796576576 710.046493557885,190.278852238987 533.10967688853,191.488245231931 PathPoint;PointKind.SMOOTHPOINT 924.918394088745,189.023423194885 949.197206497192,189.169056415558 911.29047665626,188.941677948315 PathPoint;PointKind.SMOOTHPOINT 2030.75242996216,187.492032051086 2062.52800941467,187.043330669403 1998.97653579712,187.941205501556 PathPoint;PointKind.SMOOTHPOINT 2451.90104484558,185.133576393127 2466.7035484314,184.737274646759 2431.12812995911,185.688965320587 PathPoint;PointKind.SMOOTHPOINT 2999.82593536377,185.672442913055 3000.71279525757,185.674095153809 2797.57593154907,185.314378738403 PathPoint;PointKind.SMOOTHPOINT 3002.48085021973,185.676927566528 3003.12003135681,185.896439552307 3000.7338809967,185.078108310699 PathPoint;PointKind.SMOOTHPOINT 3004.50036048889,185.680704116821 3035.61032295227,185.735464096069 3003.82844924927,185.679523944855 PathPoint;PointKind.SMOOTHPOINT 3086.59752845764,185.824685096741 3087.2659778595,185.825865268707 3063.53224754333,185.785267353058 PathPoint;PointKind.SMOOTHPOINT 3088.59060287476,185.827989578247 3089.24835205078,185.969610214233 3087.7855682373,185.655448436737 PathPoint;PointKind.SMOOTHPOINT 3090.59626579285,185.831530094147 3124.05178070068,185.888414382935 3089.93159294128,185.830585956573 PathPoint;PointKind.SMOOTHPOINT 3152.59494781494,185.920042991638 3176.89421653748,185.908005237579 3146.54837608337,185.923111438751 PathPoint;PointKind.SMOOTHPOINT 4472.55246162415,188.359458446503 4472.96253204346,188.359930515289 3948.14289093018,187.424762248993 PathPoint;PointKind.SMOOTHPOINT 4473.28511238098,188.663234710693 4473.61304283142,188.664178848267 4472.87535667419,188.662762641907 PathPoint;PointKind.SMOOTHPOINT 4474.76677894592,188.363234996796 4656.05535507202,188.685894012451 4474.43853378296,188.362526893616 PathPoint;PointKind.SMOOTHPOINT 4888.17378044128,189.034044742584 4888.69431495667,189.034516811371 4807.5985622406,188.938686847687 PathPoint;PointKind.SMOOTHPOINT 4889.7246837616,189.035696983337 4890.03939628601,188.904225826263 4888.6625289917,189.481093883514 PathPoint;PointKind.SMOOTHPOINT 4890.74089050293,189.036877155304 4927.25950241089,189.0793633461 4890.40351867676,189.036641120911 PathPoint;PointKind.SMOOTHPOINT 4950.51266670227,189.053635597229 4969.17102813721,188.732392787933 4948.53753089905,189.088096618652 PathPoint;PointKind.CORNERPOINT 5092.22299575806,190.919959545135 5092.22299575806,190.919959545135 5092.22299575806,190.919959545135 PathPoint;PointKind.CORNERPOINT 5099.60929870605,3745.99988937378 5099.60929870605,3745.99988937378 5099.60929870605,3745.99988937378 PathPoint;PointKind.CORNERPOINT 5054.93931770325,3764.1778421402 5054.93931770325,3764.1778421402 5054.93931770325,3764.1778421402 PathPoint;PointKind.SMOOTHPOINT 4489.19918060303,3770.49270629883 4483.01854133606,3770.53684473038 4830.28555870056,3768.0412530899 PathPoint;PointKind.SMOOTHPOINT 4472.18393325806,3769.79333639145 4459.47080612183,3772.15226411819 4478.3384513855,3768.6518740654 PathPoint;PointKind.SMOOTHPOINT 4453.31565856934,3770.97421646118 4442.77090072632,3770.43157339096 4460.05931854248,3771.32095098495 PathPoint;PointKind.SMOOTHPOINT 4425.68641662598,3770.92276096344 4126.74036026001,3772.82661437988 4433.98979187012,3770.87012529373 PathPoint;PointKind.SMOOTHPOINT 3358.03015708923,3773.64305734634 2743.6895942688,3775.045337677 3750.14685630798,3772.74754285812 PathPoint;PointKind.SMOOTHPOINT 1652.87269592285,3774.81213569641 1649.63933944702,3774.80977535248 2093.38746070862,3775.07295370102 PathPoint;PointKind.SMOOTHPOINT 1644.37388420105,3774.85910654068 1643.31330299377,3775.18436193466 1645.91251373291,3774.38750982285 PathPoint;PointKind.SMOOTHPOINT 1636.2895488739,3774.8019862175 1327.27489471436,3774.61174249649 1638.59009742737,3774.80340242386 PathPoint;PointKind.SMOOTHPOINT 1119.26376342773,3774.20316696167 1102.13159535637,3773.98863321301 1125.60333251953,3774.28247451782 PathPoint;PointKind.SMOOTHPOINT 766.891319255933,3772.90581766784 759.077689663358,3772.87603040552 918.283370909243,3773.48295722926 PathPoint;PointKind.SMOOTHPOINT 743.737182278973,3772.81591499173 737.565265048519,3775.12262235123 755.147899072392,3768.55124593968 PathPoint;PointKind.SMOOTHPOINT 724.244207040896,3772.73732790545 645.008357458806,3772.41171451211 730.644769857676,3772.76363050697 PathPoint;PointKind.SMOOTHPOINT 567.570819854736,3771.75147771835 557.883338928223,3771.53031349182 581.559339148118,3772.0707175663 PathPoint;PointKind.SMOOTHPOINT 499.343976974487,3771.07004642487 498.603458404541,3771.065325737 531.979036331177,3771.29522323608 PathPoint;PointKind.SMOOTHPOINT 497.112665176392,3771.05494022369 496.640596389771,3770.71363449097 497.288904190063,3771.18216276169 PathPoint;PointKind.SMOOTHPOINT 495.369787216187,3771.04290246964 407.310705184937,3770.44715166092 495.952320098877,3771.04667901993 PathPoint";
			
	negative645[2] = "PointKind.CORNERPOINT 274.482192993164,3769.92693185806 274.482192993164,3769.92693185806 274.482192993164,3769.92693185806 PathPoint;PointKind.CORNERPOINT 180.40454864502,3770.57579040527 180.40454864502,3770.57579040527 180.40454864502,3770.57579040527 PathPoint;PointKind.CORNERPOINT 199.878330230713,198.821682929993 199.878330230713,198.821682929993 199.878330230713,198.821682929993 PathPoint;PointKind.CORNERPOINT 280.882501602173,193.235692977905 280.882501602173,193.235692977905 280.882501602173,193.235692977905 PathPoint;PointKind.SMOOTHPOINT 924.918394088745,189.023423194885 949.197206497192,189.169056415558 900.639581680298,188.877789974213 PathPoint;PointKind.SMOOTHPOINT 2030.75242996216,187.492032051086 2046.24272605796,187.273294348088 1998.97653579712,187.941205501556 PathPoint;PointKind.SMOOTHPOINT 2238.04202842302,186.387617561913 2244.11115329178,186.359138599122 2141.77839049605,186.839328248702 PathPoint;PointKind.SMOOTHPOINT 2250,190 2251.8877920698,186.885818896914 2249.12719024796,191.439823633057 PathPoint;PointKind.SMOOTHPOINT 2256,186 2345.51889898621,185.580031934985 2251.24761137876,186.022295308321 PathPoint;PointKind.SMOOTHPOINT 2451.90104484558,185.133576393127 2466.7035484314,184.737274646759 2442.40007931099,185.387596162954 PathPoint;PointKind.SMOOTHPOINT 2999.82593536377,185.672442913055 3000.71279525757,185.674095153809 2797.57593154907,185.314378738403 PathPoint;PointKind.SMOOTHPOINT 3002.48085021973,185.676927566528 3003.12003135681,185.896439552307 3000.7338809967,185.078108310699 PathPoint;PointKind.SMOOTHPOINT 3004.50036048889,185.680704116821 3035.61032295227,185.735464096069 3003.82844924927,185.679523944855 PathPoint;PointKind.SMOOTHPOINT 3086.59752845764,185.824685096741 3087.2659778595,185.825865268707 3063.53224754333,185.785267353058 PathPoint;PointKind.SMOOTHPOINT 3088.59060287476,185.827989578247 3089.24835205078,185.969610214233 3087.7855682373,185.655448436737 PathPoint;PointKind.SMOOTHPOINT 3090.59626579285,185.831530094147 3124.05178070068,185.888414382935 3089.93159294128,185.830585956573 PathPoint;PointKind.SMOOTHPOINT 3152.59494781494,185.920042991638 3176.89421653748,185.908005237579 3146.54837608337,185.923111438751 PathPoint;PointKind.SMOOTHPOINT 4472.55246162415,188.359458446503 4472.96253204346,188.359930515289 3948.14289093018,187.424762248993 PathPoint;PointKind.SMOOTHPOINT 4473.28511238098,188.663234710693 4473.61304283142,188.664178848267 4472.87535667419,188.662762641907 PathPoint;PointKind.SMOOTHPOINT 4474.76677894592,188.363234996796 4656.05535507202,188.685894012451 4474.43853378296,188.362526893616 PathPoint;PointKind.SMOOTHPOINT 4888.17378044128,189.034044742584 4888.69431495667,189.034516811371 4807.5985622406,188.938686847687 PathPoint;PointKind.SMOOTHPOINT 4889.7246837616,189.035696983337 4890.03939628601,188.904225826263 4888.6625289917,189.481093883514 PathPoint;PointKind.SMOOTHPOINT 4890.74089050293,189.036877155304 4927.25950241089,189.0793633461 4890.40351867676,189.036641120911 PathPoint;PointKind.SMOOTHPOINT 4950.51266670227,189.053635597229 4969.17102813721,188.732392787933 4948.53753089905,189.088096618652 PathPoint;PointKind.CORNERPOINT 5092.22299575806,190.919959545135 5092.22299575806,190.919959545135 5092.22299575806,190.919959545135 PathPoint;PointKind.CORNERPOINT 5099.60929870605,3745.99988937378 5099.60929870605,3745.99988937378 5099.60929870605,3745.99988937378 PathPoint;PointKind.CORNERPOINT 5054.93931770325,3764.1778421402 5054.93931770325,3764.1778421402 5054.93931770325,3764.1778421402 PathPoint;PointKind.SMOOTHPOINT 4489.19918060303,3770.49270629883 4483.01854133606,3770.53684473038 4830.28555870056,3768.0412530899 PathPoint;PointKind.SMOOTHPOINT 4472.18393325806,3769.79333639145 4459.47080612183,3772.15226411819 4478.3384513855,3768.6518740654 PathPoint;PointKind.SMOOTHPOINT 4453.31565856934,3770.97421646118 4442.77090072632,3770.43157339096 4460.05931854248,3771.32095098495 PathPoint;PointKind.SMOOTHPOINT 4425.68641662598,3770.92276096344 4126.74036026001,3772.82661437988 4433.98979187012,3770.87012529373 PathPoint;PointKind.SMOOTHPOINT 3358.03015708923,3773.64305734634 2975.27405303156,3774.51672805709 3750.14685630798,3772.74754285812 PathPoint;PointKind.SMOOTHPOINT 2227.31724351047,3774.92594515228 2223.44372068934,3774.92670779592 2578.55862068195,3774.85679053124 PathPoint;PointKind.SMOOTHPOINT 2215.71334626754,3774.92813459304 2212.29065596612,3776.7444680085 2222.92645744406,3771.10032263649 PathPoint;PointKind.SMOOTHPOINT 2204.10604282181,3774.93013454753 2000.53703844919,3774.96354548307 2207.96944404148,3774.92950046352 PathPoint;PointKind.SMOOTHPOINT 1652.87269592285,3774.81213569641 1649.63933944702,3774.80977535248 1812.86786142808,3774.90686491584 PathPoint;PointKind.SMOOTHPOINT 1644.37388420105,3774.85910654068 1643.31330299377,3775.18436193466 1645.91251373291,3774.38750982285 PathPoint;PointKind.SMOOTHPOINT 1636.2895488739,3774.8019862175 1327.27489471436,3774.61174249649 1638.59009742737,3774.80340242386 PathPoint;PointKind.SMOOTHPOINT 1119.26376342773,3774.20316696167 1091.00887298584,3773.8493514061 1125.60333251953,3774.28247451782 PathPoint;PointKind.SMOOTHPOINT 567.570819854736,3771.75147771835 557.883338928223,3771.53031349182 609.292888641357,3772.70364046097 PathPoint;PointKind.SMOOTHPOINT 499.343976974487,3771.07004642487 498.603458404541,3771.065325737 531.979036331177,3771.29522323608 PathPoint;PointKind.SMOOTHPOINT 497.112665176392,3771.05494022369 496.640596389771,3770.71363449097 497.288904190063,3771.18216276169 PathPoint;PointKind.SMOOTHPOINT 495.369787216187,3771.04290246964 407.310705184937,3770.44715166092 495.952320098877,3771.04667901993 PathPoint";
			
} else if (negative_variant_645 == 1 && fancy == false ) {
		
	negative645[0] = "PointKind.CORNERPOINT 258.1137692644,3769.92693185806 258.1137692644,3769.92693185806 258.1137692644,3769.92693185806 PathPoint;PointKind.CORNERPOINT 104.825392454137,3770.57579040527 104.825392454137,3770.57579040527 104.825392454137,3770.57579040527 PathPoint;PointKind.SMOOTHPOINT 117.737757404898,3690.38050889969 134.21533718631,3676.20475530624 95.9029974419742,3709.16483402252 PathPoint;PointKind.SMOOTHPOINT 233.161389285849,3651.99258327484 244.393132457735,3639.55899953842 218.068783963963,3668.70051383972 PathPoint;PointKind.SMOOTHPOINT 251.659648707019,3600.51961898804 252.608765423213,3576.13703012466 250.835198725271,3621.6633439064 PathPoint;PointKind.CORNERPOINT 252.669671308744,3502.80775308609 252.669671308744,3502.80775308609 252.669671308744,3502.80775308609 PathPoint;PointKind.SMOOTHPOINT 253.488728581877,3324.10068511963 253.762170630459,3279.12362337112 253.267627528672,3360.52622079849 PathPoint;PointKind.SMOOTHPOINT 252.972931863785,3105.54133415222 253.461765038803,3086.53608083725 252.712178541354,3115.67027807236 PathPoint;PointKind.SMOOTHPOINT 250.611559926836,2631.14336013794 250.419325725629,2606.12135410309 250.803794128044,2656.16442203522 PathPoint;PointKind.SMOOTHPOINT 254.054962986424,2035.00002622604 254.167258212872,1982.50833749771 253.942667759976,2087.49195098877 PathPoint;PointKind.SMOOTHPOINT 255.055786261689,1541.0001039505 255.289258822892,1483.54177951813 254.822313700486,1598.45866441727 PathPoint;PointKind.SMOOTHPOINT 255.741611910222,1204.21797037125 256.10292338741,1165.95821142197 255.381252087496,1242.47725725174 PathPoint;PointKind.SMOOTHPOINT 255.435179173644,1074.36813354492 255.221056919823,1066.92455291748 255.649935863772,1081.81124210358 PathPoint;PointKind.SMOOTHPOINT 256.634263795038,1056.36579036713 257.342929150646,1051.59341096878 255.828529684366,1061.78962469101 PathPoint;PointKind.SMOOTHPOINT 257.817487508743,1031.9355225563 258.186412221622,1019.66905117035 257.449514450326,1044.20175790787 PathPoint;PointKind.SMOOTHPOINT 257.44158399648,872.516005039215 257.325482152187,862.429075241089 257.581794420463,884.705293178558 PathPoint;PointKind.SMOOTHPOINT 256.632677704269,851.942539215088 257.177975710666,842.116663455963 256.43029252214,855.574400424957 PathPoint;PointKind.SMOOTHPOINT 256.568282419046,824.944217205048 256.106412787102,820.757911205292 257.031420923606,829.130523204803 PathPoint;PointKind.SMOOTHPOINT 256.325927749537,722.092938423157 255.235648954898,711.126780509949 257.115483734366,730.036203861237 PathPoint;PointKind.SMOOTHPOINT 251.052810378784,390.999941825867 250.099887044744,373.384459018707 252.00541649467,408.615424633026 PathPoint;PointKind.SMOOTHPOINT 240.209976663466,328.57191324234 235.807305906763,310.017721652985 244.61264742017,347.127048969269 PathPoint;PointKind.SMOOTHPOINT 226.447149842345,282.324042320251 209.357656242237,251.904637813568 232.840998950502,293.705148696899 PathPoint;PointKind.SMOOTHPOINT 123.403273631912,220.961472988129 121.978964121314,213.524973392487 124.82663148805,228.398916721344 PathPoint;PointKind.CORNERPOINT 122.655273225233,193.999972343445 122.655273225233,193.999972343445 122.655273225233,193.999972343445 PathPoint;PointKind.CORNERPOINT 264.565034858397,193.235692977905 264.565034858397,193.235692977905 264.565034858397,193.235692977905 PathPoint;PointKind.SMOOTHPOINT 913.728512483445,189.023423194885 938.200624177131,189.169056415558 889.25640078976,188.877789974213 PathPoint;PointKind.SMOOTHPOINT 2028.36680637123,187.492032051086 2060.39537170678,187.043330669403 1996.33792381752,187.941205501556 PathPoint;PointKind.SMOOTHPOINT 2452.86845701548,185.133576393127 2467.78881287985,184.737274646759 2431.93015555522,185.688965320587 PathPoint;PointKind.SMOOTHPOINT 3005.15573099459,185.672442913055 3006.04965175202,185.674095153809 2801.29548444977,185.314378738403 PathPoint;PointKind.SMOOTHPOINT 3007.83178334012,185.676927566528 3008.4760534105,185.896439552307 3006.07090536833,185.078108310699 PathPoint;PointKind.SMOOTHPOINT 3009.8673722331,185.680704116821 3041.22502117335,185.735464096069 3009.19011147472,185.679523944855 PathPoint;PointKind.SMOOTHPOINT 3092.61816870812,185.824685096741 3093.29194006681,185.825865268707 3069.36925021552,185.785267353058 PathPoint;PointKind.SMOOTHPOINT 3094.62711127619,185.827989578247 3095.29009721765,185.969610214233 3093.81566723874,185.655448436737 PathPoint;PointKind.SMOOTHPOINT 3096.64874257041,185.831530094147 3130.37061841098,185.888414382935 3095.97877782956,185.830585956573 PathPoint;PointKind.SMOOTHPOINT 3159.14103608877,185.920042991638 3183.63376696245,185.908005237579 3153.04632369965,185.923111438751 PathPoint;PointKind.SMOOTHPOINT 4489.60758302825,188.359458446503 4490.02091828266,188.359930515289 3961.02284950169,187.424762248993 PathPoint;PointKind.SMOOTHPOINT 4490.34606689032,188.663234710693 4490.67660820658,188.664178848267 4489.93304885406,188.662762641907 PathPoint;PointKind.SMOOTHPOINT 4491.83952995845,188.363234996796 4674.57146136888,188.685894012451 4491.50867142402,188.362526893616 PathPoint;PointKind.SMOOTHPOINT 4908.53793123717,189.034044742584 4909.06261006357,189.034516811371 4827.32120175397,188.938686847687 PathPoint;PointKind.SMOOTHPOINT 4910.10118229914,189.035696983337 4910.41840045295,188.904225826263 4909.03057103004,189.481093883514 PathPoint;PointKind.SMOOTHPOINT 4911.12547971779,189.036877155304 4947.93483984938,189.0793633461 4910.7854218569,189.036641120911 PathPoint;PointKind.SMOOTHPOINT 4971.3731375798,189.053635597229 4990.18005026463,188.732392787933 4969.3822764465,189.088096618652 PathPoint;PointKind.CORNERPOINT 5169.51933352008,189.000055789948 5169.51933352008,189.000055789948 5169.51933352008,189.000055789948 PathPoint;PointKind.SMOOTHPOINT 5174.99705660004,218.572096824646 5174.60148556224,222.713792324066 5175.39262763784,214.430637359619 PathPoint;PointKind.SMOOTHPOINT 5149.42419791264,236.737067699432 5140.2619859762,243.187415599823 5157.79843995502,230.842108726501 PathPoint;PointKind.SMOOTHPOINT 5061.0154984463,270.918388366699 5050.57806953155,284.054410457611 5075.20942473845,253.05624961853 PathPoint;PointKind.SMOOTHPOINT 5031.49168765322,329.255232810974 5027.73519027582,346.432163715363 5035.24818503062,312.077357769012 PathPoint;PointKind.SMOOTHPOINT 5025.05469687615,423.000068664551 5023.8600533089,449.193041324615 5026.24902322523,396.806623935699 PathPoint;PointKind.SMOOTHPOINT 5023.68304557908,600.912172794342 5024.08400932549,609.507601261139 5023.28239905082,592.316980361938 PathPoint;PointKind.SMOOTHPOINT 5024.96651022939,618.908143043518 5024.76222173833,624.362897872925 5025.1717503749,613.453860282898 PathPoint;PointKind.SMOOTHPOINT 5023.76583951722,635.624570846558 5023.93237904797,643.678772449493 5023.5977138957,627.570605278015 PathPoint;PointKind.SMOOTHPOINT 5025.37001172103,972.875468730927 5025.28309394689,991.229267120361 5025.43853084225,958.269424438477 PathPoint;PointKind.SMOOTHPOINT 5026.05520293326,2149.99999523163 5026.20968817416,2166.46008968353 5025.76177614098,2118.66312503815 PathPoint;PointKind.SMOOTHPOINT 5025.05437965799,2572.79140949249 5025.47754867517,2755.05622386932 5024.59060671712,2373.48821640015 PathPoint;PointKind.SMOOTHPOINT 5027.7079095146,2950.77240228653 5027.59942090599,2990.2746462822 5027.75929885551,2931.9033408165 PathPoint;PointKind.SMOOTHPOINT 5025.78112644837,3186.05148553848 5025.2259946792,3211.4133810997 5026.33562378122,3160.68888187408 PathPoint;PointKind.SMOOTHPOINT 5026.21159148308,3368.61181497574 5026.09104858464,3391.3010931015 5026.33213438153,3345.92348098755 PathPoint;PointKind.SMOOTHPOINT 5025.38745871949,3508.28965187073 5025.61712466285,3522.36886739731 5025.15779277613,3494.20972824097 PathPoint;PointKind.SMOOTHPOINT 5026.73151203717,3551.99802875519 5028.3582067299,3556.93091154099 5025.10576899891,3547.064909935 PathPoint;PointKind.SMOOTHPOINT 5028.00990119702,3567.42264032364 5028.21641021515,3579.87628698349 5027.92108011396,3562.10549354553 PathPoint;PointKind.SMOOTHPOINT 5029.30510291902,3590.56109189987 5029.79583940296,3597.35746622086 5028.03115481333,3572.90430307388 PathPoint;PointKind.SMOOTHPOINT 5048.05713686324,3647.0823597908 5060.73888421618,3670.29492616653 5035.70656526287,3624.47262525558 PathPoint;PointKind.SMOOTHPOINT 5132.03239541195,3692.1620965004 5158.2086030279,3702.94178724289 5123.07732692995,3688.47382307053 PathPoint;PointKind.SMOOTHPOINT 5173.79892363311,3747.09933757782 5171.65230838629,3761.9725728035 5175.94458722546,3732.22657442093 PathPoint;PointKind.SMOOTHPOINT 5162.46345012492,3766.00002765656 5157.79526777348,3767.63975858688 5167.02377830407,3764.39829826355 PathPoint;PointKind.CORNERPOINT 5146.33607918532,3770.00010251999 5146.33607918532,3770.00010251999 5146.33607918532,3770.00010251999 PathPoint;PointKind.SMOOTHPOINT 4506.38683727393,3770.49270629883 4500.1569899513,3770.53684473038 4850.1888240257,3768.0412530899 PathPoint;PointKind.SMOOTHPOINT 4489.23612057014,3769.79333639145 4476.42177602891,3772.15226411819 4495.43963878601,3768.6518740654 PathPoint;PointKind.SMOOTHPOINT 4470.21762337673,3770.97421646118 4459.58891191523,3770.43157339096 4477.01497397653,3771.32095098495 PathPoint;PointKind.SMOOTHPOINT 4442.3684072176,3770.92276096344 4141.04224847891,3772.82661437988 4450.73789098767,3770.87012529373 PathPoint;PointKind.SMOOTHPOINT 3366.21184756829,3773.64305734634 2746.98012328212,3775.045337677 3761.45044074189,3772.74754285812 PathPoint;PointKind.SMOOTHPOINT 1647.4785280396,3774.81213569641 1644.21942872737,3774.80977535248 2091.50051499659,3775.07295370102 PathPoint;PointKind.SMOOTHPOINT 1638.91205179601,3774.85910654068 1637.84302661767,3775.18436193466 1640.46293134998,3774.38750982285 PathPoint;PointKind.SMOOTHPOINT 1630.76335186098,3774.8019862175 1319.28843272751,3774.61174249649 1633.08221656532,3774.80340242386 PathPoint;PointKind.SMOOTHPOINT 1109.62119065907,3774.20316696167 1081.14134481017,3773.8493514061 1116.01123314938,3774.28247451782 PathPoint;PointKind.SMOOTHPOINT 553.535863724415,3771.75147771835 543.771254513892,3771.53031349182 595.590108811073,3772.70364046097 PathPoint;PointKind.SMOOTHPOINT 484.765822942187,3771.07004642487 484.019408626277,3771.065325737 517.660711055787,3771.29522323608 PathPoint;PointKind.SMOOTHPOINT 482.516746231687,3771.05494022369 482.040919000975,3770.71363449097 482.69438839782,3771.18216276169 PathPoint;PointKind.SMOOTHPOINT 480.759992095898,3771.04290246964 391.99981491514,3770.44715166092 481.347162898596,3771.04667901993 PathPoint";
		
	negative645[1] = "PointKind.CORNERPOINT 258.1137692644,3769.92693185806 258.1137692644,3769.92693185806 258.1137692644,3769.92693185806 PathPoint;PointKind.CORNERPOINT 104.825392454137,3770.57579040527 104.825392454137,3770.57579040527 104.825392454137,3770.57579040527 PathPoint;PointKind.SMOOTHPOINT 117.737757404898,3690.38050889969 134.21533718631,3676.20475530624 95.9029974419742,3709.16483402252 PathPoint;PointKind.SMOOTHPOINT 233.161389285849,3651.99258327484 244.393132457735,3639.55899953842 218.068783963963,3668.70051383972 PathPoint;PointKind.SMOOTHPOINT 251.659648707019,3600.51961898804 252.608765423213,3576.13703012466 250.835198725271,3621.6633439064 PathPoint;PointKind.CORNERPOINT 252.669671308744,3502.80775308609 252.669671308744,3502.80775308609 252.669671308744,3502.80775308609 PathPoint;PointKind.SMOOTHPOINT 253.488728581877,3324.10068511963 253.762170630459,3279.12362337112 253.267627528672,3360.52622079849 PathPoint;PointKind.SMOOTHPOINT 252.972931863785,3105.54133415222 253.461765038803,3086.53608083725 252.712178541354,3115.67027807236 PathPoint;PointKind.SMOOTHPOINT 250.611559926836,2631.14336013794 250.419325725629,2606.12135410309 250.803794128044,2656.16442203522 PathPoint;PointKind.SMOOTHPOINT 254.054962986424,2035.00002622604 254.167258212872,1982.50833749771 253.942667759976,2087.49195098877 PathPoint;PointKind.SMOOTHPOINT 255.055786261689,1541.0001039505 255.289258822892,1483.54177951813 254.822313700486,1598.45866441727 PathPoint;PointKind.SMOOTHPOINT 255.741611910222,1204.21797037125 256.10292338741,1165.95821142197 255.381252087496,1242.47725725174 PathPoint;PointKind.SMOOTHPOINT 255.435179173644,1074.36813354492 255.221056919823,1066.92455291748 255.649935863772,1081.81124210358 PathPoint;PointKind.SMOOTHPOINT 256.634263795038,1056.36579036713 257.342929150646,1051.59341096878 255.828529684366,1061.78962469101 PathPoint;PointKind.SMOOTHPOINT 257.817487508743,1031.9355225563 258.186412221622,1019.66905117035 257.449514450326,1044.20175790787 PathPoint;PointKind.SMOOTHPOINT 257.44158399648,872.516005039215 257.325482152187,862.429075241089 257.581794420463,884.705293178558 PathPoint;PointKind.SMOOTHPOINT 256.632677704269,851.942539215088 257.177975710666,842.116663455963 256.43029252214,855.574400424957 PathPoint;PointKind.SMOOTHPOINT 256.568282419046,824.944217205048 256.106412787102,820.757911205292 257.031420923606,829.130523204803 PathPoint;PointKind.SMOOTHPOINT 256.325927749537,722.092938423157 255.235648954898,711.126780509949 257.115483734366,730.036203861237 PathPoint;PointKind.SMOOTHPOINT 251.052810378784,390.999941825867 250.099887044744,373.384459018707 252.00541649467,408.615424633026 PathPoint;PointKind.SMOOTHPOINT 240.209976663466,328.57191324234 235.807305906763,310.017721652985 244.61264742017,347.127048969269 PathPoint;PointKind.SMOOTHPOINT 226.447149842345,282.324042320251 209.357656242237,251.904637813568 232.840998950502,293.705148696899 PathPoint;PointKind.SMOOTHPOINT 123.403273631912,220.961472988129 121.978964121314,213.524973392487 124.82663148805,228.398916721344 PathPoint;PointKind.CORNERPOINT 122.655273225233,193.999972343445 122.655273225233,193.999972343445 122.655273225233,193.999972343445 PathPoint;PointKind.CORNERPOINT 264.565034858397,193.235692977905 264.565034858397,193.235692977905 264.565034858397,193.235692977905 PathPoint;PointKind.SMOOTHPOINT 913.728512483445,189.023423194885 914.164053008624,189.026019573212 889.25640078976,188.877789974213 PathPoint;PointKind.SMOOTHPOINT 918.944847804667,187.999978065491 925.446868303273,186.591560840607 917.891049097716,188.228223323822 PathPoint;PointKind.SMOOTHPOINT 928.601602842896,189.035224914551 1060.29852601421,189.026019573212 922.775574230055,189.035696983337 PathPoint;PointKind.SMOOTHPOINT 2028.36680637123,187.492032051086 2060.39537170678,187.043330669403 1998.24059830407,187.914533615112 PathPoint;PointKind.SMOOTHPOINT 2452.86845701548,185.133576393127 2467.78881287985,184.737274646759 2431.93015555522,185.688965320587 PathPoint;PointKind.SMOOTHPOINT 3005.15573099459,185.672442913055 3006.04965175202,185.674095153809 2801.29548444977,185.314378738403 PathPoint;PointKind.SMOOTHPOINT 3007.83178334012,185.676927566528 3008.4760534105,185.896439552307 3006.07090536833,185.078108310699 PathPoint;PointKind.SMOOTHPOINT 3009.8673722331,185.680704116821 3041.22502117335,185.735464096069 3009.19011147472,185.679523944855 PathPoint;PointKind.SMOOTHPOINT 3092.61816870812,185.824685096741 3093.29194006681,185.825865268707 3069.36925021552,185.785267353058 PathPoint;PointKind.SMOOTHPOINT 3094.62711127619,185.827989578247 3095.29009721765,185.969610214233 3093.81566723874,185.655448436737 PathPoint;PointKind.SMOOTHPOINT 3096.64874257041,185.831530094147 3130.37061841098,185.888414382935 3095.97877782956,185.830585956573 PathPoint;PointKind.SMOOTHPOINT 3159.14103608877,185.920042991638 3183.63376696245,185.908005237579 3153.04632369965,185.923111438751 PathPoint;PointKind.SMOOTHPOINT 4489.60758302825,188.359458446503 4490.02091828266,188.359930515289 3961.02284950169,187.424762248993 PathPoint;PointKind.SMOOTHPOINT 4490.34606689032,188.663234710693 4490.67660820658,188.664178848267 4489.93304885406,188.662762641907 PathPoint;PointKind.SMOOTHPOINT 4491.83952995845,188.363234996796 4674.57146136888,188.685894012451 4491.50867142402,188.362526893616 PathPoint;PointKind.SMOOTHPOINT 4908.53793123717,189.034044742584 4909.06261006357,189.034516811371 4827.32120175397,188.938686847687 PathPoint;PointKind.SMOOTHPOINT 4910.10118229914,189.035696983337 4910.41840045295,188.904225826263 4909.03057103004,189.481093883514 PathPoint;PointKind.SMOOTHPOINT 4911.12547971779,189.036877155304 4947.93483984938,189.0793633461 4910.7854218569,189.036641120911 PathPoint;PointKind.SMOOTHPOINT 4971.3731375798,189.053635597229 4990.18005026463,188.732392787933 4969.3822764465,189.088096618652 PathPoint;PointKind.CORNERPOINT 5169.51933352008,189.000055789948 5169.51933352008,189.000055789948 5169.51933352008,189.000055789948 PathPoint;PointKind.SMOOTHPOINT 5174.99705660004,218.572096824646 5174.60148556224,222.713792324066 5175.39262763784,214.430637359619 PathPoint;PointKind.SMOOTHPOINT 5149.42419791264,236.737067699432 5140.2619859762,243.187415599823 5157.79843995502,230.842108726501 PathPoint;PointKind.SMOOTHPOINT 5061.0154984463,270.918388366699 5050.57806953155,284.054410457611 5075.20942473845,253.05624961853 PathPoint;PointKind.SMOOTHPOINT 5031.49168765322,329.255232810974 5027.73519027582,346.432163715363 5035.24818503062,312.077357769012 PathPoint;PointKind.SMOOTHPOINT 5025.05469687615,423.000068664551 5023.8600533089,449.193041324615 5026.24902322523,396.806623935699 PathPoint;PointKind.SMOOTHPOINT 5023.68304557908,600.912172794342 5024.08400932549,609.507601261139 5023.28239905082,592.316980361938 PathPoint;PointKind.SMOOTHPOINT 5024.96651022939,618.908143043518 5024.76222173833,624.362897872925 5025.1717503749,613.453860282898 PathPoint;PointKind.SMOOTHPOINT 5023.76583951722,635.624570846558 5023.93237904797,643.678772449493 5023.5977138957,627.570605278015 PathPoint;PointKind.SMOOTHPOINT 5025.37001172103,972.875468730927 5025.30720252658,986.118886470795 5025.43853084225,958.269424438477 PathPoint;PointKind.SMOOTHPOINT 5025.78334697544,1916.49754285812 5025.78556750252,1919.75410938263 5025.53908899701,1576.81242227554 PathPoint;PointKind.SMOOTHPOINT 5026.38859921291,1926.00005149841 5025.06833725676,1928.74347925186 5028.13996064008,1922.36087322235 PathPoint;PointKind.SMOOTHPOINT 5025.79698735606,1935.25354385376 5025.88676009358,2056.44115447998 5025.79476682898,1932.2566151619 PathPoint;PointKind.SMOOTHPOINT 5026.05520293326,2149.99999523163 5026.20968817416,2166.46008968353 5025.97748448557,2141.69677734375 PathPoint;PointKind.SMOOTHPOINT 5025.05437965799,2572.79140949249 5025.47754867517,2755.05622386932 5024.59060671712,2373.48821640015 PathPoint;PointKind.SMOOTHPOINT 5027.7079095146,2950.77240228653 5027.59942090599,2990.2746462822 5027.75929885551,2931.9033408165 PathPoint;PointKind.SMOOTHPOINT 5025.78112644837,3186.05148553848 5025.2259946792,3211.4133810997 5026.33562378122,3160.68888187408 PathPoint;PointKind.SMOOTHPOINT 5026.21159148308,3368.61181497574 5026.09104858464,3391.3010931015 5026.33213438153,3345.92348098755 PathPoint;PointKind.SMOOTHPOINT 5025.38745871949,3508.28965187073 5025.61712466285,3522.36886739731 5025.15779277613,3494.20972824097 PathPoint;PointKind.SMOOTHPOINT 5026.73151203717,3551.99802875519 5026.4710759329,3556.93091154099 5027.00622295837,3546.81518554688 PathPoint;PointKind.SMOOTHPOINT 5028.00990119702,3567.42264032364 5028.21641021515,3579.87628698349 5027.92108011396,3562.10549354553 PathPoint;PointKind.SMOOTHPOINT 5029.30510291902,3590.56109189987 5029.79583940296,3597.35746622086 5028.03115481333,3572.90430307388 PathPoint;PointKind.SMOOTHPOINT 5048.05713686324,3647.0823597908 5060.73888421618,3670.29492616653 5035.70656526287,3624.47262525558 PathPoint;PointKind.SMOOTHPOINT 5132.03239541195,3692.1620965004 5158.2086030279,3702.94178724289 5123.07732692995,3688.47382307053 PathPoint;PointKind.SMOOTHPOINT 5173.79892363311,3747.09933757782 5171.65230838629,3761.9725728035 5175.94458722546,3732.22657442093 PathPoint;PointKind.SMOOTHPOINT 5162.46345012492,3766.00002765656 5157.79526777348,3767.63975858688 5167.02377830407,3764.39829826355 PathPoint;PointKind.CORNERPOINT 5146.33607918532,3770.00010251999 5146.33607918532,3770.00010251999 5146.33607918532,3770.00010251999 PathPoint;PointKind.SMOOTHPOINT 4506.38683727393,3770.49270629883 4500.1569899513,3770.53684473038 4850.1888240257,3768.0412530899 PathPoint;PointKind.SMOOTHPOINT 4489.23612057014,3769.79333639145 4476.42177602891,3772.15226411819 4495.43963878601,3768.6518740654 PathPoint;PointKind.SMOOTHPOINT 4470.21762337673,3770.97421646118 4459.58891191523,3770.43157339096 4477.01497397653,3771.32095098495 PathPoint;PointKind.SMOOTHPOINT 4442.3684072176,3770.92276096344 4141.04224847891,3772.82661437988 4450.73789098767,3770.87012529373 PathPoint;PointKind.SMOOTHPOINT 3366.21184756829,3773.64305734634 2746.98012328212,3775.045337677 3761.45044074189,3772.74754285812 PathPoint;PointKind.SMOOTHPOINT 1647.4785280396,3774.81213569641 1644.21942872737,3774.80977535248 2091.50051499659,3775.07295370102 PathPoint;PointKind.SMOOTHPOINT 1638.91205179601,3774.85910654068 1637.84302661767,3775.18436193466 1640.46293134998,3774.38750982285 PathPoint;PointKind.SMOOTHPOINT 1630.76335186098,3774.8019862175 1319.28843272751,3774.61174249649 1633.08221656532,3774.80340242386 PathPoint;PointKind.SMOOTHPOINT 1109.62119065907,3774.20316696167 1081.14134481017,3773.8493514061 1116.01123314938,3774.28247451782 PathPoint;PointKind.SMOOTHPOINT 553.535863724415,3771.75147771835 543.771254513892,3771.53031349182 595.590108811073,3772.70364046097 PathPoint;PointKind.SMOOTHPOINT 484.765822942187,3771.07004642487 484.019408626277,3771.065325737 517.660711055787,3771.29522323608 PathPoint;PointKind.SMOOTHPOINT 482.516746231687,3771.05494022369 482.040919000975,3770.71363449097 482.69438839782,3771.18216276169 PathPoint;PointKind.SMOOTHPOINT 480.759992095898,3771.04290246964 391.99981491514,3770.44715166092 481.347162898596,3771.04667901993 PathPoint";
		
	negative645[2] = "PointKind.CORNERPOINT 258.1137692644,3769.92693185806 258.1137692644,3769.92693185806 258.1137692644,3769.92693185806 PathPoint;PointKind.CORNERPOINT 104.825392454137,3770.57579040527 104.825392454137,3770.57579040527 104.825392454137,3770.57579040527 PathPoint;PointKind.SMOOTHPOINT 117.737757404898,3690.38050889969 134.21533718631,3676.20475530624 95.9029974419742,3709.16483402252 PathPoint;PointKind.SMOOTHPOINT 233.161389285849,3651.99258327484 244.393132457735,3639.55899953842 218.068783963963,3668.70051383972 PathPoint;PointKind.SMOOTHPOINT 251.659648707019,3600.51961898804 252.608765423213,3576.13703012466 250.835198725271,3621.6633439064 PathPoint;PointKind.CORNERPOINT 252.669671308744,3502.80775308609 252.669671308744,3502.80775308609 252.669671308744,3502.80775308609 PathPoint;PointKind.SMOOTHPOINT 253.488728581877,3324.10068511963 253.762170630459,3279.12362337112 253.267627528672,3360.52622079849 PathPoint;PointKind.SMOOTHPOINT 252.972931863785,3105.54133415222 253.461765038803,3086.53608083725 252.712178541354,3115.67027807236 PathPoint;PointKind.SMOOTHPOINT 250.611559926836,2631.14336013794 250.419325725629,2606.12135410309 250.803794128044,2656.16442203522 PathPoint;PointKind.SMOOTHPOINT 254.054962986424,2035.00002622604 254.167258212872,1982.50833749771 253.942667759976,2087.49195098877 PathPoint;PointKind.SMOOTHPOINT 255.055786261689,1541.0001039505 255.244213845051,1494.62501049042 254.822313700486,1598.45866441727 PathPoint;PointKind.SMOOTHPOINT 255.560163126244,1246.22123479843 255.562700871474,1245.17890691757 255.340330945655,1328.64373683929 PathPoint;PointKind.SMOOTHPOINT 255.706083476996,1243.00007343292 256.199357706167,1241.78048372269 255.295603185968,1244.01525735855 PathPoint;PointKind.SMOOTHPOINT 255.579513433626,1239.26270484924 255.627096156697,1223.01032066345 255.575706815781,1240.52973747253 PathPoint;PointKind.SMOOTHPOINT 255.741611910222,1204.21797037125 256.10292338741,1165.95821142197 255.680388806537,1210.70183515549 PathPoint;PointKind.SMOOTHPOINT 255.435179173644,1074.36813354492 255.332717709964,1070.80637454987 255.649935863772,1081.81124210358 PathPoint;PointKind.SMOOTHPOINT 255.623923975159,1064.98411417007 255.571900197935,1061.48868083954 255.665479553308,1067.78041362762 PathPoint;PointKind.SMOOTHPOINT 256.634263795038,1056.36579036713 257.342929150646,1051.59341096878 256.213949741243,1059.19442653656 PathPoint;PointKind.SMOOTHPOINT 257.817487508743,1031.9355225563 258.186412221622,1019.66905117035 257.449514450326,1044.20175790787 PathPoint;PointKind.SMOOTHPOINT 257.44158399648,872.516005039215 257.325482152187,862.429075241089 257.581794420463,884.705293178558 PathPoint;PointKind.SMOOTHPOINT 256.632677704269,851.942539215088 257.177975710666,842.116663455963 256.43029252214,855.574400424957 PathPoint;PointKind.SMOOTHPOINT 256.568282419046,824.944217205048 256.252650356007,822.084188461304 257.031420923606,829.130523204803 PathPoint;PointKind.SMOOTHPOINT 256.638704849192,749.184494018555 256.639339285499,748.184888362885 256.623795595963,778.834426403046 PathPoint;PointKind.SMOOTHPOINT 256.639022067346,746.234300136566 256.92007735162,744.67883348465 256.41696935968,747.462151050568 PathPoint;PointKind.SMOOTHPOINT 256.633629358731,741.642487049103 256.612375742426,731.59214258194 256.636801540269,743.12029838562 PathPoint;PointKind.SMOOTHPOINT 256.325927749537,722.092938423157 255.235648954898,711.126780509949 256.527995713513,724.1273188591 PathPoint;PointKind.SMOOTHPOINT 251.052810378784,390.999941825867 250.099887044744,373.384459018707 252.00541649467,408.615424633026 PathPoint;PointKind.SMOOTHPOINT 240.209976663466,328.57191324234 235.807305906763,310.017721652985 244.61264742017,347.127048969269 PathPoint;PointKind.SMOOTHPOINT 226.447149842345,282.324042320251 209.357656242237,251.904637813568 232.840998950502,293.705148696899 PathPoint;PointKind.SMOOTHPOINT 123.403273631912,220.961472988129 121.978964121314,213.524973392487 124.82663148805,228.398916721344 PathPoint;PointKind.CORNERPOINT 122.655273225233,193.999972343445 122.655273225233,193.999972343445 122.655273225233,193.999972343445 PathPoint;PointKind.CORNERPOINT 264.565034858397,193.235692977905 264.565034858397,193.235692977905 264.565034858397,193.235692977905 PathPoint;PointKind.SMOOTHPOINT 913.728512483445,189.023423194885 938.200624177131,189.169056415558 889.25640078976,188.877789974213 PathPoint;PointKind.SMOOTHPOINT 2028.36680637123,187.492032051086 2060.39537170678,187.043330669403 1996.33792381752,187.941205501556 PathPoint;PointKind.SMOOTHPOINT 2452.86845701548,185.133576393127 2467.78881287985,184.737274646759 2431.93015555522,185.688965320587 PathPoint;PointKind.SMOOTHPOINT 3005.15573099459,185.672442913055 3006.04965175202,185.674095153809 2801.29548444977,185.314378738403 PathPoint;PointKind.SMOOTHPOINT 3007.83178334012,185.676927566528 3008.4760534105,185.896439552307 3006.07090536833,185.078108310699 PathPoint;PointKind.SMOOTHPOINT 3009.8673722331,185.680704116821 3041.22502117335,185.735464096069 3009.19011147472,185.679523944855 PathPoint;PointKind.SMOOTHPOINT 3092.61816870812,185.824685096741 3093.29194006681,185.825865268707 3069.36925021552,185.785267353058 PathPoint;PointKind.SMOOTHPOINT 3094.62711127619,185.827989578247 3095.29009721765,185.969610214233 3093.81566723874,185.655448436737 PathPoint;PointKind.SMOOTHPOINT 3096.64874257041,185.831530094147 3130.37061841098,185.888414382935 3095.97877782956,185.830585956573 PathPoint;PointKind.SMOOTHPOINT 3159.14103608877,185.920042991638 3183.63376696245,185.908005237579 3153.04632369965,185.923111438751 PathPoint;PointKind.SMOOTHPOINT 4489.60758302825,188.359458446503 4490.02091828266,188.359930515289 3961.02284950169,187.424762248993 PathPoint;PointKind.SMOOTHPOINT 4490.34606689032,188.663234710693 4490.67660820658,188.664178848267 4489.93304885406,188.662762641907 PathPoint;PointKind.SMOOTHPOINT 4491.83952995845,188.363234996796 4674.57146136888,188.685894012451 4491.50867142402,188.362526893616 PathPoint;PointKind.SMOOTHPOINT 4908.53793123717,189.034044742584 4909.06261006357,189.034516811371 4827.32120175397,188.938686847687 PathPoint;PointKind.SMOOTHPOINT 4910.10118229914,189.035696983337 4910.41840045295,188.904225826263 4909.03057103004,189.481093883514 PathPoint;PointKind.SMOOTHPOINT 4911.12547971779,189.036877155304 4947.93483984938,189.0793633461 4910.7854218569,189.036641120911 PathPoint;PointKind.SMOOTHPOINT 4971.3731375798,189.053635597229 4990.18005026463,188.732392787933 4969.3822764465,189.088096618652 PathPoint;PointKind.CORNERPOINT 5169.51933352008,189.000055789948 5169.51933352008,189.000055789948 5169.51933352008,189.000055789948 PathPoint;PointKind.SMOOTHPOINT 5174.99705660004,218.572096824646 5174.60148556224,222.713792324066 5175.39262763784,214.430637359619 PathPoint;PointKind.SMOOTHPOINT 5149.42419791264,236.737067699432 5140.2619859762,243.187415599823 5157.79843995502,230.842108726501 PathPoint;PointKind.SMOOTHPOINT 5061.0154984463,270.918388366699 5050.57806953155,284.054410457611 5075.20942473845,253.05624961853 PathPoint;PointKind.SMOOTHPOINT 5031.49168765322,329.255232810974 5027.73519027582,346.432163715363 5035.24818503062,312.077357769012 PathPoint;PointKind.SMOOTHPOINT 5025.05469687615,423.000068664551 5023.8600533089,449.193041324615 5026.24902322523,396.806623935699 PathPoint;PointKind.SMOOTHPOINT 5023.68304557908,600.912172794342 5024.08400932549,609.507601261139 5023.28239905082,592.316980361938 PathPoint;PointKind.SMOOTHPOINT 5024.96651022939,618.908143043518 5024.76222173833,624.362897872925 5025.1717503749,613.453860282898 PathPoint;PointKind.SMOOTHPOINT 5023.76583951722,635.624570846558 5023.93237904797,643.678772449493 5023.5977138957,627.570605278015 PathPoint;PointKind.SMOOTHPOINT 5025.37001172103,972.875468730927 5025.28309394689,991.229267120361 5025.43853084225,958.269424438477 PathPoint;PointKind.SMOOTHPOINT 5026.05520293326,2149.99999523163 5026.20968817416,2166.46008968353 5025.76177614098,2118.66312503815 PathPoint;PointKind.SMOOTHPOINT 5025.05437965799,2572.79140949249 5025.47754867517,2755.05622386932 5024.59060671712,2373.48821640015 PathPoint;PointKind.SMOOTHPOINT 5027.7079095146,2950.77240228653 5027.59942090599,2990.2746462822 5027.75929885551,2931.9033408165 PathPoint;PointKind.SMOOTHPOINT 5025.78112644837,3186.05148553848 5025.2259946792,3211.4133810997 5026.33562378122,3160.68888187408 PathPoint;PointKind.SMOOTHPOINT 5026.21159148308,3368.61181497574 5026.09104858464,3391.3010931015 5026.33213438153,3345.92348098755 PathPoint;PointKind.SMOOTHPOINT 5025.38745871949,3508.28965187073 5025.61712466285,3522.36886739731 5025.15779277613,3494.20972824097 PathPoint;PointKind.SMOOTHPOINT 5026.38859921291,3551.99991703033 5026.77148152456,3557.02485322952 5025.99524870219,3546.82462692261 PathPoint;PointKind.SMOOTHPOINT 5028.00990119702,3567.42264032364 5028.21641021515,3579.87628698349 5027.92108011396,3562.10549354553 PathPoint;PointKind.SMOOTHPOINT 5029.30510291902,3590.56109189987 5029.79583940296,3597.35746622086 5028.03115481333,3572.90430307388 PathPoint;PointKind.SMOOTHPOINT 5048.05713686324,3647.0823597908 5060.73888421618,3670.29492616653 5035.70656526287,3624.47262525558 PathPoint;PointKind.SMOOTHPOINT 5132.03239541195,3692.1620965004 5158.2086030279,3702.94178724289 5123.07732692995,3688.47382307053 PathPoint;PointKind.SMOOTHPOINT 5173.79892363311,3747.09933757782 5171.65230838629,3761.9725728035 5175.94458722546,3732.22657442093 PathPoint;PointKind.SMOOTHPOINT 5162.46345012492,3766.00002765656 5157.79526777348,3767.63975858688 5167.02377830407,3764.39829826355 PathPoint;PointKind.CORNERPOINT 5146.33607918532,3770.00010251999 5146.33607918532,3770.00010251999 5146.33607918532,3770.00010251999 PathPoint;PointKind.SMOOTHPOINT 4506.38683727393,3770.49270629883 4500.1569899513,3770.53684473038 4850.1888240257,3768.0412530899 PathPoint;PointKind.SMOOTHPOINT 4489.23612057014,3769.79333639145 4476.42177602891,3772.15226411819 4495.43963878601,3768.6518740654 PathPoint;PointKind.SMOOTHPOINT 4470.21762337673,3770.97421646118 4459.58891191523,3770.43157339096 4477.01497397653,3771.32095098495 PathPoint;PointKind.SMOOTHPOINT 4442.3684072176,3770.92276096344 4141.04224847891,3772.82661437988 4450.73789098767,3770.87012529373 PathPoint;PointKind.SMOOTHPOINT 3366.21184756829,3773.64305734634 2746.98012328212,3775.045337677 3761.45044074189,3772.74754285812 PathPoint;PointKind.SMOOTHPOINT 1647.4785280396,3774.81213569641 1644.21942872737,3774.80977535248 2091.50051499659,3775.07295370102 PathPoint;PointKind.SMOOTHPOINT 1638.91205179601,3774.85910654068 1637.84302661767,3775.18436193466 1640.46293134998,3774.38750982285 PathPoint;PointKind.SMOOTHPOINT 1630.76335186098,3774.8019862175 1319.28843272751,3774.61174249649 1633.08221656532,3774.80340242386 PathPoint;PointKind.SMOOTHPOINT 1109.62119065907,3774.20316696167 1081.14134481017,3773.8493514061 1116.01123314938,3774.28247451782 PathPoint;PointKind.SMOOTHPOINT 553.535863724415,3771.75147771835 543.771254513892,3771.53031349182 595.590108811073,3772.70364046097 PathPoint;PointKind.SMOOTHPOINT 484.765822942187,3771.07004642487 484.019408626277,3771.065325737 517.660711055787,3771.29522323608 PathPoint;PointKind.SMOOTHPOINT 482.516746231687,3771.05494022369 482.040919000975,3770.71363449097 482.69438839782,3771.18216276169 PathPoint;PointKind.SMOOTHPOINT 480.759992095898,3771.04290246964 458.420855268418,3770.89302062988 481.347162898596,3771.04667901993 PathPoint;PointKind.SMOOTHPOINT 408.021552209529,3770.61450004578 406.495732889712,3770.6064748764 433.223582875127,3770.747859478 PathPoint;PointKind.SMOOTHPOINT 403.445045904539,3770.59042453766 401.806614140119,3771.60372018814 404.739295972076,3769.79003190994 PathPoint;PointKind.SMOOTHPOINT 398.722302030642,3770.56587696075 327.010062871844,3770.19459486008 400.295386855377,3770.57413816452 PathPoint";

} else if (negative_variant_645 == 1 && fancy == true && mask_variant_645 == 3) {
		
	negative645[0] = "PointKind.CORNERPOINT 275.873050858708,3769.92693185806 275.873050858708,3769.92693185806 275.873050858708,3769.92693185806 PathPoint;PointKind.CORNERPOINT 181.795275353816,3770.57579040527 181.795275353816,3770.57579040527 181.795275353816,3770.57579040527 PathPoint;PointKind.SMOOTHPOINT 194.605674191088,3690.38050889969 210.953085769508,3676.20475530624 172.943349876458,3709.16483402252 PathPoint;PointKind.SMOOTHPOINT 251.117719120471,3651.99258327484 262.533790962671,3639.80943202972 239.70164727827,3664.17573451996 PathPoint;PointKind.SMOOTHPOINT 269.46973016497,3600.51961898804 270.411284459643,3576.13703012466 268.651858592742,3621.6633439064 PathPoint;PointKind.CORNERPOINT 270.471716777193,3502.80775308609 270.471716777193,3502.80775308609 270.471716777193,3502.80775308609 PathPoint;PointKind.SMOOTHPOINT 271.284265295542,3324.10068511963 271.555741043292,3279.12362337112 271.065080724119,3360.52622079849 PathPoint;PointKind.SMOOTHPOINT 270.772625881676,3105.54133415222 271.257650026155,3086.53608083725 270.513988087396,3115.67027807236 PathPoint;PointKind.SMOOTHPOINT 268.429855933972,2631.14336013794 268.239165356833,2606.12135410309 268.62054651111,2656.16442203522 PathPoint;PointKind.SMOOTHPOINT 271.846317160836,2035.00002622604 271.95747505063,1982.50833749771 271.734846150226,2087.49195098877 PathPoint;PointKind.SMOOTHPOINT 272.839223269386,1541.0001039505 273.070619552646,1483.54177951813 272.607513865309,1598.45866441727 PathPoint;PointKind.SMOOTHPOINT 273.519634803249,1204.21797037125 273.877845017118,1165.95821142197 273.162050831012,1242.47725725174 PathPoint;PointKind.SMOOTHPOINT 273.215594490602,1074.36813354492 273.002985456321,1066.92455291748 273.4285166457,1081.81124210358 PathPoint;PointKind.SMOOTHPOINT 274.405140471801,1056.36579036713 275.108096704439,1051.59341096878 273.605743027737,1061.78962469101 PathPoint;PointKind.SMOOTHPOINT 275.579030412184,1031.9355225563 275.945068646461,1019.66905117035 275.213931540355,1044.20175790787 PathPoint;PointKind.SMOOTHPOINT 275.206103519947,872.516005039215 275.090875059541,862.429075241089 275.345129162393,884.705293178558 PathPoint;PointKind.SMOOTHPOINT 274.403574867719,851.942539215088 274.94464763832,842.116663455963 274.202864424458,855.574400424957 PathPoint;PointKind.SMOOTHPOINT 274.33969822119,824.944217205048 273.881289346098,820.757911205292 274.799046458731,829.130523204803 PathPoint;PointKind.SMOOTHPOINT 274.099221434256,722.092938423157 273.017389013872,711.126780509949 274.882649716688,730.036203861237 PathPoint;PointKind.SMOOTHPOINT 268.867598835187,390.999941825867 267.922287090717,373.384459018707 269.812910579656,408.615424633026 PathPoint;PointKind.SMOOTHPOINT 258.110646311339,328.57191324234 253.742610923679,310.017721652985 262.478368578183,347.127048969269 PathPoint;PointKind.SMOOTHPOINT 244.456386874085,282.324042320251 237.443419950973,263.429725170135 251.469353797198,301.217887401581 PathPoint;PointKind.SMOOTHPOINT 200.226505964844,220.961472988129 198.813391720793,213.524973392487 201.638367725629,228.398916721344 PathPoint;PointKind.SMOOTHPOINT 201.269198283188,198.821682929993 205.300315672488,195.768105983734 197.238080893888,201.874551773071 PathPoint;PointKind.CORNERPOINT 282.273240344283,193.235692977905 282.273240344283,193.235692977905 282.273240344283,193.235692977905 PathPoint;PointKind.SMOOTHPOINT 926.309215854349,189.023423194885 950.587977710147,189.169056415558 902.030140877735,188.877789974213 PathPoint;PointKind.SMOOTHPOINT 2032.14328617233,187.492032051086 2063.91878661245,187.043330669403 2000.36715949057,187.941205501556 PathPoint;PointKind.SMOOTHPOINT 2453.29172348479,185.133576393127 2468.09419695549,184.737274646759 2432.51897540933,185.688965320587 PathPoint;PointKind.SMOOTHPOINT 3001.21651690879,185.672442913055 3002.10358818142,185.674095153809 2798.96677171482,185.314378738403 PathPoint;PointKind.SMOOTHPOINT 3003.87146831036,185.676927566528 3004.51086101729,185.896439552307 3002.12456727612,185.078108310699 PathPoint;PointKind.SMOOTHPOINT 3005.89109757563,185.680704116821 3037.00090316025,185.735464096069 3005.2191403038,185.679523944855 PathPoint;PointKind.SMOOTHPOINT 3087.98824440649,185.824685096741 3088.65675734933,185.825865268707 3064.92282571393,185.785267353058 PathPoint;PointKind.SMOOTHPOINT 3089.98125840237,185.827989578247 3090.63912523745,185.969610214233 3089.17622478361,185.655448436737 PathPoint;PointKind.SMOOTHPOINT 3091.98711035171,185.831530094147 3125.44250397139,185.888414382935 3091.32235485866,185.830585956573 PathPoint;PointKind.SMOOTHPOINT 3153.98565822465,185.920042991638 3178.28508605432,185.908005237579 3147.9389821407,185.923111438751 PathPoint;PointKind.SMOOTHPOINT 4473.94332821225,188.359458446503 4474.35320336081,188.359930515289 3949.53359497305,187.424762248993 PathPoint;PointKind.SMOOTHPOINT 4474.67571780162,188.663234710693 4475.00386841712,188.664178848267 4474.26615577387,188.662762641907 PathPoint;PointKind.SMOOTHPOINT 4476.15740550445,188.363234996796 4657.44621701234,188.685894012451 4475.82925488894,188.362526893616 PathPoint;PointKind.SMOOTHPOINT 4889.56455687504,189.034044742584 4890.08496367176,189.034516811371 4808.98917721149,188.938686847687 PathPoint;PointKind.SMOOTHPOINT 4891.11544427827,189.035696983337 4891.43013069867,188.904225826263 4890.05333846932,189.481093883514 PathPoint;PointKind.SMOOTHPOINT 4892.13152132723,189.036877155304 4928.65017589297,189.0793633461 4891.79429020805,189.036641120911 PathPoint;PointKind.SMOOTHPOINT 4951.90346707532,189.053635597229 4970.56171027818,188.732392787933 4949.92830096597,189.088096618652 PathPoint;PointKind.SMOOTHPOINT 5093.6138074004,190.919959545135 5097.23379715787,191.956150531769 5089.99319140129,189.883768558502 PathPoint;PointKind.SMOOTHPOINT 5097.91890550398,219.572174549103 5097.52656512113,223.713870048523 5098.31155900764,215.430715084076 PathPoint;PointKind.SMOOTHPOINT 5072.54797824086,237.737145423889 5063.45839406391,244.18749332428 5080.85632598108,231.842186450958 PathPoint;PointKind.SMOOTHPOINT 5040.83760693052,270.918388366699 5030.44731888259,284.0265583992 5050.62795549439,258.567888736725 PathPoint;PointKind.SMOOTHPOINT 5011.54703328871,329.255232810974 5007.82026933288,346.432163715363 5015.27379724455,312.077357769012 PathPoint;PointKind.SMOOTHPOINT 5005.16093423987,423.000068664551 5003.9757719501,449.193041324615 5006.34578340883,396.806623935699 PathPoint;PointKind.SMOOTHPOINT 5003.80011117215,600.912172794342 5004.19777460887,609.507601261139 5003.40276085624,592.316980361938 PathPoint;PointKind.SMOOTHPOINT 5005.07357353212,618.908143043518 5004.87067124314,624.362897872925 5005.27710206273,613.453860282898 PathPoint;PointKind.SMOOTHPOINT 5003.88214882602,635.624570846558 5004.04747661704,643.678772449493 5003.71556855174,627.570605278015 PathPoint;PointKind.SMOOTHPOINT 5005.47374193538,972.875468730927 5005.38763371089,991.229267120361 5005.54168915252,958.269424438477 PathPoint;PointKind.SMOOTHPOINT 5006.15352722761,2149.99999523163 5006.30664330679,2166.46008968353 5005.86232486843,2118.66312503815 PathPoint;PointKind.SMOOTHPOINT 5005.16062111906,2572.79140949249 5005.58051613374,2755.05622386932 5004.70064663988,2373.48821640015 PathPoint;PointKind.SMOOTHPOINT 5007.79302782186,2950.77240228653 5007.68562738186,2990.2746462822 5007.84406651492,2931.9033408165 PathPoint;PointKind.SMOOTHPOINT 5005.88173835904,3186.05148553848 5005.33095884313,3211.4133810997 5006.4315785125,3160.68888187408 PathPoint;PointKind.SMOOTHPOINT 5006.3088351525,3368.61181497574 5006.18922300067,3391.3010931015 5006.42813418352,3345.92348098755 PathPoint;PointKind.SMOOTHPOINT 5005.49096358027,3508.28965187073 5005.71891553455,3522.36886739731 5005.26332474681,3494.20972824097 PathPoint;PointKind.SMOOTHPOINT 5006.82454513698,3551.99802875519 5008.43836982429,3556.93091154099 5005.21165981212,3547.064909935 PathPoint;PointKind.SMOOTHPOINT 5008.09268444307,3567.42264032364 5008.29777857776,3579.87628698349 5008.00469749369,3562.10549354553 PathPoint;PointKind.SMOOTHPOINT 5009.37773227325,3590.56109189987 5009.86463514263,3597.35746622086 5008.11397665858,3572.90430307388 PathPoint;PointKind.SMOOTHPOINT 5027.98180557489,3647.0823597908 5040.56331309543,3670.29492616653 5015.72876179066,3624.47262525558 PathPoint;PointKind.SMOOTHPOINT 5054.29366089105,3689.16209936142 5073.43254454696,3713.01361083984 5048.27360007649,3681.65927410126 PathPoint;PointKind.SMOOTHPOINT 5095.7301909979,3744.09934043884 5093.6003432053,3758.97257566452 5097.85878630724,3729.22657728195 PathPoint;PointKind.SMOOTHPOINT 5080.94994910516,3760.2575469017 5076.31857911098,3761.89727783203 5085.47423178017,3758.6558175087 PathPoint;PointKind.CORNERPOINT 5056.32988555958,3764.1778421402 5056.32988555958,3764.1778421402 5056.32988555958,3764.1778421402 PathPoint;PointKind.SMOOTHPOINT 4490.58977017025,3770.49270629883 4484.40939149774,3770.53684473038 4831.67634595793,3768.0412530899 PathPoint;PointKind.SMOOTHPOINT 4473.57478501144,3769.79333639145 4460.86145362723,3772.15226411819 4479.72917465621,3768.6518740654 PathPoint;PointKind.SMOOTHPOINT 4454.70643774083,3770.97421646118 4444.16146800963,3770.43157339096 4461.45012076191,3771.32095098495 PathPoint;PointKind.SMOOTHPOINT 4427.07728315041,3770.92276096344 4128.13113306467,3772.82661437988 4435.38062095758,3770.87012529373 PathPoint;PointKind.SMOOTHPOINT 3359.42078148303,3773.64305734634 2745.08024483028,3775.045337677 3751.53759606879,3772.74754285812 PathPoint;PointKind.SMOOTHPOINT 1654.263448863,3774.81213569641 1651.03016331368,3774.80977535248 2094.77809554402,3775.07295370102 PathPoint;PointKind.SMOOTHPOINT 1645.76472366645,3774.85910654068 1644.70387034076,3775.18436193466 1647.30308623703,3774.38750982285 PathPoint;PointKind.SMOOTHPOINT 1637.68025730989,3774.8019862175 1328.66570737539,3774.61174249649 1639.98075594739,3774.80340242386 PathPoint;PointKind.SMOOTHPOINT 1120.65453916114,3774.20316696167 1092.3994560589,3773.8493514061 1126.99398320835,3774.28247451782 PathPoint;PointKind.SMOOTHPOINT 568.961649833554,3771.75147771835 559.274004897438,3771.53031349182 610.683746124891,3772.70364046097 PathPoint;PointKind.SMOOTHPOINT 500.734815803202,3771.07004642487 499.994285072606,3771.065325737 533.369832884125,3771.29522323608 PathPoint;PointKind.SMOOTHPOINT 498.503516866108,3771.05494022369 498.031330675098,3770.71363449097 498.67949076488,3771.18216276169 PathPoint;PointKind.SMOOTHPOINT 496.760373281656,3771.04290246964 408.701406108062,3770.44715166092 497.343091120827,3771.04667901993 PathPoint";
		
	negative645[1] = "PointKind.CORNERPOINT 275.87290763855,3769.92693185806 275.87290763855,3769.92693185806 275.87290763855,3769.92693185806 PathPoint;PointKind.CORNERPOINT 181.795263290405,3770.57579040527 181.795263290405,3770.57579040527 181.795263290405,3770.57579040527 PathPoint;PointKind.SMOOTHPOINT 194.60563659668,3690.38050889969 210.953063964844,3676.20475530624 172.943344116211,3709.16483402252 PathPoint;PointKind.SMOOTHPOINT 251.11762046814,3651.99258327484 263.834297699607,3642.93662128113 237.517943565829,3661.67764015527 PathPoint;PointKind.SMOOTHPOINT 270.440474744609,3588.46864181312 270.771186855655,3571.67024358863 270.02398501214,3609.6240822967 PathPoint;PointKind.SMOOTHPOINT 270.471811294556,3502.80775308609 270.471811294556,3502.80775308609 270.4808063037,3502.69608342269 PathPoint;PointKind.SMOOTHPOINT 271.284399032593,3324.10068511963 271.555681228638,3279.12362337112 271.065044403076,3360.52622079849 PathPoint;PointKind.SMOOTHPOINT 270.772676467896,3105.54133415222 271.011026090681,3096.20080530228 270.513982772827,3115.67027807236 PathPoint;PointKind.SMOOTHPOINT 269.886476453973,2876.38476882151 269.861678741338,2871.85901175913 270.495288970226,2987.49733737477 PathPoint;PointKind.SMOOTHPOINT 269.811664737107,2862.80205889926 270.223623418569,2861.41016332313 268.633775656902,2866.7818235545 PathPoint;PointKind.SMOOTHPOINT 269.700852861311,2842.92447494996 269.12082951375,2739.57911332947 269.737932235932,2849.53107345137 PathPoint;PointKind.SMOOTHPOINT 268.429956436157,2631.14336013794 268.239240646362,2606.12135410309 268.517525134299,2642.63198317653 PathPoint;PointKind.SMOOTHPOINT 271.846160888672,2035.00002622604 271.957569122314,1982.50833749771 271.734752655029,2087.49195098877 PathPoint;PointKind.SMOOTHPOINT 272.839078903198,1541.0001039505 273.070707321167,1483.54177951813 272.607450485229,1598.45866441727 PathPoint;PointKind.SMOOTHPOINT 273.519487380981,1204.21797037125 273.877944946289,1165.95821142197 273.161973953247,1242.47725725174 PathPoint;PointKind.SMOOTHPOINT 274,1085 273.787569046021,1077.55641937256 274.213060379028,1092.44310855865 PathPoint;PointKind.SMOOTHPOINT 274.405088424683,1056.36579036713 274.092126392695,1051.5520637244 274.992897714908,1065.41530648645 PathPoint;PointKind.SMOOTHPOINT 275.578966140747,1031.9355225563 275.944976806641,1019.66905117035 275.213899612427,1044.20175790787 PathPoint;PointKind.SMOOTHPOINT 275.206031799316,872.516005039215 275.152342418988,867.814333587688 275.345134735107,884.705293178558 PathPoint;PointKind.SMOOTHPOINT 274.339628219604,824.944217205048 273.881406784058,820.757911205292 275.388274217974,834.498387801152 PathPoint;PointKind.SMOOTHPOINT 274.099187850952,722.092938423157 273.017520904541,711.126780509949 274.882507324219,730.036203861237 PathPoint;PointKind.SMOOTHPOINT 268.867721557617,390.999941825867 267.922325134277,373.384459018707 269.812803268433,408.615424633026 PathPoint;PointKind.SMOOTHPOINT 262,333 257.632104873657,314.445808410645 266.367895126343,351.555135726929 PathPoint;PointKind.SMOOTHPOINT 244.456415176392,282.324042320251 237.443361282349,263.429725170135 251.469469070435,301.217887401581 PathPoint;PointKind.SMOOTHPOINT 200.226402282715,220.961472988129 198.813343048096,213.524973392487 201.638517379761,228.398916721344 PathPoint;PointKind.SMOOTHPOINT 201.269044876099,198.821682929993 205.300197601318,195.768105983734 197.238206863403,201.874551773071 PathPoint;PointKind.CORNERPOINT 282.273216247559,193.235692977905 282.273216247559,193.235692977905 282.273216247559,193.235692977905 PathPoint;PointKind.SMOOTHPOINT 926.309108734131,189.023423194885 950.587921142578,189.169056415558 902.030296325684,188.877789974213 PathPoint;PointKind.SMOOTHPOINT 2032.14314460754,187.492032051086 2063.91872406006,187.043330669403 2000.3672504425,187.941205501556 PathPoint;PointKind.SMOOTHPOINT 2453.29175949097,185.133576393127 2468.09426307678,184.737274646759 2432.51884460449,185.688965320587 PathPoint;PointKind.SMOOTHPOINT 3001.21665000916,185.672442913055 3002.10350990295,185.674095153809 2798.96664619446,185.314378738403 PathPoint;PointKind.SMOOTHPOINT 3003.87156486511,185.676927566528 3004.5107460022,185.896439552307 3002.12459564209,185.078108310699 PathPoint;PointKind.SMOOTHPOINT 3005.89107513428,185.680704116821 3037.00103759766,185.735464096069 3005.21916389465,185.679523944855 PathPoint;PointKind.SMOOTHPOINT 3087.98824310303,185.824685096741 3088.65669250488,185.825865268707 3064.92296218872,185.785267353058 PathPoint;PointKind.SMOOTHPOINT 3089.98131752014,185.827989578247 3090.63906669617,185.969610214233 3089.17628288269,185.655448436737 PathPoint;PointKind.SMOOTHPOINT 3091.98698043823,185.831530094147 3125.44249534607,185.888414382935 3091.32230758667,185.830585956573 PathPoint;PointKind.SMOOTHPOINT 3153.98566246033,185.920042991638 3178.28493118286,185.908005237579 3147.93909072876,185.923111438751 PathPoint;PointKind.SMOOTHPOINT 4473.94317626953,188.359458446503 4474.35324668884,188.359930515289 3949.53360557556,187.424762248993 PathPoint;PointKind.SMOOTHPOINT 4474.67582702637,188.663234710693 4475.00375747681,188.664178848267 4474.26607131958,188.662762641907 PathPoint;PointKind.SMOOTHPOINT 4476.15749359131,188.363234996796 4657.44606971741,188.685894012451 4475.82924842834,188.362526893616 PathPoint;PointKind.SMOOTHPOINT 4889.56449508667,189.034044742584 4890.08502960205,189.034516811371 4808.98927688599,188.938686847687 PathPoint;PointKind.SMOOTHPOINT 4891.11539840698,189.035696983337 4891.4301109314,188.904225826263 4890.05324363708,189.481093883514 PathPoint;PointKind.SMOOTHPOINT 4892.13160514832,189.036877155304 4928.65021705627,189.0793633461 4891.79423332214,189.036641120911 PathPoint;PointKind.SMOOTHPOINT 4951.90338134766,189.053635597229 4970.56174278259,188.732392787933 4949.92824554443,189.088096618652 PathPoint;PointKind.SMOOTHPOINT 5093.61371040344,190.919959545135 5097.23384857178,191.956150531769 5089.99325752258,189.883768558502 PathPoint;PointKind.SMOOTHPOINT 5097.91897773743,219.572174549103 5097.52653121948,223.713870048523 5098.31142425537,215.430715084076 PathPoint;PointKind.SMOOTHPOINT 5072.54811286926,237.737145423889 5063.45827102661,244.18749332428 5080.85620880127,231.842186450958 PathPoint;PointKind.SMOOTHPOINT 5040.8376789093,270.918388366699 5036.48109779489,276.414588552725 5050.6280708313,258.567888736725 PathPoint;PointKind.SMOOTHPOINT 5026.44149929886,293.385114449328 5024.98670351124,296.043272769121 5031.28356703043,284.537836545942 PathPoint;PointKind.SMOOTHPOINT 5023,302 5021.92347620336,304.169627249432 5024.35817216011,299.262738327574 PathPoint;PointKind.SMOOTHPOINT 5019.11404601247,308.013137597041 5015.63373043533,315.693971116911 5020.09332079567,305.851940885637 PathPoint;PointKind.SMOOTHPOINT 5011.54706954956,329.255232810974 5007.82024383545,346.432163715363 5012.86962411401,323.159246900435 PathPoint;PointKind.SMOOTHPOINT 5005.16092300415,423.000068664551 5003.97571563721,449.193041324615 5006.34581565857,396.806623935699 PathPoint;PointKind.SMOOTHPOINT 5003.80010604858,600.912172794342 5004.19790267944,609.507601261139 5003.40262413025,592.316980361938 PathPoint;PointKind.SMOOTHPOINT 5005.07343292236,618.908143043518 5004.87075805664,624.362897872925 5005.27705192566,613.453860282898 PathPoint;PointKind.SMOOTHPOINT 5003.88224601746,635.624570846558 5004.04747009277,643.678772449493 5003.71544837952,627.570605278015 PathPoint;PointKind.SMOOTHPOINT 5005.47374725342,972.875468730927 5005.42909152056,982.380172557773 5005.54172515869,958.269424438477 PathPoint;PointKind.SMOOTHPOINT 5005.68777768444,1587.4328338601 5005.68912239465,1590.05539656861 5005.53491989391,1289.31719759955 PathPoint;PointKind.SMOOTHPOINT 5006,1594 5007.33032434841,1596.18269786726 5004.63593383571,1591.76194105508 PathPoint;PointKind.SMOOTHPOINT 5005.69520758745,1601.84438447092 5005.83641996462,1874.25713566867 5005.69407683129,1599.66304312122 PathPoint;PointKind.SMOOTHPOINT 5006.15352630615,2149.99999523163 5006.30679130554,2166.46008968353 5006.01560169468,2135.15289540693 PathPoint;PointKind.SMOOTHPOINT 5005.16060829163,2572.79140949249 5005.58043479919,2755.05622386932 5004.70049858093,2373.48821640015 PathPoint;PointKind.SMOOTHPOINT 5007.79317855835,2950.77240228653 5007.685546875,2990.2746462822 5007.8441619873,2931.9033408165 PathPoint;PointKind.SMOOTHPOINT 5005.88161468506,3186.05148553848 5005.33086776733,3211.4133810997 5006.43173217773,3160.68888187408 PathPoint;PointKind.SMOOTHPOINT 5006.30867958069,3368.61181497574 5006.18908882141,3391.3010931015 5006.42827033997,3345.92348098755 PathPoint;PointKind.SMOOTHPOINT 5005.49105644226,3508.28965187073 5005.71890830994,3522.36886739731 5005.26320457458,3494.20972824097 PathPoint;PointKind.SMOOTHPOINT 5006.8244934082,3551.99802875519 5007.14979430447,3557.40460526121 5006.5137502278,3546.81724195935 PathPoint;PointKind.SMOOTHPOINT 5008.09278488159,3567.42264032364 5008.29766273499,3579.87628698349 5008.00466537476,3562.10549354553 PathPoint;PointKind.SMOOTHPOINT 5009.37775611877,3590.56109189987 5009.86461639404,3597.35746622086 5008.11387062073,3572.90430307388 PathPoint;PointKind.SMOOTHPOINT 5027.98167228699,3647.0823597908 5040.56324958801,3670.29492616653 5015.72865486145,3624.47262525558 PathPoint;PointKind.SMOOTHPOINT 5054.29352760315,3689.16209936142 5073.43245506287,3713.01361083984 5048.27370643616,3681.65927410126 PathPoint;PointKind.SMOOTHPOINT 5095.73015213013,3744.09934043884 5093.60049247742,3758.97257566452 5097.85886764526,3729.22657728195 PathPoint;PointKind.SMOOTHPOINT 5080.94999313354,3760.2575469017 5076.31868362427,3761.89727783203 5085.47430038452,3758.6558175087 PathPoint;PointKind.CORNERPOINT 5056.33003234863,3764.1778421402 5056.33003234863,3764.1778421402 5056.33003234863,3764.1778421402 PathPoint;PointKind.SMOOTHPOINT 4490.58989524841,3770.49270629883 4484.40925598145,3770.53684473038 4831.67627334595,3768.0412530899 PathPoint;PointKind.SMOOTHPOINT 4473.57464790344,3769.79333639145 4460.86152076721,3772.15226411819 4479.72916603088,3768.6518740654 PathPoint;PointKind.SMOOTHPOINT 4454.70637321472,3770.97421646118 4444.1616153717,3770.43157339096 4461.45003318787,3771.32095098495 PathPoint;PointKind.SMOOTHPOINT 4427.07713127136,3770.92276096344 4128.1310749054,3772.82661437988 4435.3805065155,3770.87012529373 PathPoint;PointKind.SMOOTHPOINT 3359.42087173462,3773.64305734634 2745.08030891418,3775.045337677 3751.53757095337,3772.74754285812 PathPoint;PointKind.SMOOTHPOINT 1654.26341056824,3774.81213569641 1651.03005409241,3774.80977535248 2094.778175354,3775.07295370102 PathPoint;PointKind.SMOOTHPOINT 1647,3773 1645.93941879272,3773.32525539398 1648.53862953186,3772.52840328217 PathPoint;PointKind.SMOOTHPOINT 1637.68026351929,3774.8019862175 1328.66560935974,3774.61174249649 1639.98081207275,3774.80340242386 PathPoint;PointKind.SMOOTHPOINT 1120.65447807312,3774.20316696167 1092.39958763123,3773.8493514061 1126.99404716492,3774.28247451782 PathPoint;PointKind.SMOOTHPOINT 568.961534500122,3771.75147771835 559.274053573608,3771.53031349182 610.683603286743,3772.70364046097 PathPoint;PointKind.SMOOTHPOINT 500.734691619873,3771.07004642487 499.994173049927,3771.065325737 533.369750976562,3771.29522323608 PathPoint;PointKind.SMOOTHPOINT 498.503379821777,3771.05494022369 498.031311035156,3770.71363449097 498.679618835449,3771.18216276169 PathPoint;PointKind.SMOOTHPOINT 496.760501861572,3771.04290246964 408.701419830322,3770.44715166092 497.343034744263,3771.04667901993 PathPoint";
		
	negative645[2] = "PointKind.CORNERPOINT 275.87290763855,3769.92693185806 275.87290763855,3769.92693185806 275.87290763855,3769.92693185806 PathPoint;PointKind.CORNERPOINT 181.795263290405,3770.57579040527 181.795263290405,3770.57579040527 181.795263290405,3770.57579040527 PathPoint;PointKind.SMOOTHPOINT 194.60563659668,3690.38050889969 210.953063964844,3676.20475530624 172.943344116211,3709.16483402252 PathPoint;PointKind.SMOOTHPOINT 251.11762046814,3651.99258327484 263.834297699607,3642.93662128113 237.517943565829,3661.67764015527 PathPoint;PointKind.SMOOTHPOINT 270.440474744609,3588.46864181312 270.771186855655,3571.67024358863 270.02398501214,3609.6240822967 PathPoint;PointKind.SMOOTHPOINT 270.471811294556,3502.80775308609 270.471811294556,3502.80775308609 270.4808063037,3502.69608342269 PathPoint;PointKind.SMOOTHPOINT 271.284399032593,3324.10068511963 271.555681228638,3279.12362337112 271.065044403076,3360.52622079849 PathPoint;PointKind.SMOOTHPOINT 270.772676467896,3105.54133415222 271.011026090681,3096.20080530228 270.513982772827,3115.67027807236 PathPoint;PointKind.SMOOTHPOINT 269.886476453973,2876.38476882151 269.861678741338,2871.85901175913 270.495288970226,2987.49733737477 PathPoint;PointKind.SMOOTHPOINT 269.811664737107,2862.80205889926 270.223623418569,2861.41016332313 268.633775656902,2866.7818235545 PathPoint;PointKind.SMOOTHPOINT 269.700852861311,2842.92447494996 269.57055020041,2819.70786536421 269.737932235932,2849.53107345137 PathPoint;PointKind.SMOOTHPOINT 269.312531229323,2775.13972148808 269.289249309269,2771.151914188 269.43907259368,2796.81416136998 PathPoint;PointKind.SMOOTHPOINT 268,2763 268.838142290281,2759.70697348283 266.834541653642,2767.57903781222 PathPoint;PointKind.SMOOTHPOINT 269.183830777631,2753.22225129286 268.803472234929,2688.81742840727 269.20345624168,2756.54536460362 PathPoint;PointKind.SMOOTHPOINT 268.429956436157,2631.14336013794 268.239240646362,2606.12135410309 268.491079525332,2639.16243710703 PathPoint;PointKind.SMOOTHPOINT 271.846160888672,2035.00002622604 271.957569122314,1982.50833749771 271.734752655029,2087.49195098877 PathPoint;PointKind.SMOOTHPOINT 272.839078903198,1541.0001039505 273.070707321167,1483.54177951813 272.607450485229,1598.45866441727 PathPoint;PointKind.SMOOTHPOINT 273.519487380981,1204.21797037125 273.877944946289,1165.95821142197 273.161973953247,1242.47725725174 PathPoint;PointKind.SMOOTHPOINT 274,1085 273.787569046021,1077.55641937256 274.213060379028,1092.44310855865 PathPoint;PointKind.SMOOTHPOINT 274.405088424683,1056.36579036713 274.092126392695,1051.5520637244 274.992897714908,1065.41530648645 PathPoint;PointKind.SMOOTHPOINT 275.578966140747,1031.9355225563 275.944976806641,1019.66905117035 275.213899612427,1044.20175790787 PathPoint;PointKind.SMOOTHPOINT 275.206031799316,872.516005039215 275.152342418988,867.814333587688 275.345134735107,884.705293178558 PathPoint;PointKind.SMOOTHPOINT 274.339628219604,824.944217205048 273.881406784058,820.757911205292 275.388274217974,834.498387801152 PathPoint;PointKind.SMOOTHPOINT 274.099187850952,722.092938423157 273.017520904541,711.126780509949 274.882507324219,730.036203861237 PathPoint;PointKind.SMOOTHPOINT 268.867721557617,390.999941825867 268.179186785876,378.170538060096 269.812803268433,408.615424633026 PathPoint;PointKind.SMOOTHPOINT 264.98138404991,348.699052570677 264.165802222941,343.324459025836 267.167605479127,363.106008675536 PathPoint;PointKind.SMOOTHPOINT 262,333 262.697292143517,326.79878893043 261.421218644633,338.146735940558 PathPoint;PointKind.SMOOTHPOINT 256.722505481003,314.792790702927 253.157741403923,304.359458422745 258.679023877648,320.519118197004 PathPoint;PointKind.SMOOTHPOINT 244.456415176392,282.324042320251 237.443361282349,263.429725170135 248.984327434293,294.522675616839 PathPoint;PointKind.SMOOTHPOINT 200.226402282715,220.961472988129 198.813343048096,213.524973392487 201.638517379761,228.398916721344 PathPoint;PointKind.SMOOTHPOINT 201.269044876099,198.821682929993 205.300197601318,195.768105983734 197.238206863403,201.874551773071 PathPoint;PointKind.CORNERPOINT 282.273216247559,193.235692977905 282.273216247559,193.235692977905 282.273216247559,193.235692977905 PathPoint;PointKind.SMOOTHPOINT 926.309108734131,189.023423194885 950.587921142578,189.169056415558 902.030296325684,188.877789974213 PathPoint;PointKind.SMOOTHPOINT 2032.14314460754,187.492032051086 2063.91872406006,187.043330669403 2000.3672504425,187.941205501556 PathPoint;PointKind.SMOOTHPOINT 2453.29175949097,185.133576393127 2468.09426307678,184.737274646759 2432.51884460449,185.688965320587 PathPoint;PointKind.SMOOTHPOINT 3001.21665000916,185.672442913055 3002.10350990295,185.674095153809 2798.96664619446,185.314378738403 PathPoint;PointKind.SMOOTHPOINT 3003.87156486511,185.676927566528 3004.5107460022,185.896439552307 3002.12459564209,185.078108310699 PathPoint;PointKind.SMOOTHPOINT 3005.89107513428,185.680704116821 3037.00103759766,185.735464096069 3005.21916389465,185.679523944855 PathPoint;PointKind.SMOOTHPOINT 3087.98824310303,185.824685096741 3088.65669250488,185.825865268707 3064.92296218872,185.785267353058 PathPoint;PointKind.SMOOTHPOINT 3089.98131752014,185.827989578247 3090.63906669617,185.969610214233 3089.17628288269,185.655448436737 PathPoint;PointKind.SMOOTHPOINT 3091.98698043823,185.831530094147 3125.44249534607,185.888414382935 3091.32230758667,185.830585956573 PathPoint;PointKind.SMOOTHPOINT 3153.98566246033,185.920042991638 3178.28493118286,185.908005237579 3147.93909072876,185.923111438751 PathPoint;PointKind.SMOOTHPOINT 4473.94317626953,188.359458446503 4474.35324668884,188.359930515289 3949.53360557556,187.424762248993 PathPoint;PointKind.SMOOTHPOINT 4474.67582702637,188.663234710693 4475.00375747681,188.664178848267 4474.26607131958,188.662762641907 PathPoint;PointKind.SMOOTHPOINT 4476.15749359131,188.363234996796 4657.44606971741,188.685894012451 4475.82924842834,188.362526893616 PathPoint;PointKind.SMOOTHPOINT 4889.56449508667,189.034044742584 4890.08502960205,189.034516811371 4808.98927688599,188.938686847687 PathPoint;PointKind.SMOOTHPOINT 4891.11539840698,189.035696983337 4891.4301109314,188.904225826263 4890.05324363708,189.481093883514 PathPoint;PointKind.SMOOTHPOINT 4892.13160514832,189.036877155304 4928.65021705627,189.0793633461 4891.79423332214,189.036641120911 PathPoint;PointKind.SMOOTHPOINT 4951.90338134766,189.053635597229 4970.56174278259,188.732392787933 4949.92824554443,189.088096618652 PathPoint;PointKind.SMOOTHPOINT 5093.61371040344,190.919959545135 5097.23384857178,191.956150531769 5089.99325752258,189.883768558502 PathPoint;PointKind.SMOOTHPOINT 5097.91897773743,219.572174549103 5097.52653121948,223.713870048523 5098.31142425537,215.430715084076 PathPoint;PointKind.SMOOTHPOINT 5072.54811286926,237.737145423889 5063.45827102661,244.18749332428 5080.85620880127,231.842186450958 PathPoint;PointKind.SMOOTHPOINT 5040.8376789093,270.918388366699 5036.48109779489,276.414588552725 5050.6280708313,258.567888736725 PathPoint;PointKind.SMOOTHPOINT 5026.44149929886,293.385114449328 5024.98670351124,296.043272769121 5031.28356703043,284.537836545942 PathPoint;PointKind.SMOOTHPOINT 5023,302 5021.92347620336,304.169627249432 5024.35817216011,299.262738327574 PathPoint;PointKind.SMOOTHPOINT 5019.11404601247,308.013137597041 5015.63373043533,315.693971116911 5020.09332079567,305.851940885637 PathPoint;PointKind.SMOOTHPOINT 5011.54706954956,329.255232810974 5007.82024383545,346.432163715363 5012.86962411401,323.159246900435 PathPoint;PointKind.SMOOTHPOINT 5005.16092300415,423.000068664551 5003.97571563721,449.193041324615 5006.34581565857,396.806623935699 PathPoint;PointKind.SMOOTHPOINT 5004,606 5004.39779663086,614.595428466797 5003.60251808167,597.404807567596 PathPoint;PointKind.SMOOTHPOINT 5007,621 5006.58150448859,626.442452467138 5007.2036190033,618.358059905524 PathPoint;PointKind.SMOOTHPOINT 5004,632 5004.16522407532,640.054201602936 5003.83320236206,623.946034431458 PathPoint;PointKind.SMOOTHPOINT 5005.47374725342,972.875468730927 5005.42909152056,982.380172557773 5005.54172515869,958.269424438477 PathPoint;PointKind.SMOOTHPOINT 5005.68777768444,1587.4328338601 5005.68912239465,1590.05539656861 5005.53491989391,1289.31719759955 PathPoint;PointKind.SMOOTHPOINT 5006,1594 5007.33032434841,1596.18269786726 5004.63593383571,1591.76194105508 PathPoint;PointKind.SMOOTHPOINT 5005.69520758745,1601.84438447092 5005.83641996462,1874.25713566867 5005.69407683129,1599.66304312122 PathPoint;PointKind.SMOOTHPOINT 5006.15352630615,2149.99999523163 5006.30679130554,2166.46008968353 5006.01560169468,2135.15289540693 PathPoint;PointKind.SMOOTHPOINT 5005.16060829163,2572.79140949249 5005.58043479919,2755.05622386932 5004.70049858093,2373.48821640015 PathPoint;PointKind.SMOOTHPOINT 5007.79317855835,2950.77240228653 5007.685546875,2990.2746462822 5007.8441619873,2931.9033408165 PathPoint;PointKind.SMOOTHPOINT 5005.88161468506,3186.05148553848 5005.33086776733,3211.4133810997 5006.43173217773,3160.68888187408 PathPoint;PointKind.SMOOTHPOINT 5006.30867958069,3368.61181497574 5006.18908882141,3391.3010931015 5006.42827033997,3345.92348098755 PathPoint;PointKind.SMOOTHPOINT 5005.49105644226,3508.28965187073 5005.71890830994,3522.36886739731 5005.26320457458,3494.20972824097 PathPoint;PointKind.SMOOTHPOINT 5006.8244934082,3551.99802875519 5007.14979430447,3557.40460526121 5006.5137502278,3546.81724195935 PathPoint;PointKind.SMOOTHPOINT 5008.09278488159,3567.42264032364 5012.300107263,3578.81824992602 5006.25031502402,3562.43414157839 PathPoint;PointKind.SMOOTHPOINT 5009.37775611877,3590.56109189987 5009.86461639404,3597.35746622086 5008.11387062073,3572.90430307388 PathPoint;PointKind.SMOOTHPOINT 5027.98167228699,3647.0823597908 5040.56324958801,3670.29492616653 5015.72865486145,3624.47262525558 PathPoint;PointKind.SMOOTHPOINT 5054.29352760315,3689.16209936142 5073.43245506287,3713.01361083984 5048.27370643616,3681.65927410126 PathPoint;PointKind.SMOOTHPOINT 5095.73015213013,3744.09934043884 5093.60049247742,3758.97257566452 5097.85886764526,3729.22657728195 PathPoint;PointKind.SMOOTHPOINT 5080.94999313354,3760.2575469017 5076.31868362427,3761.89727783203 5085.47430038452,3758.6558175087 PathPoint;PointKind.CORNERPOINT 5056.33003234863,3764.1778421402 5056.33003234863,3764.1778421402 5056.33003234863,3764.1778421402 PathPoint;PointKind.SMOOTHPOINT 4490.58989524841,3770.49270629883 4484.40925598145,3770.53684473038 4831.67627334595,3768.0412530899 PathPoint;PointKind.SMOOTHPOINT 4473.57464790344,3769.79333639145 4460.86152076721,3772.15226411819 4479.72916603088,3768.6518740654 PathPoint;PointKind.SMOOTHPOINT 4454.70637321472,3770.97421646118 4444.1616153717,3770.43157339096 4461.45003318787,3771.32095098495 PathPoint;PointKind.SMOOTHPOINT 4427.07713127136,3770.92276096344 4128.1310749054,3772.82661437988 4435.3805065155,3770.87012529373 PathPoint;PointKind.SMOOTHPOINT 3359.42087173462,3773.64305734634 2745.08030891418,3775.045337677 3751.53757095337,3772.74754285812 PathPoint;PointKind.SMOOTHPOINT 1654.26341056824,3774.81213569641 1651.03005409241,3774.80977535248 2094.778175354,3775.07295370102 PathPoint;PointKind.SMOOTHPOINT 1647,3773 1645.93941879272,3773.32525539398 1648.53862953186,3772.52840328217 PathPoint;PointKind.SMOOTHPOINT 1637.68026351929,3774.8019862175 1328.66560935974,3774.61174249649 1639.98081207275,3774.80340242386 PathPoint;PointKind.SMOOTHPOINT 1120.65447807312,3774.20316696167 1092.39958763123,3773.8493514061 1126.99404716492,3774.28247451782 PathPoint;PointKind.SMOOTHPOINT 568.961534500122,3771.75147771835 559.274053573608,3771.53031349182 610.683603286743,3772.70364046097 PathPoint;PointKind.SMOOTHPOINT 500.734691619873,3771.07004642487 499.994173049927,3771.065325737 533.369750976562,3771.29522323608 PathPoint;PointKind.SMOOTHPOINT 498.503379821777,3771.05494022369 498.031311035156,3770.71363449097 498.679618835449,3771.18216276169 PathPoint;PointKind.SMOOTHPOINT 496.760501861572,3771.04290246964 408.701419830322,3770.44715166092 497.343034744263,3771.04667901993 PathPoint";
		
} else if (negative_variant_645 == 1 && fancy == true && mask_variant_645 == 2) {
		
	negative645[0] = "PointKind.CORNERPOINT 278.775682641115,3769.92693185806 278.775682641115,3769.92693185806 278.775682641115,3769.92693185806 PathPoint;PointKind.CORNERPOINT 184.793501473282,3770.57579040527 184.793501473282,3770.57579040527 184.793501473282,3770.57579040527 PathPoint;PointKind.SMOOTHPOINT 197.590948882354,3690.38050889969 213.921546914085,3676.20475530624 175.950635446771,3709.16483402252 PathPoint;PointKind.SMOOTHPOINT 254.045501308106,3651.99258327484 265.449729842031,3639.80943202972 242.640960603248,3664.17573451996 PathPoint;PointKind.SMOOTHPOINT 272.378675876712,3600.51961898804 273.31924689863,3576.13703012466 271.561724544366,3621.6633439064 PathPoint;PointKind.CORNERPOINT 273.379808059683,3502.80775308609 273.379808059683,3502.80775308609 273.379808059683,3502.80775308609 PathPoint;PointKind.SMOOTHPOINT 274.191452486164,3324.10068511963 274.462729027169,3279.12362337112 273.972620661948,3360.52622079849 PathPoint;PointKind.SMOOTHPOINT 273.680428668414,3105.54133415222 274.164917956837,3086.53608083725 273.421951135674,3115.67027807236 PathPoint;PointKind.SMOOTHPOINT 271.34008318175,2631.14336013794 271.149346741527,2606.12135410309 271.53050745104,2656.16442203522 PathPoint;PointKind.SMOOTHPOINT 271.174320416188,2034.60230827332 271.285141097496,1982.11061954498 271.062875393013,2087.09423303604 PathPoint;PointKind.SMOOTHPOINT 270.016166253786,1539.63063240051 270.247484915333,1482.17230796814 269.784847592239,1597.08919286728 PathPoint;PointKind.SMOOTHPOINT 270.472872329148,1209.21788692474 270.8309323896,1170.95812797546 270.115748781497,1247.47717380524 PathPoint;PointKind.SMOOTHPOINT 270.169130011084,1079.36805009842 269.956853776466,1071.92446947098 270.382030587569,1086.81115865707 PathPoint;PointKind.SMOOTHPOINT 271.357564754012,1061.36570692062 272.059949353852,1056.59332752228 270.559031506728,1066.78954124451 PathPoint;PointKind.SMOOTHPOINT 272.530390950277,1036.9354391098 272.895943113127,1024.66896772385 272.165463129294,1049.20167446136 PathPoint;PointKind.SMOOTHPOINT 272.157658855963,877.515921592712 272.042779952522,867.428991794586 272.296574921264,889.705209732056 PathPoint;PointKind.SMOOTHPOINT 273.339850180226,856.942455768585 273.880530236635,847.11658000946 273.139436441071,860.574316978455 PathPoint;PointKind.SMOOTHPOINT 273.27616730984,829.944133758545 272.818212550745,825.757827758789 273.735058581735,834.130439758301 PathPoint;PointKind.SMOOTHPOINT 273.035795691228,727.092854976654 271.955059920276,716.126697063446 273.818408220916,735.036120414734 PathPoint;PointKind.SMOOTHPOINT 271.017298436757,390.257849693298 270.07298136364,372.642366886139 271.961927680808,407.873332500458 PathPoint;PointKind.SMOOTHPOINT 261.031262452641,328.57191324234 256.667737147506,310.017721652985 265.394475586843,347.127048969269 PathPoint;PointKind.SMOOTHPOINT 247.390953523762,282.324042320251 240.384901268565,263.429725170135 254.396693608026,301.217887401581 PathPoint;PointKind.SMOOTHPOINT 203.205967458936,220.961472988129 201.794330498726,213.524973392487 204.616355735414,228.398916721344 PathPoint;PointKind.SMOOTHPOINT 204.247681863231,198.821682929993 208.27468690231,195.768105983734 200.220676824153,201.874551773071 PathPoint;PointKind.CORNERPOINT 285.169255525253,193.235692977905 285.169255525253,193.235692977905 285.169255525253,193.235692977905 PathPoint;PointKind.SMOOTHPOINT 928.550427268737,189.023423194885 952.804547928522,189.169056415558 904.295994438019,188.877789974213 PathPoint;PointKind.SMOOTHPOINT 2033.26030155415,187.492032051086 2065.00340290289,187.043330669403 2001.51657586355,187.941205501556 PathPoint;PointKind.SMOOTHPOINT 2453.98056041364,185.133576393127 2468.76809752226,184.737274646759 2433.22899762505,185.688965320587 PathPoint;PointKind.SMOOTHPOINT 3001.34825472656,185.672442913055 3002.23450800609,185.674095153809 2799.30404678798,185.314378738403 PathPoint;PointKind.SMOOTHPOINT 3004.00045897555,185.676927566528 3004.639160705,185.896439552307 3002.25542345861,185.078108310699 PathPoint;PointKind.SMOOTHPOINT 3006.01801971722,185.680704116821 3037.09619697811,185.735464096069 3005.34685221071,185.679523944855 PathPoint;PointKind.SMOOTHPOINT 3088.03187947473,185.824685096741 3088.69961310097,185.825865268707 3064.9899185488,185.785267353058 PathPoint;PointKind.SMOOTHPOINT 3090.02290568707,185.827989578247 3090.68002550159,185.969610214233 3089.21844119205,185.655448436737 PathPoint;PointKind.SMOOTHPOINT 3092.02641873674,185.831530094147 3125.44806319363,185.888414382935 3091.3624311617,185.830585956573 PathPoint;PointKind.SMOOTHPOINT 3153.96206840871,185.920042991638 3178.23679235009,185.908005237579 3147.92156085009,185.923111438751 PathPoint;PointKind.SMOOTHPOINT 4472.57770958386,188.359458446503 4472.9872778483,188.359930515289 3948.70119016984,187.424762248993 PathPoint;PointKind.SMOOTHPOINT 4473.30943825142,188.663234710693 4473.63721773135,188.664178848267 4472.90018215792,188.662762641907 PathPoint;PointKind.SMOOTHPOINT 4474.78975281695,188.363234996796 4655.89415889419,188.685894012451 4474.46166116609,188.362526893616 PathPoint;PointKind.SMOOTHPOINT 4887.77660114674,189.034044742584 4888.29636575062,189.034516811371 4807.28301383422,188.938686847687 PathPoint;PointKind.SMOOTHPOINT 4889.32590548852,189.035696983337 4889.64026161832,188.904225826263 4888.26483648636,189.481093883514 PathPoint;PointKind.SMOOTHPOINT 4890.34077319256,189.036877155304 4926.82231713728,189.0793633461 4890.00394075557,189.036641120911 PathPoint;PointKind.SMOOTHPOINT 4950.0518927941,189.053635597229 4968.69130704823,188.732392787933 4948.07897249588,189.088096618652 PathPoint;PointKind.SMOOTHPOINT 5091.61828931904,190.919959545135 5095.23447740995,191.956150531769 5088.00147688627,189.883768558502 PathPoint;PointKind.SMOOTHPOINT 5095.91906826659,219.572174549103 5095.52698157442,223.713870048523 5096.31115495877,215.430715084076 PathPoint;PointKind.SMOOTHPOINT 5070.57391019506,237.737145423889 5061.49348208833,244.18749332428 5078.87391096863,231.842186450958 PathPoint;PointKind.SMOOTHPOINT 5038.89574040044,270.918388366699 5028.51605686948,284.0265583992 5048.67605573953,258.567888736725 PathPoint;PointKind.SMOOTHPOINT 5009.635022313,329.255232810974 5005.91207176292,346.432163715363 5013.35797286308,312.077357769012 PathPoint;PointKind.SMOOTHPOINT 4996.97305708896,423.431067466736 4995.78930491003,449.624040126801 4998.15680926789,397.237622737885 PathPoint;PointKind.SMOOTHPOINT 4994.95237463796,601.912250518799 4995.34945606507,610.507678985596 4994.55529321085,593.317058086395 PathPoint;PointKind.SMOOTHPOINT 4996.224471191,619.908220767975 4996.02187225531,625.362975597382 4996.42769446855,614.453938007355 PathPoint;PointKind.SMOOTHPOINT 4995.03416342247,636.624648571014 4995.19930184617,644.67885017395 4994.86777631504,628.570683002472 PathPoint;PointKind.SMOOTHPOINT 4996.62404998557,973.875546455383 4996.53820297893,992.229344844818 4996.69210324903,959.269502162933 PathPoint;PointKind.SMOOTHPOINT 5001.03783481097,2151.10392808914 5001.19079856826,2167.56402254105 5000.74689150117,2119.76705789566 PathPoint;PointKind.SMOOTHPOINT 5003.25487277899,2572.79140949249 5003.6744305133,2755.05622386932 5002.79535716523,2373.48821640015 PathPoint;PointKind.SMOOTHPOINT 5002.908675214,2950.77240228653 5002.80160058389,2990.2746462822 5002.95987124706,2931.9033408165 PathPoint;PointKind.SMOOTHPOINT 5000.99943778617,3186.05148553848 5000.44939260177,3211.4133810997 5001.54885862871,3160.68888187408 PathPoint;PointKind.SMOOTHPOINT 5001.42617545194,3368.61181497574 5001.3066139845,3391.3010931015 5001.54542474845,3345.92348098755 PathPoint;PointKind.SMOOTHPOINT 5003.58514962638,3508.28965187073 5003.81272223673,3522.36886739731 5003.35757701603,3494.20972824097 PathPoint;PointKind.SMOOTHPOINT 5004.91718299861,3551.99802875519 5006.52954586891,3556.93091154099 5003.30606881205,3547.064909935 PathPoint;PointKind.SMOOTHPOINT 5006.18397264579,3567.42264032364 5006.38906894894,3579.87628698349 5006.09625261354,3562.10549354553 PathPoint;PointKind.SMOOTHPOINT 5007.46793169429,3590.56109189987 5007.95429400832,3597.35746622086 5006.20551244018,3572.90430307388 PathPoint;PointKind.SMOOTHPOINT 5026.05302820604,3647.0823597908 5038.62165432103,3670.29492616653 5013.81249374191,3624.47262525558 PathPoint;PointKind.SMOOTHPOINT 5052.33813295763,3689.16209936142 5071.45766610712,3713.01361083984 5046.32415992834,3681.65927410126 PathPoint;PointKind.SMOOTHPOINT 5093.73262305003,3744.09934043884 5091.60486596891,3758.97257566452 5095.85881927647,3729.22657728195 PathPoint;PointKind.SMOOTHPOINT 5078.96725007767,3760.2575469017 5074.3405646758,3761.89727783203 5083.48686084944,3758.6558175087 PathPoint;PointKind.CORNERPOINT 5054.37223875876,3764.1778421402 5054.37223875876,3764.1778421402 5054.37223875876,3764.1778421402 PathPoint;PointKind.SMOOTHPOINT 4489.20736736965,3770.49270629883 4483.0332506516,3770.53684473038 4829.9472479309,3768.0412530899 PathPoint;PointKind.SMOOTHPOINT 4472.20966005354,3769.79333639145 4459.50929780471,3772.15226411819 4478.35786658414,3768.6518740654 PathPoint;PointKind.SMOOTHPOINT 4453.36046693225,3770.97421646118 4442.82625878933,3770.43157339096 4460.09742784298,3771.32095098495 PathPoint;PointKind.SMOOTHPOINT 4425.75924952604,3770.92276096344 4127.11718016982,3772.82661437988 4434.05425556467,3770.87012529373 PathPoint;PointKind.SMOOTHPOINT 3359.18823467003,3773.64305734634 2745.47235454349,3775.045337677 3750.90656514575,3772.74754285812 PathPoint;PointKind.SMOOTHPOINT 1655.76447879784,3774.81213569641 1652.53475832232,3774.80977535248 2095.83153124624,3775.07295370102 PathPoint;PointKind.SMOOTHPOINT 1647.27436592592,3774.85910654068 1646.21485777843,3775.18436193466 1648.81118343037,3774.38750982285 PathPoint;PointKind.SMOOTHPOINT 1639.1981917115,3774.8019862175 1330.49797488559,3774.61174249649 1641.49639412217,3774.80340242386 PathPoint;PointKind.SMOOTHPOINT 1122.69827145046,3774.20316696167 1094.47177566491,3773.8493514061 1129.03128317354,3774.28247451782 PathPoint;PointKind.SMOOTHPOINT 571.566107853336,3771.75147771835 561.888496751283,3771.53031349182 613.245922178734,3772.70364046097 PathPoint;PointKind.SMOOTHPOINT 503.408579310528,3771.07004642487 502.66904636963,3771.065325737 536.010462896669,3771.29522323608 PathPoint;PointKind.SMOOTHPOINT 501.179678847037,3771.05494022369 500.707988566879,3770.71363449097 501.355431082464,3771.18216276169 PathPoint;PointKind.SMOOTHPOINT 499.438389381302,3771.04290246964 411.468932559027,3770.44715166092 500.020588171836,3771.04667901993 PathPoint";
		
	negative645[1] = "PointKind.CORNERPOINT 278.775682641115,3769.92693185806 278.775682641115,3769.92693185806 278.775682641115,3769.92693185806 PathPoint;PointKind.CORNERPOINT 184.793501473282,3770.57579040527 184.793501473282,3770.57579040527 184.793501473282,3770.57579040527 PathPoint;PointKind.SMOOTHPOINT 197.590948882354,3690.38050889969 213.921546914085,3676.20475530624 175.950635446771,3709.16483402252 PathPoint;PointKind.SMOOTHPOINT 254.045501308106,3651.99258327484 265.449729842031,3639.80943202972 242.640960603248,3664.17573451996 PathPoint;PointKind.SMOOTHPOINT 272.378675876712,3600.51961898804 273.31924689863,3576.13703012466 271.561724544366,3621.6633439064 PathPoint;PointKind.CORNERPOINT 273.379808059683,3502.80775308609 273.379808059683,3502.80775308609 273.379808059683,3502.80775308609 PathPoint;PointKind.SMOOTHPOINT 274.191452486164,3324.10068511963 274.462729027169,3279.12362337112 273.972620661948,3360.52622079849 PathPoint;PointKind.SMOOTHPOINT 273.680428668414,3105.54133415222 274.164917956837,3086.53608083725 273.421951135674,3115.67027807236 PathPoint;PointKind.SMOOTHPOINT 271.34008318175,2631.14336013794 271.149346741527,2606.12135410309 271.53050745104,2656.16442203522 PathPoint;PointKind.SMOOTHPOINT 276.13378003292,2033.60223054886 276.244912885161,1981.11054182053 276.022647180679,2086.09415531158 PathPoint;PointKind.SMOOTHPOINT 274.975625870518,1538.63055467606 275.206944532065,1481.17223024368 274.744307208971,1596.08935117722 PathPoint;PointKind.SMOOTHPOINT 275.432644116814,1208.21804523468 275.790704177265,1169.95805025101 275.075208398229,1246.47709608078 PathPoint;PointKind.SMOOTHPOINT 275.128589627816,1078.36797237396 274.916313393198,1070.92462778091 275.341802375234,1085.81131696701 PathPoint;PointKind.SMOOTHPOINT 276.317024370745,1060.36562919617 277.019408970584,1055.59324979782 275.518491123461,1065.78946352005 PathPoint;PointKind.SMOOTHPOINT 277.490162737943,1035.93536138535 277.855402729859,1023.66888999939 277.124922746026,1048.20159673691 PathPoint;PointKind.SMOOTHPOINT 277.117118472695,876.515843868256 277.002551740188,866.429150104523 277.256034537996,888.705132007599 PathPoint;PointKind.SMOOTHPOINT 278.299309796958,855.942614078522 278.840302024301,846.116738319397 278.099208228737,859.574239253998 PathPoint;PointKind.SMOOTHPOINT 278.235626926572,828.944056034088 277.77798433841,824.757750034332 278.694518198467,833.130362033844 PathPoint;PointKind.SMOOTHPOINT 277.995567478894,726.092777252197 276.914831707941,715.126619338989 278.778180008582,734.036042690277 PathPoint;PointKind.SMOOTHPOINT 275.977070224422,389.257771968842 275.032440980372,371.642289161682 276.92138729754,406.873254776001 PathPoint;PointKind.SMOOTHPOINT 261.031262452641,328.57191324234 256.667737147506,310.017721652985 265.394475586843,347.127048969269 PathPoint;PointKind.SMOOTHPOINT 247.390953523762,282.324042320251 240.384901268565,263.429725170135 254.396693608026,301.217887401581 PathPoint;PointKind.SMOOTHPOINT 203.205967458936,220.961472988129 201.794330498726,213.524973392487 204.616355735414,228.398916721344 PathPoint;PointKind.SMOOTHPOINT 204.247681863231,198.821682929993 208.27468690231,195.768105983734 200.220676824153,201.874551773071 PathPoint;PointKind.CORNERPOINT 285.169255525253,193.235692977905 285.169255525253,193.235692977905 285.169255525253,193.235692977905 PathPoint;PointKind.SMOOTHPOINT 928.550427268737,189.023423194885 952.804547928522,189.169056415558 904.295994438019,188.877789974213 PathPoint;PointKind.SMOOTHPOINT 2033.26030155415,187.492032051086 2065.00340290289,187.043330669403 2001.51657586355,187.941205501556 PathPoint;PointKind.SMOOTHPOINT 2453.98056041364,185.133576393127 2468.76809752226,184.737274646759 2433.22899762505,185.688965320587 PathPoint;PointKind.SMOOTHPOINT 3001.34825472656,185.672442913055 3002.23450800609,185.674095153809 2799.30404678798,185.314378738403 PathPoint;PointKind.SMOOTHPOINT 3004.00045897555,185.676927566528 3004.639160705,185.896439552307 3002.25542345861,185.078108310699 PathPoint;PointKind.SMOOTHPOINT 3006.01801971722,185.680704116821 3037.09619697811,185.735464096069 3005.34685221071,185.679523944855 PathPoint;PointKind.SMOOTHPOINT 3088.03187947473,185.824685096741 3088.69961310097,185.825865268707 3064.9899185488,185.785267353058 PathPoint;PointKind.SMOOTHPOINT 3090.02290568707,185.827989578247 3090.68002550159,185.969610214233 3089.21844119205,185.655448436737 PathPoint;PointKind.SMOOTHPOINT 3092.02641873674,185.831530094147 3125.44806319363,185.888414382935 3091.3624311617,185.830585956573 PathPoint;PointKind.SMOOTHPOINT 3153.96206840871,185.920042991638 3178.23679235009,185.908005237579 3147.92156085009,185.923111438751 PathPoint;PointKind.SMOOTHPOINT 4470.59199027738,187.999978065491 4471.00124637089,188.000450134277 3946.71515869242,187.065517902374 PathPoint;PointKind.SMOOTHPOINT 4472.57583655826,189.999897480011 4474.35926909998,189.394705295563 4472.18812025915,190.132312774658 PathPoint;PointKind.SMOOTHPOINT 4474.78975281695,188.363234996796 4655.89415889419,188.685894012451 4474.46166116609,188.362526893616 PathPoint;PointKind.SMOOTHPOINT 4887.77660114674,189.034044742584 4888.29636575062,189.034516811371 4807.28301383422,188.938686847687 PathPoint;PointKind.SMOOTHPOINT 4889.32590548852,189.035696983337 4889.64026161832,188.904225826263 4888.26483648636,189.481093883514 PathPoint;PointKind.SMOOTHPOINT 4890.34077319256,189.036877155304 4926.82231713728,189.0793633461 4890.00394075557,189.036641120911 PathPoint;PointKind.SMOOTHPOINT 4950.0518927941,189.053635597229 4968.69130704823,188.732392787933 4948.07897249588,189.088096618652 PathPoint;PointKind.SMOOTHPOINT 5091.61828931904,190.919959545135 5095.23447740995,191.956150531769 5088.00147688627,189.883768558502 PathPoint;PointKind.SMOOTHPOINT 5095.91906826659,219.572174549103 5095.52698157442,223.713870048523 5096.31115495877,215.430715084076 PathPoint;PointKind.SMOOTHPOINT 5070.57391019506,237.737145423889 5061.49348208833,244.18749332428 5078.87391096863,231.842186450958 PathPoint;PointKind.SMOOTHPOINT 5038.89574040044,270.918388366699 5028.51605686948,284.0265583992 5048.67605573953,258.567888736725 PathPoint;PointKind.SMOOTHPOINT 5009.635022313,329.255232810974 5005.91207176292,346.432163715363 5013.35797286308,312.077357769012 PathPoint;PointKind.SMOOTHPOINT 5000.94074965072,422.430989742279 4999.75699747179,448.624198436737 5002.12450182965,396.237781047821 PathPoint;PointKind.SMOOTHPOINT 4998.92006719972,600.912172794342 4999.31714862683,609.507601261139 4998.52298577261,592.317216396332 PathPoint;PointKind.SMOOTHPOINT 5000.19216375276,618.908143043518 4999.98956481707,624.363133907318 5000.39538703031,613.453860282898 PathPoint;PointKind.SMOOTHPOINT 4999.00185598423,635.624570846558 4999.16699440793,643.678772449493 4998.8354688768,627.570841312408 PathPoint;PointKind.SMOOTHPOINT 5000.59174254733,972.875468730927 5000.50589554069,991.229267120361 5000.65979581078,958.26966047287 PathPoint;PointKind.SMOOTHPOINT 5001.03783481097,2151.10392808914 5001.19079856826,2167.56402254105 5000.74689150117,2119.76705789566 PathPoint;PointKind.SMOOTHPOINT 5003.25487277899,2572.79140949249 5003.6744305133,2755.05622386932 5002.79535716523,2373.48821640015 PathPoint;PointKind.SMOOTHPOINT 5002.908675214,2950.77240228653 5002.80160058389,2990.2746462822 5002.95987124706,2931.9033408165 PathPoint;PointKind.SMOOTHPOINT 5000.99943778617,3186.05148553848 5000.44939260177,3211.4133810997 5001.54885862871,3160.68888187408 PathPoint;PointKind.SMOOTHPOINT 5001.42617545194,3368.61181497574 5001.3066139845,3391.3010931015 5001.54542474845,3345.92348098755 PathPoint;PointKind.SMOOTHPOINT 5003.58514962638,3508.28965187073 5003.81272223673,3522.36886739731 5003.35757701603,3494.20972824097 PathPoint;PointKind.SMOOTHPOINT 5004.91718299861,3551.99802875519 5006.52954586891,3556.93091154099 5003.30606881205,3547.064909935 PathPoint;PointKind.SMOOTHPOINT 5006.18397264579,3567.42264032364 5006.38906894894,3579.87628698349 5006.09625261354,3562.10549354553 PathPoint;PointKind.SMOOTHPOINT 5007.46793169429,3590.56109189987 5007.95429400832,3597.35746622086 5006.20551244018,3572.90430307388 PathPoint;PointKind.SMOOTHPOINT 5026.05302820604,3647.0823597908 5038.62165432103,3670.29492616653 5013.81249374191,3624.47262525558 PathPoint;PointKind.SMOOTHPOINT 5052.33813295763,3689.16209936142 5071.45766610712,3713.01361083984 5046.32415992834,3681.65927410126 PathPoint;PointKind.SMOOTHPOINT 5093.73262305003,3744.09934043884 5091.60486596891,3758.97257566452 5095.85881927647,3729.22657728195 PathPoint;PointKind.SMOOTHPOINT 5078.96725007767,3760.2575469017 5074.3405646758,3761.89727783203 5083.48686084944,3758.6558175087 PathPoint;PointKind.CORNERPOINT 5054.37223875876,3764.1778421402 5054.37223875876,3764.1778421402 5054.37223875876,3764.1778421402 PathPoint;PointKind.SMOOTHPOINT 4489.20736736965,3770.49270629883 4483.0332506516,3770.53684473038 4829.9472479309,3768.0412530899 PathPoint;PointKind.SMOOTHPOINT 4472.20966005354,3769.79333639145 4459.50929780471,3772.15226411819 4478.35786658414,3768.6518740654 PathPoint;PointKind.SMOOTHPOINT 4453.36046693225,3770.97421646118 4442.82625878933,3770.43157339096 4460.09742784298,3771.32095098495 PathPoint;PointKind.SMOOTHPOINT 4425.75924952604,3770.92276096344 4127.11718016982,3772.82661437988 4434.05425556467,3770.87012529373 PathPoint;PointKind.SMOOTHPOINT 3359.18823467003,3773.64305734634 2745.47235454349,3775.045337677 3750.90656514575,3772.74754285812 PathPoint;PointKind.SMOOTHPOINT 1655.76447879784,3774.81213569641 1652.53475832232,3774.80977535248 2095.83153124624,3775.07295370102 PathPoint;PointKind.SMOOTHPOINT 1647.27436592592,3774.85910654068 1646.21485777843,3775.18436193466 1648.81118343037,3774.38750982285 PathPoint;PointKind.SMOOTHPOINT 1639.1981917115,3774.8019862175 1330.49797488559,3774.61174249649 1641.49639412217,3774.80340242386 PathPoint;PointKind.SMOOTHPOINT 1122.69827145046,3774.20316696167 1094.47177566491,3773.8493514061 1129.03128317354,3774.28247451782 PathPoint;PointKind.SMOOTHPOINT 571.566107853336,3771.75147771835 561.888496751283,3771.53031349182 613.245922178734,3772.70364046097 PathPoint;PointKind.SMOOTHPOINT 503.408579310528,3771.07004642487 502.66904636963,3771.065325737 536.010462896669,3771.29522323608 PathPoint;PointKind.SMOOTHPOINT 501.179678847037,3771.05494022369 500.707988566879,3770.71363449097 501.355431082464,3771.18216276169 PathPoint;PointKind.SMOOTHPOINT 499.438389381302,3771.04290246964 411.468932559027,3770.44715166092 500.020588171836,3771.04667901993 PathPoint";
		
	negative645[2] = "PointKind.CORNERPOINT 278.775682641115,3769.9893446252 278.775682641115,3769.9893446252 278.775682641115,3769.9893446252 PathPoint;PointKind.CORNERPOINT 184.793501473282,3770.6382144689 184.793501473282,3770.6382144689 184.793501473282,3770.6382144689 PathPoint;PointKind.SMOOTHPOINT 197.590948882354,3690.4415367816 213.921546914085,3676.26553639149 175.950635446771,3709.22618893528 PathPoint;PointKind.SMOOTHPOINT 254.045501308106,3652.05294283165 265.449729842031,3639.86957948062 242.640960603248,3664.23630618267 PathPoint;PointKind.SMOOTHPOINT 272.378675876712,3600.57908241217 273.31924689863,3576.19606905344 271.561724544366,3621.72317543801 PathPoint;PointKind.CORNERPOINT 273.379808059683,3502.86551536874 273.379808059683,3502.86551536874 273.379808059683,3502.86551536874 PathPoint;PointKind.SMOOTHPOINT 274.191452486164,3324.15533615264 274.462729027169,3279.17749136366 273.972620661948,3360.58150599184 PathPoint;PointKind.SMOOTHPOINT 273.680428668414,3105.59218011636 274.164917956837,3086.58659592423 273.421951135674,3115.72130037912 PathPoint;PointKind.SMOOTHPOINT 271.34008318175,2631.18594694064 271.149346741527,2606.16350527832 271.53050745104,2656.20744444894 PathPoint;PointKind.SMOOTHPOINT 276.13378003292,2033.63441429563 276.244912885161,1981.14181169886 276.022647180679,2086.12725293089 PathPoint;PointKind.SMOOTHPOINT 274.975625870518,1538.65412107789 275.206944532065,1481.19479630908 274.744307208971,1596.1139179237 PathPoint;PointKind.SMOOTHPOINT 275.432644116814,1208.23585922944 275.790704177265,1169.97519814791 275.075208398229,1246.49557615697 PathPoint;PointKind.SMOOTHPOINT 275.128589627816,1078.38352570832 274.916313393198,1070.94005152833 275.341802375234,1085.82699988832 PathPoint;PointKind.SMOOTHPOINT 276.317024370745,1060.3808691138 277.019408970584,1055.60840662941 275.518491123461,1065.80479786542 PathPoint;PointKind.SMOOTHPOINT 277.490162737943,1035.95017597755 277.855402729859,1023.6834910351 277.124922746026,1048.21662488149 PathPoint;PointKind.SMOOTHPOINT 277.117118472695,876.527883002709 277.002551740188,866.441013631919 277.256034537996,888.717383354802 PathPoint;PointKind.SMOOTHPOINT 275.744815050075,857.011747529417 276.285807277418,847.185700704017 275.544713481855,860.643435930666 PathPoint;PointKind.SMOOTHPOINT 278.235626926572,828.955266954474 277.77798433841,824.768888072077 278.694518198467,833.14164583687 PathPoint;PointKind.SMOOTHPOINT 275.744815050075,726.009434423551 274.664391450056,715.043085592014 276.527739750696,733.952838152086 PathPoint;PointKind.SMOOTHPOINT 272.769201714223,389.003574005601 271.824572470172,371.38778451687 273.71351878734,406.619363494333 PathPoint;PointKind.SMOOTHPOINT 261.031262452641,328.57441279688 256.667737147506,310.019898183245 265.394475586843,347.129871564526 PathPoint;PointKind.SMOOTHPOINT 247.390953523762,282.325736709818 240.384901268565,263.431090613914 254.396693608026,301.219910728717 PathPoint;PointKind.SMOOTHPOINT 203.205967458936,220.962099069241 201.794330498726,213.525470005822 204.616355735414,228.399672286669 PathPoint;PointKind.SMOOTHPOINT 204.247681863231,198.821923562367 208.27468690231,195.768293454024 200.220676824153,201.874845555201 PathPoint;PointKind.CORNERPOINT 285.169255525253,193.235836359457 285.169255525253,193.235836359457 285.169255525253,193.235836359457 PathPoint;PointKind.SMOOTHPOINT 928.550427268737,189.023493241773 952.804547928522,189.169128997887 904.295994438019,188.877857485659 PathPoint;PointKind.SMOOTHPOINT 2033.26030155415,187.492075436801 2065.00340290289,187.043366243328 2001.51657586355,187.941256707279 PathPoint;PointKind.SMOOTHPOINT 2453.98056041364,185.133578718662 2468.76809752226,184.73727007277 2433.22899762505,185.688977315318 PathPoint;PointKind.SMOOTHPOINT 3001.34825472656,185.672454620134 3002.23450800609,185.674106889653 2799.30404678798,185.314384211666 PathPoint;PointKind.SMOOTHPOINT 3004.00045897555,185.676939351684 3004.639160705,185.896455159117 3002.25542345861,185.078109670547 PathPoint;PointKind.SMOOTHPOINT 3006.01801971722,185.680715967726 3037.09619697811,185.735476900333 3005.34685221071,185.679535775213 PathPoint;PointKind.SMOOTHPOINT 3088.03187947473,185.824699454322 3088.69961310097,185.825879646835 3064.9899185488,185.785281024385 PathPoint;PointKind.SMOOTHPOINT 3090.02290568707,185.828003993358 3090.68002550159,185.969627094928 3089.21844119205,185.655459847946 PathPoint;PointKind.SMOOTHPOINT 3092.02641873674,185.831544570898 3125.44806319363,185.888429850028 3091.3624311617,185.830600416887 PathPoint;PointKind.SMOOTHPOINT 3153.96206840871,185.920059009379 3178.23679235009,185.908021045745 3147.92156085009,185.923127509913 PathPoint;PointKind.SMOOTHPOINT 4470.59199027738,188.00003029443 4471.00124637089,188.000502371436 3946.71515869242,187.065553862574 PathPoint;PointKind.SMOOTHPOINT 4472.57583655826,189.999984527095 4474.35926909998,189.394781806388 4472.18812025915,190.132402127063 PathPoint;PointKind.SMOOTHPOINT 4474.78975281695,188.363293549956 4655.89415889419,188.685958183032 4474.46166116609,188.362585434448 PathPoint;PointKind.SMOOTHPOINT 4887.77660114674,189.034114974391 4888.29636575062,189.034587051396 4807.28301383422,188.938755419334 PathPoint;PointKind.SMOOTHPOINT 4889.32590548852,189.035767243909 4889.64026161832,188.904293797952 4888.26483648636,189.481171898345 PathPoint;PointKind.SMOOTHPOINT 4890.34077319256,189.036947436422 4926.82231713728,189.079434366893 4890.00394075557,189.03671139792 PathPoint;PointKind.SMOOTHPOINT 4950.0518927941,189.053706170108 4968.69130704823,188.732457768048 4948.07897249588,189.08816779149 PathPoint;PointKind.SMOOTHPOINT 5091.61828931904,190.920062610292 5095.23447740995,191.956271636776 5088.00147688627,189.883853583808 PathPoint;PointKind.SMOOTHPOINT 5095.91906826659,219.572776442843 5095.52698157442,223.714544048245 5096.31115495877,215.431244875944 PathPoint;PointKind.SMOOTHPOINT 5070.57391019506,237.738063565664 5061.49348208833,244.188523765153 5078.87391096863,231.843001962831 PathPoint;PointKind.SMOOTHPOINT 5038.89574040044,270.91988418641 5028.51605686948,284.028282429187 5048.67605573953,258.56916953703 PathPoint;PointKind.SMOOTHPOINT 5009.635022313,329.257744261954 5005.91207176292,346.434974212824 5013.35797286308,312.079570157072 PathPoint;PointKind.SMOOTHPOINT 5000.94074965072,422.435123362115 4999.75699747179,448.628788074412 5002.12450182965,396.241458649817 PathPoint;PointKind.SMOOTHPOINT 4998.92006719972,600.919413731211 4999.31714862683,609.514991842473 4998.52298577261,592.324307696953 PathPoint;PointKind.SMOOTHPOINT 5000.19216375276,618.915697286159 4999.98956481707,624.370783120116 5000.39538703031,613.461319567709 PathPoint;PointKind.SMOOTHPOINT 4999.00185598423,635.632416118426 4999.16699440793,643.68675794319 4998.8354688768,627.578546370667 PathPoint;PointKind.SMOOTHPOINT 5000.59174254733,972.889185464657 5000.50589554069,991.243303389571 5000.65979581078,958.283122922781 PathPoint;PointKind.SMOOTHPOINT 5001.03783481097,2151.13815751389 5001.19079856826,2167.59853853232 5000.74689150117,2119.80074175259 PathPoint;PointKind.SMOOTHPOINT 5003.25487277899,2572.83298040093 5003.6744305133,2755.10096796696 5002.79535716523,2373.52631748506 PathPoint;PointKind.SMOOTHPOINT 5002.908675214,2950.82055375857 5002.80160058389,2990.32348547937 5002.95987124706,2931.95116378244 PathPoint;PointKind.SMOOTHPOINT 5000.99943778617,3186.10373316615 5000.44939260177,3211.46607027223 5001.54885862871,3160.74068794456 PathPoint;PointKind.SMOOTHPOINT 5001.42617545194,3368.66724093745 5001.3066139845,3391.35691407842 5001.54542474845,3345.9785119505 PathPoint;PointKind.SMOOTHPOINT 5003.58514962638,3508.34750959199 5003.81272223673,3522.42697023453 5003.35757701603,3494.26734083395 PathPoint;PointKind.SMOOTHPOINT 5004.91718299861,3552.05664742941 5006.52954586891,3556.98961609558 5003.30606881205,3547.12344272474 PathPoint;PointKind.SMOOTHPOINT 5006.18397264579,3567.48152753686 5006.38906894894,3579.93539101189 5006.09625261354,3562.16428818843 PathPoint;PointKind.SMOOTHPOINT 5007.46793169429,3590.6203819483 5007.95429400832,3597.41687459263 5006.20551244018,3572.96328572162 PathPoint;PointKind.SMOOTHPOINT 5026.05302820604,3647.14263386173 5038.62165432103,3670.35560436299 5013.81249374191,3624.53250569614 PathPoint;PointKind.SMOOTHPOINT 5052.33813295763,3689.22310603109 5071.45766610712,3713.07503275894 5046.32415992834,3681.72015014844 PathPoint;PointKind.SMOOTHPOINT 5093.73262305003,3744.16130355346 5091.60486596891,3759.0347977188 5095.85881927647,3729.28828146513 PathPoint;PointKind.SMOOTHPOINT 5078.96725007767,3760.31979132704 5074.3405646758,3761.95955080471 5083.48686084944,3758.71803404829 PathPoint;PointKind.CORNERPOINT 5054.37223875876,3764.24015481699 5054.37223875876,3764.24015481699 5054.37223875876,3764.24015481699 PathPoint;PointKind.SMOOTHPOINT 4489.20736736965,3770.55512891597 4483.0332506516,3770.59926811596 4829.9472479309,3768.10363302781 PathPoint;PointKind.SMOOTHPOINT 4472.20966005354,3769.85574683272 4459.50929780471,3772.21471562787 4478.35786658414,3768.71426463407 PathPoint;PointKind.SMOOTHPOINT 4453.36046693225,3771.03664746131 4442.82625878933,3770.4939949438 4460.09742784298,3771.38338802165 PathPoint;PointKind.SMOOTHPOINT 4425.75924952604,3770.98519106774 4127.11718016982,3772.88907762984 4434.05425556467,3770.93255448166 PathPoint;PointKind.SMOOTHPOINT 3359.18823467003,3773.70553481039 2745.47235454349,3775.10783955443 3750.90656514575,3772.81000473147 PathPoint;PointKind.SMOOTHPOINT 1655.76447879784,3774.87463351385 1652.53475832232,3774.87227312882 2095.83153124624,3775.13545605924 PathPoint;PointKind.SMOOTHPOINT 1647.57592304745,3773.06256592926 1646.51641489996,3773.38759094737 1649.1127405519,3772.59072496254 PathPoint;PointKind.SMOOTHPOINT 1639.1981917115,3774.86448385823 1330.49797488559,3774.67423682513 1641.49639412217,3774.86590008925 PathPoint;PointKind.SMOOTHPOINT 1122.69827145046,3774.2656541771 1094.47177566491,3773.91183246168 1129.03128317354,3774.34496311398 PathPoint;PointKind.SMOOTHPOINT 571.566107853336,3771.81392225043 561.888496751283,3771.59275417347 613.245922178734,3772.76610156998 PathPoint;PointKind.SMOOTHPOINT 503.408579310528,3771.13247909337 502.66904636963,3771.12775832332 536.010462896669,3771.35765982487 PathPoint;PointKind.SMOOTHPOINT 501.179678847037,3771.11737262921 500.707988566879,3770.77606095442 501.355431082464,3771.24459738212 PathPoint;PointKind.SMOOTHPOINT 499.438389381302,3771.10533466557 411.468932559027,3770.50957348497 500.020588171836,3771.10911128161 PathPoint";
		
} else if (negative_variant_645 == 1 && fancy == true && ( mask_variant_645 == 1 || mask_variant_645 == 5 ) ) {
	
	negative645[0] = "PointKind.CORNERPOINT 4996.74526596069,193.500759601593 4996.74526596069,193.500759601593 4996.74526596069,193.500759601593 PathPoint;PointKind.CORNERPOINT 5090.56911087036,192.853317260742 5090.56911087036,192.853317260742 5090.56911087036,192.853317260742 PathPoint;PointKind.SMOOTHPOINT 5077.79304122925,272.894940376282 5061.48998832703,287.043550014496 5099.39679718018,254.146492481232 PathPoint;PointKind.SMOOTHPOINT 5021.43383407593,311.20945930481 5010.04879379272,323.369243144989 5032.81918907166,299.049439430237 PathPoint;PointKind.SMOOTHPOINT 5003.13172721863,362.58376121521 5002.19262504578,386.919615268707 5003.94714736938,341.480398178101 PathPoint;PointKind.CORNERPOINT 5002.13220024109,460.108451843262 5002.13220024109,460.108451843262 5002.13220024109,460.108451843262 PathPoint;PointKind.SMOOTHPOINT 5001.32181549072,638.473269939423 5001.05116271973,683.364179134369 5001.54022598267,602.117600440979 PathPoint;PointKind.SMOOTHPOINT 5001.8319644928,856.61413192749 5001.34825134277,875.583035945892 5002.09002876282,846.504542827606 PathPoint;PointKind.SMOOTHPOINT 5004.16839027405,1330.10360956192 5004.35879135132,1355.07770061493 5003.9783039093,1305.13046264648 PathPoint;PointKind.SMOOTHPOINT 5004.33392906189,1925.50225496292 5004.2231502533,1977.8933930397 5004.44502258301,1873.11088085175 PathPoint;PointKind.SMOOTHPOINT 5005.49018287659,2419.52601671219 5005.25918388367,2476.87434911728 5005.72118186951,2362.17744827271 PathPoint;PointKind.SMOOTHPOINT 5005.03416442871,2749.30595397949 5004.67665100098,2787.49254226685 5005.39073371887,2711.12007379532 PathPoint;PointKind.SMOOTHPOINT 5005.33754730225,2878.90724658966 5005.54934883118,2886.33642911911 5005.12480163574,2871.4783000946 PathPoint;PointKind.SMOOTHPOINT 5004.15108108521,2896.87512874603 5003.44990158081,2901.63830280304 5004.94824790955,2891.46167993546 PathPoint;PointKind.SMOOTHPOINT 5002.98003578186,2921.25866174698 5002.61528396606,2933.5015296936 5003.34447288513,2909.01579380035 PathPoint;PointKind.SMOOTHPOINT 5003.35234069824,3080.37275075912 5003.46689605713,3090.440325737 5003.21355247498,3068.20683002472 PathPoint;PointKind.SMOOTHPOINT 5002.17216873169,3100.90679883957 5001.63212203979,3110.71379184723 5002.37201118469,3097.2820186615 PathPoint;PointKind.SMOOTHPOINT 5002.23574066162,3127.85342931747 5002.69270324707,3132.03171014786 5001.77751922607,3123.67514848709 PathPoint;PointKind.SMOOTHPOINT 5002.47555160522,3230.50785541534 5003.55438613892,3241.45300626755 5001.6941204071,3222.57969617844 PathPoint;PointKind.SMOOTHPOINT 5004.49065589905,3566.69777870178 5005.43353462219,3584.2795085907 5003.5477771759,3549.11604881287 PathPoint;PointKind.SMOOTHPOINT 5014.45980453491,3628.26546192169 5018.81605529785,3646.78424835205 5010.1038684845,3609.74596738815 PathPoint;PointKind.SMOOTHPOINT 5028.07710075378,3674.42481994629 5035.07127189636,3693.28302383423 5021.08324432373,3655.56708812714 PathPoint;PointKind.SMOOTHPOINT 5072.18783760071,3735.66984415054 5073.59680557251,3743.09218168259 5070.77981376648,3728.24679851532 PathPoint;PointKind.SMOOTHPOINT 5071.14771270752,3757.76738405228 5067.12757492065,3760.8150601387 5075.16785049438,3754.72018003464 PathPoint;PointKind.CORNERPOINT 4990.36258125305,3763.34251642227 4990.36258125305,3763.34251642227 4990.36258125305,3763.34251642227 PathPoint;PointKind.SMOOTHPOINT 4348.06579017639,3767.54676103592 4323.85275268555,3767.40136384964 4372.27945709229,3767.6921582222 PathPoint;PointKind.SMOOTHPOINT 3245.21806144714,3769.075319767 3213.52839851379,3769.52307701111 3276.90835380554,3768.62685441971 PathPoint;PointKind.SMOOTHPOINT 2825.20681762695,3771.42929077148 2810.44428253174,3771.82464838028 2845.92339897156,3770.8748459816 PathPoint;PointKind.SMOOTHPOINT 2278.76202011108,3770.89136838913 2277.87704849243,3770.88971614838 2480.4656829834,3771.2487244606 PathPoint;PointKind.SMOOTHPOINT 2276.11402893066,3770.88688373566 2275.4764213562,3770.66784381866 2277.85627746582,3771.48452281952 PathPoint;PointKind.SMOOTHPOINT 2274.09986877441,3770.88310718536 2243.07424926758,3770.82834720612 2274.76989173889,3770.88428735733 PathPoint;PointKind.SMOOTHPOINT 2192.22425842285,3770.73936223984 2191.55769729614,3770.73818206787 2215.22754096985,3770.77877998352 PathPoint;PointKind.SMOOTHPOINT 2190.23684883118,3770.73605775833 2189.58067321777,3770.59467315674 2191.03968048096,3770.90836286545 PathPoint;PointKind.SMOOTHPOINT 2188.236536026,3770.73251724243 2154.87134361267,3770.67586898804 2188.89932060242,3770.73346138 PathPoint;PointKind.SMOOTHPOINT 2126.40528106689,3770.64424037933 2102.17147254944,3770.65627813339 2132.43580245972,3770.64117193222 PathPoint;PointKind.SMOOTHPOINT 810.012201309204,3768.20954561234 809.60338973999,3768.20907354355 1333.00588035583,3769.1423535347 PathPoint;PointKind.SMOOTHPOINT 809.281753540039,3767.90624141693 808.954452514648,3767.90529727936 809.690250396729,3767.90671348572 PathPoint;PointKind.SMOOTHPOINT 807.803863525391,3768.20576906204 627.00498008728,3767.88358211517 808.131479263306,3768.20647716522 PathPoint;PointKind.SMOOTHPOINT 395.513147354126,3767.53613948822 394.994501113892,3767.53566741943 475.871213912964,3767.63126134872 PathPoint;PointKind.SMOOTHPOINT 393.966650009155,3767.53448724747 393.652881622314,3767.66572237015 395.025972366333,3767.09003448486 PathPoint;PointKind.SMOOTHPOINT 392.953275680542,3767.5333070755 356.533483505249,3767.4910569191 393.289703369141,3767.53354310989 PathPoint;PointKind.SMOOTHPOINT 333.342947006226,3767.51654863358 314.734939575195,3767.83731937408 335.312417984009,3767.48232364655 PathPoint;PointKind.SMOOTHPOINT 192.015308380127,3765.65376520157 188.404926300049,3764.61969852448 195.626005172729,3766.68806791306 PathPoint;PointKind.SMOOTHPOINT 187.721685409546,3737.05654621124 188.113187789917,3732.9228758812 187.330183029175,3741.1899805069 PathPoint;PointKind.SMOOTHPOINT 213.023942947388,3718.92627239227 222.089237213135,3712.48843431473 204.738191604614,3724.80990171432 PathPoint;PointKind.SMOOTHPOINT 244.648775100708,3685.80875873566 255.010999679565,3672.72560834885 234.885133743286,3698.13541889191 PathPoint;PointKind.SMOOTHPOINT 273.860391616821,3627.58355855942 277.576831817627,3610.4394364357 270.143636703491,3644.72838878632 PathPoint;PointKind.SMOOTHPOINT 286.500820159912,3533.58805418015 287.682565689087,3507.44512081146 285.319074630737,3559.73122358322 PathPoint;PointKind.SMOOTHPOINT 288.518127441406,3355.4486489296 288.121589660645,3346.86974287033 288.914665222168,3364.02731895447 PathPoint;PointKind.SMOOTHPOINT 287.248262405396,3337.48713970184 287.450307846069,3332.04277038574 287.045272827148,3342.93103694916 PathPoint;PointKind.SMOOTHPOINT 288.436616897583,3320.80281257629 288.27170753479,3312.76395320892 288.602470397949,3328.84119987488 PathPoint;PointKind.SMOOTHPOINT 286.849206924438,2984.19770479202 286.935123443604,2965.87907552719 286.781229019165,2998.77566099167 PathPoint;PointKind.SMOOTHPOINT 282.442916870117,1809.22368764877 282.290281295776,1792.79522180557 282.733396530151,1840.50060510635 PathPoint;PointKind.SMOOTHPOINT 280.229543685913,1388.34391593933 279.810661315918,1206.42796039581 280.688394546509,1587.26544141769 PathPoint;PointKind.SMOOTHPOINT 280.575412750244,1011.08660459518 280.682100296021,971.660127639771 280.524114608765,1029.91955280304 PathPoint;PointKind.SMOOTHPOINT 282.481311798096,776.258111000061 283.030485153198,750.944838523865 281.932767868042,801.572091579437 PathPoint;PointKind.SMOOTHPOINT 282.055191040039,594.047348499298 282.174467086792,571.401500701904 281.936229705811,616.692252159119 PathPoint;PointKind.SMOOTHPOINT 279.900039672852,454.637174606323 279.672817230225,440.58486700058 280.127262115479,468.689954280853 PathPoint;PointKind.SMOOTHPOINT 278.570064544678,411.012353897095 276.960624694824,406.08891248703 280.178560256958,415.936031341553 PathPoint;PointKind.SMOOTHPOINT 277.305549621582,395.617246627808 277.100671768188,383.187439441681 277.393039703369,400.924243927002 PathPoint;PointKind.SMOOTHPOINT 276.023725509644,372.523169517517 275.538124084473,365.739777088165 277.283834457397,390.146205425262 PathPoint;PointKind.SMOOTHPOINT 257.469848632812,316.110241413116 244.922574996948,292.942049503326 269.689821243286,338.676545619965 PathPoint;PointKind.SMOOTHPOINT 231.229118347168,274.110989570618 212.141803741455,250.305268764496 237.232889175415,281.599416732788 PathPoint;PointKind.SMOOTHPOINT 189.904531478882,219.279019832611 192.028526306152,204.434344768524 187.781795501709,234.123222827911 PathPoint;PointKind.SMOOTHPOINT 204.645036697388,203.151733875275 209.263757705688,201.515071392059 200.133003234863,204.750394821167 PathPoint;PointKind.CORNERPOINT 229.198593139648,199.238991737366 229.198593139648,199.238991737366 229.198593139648,199.238991737366 PathPoint;PointKind.SMOOTHPOINT 793.410800933838,192.936165332794 799.574445724487,192.892026901245 453.245271682739,195.382897853851 PathPoint;PointKind.SMOOTHPOINT 810.37978553772,193.634119033813 823.058609008789,191.279675960541 804.241947174072,194.773457050323 PathPoint;PointKind.SMOOTHPOINT 829.197076797485,192.455599308014 839.713510513306,192.997062206268 822.471670150757,192.109572887421 PathPoint;PointKind.SMOOTHPOINT 856.751731872559,192.506818771362 1154.8905506134,190.606741905212 848.470701217651,192.559454441071 PathPoint;PointKind.SMOOTHPOINT 1921.52522468567,189.791951179504 2534.20662307739,188.392267227173 1530.46690368652,190.685577392578 PathPoint;PointKind.SMOOTHPOINT 3622.0774974823,188.624997138977 3625.30172729492,188.62735748291 3182.75234603882,188.364651203156 PathPoint;PointKind.SMOOTHPOINT 3630.55333518982,188.578026294708 3631.61108398438,188.253479003906 3629.0191116333,189.048914909363 PathPoint;PointKind.SMOOTHPOINT 3638.61595535278,188.635146617889 3946.79567718506,188.824918270111 3636.3217010498,188.63373041153 PathPoint;PointKind.SMOOTHPOINT 4154.24536132812,189.232785701752 4182.42409133911,189.585893154144 4147.92278671265,189.153714179993 PathPoint;PointKind.SMOOTHPOINT 4704.44845581055,191.679754257202 4714.10981559753,191.900446414948 4662.83873939514,190.729479789734 PathPoint;PointKind.SMOOTHPOINT 4772.49119186401,192.360005378723 4773.22950744629,192.364726066589 4739.94425201416,192.135064601898 PathPoint;PointKind.SMOOTHPOINT 4774.71620941162,192.375111579895 4775.18701934814,192.715709209442 4774.54091453552,192.248125076294 PathPoint;PointKind.SMOOTHPOINT 4776.45468139648,192.386913299561 4864.27584075928,192.981719970703 4775.87340736389,192.383136749268 PathPoint";
		
	negative645[1] = "PointKind.CORNERPOINT 4998.18578529358,193.766298294067 4998.18578529358,193.766298294067 4998.18578529358,193.766298294067 PathPoint;PointKind.CORNERPOINT 5089.00963020325,197.118855953217 5089.00963020325,197.118855953217 5089.00963020325,197.118855953217 PathPoint;PointKind.SMOOTHPOINT 5076.23356056213,277.160479068756 5053.42728805542,296.268407344818 5098.15989685059,258.79015827179 PathPoint;PointKind.SMOOTHPOINT 5022.45610046387,309.75005865097 5011.07106018066,321.90984249115 5033.84145545959,297.590038776398 PathPoint;PointKind.SMOOTHPOINT 5004.57224655151,362.849299907684 5003.63314437866,387.185153961182 5005.38766670227,341.745936870575 PathPoint;PointKind.CORNERPOINT 5003.57271957397,460.373990535736 5003.57271957397,460.373990535736 5003.57271957397,460.373990535736 PathPoint;PointKind.SMOOTHPOINT 5002.76233482361,638.738808631897 5002.49168205261,683.629717826843 5002.98074531555,602.383139133453 PathPoint;PointKind.SMOOTHPOINT 5003.27248382568,856.879670619965 5002.78877067566,875.848574638367 5003.5305480957,846.770081520081 PathPoint;PointKind.SMOOTHPOINT 5005.60890960693,1330.36914825439 5005.7993106842,1355.3432393074 5005.41882324219,1305.39600133896 PathPoint;PointKind.SMOOTHPOINT 5005.77444839478,1925.7677936554 5005.66366958618,1978.15893173218 5005.88554191589,1873.37641954422 PathPoint;PointKind.SMOOTHPOINT 5006.93070220947,2419.79155540466 5006.69970321655,2477.13988780975 5007.16170120239,2362.44298696518 PathPoint;PointKind.SMOOTHPOINT 5006.4746837616,2749.57149267197 5006.11717033386,2787.75808095932 5006.83125305176,2711.38561248779 PathPoint;PointKind.SMOOTHPOINT 5006.77806663513,2879.17278528214 5006.98986816406,2886.60196781158 5006.56532096863,2871.74383878708 PathPoint;PointKind.SMOOTHPOINT 5005.59160041809,2897.14066743851 5004.8904209137,2901.90384149551 5006.38876724243,2891.72721862793 PathPoint;PointKind.SMOOTHPOINT 5004.42055511475,2921.52420043945 5004.05580329895,2933.76706838608 5004.78499221802,2909.28133249283 PathPoint;PointKind.SMOOTHPOINT 5004.79286003113,3080.6382894516 5004.90741539001,3090.70586442947 5004.65407180786,3068.47236871719 PathPoint;PointKind.SMOOTHPOINT 5003.61268806458,3101.17233753204 5003.07264137268,3110.9793305397 5003.81253051758,3097.54755735397 PathPoint;PointKind.SMOOTHPOINT 5003.67625999451,3128.11896800995 5004.13322257996,3132.29724884033 5003.21803855896,3123.94068717957 PathPoint;PointKind.SMOOTHPOINT 5003.91607093811,3230.77339410782 5004.67421340942,3238.4659910202 5003.13463973999,3222.84523487091 PathPoint;PointKind.SMOOTHPOINT 5005.2888469696,3489.83860731125 5005.29671478271,3491.82224035263 5004.89640045166,3392.72980928421 PathPoint;PointKind.SMOOTHPOINT 5005.31307983398,3495.71657180786 5004.06398582458,3496.84245586395 5007.30804252625,3493.91798973083 PathPoint;PointKind.SMOOTHPOINT 5005.33448028564,3500.70256233215 5005.49089241028,3536.25972747803 5005.32724189758,3499.06070709229 PathPoint;PointKind.SMOOTHPOINT 5005.93117523193,3566.96331739426 5006.87405395508,3584.54504728317 5005.67625808716,3562.21052885056 PathPoint;PointKind.SMOOTHPOINT 5015.9003238678,3628.53100061417 5020.25657463074,3647.04978704453 5011.54438781738,3610.01150608063 PathPoint;PointKind.SMOOTHPOINT 5029.51762008667,3674.69035863876 5036.51179122925,3693.5485625267 5022.52376365662,3655.83262681961 PathPoint;PointKind.SMOOTHPOINT 5073.62835693359,3735.93538284302 5075.0373249054,3743.35772037506 5072.22033309937,3728.51233720779 PathPoint;PointKind.SMOOTHPOINT 5072.58823204041,3758.03292274475 5068.56809425354,3761.08059883118 5076.60836982727,3754.98571872711 PathPoint;PointKind.CORNERPOINT 4991.80310058594,3763.60805511475 4991.80310058594,3763.60805511475 4991.80310058594,3763.60805511475 PathPoint;PointKind.SMOOTHPOINT 4349.50630950928,3767.81229972839 4325.29327201843,3767.66690254211 4373.71997642517,3767.95769691467 PathPoint;PointKind.SMOOTHPOINT 3246.65858078003,3769.34085845947 3214.96891784668,3769.78861570358 3278.34887313843,3768.89239311218 PathPoint;PointKind.SMOOTHPOINT 2826.64733695984,3771.69482946396 2821.17920684814,3771.84117078781 2847.36391830444,3771.14038467407 PathPoint;PointKind.SMOOTHPOINT 2703.04367828369,3771.79490804672 2701.20544242859,3771.79325580597 2772.46611404419,3771.85438871384 PathPoint;PointKind.SMOOTHPOINT 2697.48585510254,3771.78995132446 2696.26728820801,3771.26666307449 2699.90567970276,3772.82921075821 PathPoint;PointKind.SMOOTHPOINT 2693.48585891724,3771.78641080856 2575.59737968445,3771.67689085007 2694.82621955872,3771.78759098053 PathPoint;PointKind.SMOOTHPOINT 2280.20253944397,3771.1569070816 2279.31756782532,3771.15525484085 2403.81249237061,3771.3759469986 PathPoint;PointKind.SMOOTHPOINT 2277.55454826355,3771.15242242813 2276.91694068909,3770.93338251114 2279.29679679871,3771.75006151199 PathPoint;PointKind.SMOOTHPOINT 2275.5403881073,3771.14864587784 2244.51476860046,3771.09388589859 2276.21041107178,3771.1498260498 PathPoint;PointKind.SMOOTHPOINT 2193.66477775574,3771.00490093231 2192.99821662903,3771.00372076035 2216.66806030273,3771.04431867599 PathPoint;PointKind.SMOOTHPOINT 2191.67736816406,3771.00159645081 2191.02119255066,3770.86021184921 2192.48019981384,3771.17390155792 PathPoint;PointKind.SMOOTHPOINT 2189.67705535889,3770.99805593491 2156.31186294556,3770.94140768051 2190.3398399353,3770.99900007248 PathPoint;PointKind.SMOOTHPOINT 2127.84580039978,3770.90977907181 2122.66500282288,3770.91237545013 2133.8763217926,3770.90671062469 PathPoint;PointKind.SMOOTHPOINT 2019.85440063477,3770.72897672653 2017.8632144928,3770.72520017624 2083.44049263,3770.84510564804 PathPoint;PointKind.SMOOTHPOINT 2013.81003189087,3770.71788311005 2012.40074920654,3770.43700218201 2016.48603248596,3771.25132083893 PathPoint;PointKind.SMOOTHPOINT 2009.46416664124,3770.70985794067 1769.67840003967,3770.26941776276 2010.92443275452,3770.712454319 PathPoint;PointKind.SMOOTHPOINT 811.45272064209,3768.47508430481 811.043909072876,3768.47461223602 1216.67341995239,3769.19782161713 PathPoint;PointKind.SMOOTHPOINT 810.722272872925,3768.17178010941 810.394971847534,3768.17083597183 811.130769729614,3768.17225217819 PathPoint;PointKind.SMOOTHPOINT 809.244382858276,3768.47130775452 639.031484603882,3768.16800355911 809.571998596191,3768.4720158577 PathPoint;PointKind.SMOOTHPOINT 424.097621917725,3767.93787002563 422.318866729736,3767.92960882187 565.187023162842,3768.59829425812 PathPoint;PointKind.SMOOTHPOINT 418.456085205078,3766.7499089241 417.158525466919,3765.42976856232 419.718397140503,3768.03393602371 PathPoint;PointKind.SMOOTHPOINT 411.456249237061,3767.74998664856 408.130367279053,3767.73299217224 415.402429580688,3767.77004957199 PathPoint;PointKind.SMOOTHPOINT 396.953666687012,3767.80167818069 391.674364089966,3767.77477025986 400.35728263855,3767.81985282898 PathPoint;PointKind.SMOOTHPOINT 334.783466339111,3767.78208732605 316.172626495361,3767.75093078613 390.08758354187,3767.86705970764 PathPoint;PointKind.SMOOTHPOINT 193.455827713013,3765.91930389404 189.845445632935,3764.88523721695 197.066524505615,3766.95360660553 PathPoint;PointKind.SMOOTHPOINT 189.162204742432,3737.32208490372 189.553707122803,3733.18841457367 188.770702362061,3741.45551919937 PathPoint;PointKind.SMOOTHPOINT 206.464469909668,3718.19173336029 215.529764175415,3711.75389528275 198.178718566895,3724.07536268234 PathPoint;PointKind.SMOOTHPOINT 238.089302062988,3685.07421970367 248.451526641846,3671.99106931686 228.325660705566,3697.40087985992 PathPoint;PointKind.SMOOTHPOINT 267.300918579102,3626.84901952744 271.017358779907,3609.70489740372 263.584163665771,3643.99384975433 PathPoint;PointKind.SMOOTHPOINT 279.941347122192,3532.85351514816 281.123092651367,3506.71058177948 278.759601593018,3558.99668455124 PathPoint;PointKind.SMOOTHPOINT 281.958654403687,3354.71410989761 281.562116622925,3346.13520383835 282.355192184448,3363.29277992249 PathPoint;PointKind.SMOOTHPOINT 280.688789367676,3336.75260066986 280.89083480835,3331.30823135376 280.485799789429,3342.19649791718 PathPoint;PointKind.SMOOTHPOINT 281.877143859863,3320.06827354431 281.71223449707,3312.02941417694 282.042997360229,3328.1066608429 PathPoint;PointKind.SMOOTHPOINT 280.289733886719,2983.46316576004 280.33757019043,2973.29244375229 280.221755981445,2998.04112195969 PathPoint;PointKind.SMOOTHPOINT 281.870849609375,2297.88097143173 281.860778808594,2295.19608020782 283.06329536438,2613.85124444962 PathPoint;PointKind.SMOOTHPOINT 281.840637207031,2289.83455896378 280.664556503296,2288.1188249588 283.775489807129,2292.65776634216 PathPoint;PointKind.SMOOTHPOINT 281.8170337677,2283.59947443008 280.881708145142,2036.15565061569 281.824901580811,2285.67610502243 PathPoint;PointKind.SMOOTHPOINT 283.883436203003,1809.48922634125 283.730800628662,1793.06076049805 284.010265350342,1823.13862323761 PathPoint;PointKind.SMOOTHPOINT 281.670063018799,1388.60945463181 281.657789230347,1383.23495149612 282.128913879395,1587.53098011017 PathPoint;PointKind.SMOOTHPOINT 281.635759353638,1372.50411987305 281.631982803345,1370.43858289719 281.646144866943,1377.86516904831 PathPoint;PointKind.SMOOTHPOINT 281.624114990234,1366.31152153015 283.040321350098,1362.64921188354 280.88013458252,1368.23543787003 PathPoint;PointKind.SMOOTHPOINT 281.607749938965,1356.74292325974 281.332376480103,1186.56543016434 281.612785339355,1359.92820739746 PathPoint;PointKind.SMOOTHPOINT 282.01593208313,1011.35214328766 282.122619628906,971.925666332245 281.967781066895,1029.08233880997 PathPoint;PointKind.SMOOTHPOINT 283.921831130981,776.523649692535 284.471004486084,751.210377216339 283.373287200928,801.837630271912 PathPoint;PointKind.SMOOTHPOINT 283.495710372925,594.312887191772 283.614986419678,571.667039394379 283.376749038696,616.957790851593 PathPoint;PointKind.SMOOTHPOINT 281.340559005737,454.902713298798 281.11333656311,440.850405693054 281.567781448364,468.955492973328 PathPoint;PointKind.SMOOTHPOINT 280.456216812134,410.749883651733 280.412786483765,406.839973926544 280.512550354004,415.92942237854 PathPoint;PointKind.SMOOTHPOINT 279.764478683472,393.737468719482 279.676044464111,392.488610744476 280.275886535645,400.951151847839 PathPoint;PointKind.SMOOTHPOINT 279.463613510132,389.874765872955 277.597053527832,387.843453884125 280.363691329956,390.853836536407 PathPoint;PointKind.SMOOTHPOINT 278.823488235474,383.274064064026 278.458106994629,379.932761192322 279.073055267334,385.557460784912 PathPoint;PointKind.SMOOTHPOINT 277.464244842529,372.788708209991 276.451499938965,366.063852310181 278.011215209961,376.423401832581 PathPoint;PointKind.SMOOTHPOINT 261.456077575684,315.750052928925 249.855773925781,295.622456073761 274.269912719727,337.984728813171 PathPoint;PointKind.SMOOTHPOINT 232.669637680054,274.376528263092 213.4296875,250.694017410278 246.518562316895,291.42434835434 PathPoint;PointKind.SMOOTHPOINT 191.345050811768,219.544558525085 193.469045639038,204.699883460999 189.222314834595,234.388761520386 PathPoint;PointKind.SMOOTHPOINT 206.085556030273,203.417272567749 210.704277038574,201.780610084534 201.573522567749,205.015933513641 PathPoint;PointKind.CORNERPOINT 230.639112472534,199.50453042984 230.639112472534,199.50453042984 230.639112472534,199.50453042984 PathPoint;PointKind.SMOOTHPOINT 794.851320266724,193.201704025269 801.014965057373,193.157565593719 454.685791015625,195.648436546326 PathPoint;PointKind.SMOOTHPOINT 811.820304870605,193.899657726288 824.499128341675,191.545214653015 805.682466506958,195.038995742798 PathPoint;PointKind.SMOOTHPOINT 830.637596130371,192.721138000488 841.154029846191,193.262600898743 823.912189483643,192.375111579895 PathPoint;PointKind.SMOOTHPOINT 858.192251205444,192.772357463837 1156.33106994629,190.872280597687 849.911220550537,192.824993133545 PathPoint;PointKind.SMOOTHPOINT 1922.96574401855,190.057489871979 2261.83623123169,189.28329706192 1531.90742301941,190.951116085052 PathPoint;PointKind.SMOOTHPOINT 2931.02331924438,188.810756206512 2932.31049346924,188.810284137726 2611.67822647095,188.929009437561 PathPoint;PointKind.SMOOTHPOINT 2934.45620346069,187.750017642975 2935.34872817993,187.749545574188 2933.17028808594,187.750489711761 PathPoint;PointKind.SMOOTHPOINT 2937.55926895142,188.808395862579 3193.07814407349,188.716342449188 2936.66737365723,188.808631896973 PathPoint;PointKind.SMOOTHPOINT 3623.51801681519,188.890535831451 3626.74224662781,188.892896175385 3428.83999633789,188.775115013123 PathPoint;PointKind.SMOOTHPOINT 3631.99385452271,188.843564987183 3633.05160331726,188.519017696381 3630.45963096619,189.314453601837 PathPoint;PointKind.SMOOTHPOINT 3640.05647468567,188.900685310364 3948.23619651794,189.090456962585 3637.76222038269,188.899269104004 PathPoint;PointKind.SMOOTHPOINT 4155.68588066101,189.498324394226 4183.864610672,189.851431846619 4149.36330604553,189.419252872467 PathPoint;PointKind.SMOOTHPOINT 4705.88897514343,191.945292949677 4715.55033493042,192.165985107422 4664.27925872803,190.995018482208 PathPoint;PointKind.SMOOTHPOINT 4773.9317111969,192.625544071198 4774.67002677917,192.630264759064 4741.38477134705,192.400603294373 PathPoint;PointKind.SMOOTHPOINT 4776.15672874451,192.640650272369 4776.62753868103,192.981247901917 4775.98143386841,192.513663768768 PathPoint;PointKind.SMOOTHPOINT 4777.89520072937,192.652451992035 4847.68018531799,193.124992847443 4777.31392669678,192.648675441742 PathPoint;PointKind.SMOOTHPOINT 4982.95810508728,193.70445728302 4984.47722244263,193.710830211639 4945.65743255615,193.549854755402 PathPoint;PointKind.SMOOTHPOINT 4987.20766830444,193.721923828125 4988.08477210999,192.29202747345 4986.05833816528,195.596272945404 PathPoint;PointKind.SMOOTHPOINT 4991.7045955658,193.740334510803 4995.89058685303,193.757328987122 4990.3884677887,193.734905719757 PathPoint";
		
	negative645[2] = "PointKind.CORNERPOINT 4995.49524307251,193.50071144104 4995.49524307251,193.50071144104 4995.49524307251,193.50071144104 PathPoint;PointKind.CORNERPOINT 5099.31908798218,196.853269100189 5099.31908798218,196.853269100189 5099.31908798218,196.853269100189 PathPoint;PointKind.SMOOTHPOINT 5086.54301834106,276.894892215729 5067.85570335388,291.134139060974 5109.2954750061,259.558402061462 PathPoint;PointKind.SMOOTHPOINT 5020.18381118774,311.209411144257 5010.01041412354,324.399485111237 5030.91141700745,297.300848484039 PathPoint;PointKind.SMOOTHPOINT 5001.88170433044,362.583713054657 5000.94260215759,386.919567108154 5002.6971244812,341.480350017548 PathPoint;PointKind.CORNERPOINT 5000.88217735291,460.108403682709 5000.88217735291,460.108403682709 5000.88217735291,460.108403682709 PathPoint;PointKind.SMOOTHPOINT 5000.07179260254,638.47322177887 4999.80113983154,683.364130973816 5000.29020309448,602.117552280426 PathPoint;PointKind.SMOOTHPOINT 5000.58194160461,856.614083766937 5000.09822845459,875.582987785339 5000.84000587463,846.504494667053 PathPoint;PointKind.SMOOTHPOINT 5002.91836738586,1330.10356140137 5003.10876846313,1355.07765245438 5002.72828102112,1305.13041448593 PathPoint;PointKind.SMOOTHPOINT 5003.08390617371,1925.50220680237 5003.04393768311,1944.38566637039 5003.19499969482,1873.11083269119 PathPoint;PointKind.SMOOTHPOINT 5003.43481063843,2080.65398645401 5003.44079017639,2082.62628984451 5003.21293830872,2006.38600063324 PathPoint;PointKind.SMOOTHPOINT 5003.45274925232,2086.59662437439 5002.19232559204,2087.19331932068 5006.86391830444,2084.98096895218 PathPoint;PointKind.SMOOTHPOINT 5003.4653377533,2090.7914276123 5003.85652542114,2221.02812480927 5003.46093177795,2089.38938331604 PathPoint;PointKind.SMOOTHPOINT 5004.2401599884,2419.52596855164 5004.00916099548,2476.87430095673 5004.38398361206,2383.78139209747 PathPoint;PointKind.SMOOTHPOINT 5003.78414154053,2749.30590581894 5003.42662811279,2787.49249410629 5004.14071083069,2711.12002563477 PathPoint;PointKind.SMOOTHPOINT 5004.08752441406,2878.90719842911 5004.29932594299,2886.33638095856 5003.87477874756,2871.47825193405 PathPoint;PointKind.SMOOTHPOINT 5002.90105819702,2896.87508058548 5002.19987869263,2901.63825464249 5003.69822502136,2891.4616317749 PathPoint;PointKind.SMOOTHPOINT 5001.73001289368,2921.25861358643 5001.36526107788,2933.50148153305 5002.09444999695,2909.0157456398 PathPoint;PointKind.SMOOTHPOINT 5002.10231781006,3080.37270259857 5002.21687316895,3090.44027757645 5001.96352958679,3068.20678186417 PathPoint;PointKind.SMOOTHPOINT 5000.92214584351,3100.90675067902 5000.38209915161,3110.71374368668 5001.12198829651,3097.28197050095 PathPoint;PointKind.SMOOTHPOINT 5000.98571777344,3127.85338115692 5001.44268035889,3132.0316619873 5000.52749633789,3123.67510032654 PathPoint;PointKind.SMOOTHPOINT 5001.22552871704,3230.50780725479 5002.30436325073,3241.45295810699 5000.44409751892,3222.57964801788 PathPoint;PointKind.SMOOTHPOINT 5003.24063301086,3566.69773054123 5004.18351173401,3584.27946043015 5002.29775428772,3549.11600065231 PathPoint;PointKind.SMOOTHPOINT 5013.20978164673,3628.26541376114 5017.56603240967,3646.7842001915 5008.85384559631,3609.7459192276 PathPoint;PointKind.SMOOTHPOINT 5026.8270778656,3674.42477178574 5033.82124900818,3693.28297567368 5019.83322143555,3655.56703996658 PathPoint;PointKind.SMOOTHPOINT 5070.93781471252,3735.66979598999 5072.34678268433,3743.09213352203 5069.5297908783,3728.24675035477 PathPoint;PointKind.SMOOTHPOINT 5069.89768981934,3757.76733589172 5065.87755203247,3760.81501197815 5073.9178276062,3754.72013187408 PathPoint;PointKind.CORNERPOINT 4989.11255836487,3763.34246826172 4989.11255836487,3763.34246826172 4989.11255836487,3763.34246826172 PathPoint;PointKind.SMOOTHPOINT 4763.58610153198,3764.90832042694 4761.79444313049,3764.92059421539 4886.6827583313,3764.06331729889 PathPoint;PointKind.SMOOTHPOINT 4757.76549339294,3764.48440265656 4756.30491256714,3763.40242099762 4759.5502281189,3765.80643129349 PathPoint;PointKind.SMOOTHPOINT 4752.73292541504,3764.98267126083 4575.42137145996,3766.19824838638 4754.55857276917,3764.97016143799 PathPoint;PointKind.SMOOTHPOINT 4346.81576728821,3767.54671287537 4322.60272979736,3767.40131568909 4360.88404655457,3767.63121318817 PathPoint;PointKind.SMOOTHPOINT 3243.96803855896,3769.07527160645 3212.27837562561,3769.52302885056 3275.65833091736,3768.62680625916 PathPoint;PointKind.SMOOTHPOINT 2823.95679473877,3771.42924261093 2809.19425964355,3771.82460021973 2844.67337608337,3770.87479782104 PathPoint;PointKind.SMOOTHPOINT 2277.5119972229,3770.89132022858 2276.62702560425,3770.88966798782 2479.21566009521,3771.24867630005 PathPoint;PointKind.SMOOTHPOINT 2274.86400604248,3770.8868355751 2274.22639846802,3770.66779565811 2276.60625457764,3771.48447465897 PathPoint;PointKind.SMOOTHPOINT 2272.84984588623,3770.88305902481 2241.82422637939,3770.82829904556 2273.51986885071,3770.88423919678 PathPoint;PointKind.SMOOTHPOINT 2190.97423553467,3770.73931407928 2190.30767440796,3770.73813390732 2213.97751808167,3770.77873182297 PathPoint;PointKind.SMOOTHPOINT 2188.98682594299,3770.73600959778 2188.33065032959,3770.59462499619 2189.78965759277,3770.9083147049 PathPoint;PointKind.SMOOTHPOINT 2186.98651313782,3770.73246908188 2153.62132072449,3770.67582082748 2187.64929771423,3770.73341321945 PathPoint;PointKind.SMOOTHPOINT 2125.15525817871,3770.64419221878 2106.24921798706,3770.65363359451 2131.18577957153,3770.64112377167 PathPoint;PointKind.SMOOTHPOINT 1178.85592460632,3768.88668012619 1177.58983612061,3768.88431978226 1633.94534111023,3769.73427963257 PathPoint;PointKind.SMOOTHPOINT 1175.05797386169,3768.87959909439 1174.32532310486,3768.25741243362 1176.68787002563,3770.26323270798 PathPoint;PointKind.SMOOTHPOINT 1172.17457771301,3768.87417030334 1046.21026039124,3768.63955211639 1173.13570976257,3768.8758225441 PathPoint;PointKind.SMOOTHPOINT 808.762178421021,3768.20949745178 808.353366851807,3768.209025383 921.742086410522,3768.41107082367 PathPoint;PointKind.SMOOTHPOINT 808.031730651855,3767.90619325638 807.704429626465,3767.9052491188 808.440227508545,3767.90666532516 PathPoint;PointKind.SMOOTHPOINT 806.553840637207,3768.20572090149 625.754957199097,3767.88353395462 806.881456375122,3768.20642900467 PathPoint;PointKind.SMOOTHPOINT 394.263124465942,3767.53609132767 393.744478225708,3767.53561925888 474.62119102478,3767.63121318817 PathPoint;PointKind.SMOOTHPOINT 392.716627120972,3767.53443908691 392.402858734131,3767.66567420959 393.775949478149,3767.08998632431 PathPoint;PointKind.SMOOTHPOINT 391.703252792358,3767.53325891495 355.283460617065,3767.49100875854 392.039680480957,3767.53349494934 PathPoint;PointKind.SMOOTHPOINT 332.092924118042,3767.51650047302 313.484916687012,3767.83727121353 334.062395095825,3767.48227548599 PathPoint;PointKind.SMOOTHPOINT 190.765285491943,3765.65371704102 187.154903411865,3764.61965036392 194.375982284546,3766.6880197525 PathPoint;PointKind.SMOOTHPOINT 178.471670150757,3738.05657577515 178.863172531128,3733.9229054451 178.080167770386,3742.1900100708 PathPoint;PointKind.SMOOTHPOINT 203.773927688599,3719.92630195618 212.839221954346,3713.48846387863 195.488176345825,3725.80993127823 PathPoint;PointKind.SMOOTHPOINT 235.398759841919,3686.80878829956 245.760984420776,3673.72563791275 225.635118484497,3699.13544845581 PathPoint;PointKind.SMOOTHPOINT 264.610376358032,3628.58358812332 268.326816558838,3611.4394659996 260.893621444702,3645.72841835022 PathPoint;PointKind.SMOOTHPOINT 277.250804901123,3534.58808374405 278.432550430298,3508.44515037537 276.069059371948,3560.73125314713 PathPoint;PointKind.SMOOTHPOINT 279.268112182617,3356.4486784935 278.871574401855,3347.86977243423 279.664649963379,3365.02734851837 PathPoint;PointKind.SMOOTHPOINT 277.998247146606,3338.48716926575 278.20029258728,3333.04279994965 277.795257568359,3343.93106651306 PathPoint;PointKind.SMOOTHPOINT 279.186601638794,3321.8028421402 279.021692276001,3313.76398277283 279.35245513916,3329.84122943878 PathPoint;PointKind.SMOOTHPOINT 277.599191665649,2985.19773435593 277.685108184814,2966.87910509109 277.531213760376,2999.77569055557 PathPoint;PointKind.SMOOTHPOINT 281.192893981934,1809.22363948822 281.040258407593,1792.79517364502 281.483373641968,1840.5005569458 PathPoint;PointKind.SMOOTHPOINT 278.979520797729,1388.34386777878 278.976373672485,1387.02089500427 279.438371658325,1587.26539325714 PathPoint;PointKind.SMOOTHPOINT 280.765514373779,1384.48446941376 279.666538238525,1382.78785419464 281.484632492065,1385.59406709671 PathPoint;PointKind.SMOOTHPOINT 278.959379196167,1379.20390796661 278.584241867065,1200.55655670166 278.96315574646,1380.92719507217 PathPoint;PointKind.SMOOTHPOINT 279.325389862061,1011.08655643463 279.432077407837,971.660079479218 279.275035858154,1029.60392665863 PathPoint;PointKind.SMOOTHPOINT 281.231288909912,776.258062839508 281.780462265015,750.944790363312 280.682744979858,801.572043418884 PathPoint;PointKind.SMOOTHPOINT 280.805168151855,594.047300338745 280.924444198608,571.401452541351 280.686206817627,616.692203998566 PathPoint;PointKind.SMOOTHPOINT 278.650016784668,454.63712644577 278.422794342041,440.584818840027 278.877239227295,468.6899061203 PathPoint;PointKind.SMOOTHPOINT 277.320041656494,411.012305736542 275.710601806641,406.088864326477 278.928537368774,415.935983181 PathPoint;PointKind.SMOOTHPOINT 276.055526733398,395.617198467255 275.850648880005,383.187391281128 276.143016815186,400.924195766449 PathPoint;PointKind.SMOOTHPOINT 274.77370262146,372.523121356964 274.288101196289,365.739728927612 276.033811569214,390.146157264709 PathPoint;PointKind.SMOOTHPOINT 256.219825744629,316.110193252563 245.605201721191,294.665524482727 267.602977752686,339.110092639923 PathPoint;PointKind.SMOOTHPOINT 229.979095458984,274.110941410065 210.5943775177,250.5466837883 236.065635681152,281.510383605957 PathPoint;PointKind.SMOOTHPOINT 188.654508590698,219.278971672058 190.778503417969,204.434296607971 186.531772613525,234.123174667358 PathPoint;PointKind.SMOOTHPOINT 203.395013809204,203.151685714722 208.013734817505,201.515023231506 198.88298034668,204.750346660614 PathPoint;PointKind.CORNERPOINT 227.948570251465,199.238943576813 227.948570251465,199.238943576813 227.948570251465,199.238943576813 PathPoint;PointKind.SMOOTHPOINT 509.812660217285,195.490481376648 511.176624298096,195.475375175476 333.543748855591,197.421478748322 PathPoint;PointKind.SMOOTHPOINT 513.76576423645,194.484266757965 515.418319702148,195.23037147522 512.514781951904,193.919672489166 PathPoint;PointKind.SMOOTHPOINT 519.327993392944,195.386862277985 597.770404815674,194.53808259964 517.517137527466,195.406453132629 PathPoint;PointKind.SMOOTHPOINT 792.160778045654,192.936117172241 798.324422836304,192.891978740692 689.697933197021,193.673016548157 PathPoint;PointKind.SMOOTHPOINT 809.129762649536,193.63407087326 821.808586120605,191.279627799988 802.991924285889,194.773408889771 PathPoint;PointKind.SMOOTHPOINT 827.947053909302,192.455551147461 838.463487625122,192.997014045715 821.221647262573,192.109524726868 PathPoint;PointKind.SMOOTHPOINT 855.501708984375,192.506770610809 1153.64052772522,190.606693744659 847.220678329468,192.559406280518 PathPoint;PointKind.SMOOTHPOINT 1920.27520179749,189.791903018951 2532.95660018921,188.39221906662 1529.21688079834,190.685529232025 PathPoint;PointKind.SMOOTHPOINT 3620.82747459412,188.624948978424 3624.05170440674,188.627309322357 3181.50232315063,188.364603042603 PathPoint;PointKind.SMOOTHPOINT 3629.30331230164,188.577978134155 3630.36106109619,188.253430843353 3627.76908874512,189.04886674881 PathPoint;PointKind.SMOOTHPOINT 3637.3659324646,188.635098457336 3945.54565429688,188.824870109558 3635.07167816162,188.633682250977 PathPoint;PointKind.SMOOTHPOINT 4152.99533843994,189.232737541199 4181.17406845093,189.585844993591 4146.67276382446,189.15366601944 PathPoint;PointKind.SMOOTHPOINT 4703.19843292236,191.679706096649 4712.85979270935,191.900398254395 4661.58871650696,190.729431629181 PathPoint;PointKind.SMOOTHPOINT 4771.24116897583,192.35995721817 4771.97948455811,192.364677906036 4738.69422912598,192.135016441345 PathPoint;PointKind.SMOOTHPOINT 4773.46618652344,192.375063419342 4773.93699645996,192.715661048889 4773.29089164734,192.248076915741 PathPoint;PointKind.SMOOTHPOINT 4775.2046585083,192.386865139008 4863.02581787109,192.98167181015 4774.62338447571,192.383088588715 PathPoint";
		
} else if ( (negative_variant_645 == 2 && fancy == false) || (negative_variant_645 == 2 && fancy == true && mask_variant_645 == 3) )  {
	
	negative645[0] = "PointKind.SMOOTHPOINT 5056.03539237126,230.561030910378 5047.74425759014,240.516378273956 5059.16924677686,226.799009960899 PathPoint;PointKind.SMOOTHPOINT 5030.04000266143,299.558557992453 5030.98413970372,317.515428174796 5027.41690039262,249.669944775161 PathPoint;PointKind.SMOOTHPOINT 5031.05990180572,370.55617074652 5033.05507750033,394.241395809587 5029.23358571133,348.875515852469 PathPoint;PointKind.SMOOTHPOINT 5031.05990180572,465.552923355222 5031.05990180572,465.552923355222 5031.0563705213,465.556935799927 PathPoint;PointKind.SMOOTHPOINT 5032.08012197587,594.548300073884 5031.9385495734,607.438632725546 5032.72474189458,535.838681213523 PathPoint;PointKind.SMOOTHPOINT 5018.81918591909,635.546988009658 5009.38006267716,652.018545572949 5023.97421911362,626.551323008874 PathPoint;PointKind.SMOOTHPOINT 4999.43821294485,683.545267718927 5000.24109861053,728.428474180739 4999.18396046695,669.360095558586 PathPoint;PointKind.SMOOTHPOINT 5002.49823140358,865.53890230068 5002.00481466301,884.507144574655 5002.76147260544,855.429665881386 PathPoint;PointKind.SMOOTHPOINT 5002.49823140358,1338.52234364604 5002.69245204641,1363.49556345917 5002.30433178659,1313.55006793754 PathPoint;PointKind.SMOOTHPOINT 5004.53835071801,1934.50161277256 5004.42534961673,1986.89092314524 5004.65167284516,1882.11206637372 PathPoint;PointKind.SMOOTHPOINT 5004.53835071801,2426.48445184489 5004.30271773976,2483.83078361044 5004.77398369627,2369.13788405318 PathPoint;PointKind.SMOOTHPOINT 5004.53835071801,2758.47271051811 5004.17366534568,2796.65796663772 5004.90207301278,2720.28816247698 PathPoint;PointKind.SMOOTHPOINT 5003.51845157372,2881.46853829927 5003.73450197476,2888.89746165612 5003.30143809511,2874.03985096858 PathPoint;PointKind.SMOOTHPOINT 5002.49823140358,2907.46752779974 5001.78298579656,2912.23053568985 5003.31138989665,2902.05426784138 PathPoint;PointKind.SMOOTHPOINT 5002.49823140358,2936.4666458082 5002.12616243655,2948.7090866532 5002.86997934474,2924.22420496319 PathPoint;PointKind.SMOOTHPOINT 5002.49823140358,3083.46137741784 5002.61508481513,3093.52860118081 5002.35665900111,3071.29588110069 PathPoint;PointKind.SMOOTHPOINT 5002.49823140358,3110.46064578046 5001.9473510348,3120.26729666382 5002.70208282209,3106.83599205556 PathPoint;PointKind.SMOOTHPOINT 5002.45810317158,3138.24847754055 5003.84782410191,3141.88918104426 5000.95538113997,3134.31203325951 PathPoint;PointKind.SMOOTHPOINT 5001.47833225928,3232.45619469947 5001.7011242033,3234.50985830957 5000.62119322395,3224.56324391387 PathPoint;PointKind.SMOOTHPOINT 5005.55857088816,3273.45488263524 5012.48277757473,3291.83730798239 5000.44623413247,3259.88337848849 PathPoint;PointKind.SMOOTHPOINT 5031.05990180572,3321.45316234451 5032.82008657379,3419.062488508 5030.72667696726,3302.96287304266 PathPoint;PointKind.SMOOTHPOINT 5030.04000266143,3576.44425932616 5031.0017961258,3594.02537586326 5029.38318376019,3564.43855271871 PathPoint;PointKind.SMOOTHPOINT 5027.64900208646,3636.44210896275 5026.76810713778,3706.83997924661 5027.97484333023,3610.45657295335 PathPoint;PointKind.SMOOTHPOINT 5056.03539237126,3719.43929164413 5058.13907480518,3722.45901032332 5047.98085364596,3707.87873037269 PathPoint;PointKind.SMOOTHPOINT 5055.03154451977,3762.43782922574 5005.35889280577,3766.46372742106 5061.89250911272,3761.88175159496 PathPoint;PointKind.SMOOTHPOINT 4379.29234241482,3766.98440112798 4354.59357613709,3766.83900901399 4402.98308750493,3767.12389258799 PathPoint;PointKind.SMOOTHPOINT 3254.32079342558,3768.51290653414 3221.9954158885,3768.96064815791 3286.64681301436,3768.0644568319 PathPoint;PointKind.SMOOTHPOINT 2825.88385943675,3770.86679541859 2810.82517858676,3771.26213923504 2847.01602845509,3770.31236997092 PathPoint;PointKind.SMOOTHPOINT 2268.47703500881,3770.32889180206 2267.57431030193,3770.32723961894 2474.2270004367,3770.6862354069 PathPoint;PointKind.SMOOTHPOINT 2265.77592345701,3770.32440730504 2265.12552507289,3770.10537502941 2267.55312259544,3770.92202553981 PathPoint;PointKind.SMOOTHPOINT 2263.72135797905,3770.32063088649 2232.07334499799,3770.26587281759 2264.40482202633,3770.32181101729 PathPoint;PointKind.SMOOTHPOINT 2180.20327130015,3770.17689095561 2179.52333853729,3770.17571082482 2203.66801418769,3770.21630732418 PathPoint;PointKind.SMOOTHPOINT 2178.17599301995,3770.17358658939 2177.50665411033,3770.0322069201 2178.99492997843,3770.34588568551 PathPoint;PointKind.SMOOTHPOINT 2176.13555267965,3770.170046197 2142.10103348561,3770.11339991882 2176.81163313224,3770.17099030164 PathPoint;PointKind.SMOOTHPOINT 2113.06392379083,3770.08177241351 2088.34396980661,3770.09380974762 2119.21542124217,3770.07870407344 PathPoint;PointKind.SMOOTHPOINT 770.263169492594,3767.64716258266 769.84615690574,3767.64669053034 1303.74843124001,3768.57993796332 PathPoint;PointKind.SMOOTHPOINT 769.518068480979,3767.34386896825 769.184201590811,3767.34292486361 769.934760041976,3767.34434102057 PathPoint;PointKind.SMOOTHPOINT 768.010531061529,3767.64338616412 583.584708113826,3767.32121045698 768.344718977552,3767.64409424259 PathPoint;PointKind.SMOOTHPOINT 347.449003370392,3766.97377995082 346.919952759819,3766.9733078985 429.419103371995,3767.06889849293 PathPoint;PointKind.SMOOTHPOINT 345.871482314349,3766.97212776771 345.551419535987,3767.10335831215 346.952055345412,3766.52769051017 PathPoint;PointKind.SMOOTHPOINT 344.837779058253,3766.97094763691 307.687382906542,3766.92869895444 345.180955698243,3766.97118366307 PathPoint;PointKind.SMOOTHPOINT 293.388570257539,3767.4375713534 276.774198109707,3767.7184424827 295.397550063952,3767.40334756034 PathPoint;PointKind.SMOOTHPOINT 224.183421365304,3762.43782922574 221.646354025884,3759.32676842299 230.646313896898,3770.36287956896 PathPoint;PointKind.SMOOTHPOINT 224.183421365304,3716.4393991623 257.164654726044,3683.82790078922 220.92565097932,3719.65997610287 PathPoint;PointKind.SMOOTHPOINT 252.745412793303,3652.44161420789 253.970126433679,3639.80949417426 251.533219161309,3664.9441558802 PathPoint;PointKind.SMOOTHPOINT 253.09597302798,3544.44548486204 254.301425116999,3518.30346350917 251.89052093896,3570.58774224106 PathPoint;PointKind.SMOOTHPOINT 254.116193198127,3313.45352773502 253.711700619654,3304.87492095732 254.520685776599,3322.03189848656 PathPoint;PointKind.SMOOTHPOINT 263.296569600174,3277.45481795306 277.200520446383,3257.00480345242 260.213758305672,3281.9869922596 PathPoint;PointKind.SMOOTHPOINT 279.266963881008,3221.45666760814 279.382212163287,3213.41714457777 279.235503347127,3223.66941284946 PathPoint;PointKind.SMOOTHPOINT 279.447701437897,2980.66278012095 279.535341496566,2962.34478991522 279.378359853016,2995.24022775767 PathPoint;PointKind.SMOOTHPOINT 279.266963881008,1804.5061932179 279.111266340882,1788.07830049404 279.563270746032,1835.78201955678 PathPoint;PointKind.SMOOTHPOINT 279.617524115684,1389.52051583714 279.190238701441,1207.61090656802 280.085579813631,1588.43510178906 PathPoint;PointKind.SMOOTHPOINT 279.617524115684,1009.53374142849 279.726351880845,970.108639895261 279.565196901168,1028.36603263484 PathPoint;PointKind.SMOOTHPOINT 281.657643430123,778.54178430147 282.217833548722,753.229394897748 281.098095363236,803.854881783669 PathPoint;PointKind.SMOOTHPOINT 285.737882059001,650.546450418805 285.765490282611,645.40462054338 285.616534285459,673.190564094196 PathPoint;PointKind.SMOOTHPOINT 273.497166172368,613.547697800856 267.776806445541,604.513560536143 283.774166898274,629.778036629573 PathPoint;PointKind.SMOOTHPOINT 255.136092342418,583.548772982563 253.036904270488,528.379310482151 255.530954145213,593.922122673861 PathPoint;PointKind.SMOOTHPOINT 256.156312512566,453.553353427905 255.924531844584,439.50153604744 256.306873638997,462.695826699633 PathPoint;PointKind.SMOOTHPOINT 256.156312512566,390.55537528333 256.195156641133,385.376017248612 255.965944179999,415.15189734658 PathPoint;PointKind.SMOOTHPOINT 257.471876470169,368.173486670669 257.262888637958,355.744113107678 257.561121658118,373.480298831287 PathPoint;PointKind.SMOOTHPOINT 256.164338158964,345.08021521456 255.660006539297,338.196040232851 257.455183125661,362.702164277177 PathPoint;PointKind.SMOOTHPOINT 251.725192623156,279.559353455644 247.728741742676,248.92835058335 254.580717611658,301.442282768022 PathPoint;PointKind.SMOOTHPOINT 224.008141247966,235.560773038041 223.72852772745,234.926570748609 227.061418163721,242.487904780701 PathPoint;PointKind.SMOOTHPOINT 224.183421365304,200.562106092085 228.285810778241,194.188219666294 220.081352978223,206.935992517876 PathPoint;PointKind.SMOOTHPOINT 753.3287345664,192.498508393484 759.6160259548,192.454371501737 419.584476275561,194.851689199451 PathPoint;PointKind.SMOOTHPOINT 770.63812769232,193.196437745865 783.571296350196,190.842076809103 764.377160424106,194.335736015715 PathPoint;PointKind.SMOOTHPOINT 789.832905670122,192.017959133609 800.560305671898,192.559403142525 782.972583128885,191.671944784407 PathPoint;PointKind.SMOOTHPOINT 817.940324486124,192.069176810128 1122.05999576583,190.169166229583 809.493171139022,192.121810643602 PathPoint;PointKind.SMOOTHPOINT 1904.07384439903,189.35440392846 2529.04601764712,187.954768805152 1505.17064710411,190.247998966714 PathPoint;PointKind.SMOOTHPOINT 3638.74026717848,188.187490597999 3642.02917707249,188.18985085959 3190.60197641119,187.92715374454 PathPoint;PointKind.SMOOTHPOINT 3647.3861355304,188.140521392343 3648.46510343219,187.815985423617 3645.82113448274,188.611393579696 PathPoint;PointKind.SMOOTHPOINT 3655.61049693349,188.197639722839 3969.97249814666,188.387404754734 3653.27021844375,188.196223565885 PathPoint;PointKind.SMOOTHPOINT 4181.58375365213,188.795257957614 4210.32776674045,189.148353091589 4175.13434420649,188.716189194324 PathPoint;PointKind.SMOOTHPOINT 4742.8242688516,191.242141148733 4752.67944160281,191.462825607467 4700.37983530974,190.291899832302 PathPoint;PointKind.SMOOTHPOINT 4812.23198505893,191.922368539184 4812.98511171694,191.927089062366 4779.0321330903,191.697435609587 PathPoint;PointKind.SMOOTHPOINT 4814.50163786036,191.937474213365 4814.98189254083,192.278059960909 4814.3228264586,191.810492139783 PathPoint;PointKind.SMOOTHPOINT 4816.27498468852,191.949275521319 4897.19340398609,192.486471059371 4815.68204993261,191.945499102774 PathPoint;PointKind.SMOOTHPOINT 5056.05144366406,193.56227829243 5060.72654320398,193.749447036575 5029.75942606335,192.510545727597 PathPoint";
	
	negative645[1] = "PointKind.SMOOTHPOINT 5056.03535329591,230.561030910378 5052.00289436999,235.40287153762 5059.16924900763,226.799009960899 PathPoint;PointKind.SMOOTHPOINT 5038.69427107301,254.560170765013 5032.67238869641,264.319852442719 5044.39576542255,245.319274584951 PathPoint;PointKind.SMOOTHPOINT 5030.03962095088,299.558557992453 5030.98377043748,317.515428174796 5028.6922576747,273.933433927958 PathPoint;PointKind.SMOOTHPOINT 5031.05953353807,370.55617074652 5033.05473553032,394.241395809587 5029.23319337172,348.875515852469 PathPoint;PointKind.SMOOTHPOINT 5031.05953353807,465.552923355222 5031.05953353807,465.552923355222 5031.05600220711,465.556935799927 PathPoint;PointKind.SMOOTHPOINT 5032.07976715535,594.548300073884 5031.93819288687,607.438632725546 5032.72439557054,535.838681213523 PathPoint;PointKind.SMOOTHPOINT 5018.81865631129,635.546988009658 5016.82538049956,639.02530551593 5023.97375745232,626.551323008874 PathPoint;PointKind.SMOOTHPOINT 5012.84300226725,646.060537239446 5012.14187255669,656.606422053027 5012.9171602174,644.943661454708 PathPoint;PointKind.SMOOTHPOINT 4999.43742788393,683.545267718927 5000.24032413213,728.428474180739 4999.23678407939,672.355503543393 PathPoint;PointKind.SMOOTHPOINT 5002.49748667558,865.53890230068 5002.00406343148,884.507144574655 5002.76073134712,855.429665881386 PathPoint;PointKind.SMOOTHPOINT 5002.49748667558,1338.52234364604 5002.69170987836,1363.49556345917 5002.30358450288,1313.55006793754 PathPoint;PointKind.SMOOTHPOINT 5004.53763288004,1934.50161277256 5004.42463028933,1986.89092314524 5004.65095650084,1882.11206637372 PathPoint;PointKind.SMOOTHPOINT 5004.53763288004,2426.48445184489 5004.42751956011,2453.28522220773 5004.77326896408,2369.13788405318 PathPoint;PointKind.SMOOTHPOINT 5004.57069897903,2585.72728892735 5004.57423030999,2588.91883465035 5004.49975132975,2519.20685638476 PathPoint;PointKind.SMOOTHPOINT 5004.01178559713,2596.47851649933 5006.3816297012,2601.72797430329 5002.69459914915,2593.56123317317 PathPoint;PointKind.SMOOTHPOINT 5004.59638138601,2609.81139819925 5004.66572388485,2677.15768627245 5004.59124490461,2604.9915080048 PathPoint;PointKind.SMOOTHPOINT 5004.53763288004,2758.47271051811 5004.17294270093,2796.65796663772 5004.71066809707,2740.29114343233 PathPoint;PointKind.SMOOTHPOINT 5003.51772029285,2881.46853829927 5003.73377354157,2888.89746165612 5003.30070395387,2874.03985096858 PathPoint;PointKind.SMOOTHPOINT 5002.49748667558,2907.46752779974 5001.78223164119,2912.23053568985 5003.31065588658,2902.05426784138 PathPoint;PointKind.SMOOTHPOINT 5002.49748667558,2936.4666458082 5002.12541280446,2948.7090866532 5002.86923951661,2924.22420496319 PathPoint;PointKind.SMOOTHPOINT 5002.49748667558,3083.46137741784 5002.61434162734,3093.52860118081 5002.3559124071,3071.29588110069 PathPoint;PointKind.SMOOTHPOINT 5002.49748667558,3110.46064578046 5001.94659904586,3120.26729666382 5002.70134078098,3106.83599205556 PathPoint;PointKind.SMOOTHPOINT 5002.99155197985,3133.4597427991 5004.38129122755,3137.10044630281 5001.48881014144,3129.52329851806 PathPoint;PointKind.SMOOTHPOINT 5001.47757408839,3232.45619469947 5001.70036896894,3234.50985830957 5000.62042375543,3224.56324391387 PathPoint;PointKind.SMOOTHPOINT 5005.55786649732,3273.45488263524 5012.48216444918,3291.83730798239 5000.44546235788,3259.88337848849 PathPoint;PointKind.SMOOTHPOINT 5031.05953353807,3321.45316234451 5032.81974150646,3419.062488508 5030.72630430751,3302.96287304266 PathPoint;PointKind.SMOOTHPOINT 5030.03962095088,3576.44425932616 5031.00142709228,3594.02537586326 5029.38279339237,3564.43855271871 PathPoint;PointKind.SMOOTHPOINT 5027.64858886106,3636.44210896275 5025.94616630838,3681.24483050432 5028.63607740943,3610.47262273217 PathPoint;PointKind.SMOOTHPOINT 5056.03535329591,3719.43929164413 5058.13906345765,3722.45901032332 5047.98070840685,3707.87873037269 PathPoint;PointKind.SMOOTHPOINT 5055.03149221309,3762.43782922574 5005.35818578305,3766.46372742106 5061.89254723776,3761.88175159496 PathPoint;PointKind.SMOOTHPOINT 4379.28338345059,3766.98440112798 4354.58429162795,3766.83900901399 4402.97444079926,3767.12389258799 PathPoint;PointKind.SMOOTHPOINT 3254.29700664565,3768.51290653414 3221.97120304025,3768.96064815791 3286.62345231122,3768.0644568319 PathPoint;PointKind.SMOOTHPOINT 2825.85442559499,3770.86679541859 2810.79554626234,3771.26213923504 2846.98687314829,3770.31236997092 PathPoint;PointKind.SMOOTHPOINT 2268.44025420288,3770.32889180206 2267.53751759754,3770.32723961894 2474.19293154164,3770.6862354069 PathPoint;PointKind.SMOOTHPOINT 2265.73910704877,3770.32440730504 2265.088700092,3770.10537502941 2267.51632961178,3770.92202553981 PathPoint;PointKind.SMOOTHPOINT 2263.68451449038,3770.32063088649 2232.03608436908,3770.26587281759 2264.36798754613,3770.32181101729 PathPoint;PointKind.SMOOTHPOINT 2180.16532699182,3770.17689095561 2179.48538526703,3770.17571082482 2203.63037915907,3770.21630732418 PathPoint;PointKind.SMOOTHPOINT 2178.13802199085,3770.17358658939 2177.46867425893,3770.0322069201 2178.95696974342,3770.34588568551 PathPoint;PointKind.SMOOTHPOINT 2176.0975547563,3770.170046197 2142.06258696639,3770.11339991882 2176.77364412004,3770.17099030164 PathPoint;PointKind.SMOOTHPOINT 2113.02509454468,3770.08177241351 2088.30481473629,3770.09380974762 2119.17667307653,3770.07870407344 PathPoint;PointKind.SMOOTHPOINT 770.206641308085,3767.64716258266 769.789623224749,3767.64669053034 1303.69893471879,3768.57993796332 PathPoint;PointKind.SMOOTHPOINT 769.461530475581,3767.34386896825 769.127659184843,3767.34292486361 769.878227528829,3767.34434102057 PathPoint;PointKind.SMOOTHPOINT 767.953973185862,3767.64338616412 583.525719392584,3767.32121045698 768.288165506688,3767.64409424259 PathPoint;PointKind.SMOOTHPOINT 347.386902235586,3766.97377995082 346.8578446518,3766.9733078985 429.358082653432,3767.06889849293 PathPoint;PointKind.SMOOTHPOINT 345.809360386847,3766.97212776771 345.48929338986,3767.10335831215 346.889947660525,3766.52769051017 PathPoint;PointKind.SMOOTHPOINT 344.775643505907,3766.97094763691 307.624757689167,3766.92869895444 345.118824669176,3766.97118366307 PathPoint;PointKind.SMOOTHPOINT 293.325756573033,3767.4375713534 276.711165437577,3767.7184424827 295.334762859034,3767.40334756034 PathPoint;PointKind.SMOOTHPOINT 224.119695514447,3762.43782922574 221.582594734923,3759.32676842299 230.582673230933,3770.36287956896 PathPoint;PointKind.SMOOTHPOINT 224.119695514447,3716.4393991623 250.728274296035,3688.46180237032 220.964290786882,3719.75651080193 PathPoint;PointKind.SMOOTHPOINT 252.506459949305,3648.44167889007 253.731189732158,3635.80955885643 251.294250339854,3660.94422056237 PathPoint;PointKind.SMOOTHPOINT 253.032628262305,3544.44548486204 253.83006699903,3527.14972395126 251.827160284687,3570.58774224106 PathPoint;PointKind.SMOOTHPOINT 254.235206969138,3372.77516242586 254.236491089487,3370.84706473238 254.196041298493,3435.38440548644 PathPoint;PointKind.SMOOTHPOINT 253.52669356658,3367.45159240795 251.080765331834,3365.46920869788 254.996690336091,3368.64305245895 PathPoint;PointKind.SMOOTHPOINT 254.238738300097,3360.71941827268 254.237133149661,3334.78014339046 254.238738300097,3362.7943242371 PathPoint;PointKind.SMOOTHPOINT 254.05286187958,3313.45352773502 253.648363969647,3304.87492095732 254.17196404195,3315.97947968943 PathPoint;PointKind.SMOOTHPOINT 263.233359284625,3277.45481795306 277.137493393442,3257.00480345242 260.150507356778,3281.9869922596 PathPoint;PointKind.SMOOTHPOINT 279.203964065061,3221.45666760814 279.319213866383,3213.41714457777 279.17250311651,3223.66941284946 PathPoint;PointKind.SMOOTHPOINT 279.384704004182,2980.66278012095 279.472345218,2962.34478991522 279.315361505336,2995.24022775767 PathPoint;PointKind.SMOOTHPOINT 279.203964065061,1804.5061932179 279.083577782343,1791.79547647329 279.500274835591,1835.78201955678 PathPoint;PointKind.SMOOTHPOINT 279.680372714537,1522.52456084151 279.681014774712,1520.33069769292 279.639601893457,1669.40009924082 PathPoint;PointKind.SMOOTHPOINT 278.008448020148,1515.51623610013 279.142647318396,1513.78805256339 276.600410057476,1517.66100580763 PathPoint;PointKind.SMOOTHPOINT 279.682619925148,1509.74893690316 279.685509195933,1470.68259513172 279.682619925148,1511.8127496381 PathPoint;PointKind.SMOOTHPOINT 279.554528920336,1389.52051583714 279.127237874208,1207.61090656802 279.649874856249,1430.08633179717 PathPoint;PointKind.SMOOTHPOINT 279.554528920336,1009.53374142849 279.663358119913,970.108639895261 279.502201016115,1028.36603263484 PathPoint;PointKind.SMOOTHPOINT 282.088740429075,777.541977491633 281.057270758746,750.969208398457 283.07173455623,802.842565587402 PathPoint;PointKind.SMOOTHPOINT 285.674967533728,650.546450418805 285.702576121231,645.40462054338 285.553618160748,673.190564094196 PathPoint;PointKind.SMOOTHPOINT 273.434090306944,613.547697800856 267.713655182264,604.513560536143 283.711226490029,629.778036629573 PathPoint;PointKind.SMOOTHPOINT 255.072774466769,583.548772982563 252.973558726251,528.379310482151 255.467641474084,593.922122673861 PathPoint;PointKind.SMOOTHPOINT 256.093008084044,453.553353427905 255.861224361051,439.50153604744 256.243571194964,462.695826699633 PathPoint;PointKind.SMOOTHPOINT 256.093008084044,390.55537528333 256.131852724602,385.376017248612 255.902637242306,415.15189734658 PathPoint;PointKind.SMOOTHPOINT 257.408589381589,368.173486670669 257.19959879479,355.744113107678 257.497835745844,373.480298831287 PathPoint;PointKind.SMOOTHPOINT 256.101033836226,345.08021521456 255.596695569158,338.196040232851 257.391895817052,362.702164277177 PathPoint;PointKind.SMOOTHPOINT 253.52669356658,282.559245937473 248.367740064498,252.167101538163 257.221107810635,304.321093830246 PathPoint;PointKind.SMOOTHPOINT 225.984559291273,236.560815874037 225.70494208528,235.926613584605 229.037876451094,243.487947616697 PathPoint;PointKind.SMOOTHPOINT 224.119695514447,200.562106092085 228.222138999395,194.188219666294 220.017573059586,206.935992517876 PathPoint;PointKind.SMOOTHPOINT 753.271983175641,192.498508393484 759.559357434402,192.454371501737 419.523325930576,194.851689199451 PathPoint;PointKind.SMOOTHPOINT 770.581604449991,193.196437745865 783.514943574969,190.842076809103 764.320554658384,194.335736015715 PathPoint;PointKind.SMOOTHPOINT 789.776635426751,192.017959133609 800.504176822245,192.559403142525 782.916222462251,191.671944784407 PathPoint;PointKind.SMOOTHPOINT 817.884424715789,192.069176810128 1122.00810447948,190.169166229583 809.437160030021,192.121810643602 PathPoint;PointKind.SMOOTHPOINT 1904.03226053532,189.35440392846 2529.01267130036,187.954768805152 1505.12380545135,190.247998966714 PathPoint;PointKind.SMOOTHPOINT 3638.72154728323,188.187490597999 3642.01050052709,188.18985085959 3190.57734977814,187.92715374454 PathPoint;PointKind.SMOOTHPOINT 3647.367529593,188.140521392343 3648.44651171625,187.815985423617 3645.80250791767,188.611393579696 PathPoint;PointKind.SMOOTHPOINT 3655.59199939822,188.197639722839 3969.95814409558,188.387404754734 3653.25169006218,188.196223565885 PathPoint;PointKind.SMOOTHPOINT 4181.57218876731,188.795257957614 4210.31658071937,189.148353091589 4175.12269431449,188.716189194324 PathPoint;PointKind.SMOOTHPOINT 4742.82010146135,191.242141148733 4752.67540410979,191.462825607467 4700.37510847579,190.291899832302 PathPoint;PointKind.SMOOTHPOINT 4812.22873250499,191.922368539184 4812.98186908967,191.927089062366 4779.02844294193,191.697435609587 PathPoint;PointKind.SMOOTHPOINT 4814.49841522183,191.937474213365 4814.97867623236,192.278059960909 4814.31960146324,191.810492139783 PathPoint;PointKind.SMOOTHPOINT 4816.27178542379,191.949275521319 4897.19127127581,192.486471059371 4815.67884285265,191.945499102774 PathPoint;PointKind.SMOOTHPOINT 5056.05140480028,193.56227829243 5060.72656596088,193.749447036575 5029.75904065463,192.510545727597 PathPoint";
	
	negative645[2] = "PointKind.SMOOTHPOINT 5055.03569763317,230.561030910378 5050.91029816366,235.51498396318 5058.16922934973,226.799009960899 PathPoint;PointKind.SMOOTHPOINT 5040.75633291166,250.560235447187 5039.57572139214,255.319466918754 5042.83090938002,242.196884526563 PathPoint;PointKind.SMOOTHPOINT 5031.58139570058,265.872432517107 5029.41148437053,274.434281437513 5033.23707656455,259.33970048626 PathPoint;PointKind.SMOOTHPOINT 5029.04298463578,299.558557992453 5029.98702446147,317.515428174796 5028.29571339667,285.342466405273 PathPoint;PointKind.SMOOTHPOINT 5030.06277876234,370.55617074652 5032.05774901623,394.241395809587 5028.23665072142,348.875515852469 PathPoint;PointKind.SMOOTHPOINT 5030.06277876234,465.552923355222 5030.06277876234,465.552923355222 5030.05924784154,465.556935799927 PathPoint;PointKind.SMOOTHPOINT 5031.08289388171,594.548300073884 5030.94133605678,607.438632725546 5031.72744742472,535.838681213523 PathPoint;PointKind.SMOOTHPOINT 5017.82332328677,635.546988009658 5017.06449630685,636.871094762063 5022.97782567404,626.551323008874 PathPoint;PointKind.SMOOTHPOINT 5011.17780934208,646.546515100979 5002.45290403703,661.798525500335 5011.9404882356,645.213203328371 PathPoint;PointKind.SMOOTHPOINT 4997.91823874714,687.544967010594 4998.18273681459,702.326341248756 4997.68455598852,674.500273250897 PathPoint;PointKind.SMOOTHPOINT 4999.24297603399,750.483230536923 4999.31134750046,753.563371912838 4998.69022643187,725.579638440717 PathPoint;PointKind.SMOOTHPOINT 5001.998057239,757.542536928665 5004.37597190365,760.602380054899 4998.94734166491,753.617185877107 PathPoint;PointKind.SMOOTHPOINT 4999.70713162323,771.356203914624 5000.69707341937,815.880886640803 4999.62142654555,767.496940187607 PathPoint;PointKind.SMOOTHPOINT 5001.50404931933,865.53890230068 5001.01068338526,884.507144574655 5001.65652089947,859.678608797034 PathPoint;PointKind.SMOOTHPOINT 5001.50404931933,1338.52234364604 5001.69824996351,1363.49556345917 5001.31016966795,1313.55006793754 PathPoint;PointKind.SMOOTHPOINT 5003.54395856526,1934.50161277256 5003.43096909955,1986.89092314524 5003.65726902377,1882.11206637372 PathPoint;PointKind.SMOOTHPOINT 5003.54395856526,2426.48445184489 5003.30834984984,2483.83078361044 5003.77956728068,2369.13788405318 PathPoint;PointKind.SMOOTHPOINT 5003.54395856526,2758.47271051811 5003.17931074412,2796.65796663772 5003.907643408,2720.28816247698 PathPoint;PointKind.SMOOTHPOINT 5002.5241644387,2881.46853829927 5002.7401925933,2888.89746165612 5002.30717330569,2874.03985096858 PathPoint;PointKind.SMOOTHPOINT 5001.50404931933,2907.46752779974 5000.78887736025,2912.23053568985 5002.3171240825,2902.05426784138 PathPoint;PointKind.SMOOTHPOINT 5001.50404931933,2936.4666458082 5001.13201866378,2948.7090866532 5001.87575898208,2924.22420496319 PathPoint;PointKind.SMOOTHPOINT 5001.50404931933,3083.46137741784 5001.62089069864,3093.52860118081 5001.3624914944,3071.29588110069 PathPoint;PointKind.SMOOTHPOINT 5001.50404931933,3110.46064578046 5000.95322567401,3120.26729666382 5001.70787974752,3106.83599205556 PathPoint;PointKind.SMOOTHPOINT 5001.46392521929,3138.24847754055 5002.85350305181,3141.88918104426 4999.96135792107,3134.31203325951 PathPoint;PointKind.SMOOTHPOINT 5000.48425519277,3232.45619469947 5000.70702419618,3234.50985830957 4999.62720441596,3224.56324391387 PathPoint;PointKind.SMOOTHPOINT 5004.03796648493,3266.45505483558 5010.96146019468,3284.83748018274 4998.92615614009,3252.88355068883 PathPoint;PointKind.SMOOTHPOINT 5030.06277876234,3321.45316234451 5031.82278228641,3419.062488508 5029.72958823563,3302.96287304266 PathPoint;PointKind.SMOOTHPOINT 5029.04298463578,3576.44425932616 5030.00467906549,3594.02537586326 5028.38623336636,3564.43855271871 PathPoint;PointKind.SMOOTHPOINT 5026.65223025912,3636.44210896275 5027.10739804995,3684.3684006935 5026.40602878129,3610.45562884871 PathPoint;PointKind.SMOOTHPOINT 5055.03569763317,3719.43929164413 5057.13916345356,3722.45901032332 5046.98198827355,3707.87873037269 PathPoint;PointKind.SMOOTHPOINT 5054.03195314662,3762.43782922574 5004.36441616284,3766.46372742106 5060.89221127471,3761.88175159496 PathPoint;PointKind.SMOOTHPOINT 4378.36233105389,3766.98440112798 4353.66610797693,3766.83900901399 4402.0506367379,3767.12389258799 PathPoint;PointKind.SMOOTHPOINT 3253.50661896427,3768.51290653414 3221.18456993049,3768.96064815791 3285.82930998364,3768.0644568319 PathPoint;PointKind.SMOOTHPOINT 2825.11380058544,3770.86679541859 2810.0566703088,3771.26213923504 2846.24379365103,3770.31236997092 PathPoint;PointKind.SMOOTHPOINT 2267.76437163424,3770.32889180206 2266.86173987978,3770.32723961894 2473.49315124804,3770.6862354069 PathPoint;PointKind.SMOOTHPOINT 2265.06353821248,3770.32440730504 2264.41320679907,3770.10537502941 2266.84055435496,3770.92202553981 PathPoint;PointKind.SMOOTHPOINT 2263.00918429054,3770.32063088649 2231.36443006541,3770.26587281759 2263.69257796239,3770.32181101729 PathPoint;PointKind.SMOOTHPOINT 2179.49969736355,3770.17689095561 2178.8198346125,3770.17571082482 2202.96202411614,3770.21630732418 PathPoint;PointKind.SMOOTHPOINT 2177.47262782963,3770.17358658939 2176.803357841,3770.0322069201 2178.2914804632,3770.34588568551 PathPoint;PointKind.SMOOTHPOINT 2175.4323975909,3770.170046197 2141.40138288831,3770.11339991882 2176.10840842834,3770.17099030164 PathPoint;PointKind.SMOOTHPOINT 2112.36726310805,3770.08177241351 2087.64985450626,3770.09380974762 2118.51812714746,3770.07870407344 PathPoint;PointKind.SMOOTHPOINT 769.704775307597,3767.64716258266 769.287805660003,3767.64669053034 1303.13510475138,3768.57993796332 PathPoint;PointKind.SMOOTHPOINT 768.959751018092,3767.34386896825 768.625918505777,3767.34292486361 769.376399672886,3767.34434102057 PathPoint;PointKind.SMOOTHPOINT 767.452368827867,3767.64338616412 583.045535974233,3767.32121045698 767.786522332983,3767.64409424259 PathPoint;PointKind.SMOOTHPOINT 346.934145826091,3766.97377995082 346.405149691191,3766.9733078985 428.89580547002,3767.06889849293 PathPoint;PointKind.SMOOTHPOINT 345.356787205399,3766.97212776771 345.036757383496,3767.10335831215 346.437248971221,3766.52769051017 PathPoint;PointKind.SMOOTHPOINT 344.323190388421,3766.97094763691 307.176619566084,3766.92869895444 344.666331691946,3766.97118366307 PathPoint;PointKind.SMOOTHPOINT 292.87927924776,3767.4375713534 276.266617860845,3767.7184424827 294.88805219206,3767.40334756034 PathPoint;PointKind.SMOOTHPOINT 223.681256322304,3762.43782922574 221.144450221504,3759.32676842299 230.143483378017,3770.36287956896 PathPoint;PointKind.SMOOTHPOINT 221.466085007409,3718.43924880814 230.599935140048,3709.77236824694 218.141562574664,3721.59326637184 PathPoint;PointKind.SMOOTHPOINT 241.362181748629,3689.73610760316 242.244590956663,3687.74947542223 236.93408606844,3699.70679666708 PathPoint;PointKind.SMOOTHPOINT 242.885292586069,3684.44062469818 244.054990350376,3681.32201105833 242.147330138171,3686.4076667079 PathPoint;PointKind.SMOOTHPOINT 246.810071555382,3674.60848298964 250.494747910067,3661.68321846643 245.956551699375,3677.60176673901 PathPoint;PointKind.SMOOTHPOINT 252.064723696352,3644.4419795984 253.289311229511,3631.80985956476 251.490788569409,3650.3648200342 PathPoint;PointKind.SMOOTHPOINT 252.59083089605,3544.44548486204 253.79615886119,3518.30346350917 251.38550293091,3570.58774224106 PathPoint;PointKind.SMOOTHPOINT 253.610946015415,3313.45352773502 253.206495087032,3304.87492095732 254.015396943798,3322.03189848656 PathPoint;PointKind.SMOOTHPOINT 262.790377125698,3277.45481795306 276.692896299649,3257.00480345242 259.707883264382,3281.9869922596 PathPoint;PointKind.SMOOTHPOINT 278.759126955203,3221.45666760814 278.874363370512,3213.41714457777 278.727669660773,3223.66941284946 PathPoint;PointKind.SMOOTHPOINT 278.939845901774,2980.66278012095 279.027476936257,2962.34478991522 278.870511456908,2995.24022775767 PathPoint;PointKind.SMOOTHPOINT 278.759126955203,1804.5061932179 278.603445447056,1788.07830049404 279.055403309883,1835.78201955678 PathPoint;PointKind.SMOOTHPOINT 279.109651093135,1389.52051583714 278.682409675931,1207.61090656802 279.577658595977,1588.43510178906 PathPoint;PointKind.SMOOTHPOINT 279.109651093135,1009.53374142849 279.218467652438,970.108639895261 279.057329266685,1028.36603263484 PathPoint;PointKind.SMOOTHPOINT 281.149560339064,778.54178430147 281.709692775594,753.229394897748 280.590069888135,803.854881783669 PathPoint;PointKind.SMOOTHPOINT 285.229378830923,650.546450418805 285.25698421175,645.40462054338 285.108043552409,673.190564094196 PathPoint;PointKind.SMOOTHPOINT 270.423906909719,612.54765496486 264.704136201108,603.513517700147 280.699849425839,628.777993793577 PathPoint;PointKind.SMOOTHPOINT 254.63074014198,583.548772982563 252.531768220794,528.379310482151 255.025561286353,593.922122673861 PathPoint;PointKind.SMOOTHPOINT 255.650855261345,453.553353427905 255.419098459525,439.50153604744 255.801400884687,462.695826699633 PathPoint;PointKind.SMOOTHPOINT 255.650855261345,390.55537528333 255.689695390181,385.376017248612 255.460506530765,415.15189734658 PathPoint;PointKind.SMOOTHPOINT 255.124748061647,365.556192592699 254.915781748649,353.126819029708 255.213984060131,370.863004753316 PathPoint;PointKind.SMOOTHPOINT 255.658880081352,345.08021521456 255.154600392075,338.196040232851 256.949592131373,362.702164277177 PathPoint;PointKind.SMOOTHPOINT 251.220191638754,279.559353455644 248.15053748945,259.811752804407 254.610838588361,301.368642606391 PathPoint;PointKind.SMOOTHPOINT 223.505994253338,235.560773038041 223.226409524274,234.926570748609 226.558956777026,242.487904780701 PathPoint;PointKind.SMOOTHPOINT 223.681256322304,200.562106092085 227.783223317384,194.188219666294 219.579610320024,206.935992517876 PathPoint;PointKind.SMOOTHPOINT 752.77208409878,192.498508393484 759.058728092727,192.454371501737 419.062191032718,194.851689199451 PathPoint;PointKind.SMOOTHPOINT 770.079694898352,193.196437745865 783.011531844184,190.842076809103 763.81937231403,194.335736015715 PathPoint;PointKind.SMOOTHPOINT 789.272496414107,192.017959133609 799.998791829053,192.559403142525 782.412880271618,191.671944784407 PathPoint;PointKind.SMOOTHPOINT 817.377021044691,192.069176810128 1121.46537750593,190.169166229583 808.930737490302,192.121810643602 PathPoint;PointKind.SMOOTHPOINT 1903.39870316078,189.35440392846 2528.30652381349,187.954768805152 1504.53658042429,190.247998966714 PathPoint;PointKind.SMOOTHPOINT 3637.88650952946,188.187490597999 3641.17508076857,188.18985085959 3189.794362996,187.92715374454 PathPoint;PointKind.SMOOTHPOINT 3646.53148762724,188.140521392343 3647.61034442906,187.815985423617 3644.96664772576,188.611393579696 PathPoint;PointKind.SMOOTHPOINT 3654.75500217822,188.197639722839 3969.08463393315,188.387404754734 3652.414964664,188.196223565885 PathPoint;PointKind.SMOOTHPOINT 4180.67410009489,188.795257957614 4209.41515344848,189.148353091589 4174.22535473679,188.716189194324 PathPoint;PointKind.SMOOTHPOINT 4741.85682506733,191.242141148733 4751.71098304385,191.462825607467 4699.41676197518,190.291899832302 PathPoint;PointKind.SMOOTHPOINT 4811.25739444977,191.922368539184 4812.01044355928,191.927089062366 4778.06096102797,191.697435609587 PathPoint;PointKind.SMOOTHPOINT 4813.52681354792,191.937474213365 4814.00701877717,192.278059960909 4813.34802055815,191.810492139783 PathPoint;PointKind.SMOOTHPOINT 4815.2999777768,191.949275521319 4896.21006500693,192.486471059371 4814.70710407464,191.945499102774 PathPoint;PointKind.SMOOTHPOINT 5055.05174727318,193.56227829243 5059.726365424,193.749447036575 5028.76243692831,192.510545727597 PathPoint";
	
} else if ( (negative_variant_645 == 2 && fancy == true && mask_variant_645 == 1) || (negative_variant_645 == 2 && fancy == true && mask_variant_645 == 2) || (negative_variant_645 == 2 && fancy == true && mask_variant_645 == 5) ) {
	
	negative645[0] = "PointKind.SMOOTHPOINT 5008,231 4999.87196851886,240.955617240294 5011.07214797876,227.237794986571 PathPoint;PointKind.SMOOTHPOINT 4982.51566696167,299.999949932098 4983.44123649597,317.957446575165 4979.94415092468,250.109596252441 PathPoint;PointKind.SMOOTHPOINT 4983.51550865173,371.000039577484 4985.47144699097,394.686090946198 4981.72510910034,349.318628311157 PathPoint;PointKind.SMOOTHPOINT 4983.51550865173,466.000106334686 4983.51550865173,466.000106334686 4983.51204681396,466.004118919373 PathPoint;PointKind.SMOOTHPOINT 4984.51566505432,594.999983310699 4984.37687683105,607.890765666962 4985.14760780334,536.288316249847 PathPoint;PointKind.SMOOTHPOINT 4971.51552009583,636.000101566315 4962.26202774048,652.472233772278 4976.56917381287,627.00412273407 PathPoint;PointKind.SMOOTHPOINT 4952.5156955719,684.000055789948 4953.30279159546,728.884828090668 4952.26644325256,669.814388751984 PathPoint;PointKind.SMOOTHPOINT 4955.51553535461,866.000039577484 4955.03182220459,884.968943595886 4955.77359962463,855.8904504776 PathPoint;PointKind.SMOOTHPOINT 4955.51553535461,1338.99998188019 4955.70593643188,1363.9740729332 4955.32544898987,1314.02683496475 PathPoint;PointKind.SMOOTHPOINT 4957.51553344727,1935.00004291534 4957.40475463867,1987.39118099213 4957.62662696838,1882.60866880417 PathPoint;PointKind.SMOOTHPOINT 4957.51553344727,2427.00004577637 4957.28453445435,2484.34837818146 4957.74653244019,2369.65147733688 PathPoint;PointKind.SMOOTHPOINT 4957.51553344727,2758.99988651276 4957.15802001953,2797.18647480011 4957.87210273743,2720.81400632858 PathPoint;PointKind.SMOOTHPOINT 4956.5156917572,2882.00000524521 4956.72749328613,2889.42918777466 4956.3029460907,2874.57105875015 PathPoint;PointKind.SMOOTHPOINT 4955.51553535461,2907.99990177155 4954.81435585022,2912.76307582855 4956.31270217896,2902.58645296097 PathPoint;PointKind.SMOOTHPOINT 4955.51553535461,2937.00003147125 4955.15078353882,2949.24289941788 4955.87997245789,2924.75716352463 PathPoint;PointKind.SMOOTHPOINT 4955.51553535461,3083.99989128113 4955.6300907135,3094.067466259 4955.37674713135,3071.83397054672 PathPoint;PointKind.SMOOTHPOINT 4955.51553535461,3111.00010156631 4954.97548866272,3120.80709457397 4955.71537780762,3107.37532138824 PathPoint;PointKind.SMOOTHPOINT 4955.47619628906,3138.78890275955 4956.83858680725,3142.42973327637 4954.00302696228,3134.85232114792 PathPoint;PointKind.SMOOTHPOINT 4954.51569366455,3232.99990653992 4954.73410415649,3235.05364179611 4953.67541122437,3225.10668039322 PathPoint;PointKind.SMOOTHPOINT 4958.51568984985,3274.00002479553 4965.30372428894,3292.38309144974 4953.50389289856,3260.42804718018 PathPoint;PointKind.SMOOTHPOINT 4983.51550865173,3321.99997901917 4985.2410774231,3419.61271047592 4983.18883705139,3303.50904464722 PathPoint;PointKind.SMOOTHPOINT 4982.51566696167,3576.99997186661 4983.45854568481,3594.58170175552 4981.87176513672,3564.99384641647 PathPoint;PointKind.SMOOTHPOINT 4980.171875,3637 4979.30830383301,3707.40032625198 4980.49130821228,3611.01355743408 PathPoint;PointKind.SMOOTHPOINT 5008,3720 5010.06231117249,3723.01982402802 5000.10386276245,3708.43903541565 PathPoint;PointKind.SMOOTHPOINT 5007.01571273804,3763.00003051758 4958.32005860655,3767.02615589617 5013.74194628495,3762.44400719872 PathPoint;PointKind.SMOOTHPOINT 4344.56568527222,3767.54676103592 4320.35264778137,3767.40136384964 4367.7905254364,3767.68625736237 PathPoint;PointKind.SMOOTHPOINT 3241.71795654297,3769.075319767 3210.02829360962,3769.52307701111 3273.40824890137,3768.62685441971 PathPoint;PointKind.SMOOTHPOINT 2821.70671272278,3771.42929077148 2806.94417762756,3771.82464838028 2842.42329406738,3770.8748459816 PathPoint;PointKind.SMOOTHPOINT 2275.26191520691,3770.89136838913 2274.37694358826,3770.88971614838 2476.96557807922,3771.2487244606 PathPoint;PointKind.SMOOTHPOINT 2272.61392402649,3770.88688373566 2271.97631645203,3770.66784381866 2274.35617256165,3771.48452281952 PathPoint;PointKind.SMOOTHPOINT 2270.59976387024,3770.88310718536 2239.5741443634,3770.82834720612 2271.26978683472,3770.88428735733 PathPoint;PointKind.SMOOTHPOINT 2188.72415351868,3770.73936223984 2188.05759239197,3770.73818206787 2211.72743606567,3770.77877998352 PathPoint;PointKind.SMOOTHPOINT 2186.736743927,3770.73605775833 2186.0805683136,3770.59467315674 2187.53957557678,3770.90836286545 PathPoint;PointKind.SMOOTHPOINT 2184.73643112183,3770.73251724243 2151.3712387085,3770.67586898804 2185.39921569824,3770.73346138 PathPoint;PointKind.SMOOTHPOINT 2122.90517616272,3770.64424037933 2098.67136764526,3770.65627813339 2128.93569755554,3770.64117193222 PathPoint;PointKind.SMOOTHPOINT 806.512096405029,3768.20954561234 806.103284835815,3768.20907354355 1329.50577545166,3769.1423535347 PathPoint;PointKind.SMOOTHPOINT 805.781648635864,3767.90624141693 805.454347610474,3767.90529727936 806.190145492554,3767.90671348572 PathPoint;PointKind.SMOOTHPOINT 804.303758621216,3768.20576906204 623.504875183105,3767.88358211517 804.631374359131,3768.20647716522 PathPoint;PointKind.SMOOTHPOINT 392.013042449951,3767.53613948822 391.494396209717,3767.53566741943 472.371109008789,3767.63126134872 PathPoint;PointKind.SMOOTHPOINT 390.46654510498,3767.53448724747 390.15277671814,3767.66572237015 391.525867462158,3767.09003448486 PathPoint;PointKind.SMOOTHPOINT 389.453170776367,3767.5333070755 353.033378601074,3767.4910569191 389.789598464966,3767.53354310989 PathPoint;PointKind.SMOOTHPOINT 339.015768051147,3767.99994707108 322.728136062622,3768.28082799911 340.985239028931,3767.96572208405 PathPoint;PointKind.SMOOTHPOINT 271.171875,3763 268.684460577257,3759.88875741719 277.507511764701,3770.9252479648 PathPoint;PointKind.SMOOTHPOINT 271.171875,3717 303.504352767028,3684.38737503483 267.977889158991,3720.22062938074 PathPoint;PointKind.SMOOTHPOINT 299.171903610229,3652.99997806549 300.372531890869,3640.36741733551 297.983549118042,3665.50295591354 PathPoint;PointKind.SMOOTHPOINT 299.51556968689,3545.00008106232 300.697315216064,3518.85714769363 298.333824157715,3571.14325046539 PathPoint;PointKind.SMOOTHPOINT 300.515726089478,3314.00006532669 300.119188308716,3305.42115926743 300.912263870239,3322.57873535156 PathPoint;PointKind.SMOOTHPOINT 309.515560150146,3278.00009965897 323.146074295044,3257.54937171936 306.493375778198,3282.53243207932 PathPoint;PointKind.SMOOTHPOINT 325.171878814697,3221.99999570847 325.284860610962,3213.96019220352 325.141036987305,3224.21281814575 PathPoint;PointKind.SMOOTHPOINT 325.349061965942,2981.19770765305 325.434978485107,2962.87907838821 325.281084060669,2995.77566385269 PathPoint;PointKind.SMOOTHPOINT 325.171878814697,1805.00008821487 325.019243240356,1788.57162237167 325.462358474731,1836.27700567245 PathPoint;PointKind.SMOOTHPOINT 325.515544891357,1389.9999332428 325.096662521362,1208.08397769928 325.974395751953,1588.92145872116 PathPoint;PointKind.SMOOTHPOINT 325.515544891357,1009.99990224838 325.622232437134,970.573425292969 325.464246749878,1028.83285045624 PathPoint;PointKind.SMOOTHPOINT 327.515542984009,778.999886512756 328.064716339111,753.68661403656 326.966999053955,804.313867092133 PathPoint;PointKind.SMOOTHPOINT 331.515539169312,651.0000872612 331.542604446411,645.85807800293 331.396577835083,673.644990921021 PathPoint;PointKind.SMOOTHPOINT 319.515550613403,614.000043869019 313.907688140869,604.965591430664 329.590442657471,630.230948925018 PathPoint;PointKind.SMOOTHPOINT 301.515567779541,584.000072479248 299.457662582397,528.828685283661 301.90266418457,594.373784065247 PathPoint;PointKind.SMOOTHPOINT 302.515724182129,454.000117778778 302.288501739502,439.947810173035 302.663324356079,463.142910003662 PathPoint;PointKind.SMOOTHPOINT 302.515724182129,390.999941825867 302.553804397583,385.82040309906 302.329099655151,415.597321987152 PathPoint;PointKind.SMOOTHPOINT 303.805416107178,368.617272377014 303.600538253784,356.187465190887 303.892906188965,373.924269676208 PathPoint;PointKind.SMOOTHPOINT 302.523591995239,345.523195266724 302.029178619385,338.638780117035 303.789051055908,363.145759105682 PathPoint;PointKind.SMOOTHPOINT 298.171747207642,280.000047683716 294.253890991211,249.36797618866 300.971115112305,301.88374042511 PathPoint;PointKind.SMOOTHPOINT 271,236 270.725885391235,235.365775585175 273.993230819702,242.927373409271 PathPoint;PointKind.SMOOTHPOINT 271.171875,201 275.193493829779,194.625830054107 267.150256170221,207.374169945893 PathPoint;PointKind.SMOOTHPOINT 789.910696029663,192.936165332794 796.074340820312,192.892026901245 462.729890823364,195.2894282341 PathPoint;PointKind.SMOOTHPOINT 806.879680633545,193.634119033813 819.558504104614,191.279675960541 800.741842269897,194.773457050323 PathPoint;PointKind.SMOOTHPOINT 825.696971893311,192.455599308014 836.213405609131,192.997062206268 818.971565246582,192.109572887421 PathPoint;PointKind.SMOOTHPOINT 853.251626968384,192.506818771362 1151.39044570923,190.606741905212 844.970596313477,192.559454441071 PathPoint;PointKind.SMOOTHPOINT 1918.02511978149,189.791951179504 2530.70651817322,188.392267227173 1526.96679878235,190.685577392578 PathPoint;PointKind.SMOOTHPOINT 3618.57739257812,188.624997138977 3621.80162239075,188.62735748291 3179.25224113464,188.364651203156 PathPoint;PointKind.SMOOTHPOINT 3627.05323028564,188.578026294708 3628.1109790802,188.253479003906 3625.51900672913,189.048914909363 PathPoint;PointKind.SMOOTHPOINT 3635.11585044861,188.635146617889 3943.29557228088,188.824918270111 3632.82159614563,188.63373041153 PathPoint;PointKind.SMOOTHPOINT 4150.74525642395,189.232785701752 4178.92398643494,189.585893154144 4144.42268180847,189.153714179993 PathPoint;PointKind.SMOOTHPOINT 4700.94835090637,191.679754257202 4710.60971069336,191.900446414948 4659.33863449097,190.729479789734 PathPoint;PointKind.SMOOTHPOINT 4768.99108695984,192.360005378723 4769.72940254211,192.364726066589 4736.44414710999,192.135064601898 PathPoint;PointKind.SMOOTHPOINT 4771.21610450745,192.375111579895 4771.68691444397,192.715709209442 4771.04080963135,192.248125076294 PathPoint;PointKind.SMOOTHPOINT 4772.95457649231,192.386913299561 4852.28164482117,192.924127578735 4772.37330245972,192.383136749268 PathPoint;PointKind.SMOOTHPOINT 5008.01571273804,193.999972343445 5012.59898402339,194.187187358012 4982.2407754027,192.948297063215 PathPoint";
	
	negative645[1] = "PointKind.SMOOTHPOINT 5007.99994468689,231.000015735626 5004.04684399786,235.841978622214 5011.07216835022,227.237863540649 PathPoint;PointKind.SMOOTHPOINT 4991,255 4985.09684466175,264.759909050441 4996.58943257913,245.75878060291 PathPoint;PointKind.SMOOTHPOINT 4982.51578330994,299.999949932098 4983.44135284424,317.957446575165 4981.19492688227,274.373823791623 PathPoint;PointKind.SMOOTHPOINT 4983.515625,371.000039577484 4985.47156333923,394.686090946198 4981.72522544861,349.318628311157 PathPoint;PointKind.SMOOTHPOINT 4983.515625,466.000106334686 4983.515625,466.000106334686 4983.51216316223,466.004118919373 PathPoint;PointKind.SMOOTHPOINT 4984.51578140259,594.999983310699 4984.37699317932,607.890765666962 4985.14772415161,536.288316249847 PathPoint;PointKind.SMOOTHPOINT 4971.51563644409,636.000101566315 4969.56156431722,639.478543345682 4976.56929016113,627.00412273407 PathPoint;PointKind.SMOOTHPOINT 4965.6576050491,646.513901555468 4964.97012810384,657.060289516244 4965.73040715486,645.397065191812 PathPoint;PointKind.SMOOTHPOINT 4952.51581192017,684.000055789948 4953.30290794373,728.884828090668 4952.31919454027,672.809994680595 PathPoint;PointKind.SMOOTHPOINT 4955.51565170288,866.000039577484 4955.03193855286,884.968943595886 4955.7737159729,855.8904504776 PathPoint;PointKind.SMOOTHPOINT 4955.51565170288,1338.99998188019 4955.70605278015,1363.9740729332 4955.32556533813,1314.02683496475 PathPoint;PointKind.SMOOTHPOINT 4957.51564979553,1935.00004291534 4957.40487098694,1987.39118099213 4957.62674331665,1882.60866880417 PathPoint;PointKind.SMOOTHPOINT 4957.51564979553,2427.00004577637 4957.4076922825,2453.80182211626 4957.74664878845,2369.65147733688 PathPoint;PointKind.SMOOTHPOINT 4957.54821139848,2586.24832883142 4957.55155507254,2589.44012344831 4957.47852342085,2519.72578264809 PathPoint;PointKind.SMOOTHPOINT 4957,2597 4959.32339871374,2602.2496969583 4955.70884687097,2594.08265197269 PathPoint;PointKind.SMOOTHPOINT 4957.57311818863,2610.33329555158 4957.64115717051,2677.68200539194 4957.56824882022,2605.51332806155 PathPoint;PointKind.SMOOTHPOINT 4957.51564979553,2758.99988651276 4957.1581363678,2797.18647480011 4957.68542988178,2740.81772049394 PathPoint;PointKind.SMOOTHPOINT 4956.51580810547,2882.00000524521 4956.7276096344,2889.42918777466 4956.30306243896,2874.57105875015 PathPoint;PointKind.SMOOTHPOINT 4955.51565170288,2907.99990177155 4954.81447219849,2912.76307582855 4956.31281852722,2902.58645296097 PathPoint;PointKind.SMOOTHPOINT 4955.51565170288,2937.00003147125 4955.15089988708,2949.24289941788 4955.88008880615,2924.75716352463 PathPoint;PointKind.SMOOTHPOINT 4955.51565170288,3083.99989128113 4955.63020706177,3094.067466259 4955.37686347961,3071.83397054672 PathPoint;PointKind.SMOOTHPOINT 4955.51565170288,3111.00010156631 4954.97560501099,3120.80709457397 4955.71549415588,3107.37532138824 PathPoint;PointKind.SMOOTHPOINT 4956,3134 4957.36239051819,3137.64083051682 4954.52683067322,3130.06341838837 PathPoint;PointKind.SMOOTHPOINT 4954.51581001282,3232.99990653992 4954.73422050476,3235.05364179611 4953.67552757263,3225.10668039322 PathPoint;PointKind.SMOOTHPOINT 4958.51580619812,3274.00002479553 4965.30384063721,3292.38309144974 4953.50400924683,3260.42804718018 PathPoint;PointKind.SMOOTHPOINT 4983.515625,3321.99997901917 4985.24119377136,3419.61271047592 4983.18895339966,3303.50904464722 PathPoint;PointKind.SMOOTHPOINT 4982.51578330994,3576.99997186661 4983.45866203308,3594.58170175552 4981.87188148499,3564.99384641647 PathPoint;PointKind.SMOOTHPOINT 4980.1718044281,3636.99991464615 4978.50278393032,3681.80420961192 4981.13990458602,3611.02954659152 PathPoint;PointKind.SMOOTHPOINT 5007.99994468689,3719.99999284744 5010.06225585938,3723.01981687546 5000.10380744934,3708.43902826309 PathPoint;PointKind.SMOOTHPOINT 5007.01583862305,3763.00003051758 4958.32005500793,3767.02606916428 5013.74187469482,3762.44393348694 PathPoint;PointKind.SMOOTHPOINT 4344.56580162048,3767.54676103592 4320.35276412964,3767.40136384964 4367.79064178467,3767.68625736237 PathPoint;PointKind.SMOOTHPOINT 3241.71807289124,3769.075319767 3210.02840995789,3769.52307701111 3273.40836524963,3768.62685441971 PathPoint;PointKind.SMOOTHPOINT 2821.70682907104,3771.42929077148 2806.94429397583,3771.82464838028 2842.42341041565,3770.8748459816 PathPoint;PointKind.SMOOTHPOINT 2275.26203155518,3770.89136838913 2274.37705993652,3770.88971614838 2476.96569442749,3771.2487244606 PathPoint;PointKind.SMOOTHPOINT 2272.61404037476,3770.88688373566 2271.97643280029,3770.66784381866 2274.35628890991,3771.48452281952 PathPoint;PointKind.SMOOTHPOINT 2270.59988021851,3770.88310718536 2239.57426071167,3770.82834720612 2271.26990318298,3770.88428735733 PathPoint;PointKind.SMOOTHPOINT 2188.72426986694,3770.73936223984 2188.05770874023,3770.73818206787 2211.72755241394,3770.77877998352 PathPoint;PointKind.SMOOTHPOINT 2186.73686027527,3770.73605775833 2186.08068466187,3770.59467315674 2187.53969192505,3770.90836286545 PathPoint;PointKind.SMOOTHPOINT 2184.73654747009,3770.73251724243 2151.37135505676,3770.67586898804 2185.39933204651,3770.73346138 PathPoint;PointKind.SMOOTHPOINT 2122.90529251099,3770.64424037933 2098.67148399353,3770.65627813339 2128.93581390381,3770.64117193222 PathPoint;PointKind.SMOOTHPOINT 806.512212753296,3768.20954561234 806.103401184082,3768.20907354355 1329.50589179993,3769.1423535347 PathPoint;PointKind.SMOOTHPOINT 805.781764984131,3767.90624141693 805.45446395874,3767.90529727936 806.19026184082,3767.90671348572 PathPoint;PointKind.SMOOTHPOINT 804.303874969482,3768.20576906204 623.504991531372,3767.88358211517 804.631490707397,3768.20647716522 PathPoint;PointKind.SMOOTHPOINT 392.013158798218,3767.53613948822 391.494512557983,3767.53566741943 472.371225357056,3767.63126134872 PathPoint;PointKind.SMOOTHPOINT 390.466661453247,3767.53448724747 390.152893066406,3767.66572237015 391.525983810425,3767.09003448486 PathPoint;PointKind.SMOOTHPOINT 389.453287124634,3767.5333070755 353.033494949341,3767.4910569191 389.789714813232,3767.53354310989 PathPoint;PointKind.SMOOTHPOINT 339.015884399414,3767.99994707108 322.728252410889,3768.28082799911 340.985355377197,3767.96572208405 PathPoint;PointKind.SMOOTHPOINT 271.171731948853,3763.00003051758 268.684558868408,3759.88886117935 277.507524490356,3770.92535734177 PathPoint;PointKind.SMOOTHPOINT 271.171731948853,3716.99999570847 297.256742626941,3689.0214123422 268.078390684147,3720.31719577595 PathPoint;PointKind.SMOOTHPOINT 299,3649 300.20062828064,3636.36743927002 297.811645507812,3661.50297784805 PathPoint;PointKind.SMOOTHPOINT 299.515686035156,3545.00008106232 300.297536252554,3527.70375318706 298.333940505981,3571.14325046539 PathPoint;PointKind.SMOOTHPOINT 300.69456748537,3373.32368662601 300.695749131402,3371.39549879812 300.656197417244,3435.93524398742 PathPoint;PointKind.SMOOTHPOINT 300,3368 297.602312154142,3366.01750624917 301.441058008982,3369.19151811289 PathPoint;PointKind.SMOOTHPOINT 300.698004483559,3361.26759342718 300.696353068128,3335.32750131044 300.698136586709,3363.34264238661 PathPoint;PointKind.SMOOTHPOINT 300.515842437744,3314.00006532669 300.119304656982,3305.42115926743 300.632608387187,3316.5261715365 PathPoint;PointKind.SMOOTHPOINT 309.515676498413,3278.00009965897 323.146190643311,3257.54937171936 306.493492126465,3282.53243207932 PathPoint;PointKind.SMOOTHPOINT 325.171995162964,3221.99999570847 325.284976959229,3213.96019220352 325.141153335571,3224.21281814575 PathPoint;PointKind.SMOOTHPOINT 325.349178314209,2981.19770765305 325.435094833374,2962.87907838821 325.281200408936,2995.77566385269 PathPoint;PointKind.SMOOTHPOINT 325.171995162964,1805.00008821487 325.053895880687,1792.28883113497 325.462474822998,1836.27700567245 PathPoint;PointKind.SMOOTHPOINT 325.63916538809,1523.00869117273 325.639765496514,1520.81474609404 325.598989205441,1669.88937919565 PathPoint;PointKind.SMOOTHPOINT 324,1516 325.112021430039,1514.27192195163 322.619792549687,1518.14483833913 PathPoint;PointKind.SMOOTHPOINT 325.641354129091,1510.23261776919 325.644005528295,1471.16489560427 325.64121407083,1512.29634216173 PathPoint;PointKind.SMOOTHPOINT 325.515661239624,1389.9999332428 325.096778869629,1208.08397769928 325.609237607703,1430.56726238058 PathPoint;PointKind.SMOOTHPOINT 325.515661239624,1009.99990224838 325.6223487854,970.573425292969 325.464363098145,1028.83285045624 PathPoint;PointKind.SMOOTHPOINT 328,778 326.988677803685,751.426353006607 328.963555910776,803.301582425276 PathPoint;PointKind.SMOOTHPOINT 331.515655517578,651.0000872612 331.542720794678,645.85807800293 331.39669418335,673.644990921021 PathPoint;PointKind.SMOOTHPOINT 319.51566696167,614.000043869019 313.907804489136,604.965591430664 329.590559005737,630.230948925018 PathPoint;PointKind.SMOOTHPOINT 301.515684127808,584.000072479248 299.457778930664,528.828685283661 301.902780532837,594.373784065247 PathPoint;PointKind.SMOOTHPOINT 302.515840530396,454.000117778778 302.288618087769,439.947810173035 302.663440704346,463.142910003662 PathPoint;PointKind.SMOOTHPOINT 302.515840530396,390.999941825867 302.55392074585,385.82040309906 302.329216003418,415.597321987152 PathPoint;PointKind.SMOOTHPOINT 303.805532455444,368.617272377014 303.600654602051,356.187465190887 303.893022537231,373.924269676208 PathPoint;PointKind.SMOOTHPOINT 302.523708343506,345.523195266724 302.029294967651,338.638780117035 303.789167404175,363.145759105682 PathPoint;PointKind.SMOOTHPOINT 300,283 294.942711753774,252.606915998047 303.621665918907,304.762720524724 PathPoint;PointKind.SMOOTHPOINT 273,237 272.725885391235,236.365775585175 275.993230819702,243.927373409271 PathPoint;PointKind.SMOOTHPOINT 271.171731948853,201.000044345856 275.19344329834,194.625935554504 267.15033531189,207.374153137207 PathPoint;PointKind.SMOOTHPOINT 789.91081237793,192.936165332794 796.074457168579,192.892026901245 462.730007171631,195.2894282341 PathPoint;PointKind.SMOOTHPOINT 806.879796981812,193.634119033813 819.558620452881,191.279675960541 800.741958618164,194.773457050323 PathPoint;PointKind.SMOOTHPOINT 825.697088241577,192.455599308014 836.213521957397,192.997062206268 818.971681594849,192.109572887421 PathPoint;PointKind.SMOOTHPOINT 853.25174331665,192.506818771362 1151.3905620575,190.606741905212 844.970712661743,192.559454441071 PathPoint;PointKind.SMOOTHPOINT 1918.02523612976,189.791951179504 2530.70663452148,188.392267227173 1526.96691513062,190.685577392578 PathPoint;PointKind.SMOOTHPOINT 3618.57750892639,188.624997138977 3621.80173873901,188.62735748291 3179.25235748291,188.364651203156 PathPoint;PointKind.SMOOTHPOINT 3627.05334663391,188.578026294708 3628.11109542847,188.253479003906 3625.51912307739,189.048914909363 PathPoint;PointKind.SMOOTHPOINT 3635.11596679688,188.635146617889 3943.29568862915,188.824918270111 3632.8217124939,188.63373041153 PathPoint;PointKind.SMOOTHPOINT 4150.74537277222,189.232785701752 4178.9241027832,189.585893154144 4144.42279815674,189.153714179993 PathPoint;PointKind.SMOOTHPOINT 4700.94846725464,191.679754257202 4710.60982704163,191.900446414948 4659.33875083923,190.729479789734 PathPoint;PointKind.SMOOTHPOINT 4768.99120330811,192.360005378723 4769.72951889038,192.364726066589 4736.44426345825,192.135064601898 PathPoint;PointKind.SMOOTHPOINT 4771.21622085571,192.375111579895 4771.68703079224,192.715709209442 4771.04092597961,192.248125076294 PathPoint;PointKind.SMOOTHPOINT 4772.95469284058,192.386913299561 4852.28176116943,192.924127578735 4772.37341880798,192.383136749268 PathPoint;PointKind.SMOOTHPOINT 5008.01568031311,193.999972343445 5012.59883880615,194.18714761734 4982.2407245636,192.948203086853 PathPoint";
	
	negative645[2] = "PointKind.SMOOTHPOINT 5007.99994468689,231.000015735626 5003.95521480203,235.954210816753 5011.07216835022,227.237863540649 PathPoint;PointKind.SMOOTHPOINT 4994,251 4992.84256788224,255.759400883755 4996.0339440313,242.636351824437 PathPoint;PointKind.SMOOTHPOINT 4985.00462190449,266.312618964415 4982.87716561023,274.874697292078 4986.62786895796,259.779761648167 PathPoint;PointKind.SMOOTHPOINT 4982.51578330994,299.999949932098 4983.44135284424,317.957446575165 4981.78301642136,285.783433795226 PathPoint;PointKind.SMOOTHPOINT 4983.515625,371.000039577484 4985.47156333923,394.686090946198 4981.72522544861,349.318628311157 PathPoint;PointKind.SMOOTHPOINT 4983.515625,466.000106334686 4983.515625,466.000106334686 4983.51216316223,466.004118919373 PathPoint;PointKind.SMOOTHPOINT 4984.51578140259,594.999983310699 4984.37699317932,607.890765666962 4985.14772415161,536.288316249847 PathPoint;PointKind.SMOOTHPOINT 4971.51563644409,636.000101566315 4970.77175021979,637.324292667616 4976.56929016113,627.00412273407 PathPoint;PointKind.SMOOTHPOINT 4965,647 4956.44596746783,662.252648372072 4965.74776985737,645.666655679077 PathPoint;PointKind.SMOOTHPOINT 4952,688 4952.25921057164,702.781687542389 4951.77078502004,674.954715629126 PathPoint;PointKind.SMOOTHPOINT 4953.29882970063,750.940340810354 4953.36584896185,754.020609978984 4952.75697073273,726.035985819088 PathPoint;PointKind.SMOOTHPOINT 4956,758 4958.33142614216,761.059915892309 4953.00895928028,754.074362868581 PathPoint;PointKind.SMOOTHPOINT 4953.75389700916,771.81398944989 4954.72447598114,816.340363385967 4953.6697728491,767.95470142063 PathPoint;PointKind.SMOOTHPOINT 4955.51565170288,866.000039577484 4955.03193855286,884.968943595886 4955.66525096574,860.139534064701 PathPoint;PointKind.SMOOTHPOINT 4955.51565170288,1338.99998188019 4955.70605278015,1363.9740729332 4955.32556533813,1314.02683496475 PathPoint;PointKind.SMOOTHPOINT 4957.51564979553,1935.00004291534 4957.40487098694,1987.39118099213 4957.62674331665,1882.60866880417 PathPoint;PointKind.SMOOTHPOINT 4957.51564979553,2427.00004577637 4957.28465080261,2484.34837818146 4957.74664878845,2369.65147733688 PathPoint;PointKind.SMOOTHPOINT 4957.51564979553,2758.99988651276 4957.1581363678,2797.18647480011 4957.87221908569,2720.81400632858 PathPoint;PointKind.SMOOTHPOINT 4956.51580810547,2882.00000524521 4956.7276096344,2889.42918777466 4956.30306243896,2874.57105875015 PathPoint;PointKind.SMOOTHPOINT 4955.51565170288,2907.99990177155 4954.81447219849,2912.76307582855 4956.31281852722,2902.58645296097 PathPoint;PointKind.SMOOTHPOINT 4955.51565170288,2937.00003147125 4955.15089988708,2949.24289941788 4955.88008880615,2924.75716352463 PathPoint;PointKind.SMOOTHPOINT 4955.51565170288,3083.99989128113 4955.63020706177,3094.067466259 4955.37686347961,3071.83397054672 PathPoint;PointKind.SMOOTHPOINT 4955.51565170288,3111.00010156631 4954.97560501099,3120.80709457397 4955.71549415588,3107.37532138824 PathPoint;PointKind.SMOOTHPOINT 4955.47631263733,3138.78890275955 4956.83870315552,3142.42973327637 4954.00314331055,3134.85232114792 PathPoint;PointKind.SMOOTHPOINT 4954.51581001282,3232.99990653992 4954.73422050476,3235.05364179611 4953.67552757263,3225.10668039322 PathPoint;PointKind.SMOOTHPOINT 4958,3267 4964.78803443909,3285.38306665421 4952.98820304871,3253.42802238464 PathPoint;PointKind.SMOOTHPOINT 4983.515625,3321.99997901917 4985.24119377136,3419.61271047592 4983.18895339966,3303.50904464722 PathPoint;PointKind.SMOOTHPOINT 4982.51578330994,3576.99997186661 4983.45866203308,3594.58170175552 4981.87188148499,3564.99384641647 PathPoint;PointKind.SMOOTHPOINT 4980.1718044281,3636.99991464615 4980.61798469514,3684.92783359802 4979.93054677426,3611.01262872489 PathPoint;PointKind.SMOOTHPOINT 5007.99994468689,3719.99999284744 5010.06225585938,3723.01981687546 5000.10380744934,3708.43902826309 PathPoint;PointKind.SMOOTHPOINT 5007.01583862305,3763.00003051758 4958.32005500793,3767.02606916428 5013.74187469482,3762.44393348694 PathPoint;PointKind.SMOOTHPOINT 4344.56580162048,3767.54676103592 4320.35276412964,3767.40136384964 4367.79064178467,3767.68625736237 PathPoint;PointKind.SMOOTHPOINT 3241.71807289124,3769.075319767 3210.02840995789,3769.52307701111 3273.40836524963,3768.62685441971 PathPoint;PointKind.SMOOTHPOINT 2821.70682907104,3771.42929077148 2806.94429397583,3771.82464838028 2842.42341041565,3770.8748459816 PathPoint;PointKind.SMOOTHPOINT 2275.26203155518,3770.89136838913 2274.37705993652,3770.88971614838 2476.96569442749,3771.2487244606 PathPoint;PointKind.SMOOTHPOINT 2272.61404037476,3770.88688373566 2271.97643280029,3770.66784381866 2274.35628890991,3771.48452281952 PathPoint;PointKind.SMOOTHPOINT 2270.59988021851,3770.88310718536 2239.57426071167,3770.82834720612 2271.26990318298,3770.88428735733 PathPoint;PointKind.SMOOTHPOINT 2188.72426986694,3770.73936223984 2188.05770874023,3770.73818206787 2211.72755241394,3770.77877998352 PathPoint;PointKind.SMOOTHPOINT 2186.73686027527,3770.73605775833 2186.08068466187,3770.59467315674 2187.53969192505,3770.90836286545 PathPoint;PointKind.SMOOTHPOINT 2184.73654747009,3770.73251724243 2151.37135505676,3770.67586898804 2185.39933204651,3770.73346138 PathPoint;PointKind.SMOOTHPOINT 2122.90529251099,3770.64424037933 2098.67148399353,3770.65627813339 2128.93581390381,3770.64117193222 PathPoint;PointKind.SMOOTHPOINT 806.512212753296,3768.20954561234 806.103401184082,3768.20907354355 1329.50589179993,3769.1423535347 PathPoint;PointKind.SMOOTHPOINT 805.781764984131,3767.90624141693 805.45446395874,3767.90529727936 806.19026184082,3767.90671348572 PathPoint;PointKind.SMOOTHPOINT 804.303874969482,3768.20576906204 623.504991531372,3767.88358211517 804.631490707397,3768.20647716522 PathPoint;PointKind.SMOOTHPOINT 392.013158798218,3767.53613948822 391.494512557983,3767.53566741943 472.371225357056,3767.63126134872 PathPoint;PointKind.SMOOTHPOINT 390.466661453247,3767.53448724747 390.152893066406,3767.66572237015 391.525983810425,3767.09003448486 PathPoint;PointKind.SMOOTHPOINT 389.453287124634,3767.5333070755 353.033494949341,3767.4910569191 389.789714813232,3767.53354310989 PathPoint;PointKind.SMOOTHPOINT 339.015884399414,3767.99994707108 322.728252410889,3768.28082799911 340.985355377197,3767.96572208405 PathPoint;PointKind.SMOOTHPOINT 271.171731948853,3763.00003051758 268.684558868408,3759.88886117935 277.507524490356,3770.92535734177 PathPoint;PointKind.SMOOTHPOINT 269,3719 277.95512939474,3710.33265747498 265.740504851647,3722.15408748222 PathPoint;PointKind.SMOOTHPOINT 288.506802384406,3690.29581366171 289.371818987616,3688.3091461466 284.165308361908,3700.26684208999 PathPoint;PointKind.SMOOTHPOINT 290,3685 291.147002514345,3681.88143571893 289.276419208433,3686.9673306578 PathPoint;PointKind.SMOOTHPOINT 293.847875802673,3675.16766612284 297.460697174021,3662.24188237139 293.011247367417,3678.16091630681 PathPoint;PointKind.SMOOTHPOINT 299,3645 300.20062828064,3632.36743927002 298.437028267567,3650.92316783078 PathPoint;PointKind.SMOOTHPOINT 299.515686035156,3545.00008106232 300.697431564331,3518.85714769363 298.333940505981,3571.14325046539 PathPoint;PointKind.SMOOTHPOINT 300.515842437744,3314.00006532669 300.119304656982,3305.42115926743 300.912380218506,3322.57873535156 PathPoint;PointKind.SMOOTHPOINT 309.515676498413,3278.00009965897 323.146190643311,3257.54937171936 306.493492126465,3282.53243207932 PathPoint;PointKind.SMOOTHPOINT 325.171995162964,3221.99999570847 325.284976959229,3213.96019220352 325.141153335571,3224.21281814575 PathPoint;PointKind.SMOOTHPOINT 325.349178314209,2981.19770765305 325.435094833374,2962.87907838821 325.281200408936,2995.77566385269 PathPoint;PointKind.SMOOTHPOINT 325.171995162964,1805.00008821487 325.019359588623,1788.57162237167 325.462474822998,1836.27700567245 PathPoint;PointKind.SMOOTHPOINT 325.515661239624,1389.9999332428 325.096778869629,1208.08397769928 325.97451210022,1588.92145872116 PathPoint;PointKind.SMOOTHPOINT 325.515661239624,1009.99990224838 325.6223487854,970.573425292969 325.464363098145,1028.83285045624 PathPoint;PointKind.SMOOTHPOINT 327.515659332275,778.999886512756 328.064832687378,753.68661403656 326.967115402222,804.313867092133 PathPoint;PointKind.SMOOTHPOINT 331.515655517578,651.0000872612 331.542720794678,645.85807800293 331.39669418335,673.644990921021 PathPoint;PointKind.SMOOTHPOINT 317,613 311.392137527466,603.965547561646 327.074892044067,629.230905056 PathPoint;PointKind.SMOOTHPOINT 301.515684127808,584.000072479248 299.457778930664,528.828685283661 301.902780532837,594.373784065247 PathPoint;PointKind.SMOOTHPOINT 302.515840530396,454.000117778778 302.288618087769,439.947810173035 302.663440704346,463.142910003662 PathPoint;PointKind.SMOOTHPOINT 302.515840530396,390.999941825867 302.55392074585,385.82040309906 302.329216003418,415.597321987152 PathPoint;PointKind.SMOOTHPOINT 302,366 301.795122146606,353.570192813873 302.087490081787,371.306997299194 PathPoint;PointKind.SMOOTHPOINT 302.523708343506,345.523195266724 302.029294967651,338.638780117035 303.789167404175,363.145759105682 PathPoint;PointKind.SMOOTHPOINT 298.171863555908,280.000047683716 295.162229136801,260.251666802796 301.496141015505,301.810174873556 PathPoint;PointKind.SMOOTHPOINT 270.999898910522,235.999932289124 270.725784301758,235.365707874298 273.993129730225,242.927305698395 PathPoint;PointKind.SMOOTHPOINT 271.171731948853,201.000044345856 275.19344329834,194.625935554504 267.15033531189,207.374153137207 PathPoint;PointKind.SMOOTHPOINT 789.91081237793,192.936165332794 796.074457168579,192.892026901245 462.730007171631,195.2894282341 PathPoint;PointKind.SMOOTHPOINT 806.879796981812,193.634119033813 819.558620452881,191.279675960541 800.741958618164,194.773457050323 PathPoint;PointKind.SMOOTHPOINT 825.697088241577,192.455599308014 836.213521957397,192.997062206268 818.971681594849,192.109572887421 PathPoint;PointKind.SMOOTHPOINT 853.25174331665,192.506818771362 1151.3905620575,190.606741905212 844.970712661743,192.559454441071 PathPoint;PointKind.SMOOTHPOINT 1918.02523612976,189.791951179504 2530.70663452148,188.392267227173 1526.96691513062,190.685577392578 PathPoint;PointKind.SMOOTHPOINT 3618.57750892639,188.624997138977 3621.80173873901,188.62735748291 3179.25235748291,188.364651203156 PathPoint;PointKind.SMOOTHPOINT 3627.05334663391,188.578026294708 3628.11109542847,188.253479003906 3625.51912307739,189.048914909363 PathPoint;PointKind.SMOOTHPOINT 3635.11596679688,188.635146617889 3943.29568862915,188.824918270111 3632.8217124939,188.63373041153 PathPoint;PointKind.SMOOTHPOINT 4150.74537277222,189.232785701752 4178.9241027832,189.585893154144 4144.42279815674,189.153714179993 PathPoint;PointKind.SMOOTHPOINT 4700.94846725464,191.679754257202 4710.60982704163,191.900446414948 4659.33875083923,190.729479789734 PathPoint;PointKind.SMOOTHPOINT 4768.99120330811,192.360005378723 4769.72951889038,192.364726066589 4736.44426345825,192.135064601898 PathPoint;PointKind.SMOOTHPOINT 4771.21622085571,192.375111579895 4771.68703079224,192.715709209442 4771.04092597961,192.248125076294 PathPoint;PointKind.SMOOTHPOINT 4772.95469284058,192.386913299561 4852.28176116943,192.924127578735 4772.37341880798,192.383136749268 PathPoint;PointKind.SMOOTHPOINT 5008.01568031311,193.999972343445 5012.59883880615,194.18714761734 4982.2407245636,192.948203086853 PathPoint";
	
}


// Masks

if (mask_variant_645 == 5) {
	
	mask645[0] = "PointKind.SMOOTHPOINT 265.000030994036,142.244321918427 266.186551807507,132.514957482151 262.393147201468,163.618877941357 PathPoint;PointKind.SMOOTHPOINT 276.000684042644,132.283854513833 281.883246516008,130.232374858147 270.117492115266,134.335099069858 PathPoint;PointKind.SMOOTHPOINT 348.810888570926,132.377894378866 366.505470314948,132.16606958288 331.116306826904,132.589719174852 PathPoint;PointKind.SMOOTHPOINT 942.031324976615,131.287737243475 977.465809153556,131.205452361572 906.596526072667,131.370022125379 PathPoint;PointKind.SMOOTHPOINT 1491.05653626006,130.29185507278 1502.73133455601,130.080030276794 1479.38205269113,130.503679868766 PathPoint;PointKind.SMOOTHPOINT 1535.30054406827,131.421979150809 1541.85158670286,131.454422904246 1524.24229597752,131.367200929428 PathPoint;PointKind.SMOOTHPOINT 1545.04228909197,129.413757833037 1548.46179801461,128.824833178271 1540.07117602864,130.26999080416 PathPoint;PointKind.SMOOTHPOINT 1568.0601634193,131.287737243475 1571.988271184,131.227081530529 1562.65850381144,131.370727424367 PathPoint;PointKind.SMOOTHPOINT 1580.11137521469,130.417868491923 1584.0955043865,131.504264032713 1574.5108081389,128.890661083793 PathPoint;PointKind.SMOOTHPOINT 1605.43934576771,132.426089809695 1620.91541684484,132.379069877179 1594.5497913523,132.459238862119 PathPoint;PointKind.SMOOTHPOINT 1857.74434175963,133.430200468581 1868.95837971846,133.928376653592 1846.53030380081,132.932024283571 PathPoint;PointKind.CORNERPOINT 1889.89118762954,133.430200468581 1889.89118762954,133.430200468581 1889.89118762954,133.430200468581 PathPoint;PointKind.SMOOTHPOINT 1895.73629758917,134.434311127467 1897.24415467599,134.560324546611 1889.8892992675,133.94553892896 PathPoint;PointKind.SMOOTHPOINT 1903.54656297566,132.268337936103 1908.37353107015,132.069678721222 1897.41190417031,132.520834973716 PathPoint;PointKind.SMOOTHPOINT 1916.19355299384,133.430200468581 1927.82208641987,134.497082737377 1904.5643901138,132.363318199786 PathPoint;PointKind.SMOOTHPOINT 1970.74581443695,133.430200468581 1979.69602104,133.351677181279 1961.79560783391,133.508488656221 PathPoint;PointKind.SMOOTHPOINT 2015.55664558337,133.430200468581 2029.47639161472,133.308653943027 2001.63689955202,133.551746994136 PathPoint;PointKind.SMOOTHPOINT 2065.23850660515,133.430200468581 1879.69875353292,133.267511502075 2050.97319032096,133.417505086802 PathPoint;PointKind.SMOOTHPOINT 2562.05491373383,134.434311127467 2582.96789384352,134.215903540929 2428.76487932718,135.825630930625 PathPoint;PointKind.SMOOTHPOINT 2612.71116956688,133.430200468581 2620.59917252392,133.026064148604 2604.82253715583,133.834101688896 PathPoint;PointKind.SMOOTHPOINT 2640.96138037271,134.434311127467 2650.68392704903,134.104701400528 2631.23883369638,134.763685754744 PathPoint;PointKind.SMOOTHPOINT 2698.43619679564,134.434311127467 2705.96698460061,134.340036162772 2690.90540899067,134.5283509925 PathPoint;PointKind.SMOOTHPOINT 2716.94497730476,134.434311127467 2725.98645473962,134.798950704131 2707.90381459692,134.069436451141 PathPoint;PointKind.SMOOTHPOINT 2758.83356819838,135.438186686691 2777.12927852429,135.956111243358 2740.53785787246,134.920497229686 PathPoint;PointKind.SMOOTHPOINT 2799.74807900772,135.438186686691 2807.31663405344,135.285371906013 2792.179209235,135.591236567031 PathPoint;PointKind.SMOOTHPOINT 2821.17909976965,133.430200468581 2835.22158933343,133.106233133544 2810.67351230184,133.672588220703 PathPoint;PointKind.SMOOTHPOINT 2853.32626036657,134.434311127467 2858.3678722793,134.642139229189 2848.28401899983,134.226247926083 PathPoint;PointKind.SMOOTHPOINT 2866.13627897397,134.0238271166 2872.51516593615,133.498614470393 2859.10968383297,134.602407386213 PathPoint;PointKind.SMOOTHPOINT 2882.55055125666,135.438186686691 2885.15995286528,135.661531366143 2878.89184980929,135.125269035794 PathPoint;PointKind.SMOOTHPOINT 2900.08525168152,134.434311127467 2903.01252756643,133.882297119726 2893.04449382525,135.761918922065 PathPoint;PointKind.SMOOTHPOINT 2906.90444172542,131.421979150809 2914.82989719619,130.697872190058 2903.13180910179,131.766635256154 PathPoint;PointKind.SMOOTHPOINT 2918.59434691766,135.438186686691 2925.90797308833,135.606988244424 2911.28040601998,135.26962022862 PathPoint;PointKind.SMOOTHPOINT 2954.63782785165,134.434311127467 2964.73301130334,134.783199026738 2944.54232967294,134.085188128534 PathPoint;PointKind.SMOOTHPOINT 2983.86211874174,134.434311127467 3000.55618333297,134.257751280868 2967.16868360452,134.610635874403 PathPoint;PointKind.SMOOTHPOINT 3556.6627522565,135.438186686691 3589.20930142431,136.387519124195 3524.11620308868,134.489089348849 PathPoint;PointKind.SMOOTHPOINT 3657.97431974158,135.438186686691 3662.59797419004,135.712783092586 3639.98169152266,134.370128919582 PathPoint;PointKind.SMOOTHPOINT 3673.5608599979,137.446408004462 3678.35761429978,137.866060902171 3668.76379096901,137.026755106754 PathPoint;PointKind.SMOOTHPOINT 3698.88883055092,138.450518663348 3703.1848541859,137.171811598567 3696.11136472098,139.277129076985 PathPoint;PointKind.SMOOTHPOINT 3716.42353097578,135.438186686691 3720.35352710252,135.427137002549 3711.11817783183,135.453233065096 PathPoint;PointKind.SMOOTHPOINT 3727.13904135675,137.446408004462 3730.71371069346,137.472033867684 3720.03691173426,137.395391377682 PathPoint;PointKind.SMOOTHPOINT 3739.80302663326,136.442297345576 3741.06508192822,136.417611881005 3731.98866979568,136.595817425242 PathPoint;PointKind.SMOOTHPOINT 3746.62190195014,137.446408004462 3748.51624380062,136.756625594448 3744.47829631074,138.227409083558 PathPoint;PointKind.SMOOTHPOINT 3750.51853701422,137.446408004462 3757.2511771314,137.52634188974 3749.67916008862,137.436533818634 PathPoint;PointKind.SMOOTHPOINT 3769.02763225036,136.442297345576 3785.85482636522,135.465693347213 3763.60929211118,136.756860694111 PathPoint;PointKind.SMOOTHPOINT 3790.4589677393,133.430200468581 3791.86359436808,133.430670667906 3779.07749501316,133.426203774317 PathPoint;PointKind.SMOOTHPOINT 3797.27784305618,133.430200468581 3804.52852382561,133.932138248193 3796.25718337499,133.359435470144 PathPoint;PointKind.SMOOTHPOINT 3807.01958807989,134.434311127467 3812.85305314028,134.838212347782 3801.90590368273,134.080015935957 PathPoint;PointKind.SMOOTHPOINT 3818.70917854512,130.417868491923 3822.58976253189,130.532362027601 3816.84316212521,130.362855170879 PathPoint;PointKind.SMOOTHPOINT 3826.50244867329,131.421979150809 3827.63515116869,132.384712269081 3824.87153332702,130.035596440566 PathPoint;PointKind.SMOOTHPOINT 3832.3472439059,133.430200468581 3838.12374337817,133.675644516316 3828.45784756297,133.264925405786 PathPoint;PointKind.SMOOTHPOINT 3841.11459411833,130.417868491923 3848.49934859241,130.983518280095 3839.9752823558,130.330646517106 PathPoint;PointKind.SMOOTHPOINT 3862.54592960727,133.430200468581 3870.57902171418,132.963527638357 3854.51315222738,133.896873298806 PathPoint;PointKind.SMOOTHPOINT 3882.02910492768,133.430200468581 3893.4599897938,134.36354612903 3870.59790533455,132.49661970847 PathPoint;PointKind.SMOOTHPOINT 3906.38268066942,134.434311127467 3913.39605727616,134.465579382591 3899.3696187897,134.402807772681 PathPoint;PointKind.SMOOTHPOINT 3922.94330101001,131.421979150809 3933.97700039428,130.455014238611 3907.65858395266,132.761341928537 PathPoint;PointKind.SMOOTHPOINT 3937.55544645506,134.434311127467 3947.68871187451,134.084953028871 3931.02423162187,134.659301504558 PathPoint;PointKind.CORNERPOINT 3956.0645416912,133.430200468581 3956.0645416912,133.430200468581 3956.0645416912,133.430200468581 PathPoint;PointKind.SMOOTHPOINT 3966.78036679917,131.421979150809 3974.27653463345,130.759233201992 3959.28356951087,132.084960199289 PathPoint;PointKind.SMOOTHPOINT 3980.41811743294,132.426089809695 3988.17960013348,132.376013581565 3970.07178183028,132.492858113868 PathPoint;PointKind.SMOOTHPOINT 3994.05649752073,131.421979150809 3995.70189030928,131.113058194177 3989.11559824999,132.349682419356 PathPoint;PointKind.SMOOTHPOINT 3999.90129275335,129.413757833037 4007.99858916952,129.001157925207 3996.55542995016,129.584440188072 PathPoint;PointKind.SMOOTHPOINT 4013.53935811412,131.421979150809 4016.25891417492,131.855973127935 4009.37929654583,130.758292803342 PathPoint;PointKind.SMOOTHPOINT 4026.20334339063,131.421979150809 4038.52459095737,132.1514934038 4021.33231351528,131.133511864822 PathPoint;PointKind.SMOOTHPOINT 4059.32458407182,132.426089809695 4066.90950492186,132.508139591936 4041.21896885766,132.230016691102 PathPoint;PointKind.SMOOTHPOINT 4082.70407972929,131.421979150809 4084.95469255081,131.162664222982 4074.9750139104,132.312536672668 PathPoint;PointKind.SMOOTHPOINT 4089.52295504618,129.413757833037 4094.05785647889,129.286804015243 4087.40452756728,129.473238047671 PathPoint;PointKind.SMOOTHPOINT 4102.1872550497,131.421979150809 4105.17149652273,131.887241383058 4098.25127910984,130.808604131134 PathPoint;PointKind.SMOOTHPOINT 4110.95429053512,131.421979150809 4126.13735076946,131.088607829269 4107.94864762567,131.488042155995 PathPoint;PointKind.SMOOTHPOINT 4153.816961513,134.434311127467 4162.85623585881,134.273973157587 4139.44432331969,134.689159161706 PathPoint;PointKind.SMOOTHPOINT 4178.17148143577,133.253640621982 4179.03572179486,133.195806104987 4170.55886460918,133.762866491134 PathPoint;PointKind.SMOOTHPOINT 4180.76294360503,133.080607270322 4181.20765286483,132.490507117243 4179.58995605283,134.635556438637 PathPoint;PointKind.SMOOTHPOINT 4184.01564721437,132.426089809695 4186.92529838693,132.23801007963 4183.28988673802,132.473109742212 PathPoint;PointKind.SMOOTHPOINT 4191.80891734253,132.426089809695 4204.43482065129,131.814125387995 4188.78061408863,132.572791999146 PathPoint;PointKind.SMOOTHPOINT 4216.16249308428,133.430200468581 4222.8362792513,133.480041597049 4206.17022536362,133.355673875543 PathPoint;PointKind.SMOOTHPOINT 4235.64566840468,131.421979150809 4237.63726090008,131.01314083758 4229.76782683641,132.628980818503 PathPoint;PointKind.SMOOTHPOINT 4239.57629398543,129.591258078287 4240.77666278718,129.496748013929 4237.01000997667,129.793443788107 PathPoint;PointKind.SMOOTHPOINT 4243.43893853284,129.413757833037 4247.57319248662,129.351691522116 4242.05854588354,129.434681703007 PathPoint;PointKind.SMOOTHPOINT 4255.12852899808,129.413757833037 4257.0710240805,129.777927210376 4251.46132992154,128.726326419649 PathPoint;PointKind.SMOOTHPOINT 4259.99924414643,131.421979150809 4265.76787544354,133.047693317561 4258.11906501124,130.89206451135 PathPoint;PointKind.SMOOTHPOINT 4274.61170431848,131.421979150809 4286.80359908565,131.417982456546 4268.33195636326,131.424095047773 PathPoint;PointKind.SMOOTHPOINT 4291.17232465907,130.417868491923 4301.68231830497,130.139510491427 4280.66201628617,130.696461592083 PathPoint;PointKind.SMOOTHPOINT 4306.75855018839,134.434311127467 4309.04032098353,134.353436843539 4297.67552878872,134.755927465879 PathPoint;PointKind.SMOOTHPOINT 4310.65549997948,132.426089809695 4311.56726411651,132.268808135428 4309.12844454527,132.689166332124 PathPoint;PointKind.SMOOTHPOINT 4315.52621512783,133.430200468581 4316.34765261407,133.365312961709 4314.32112542099,133.525415831927 PathPoint;PointKind.SMOOTHPOINT 4318.44845538063,131.421979150809 4319.2406232553,131.333111478354 4317.45612113,131.533416390873 PathPoint;PointKind.SMOOTHPOINT 4322.34509044471,133.430200468581 4323.02553023217,133.410216997262 4321.37824908159,133.458412428091 PathPoint;PointKind.SMOOTHPOINT 4324.29325061325,131.421979150809 4325.3774851497,131.320651196237 4323.53853525232,131.492509049584 PathPoint;PointKind.SMOOTHPOINT 4331.11244065714,131.421979150809 4332.48842712836,131.854092330634 4329.21809880667,130.827177004478 PathPoint;PointKind.SMOOTHPOINT 4333.06060082568,133.430200468581 4335.10664109315,133.460998524379 4331.89107527054,133.412567993888 PathPoint;PointKind.SMOOTHPOINT 4338.9057107853,131.421979150809 4341.33980945145,130.913928779971 4336.58428438738,131.90651955539 PathPoint;PointKind.SMOOTHPOINT 4348.647141082,131.421979150809 4352.0439896602,131.378720812894 4344.65923518612,131.47299577759 PathPoint;PointKind.SMOOTHPOINT 4358.38888610571,129.413757833037 4369.07512687509,129.363211405582 4354.90171087672,129.430449909081 PathPoint;PointKind.SMOOTHPOINT 4381.76838176318,129.413757833037 4383.10219481557,129.461247964879 4370.95341764825,129.029840084042 PathPoint;PointKind.SMOOTHPOINT 4386.63909691153,131.421979150809 4409.43288561042,132.321470459847 4385.2571306272,131.36743602909 PathPoint;PointKind.SMOOTHPOINT 4447.03615358727,131.421979150809 4448.97078049454,131.445254017405 4433.38077824114,131.25717428734 PathPoint;PointKind.SMOOTHPOINT 4452.88126354689,129.413757833037 4453.59537912402,128.120474589176 4451.98617994118,131.035240205863 PathPoint;PointKind.SMOOTHPOINT 4457.75197869524,131.421979150809 4459.50595230094,132.667066963841 4456.37630695103,130.445610252108 PathPoint;PointKind.SMOOTHPOINT 4463.59677392786,129.413757833037 4466.51460800258,130.668484732235 4461.92274098174,128.693882666213 PathPoint;PointKind.SMOOTHPOINT 4471.88007400471,131.903463259776 4472.95423727696,131.780741235909 4468.58173497947,132.27985781957 PathPoint;PointKind.SMOOTHPOINT 4478.20923409991,129.413757833037 4483.46769291993,129.21274762153 4475.66970188668,129.510853993684 PathPoint;PointKind.SMOOTHPOINT 4493.79545962923,131.421979150809 4500.85982201097,131.72619811419 4489.992613213,131.25811468599 PathPoint;PointKind.SMOOTHPOINT 4512.30424013836,130.417868491923 4515.76592247983,130.219679476367 4501.3111405379,131.04770048798 PathPoint;PointKind.SMOOTHPOINT 4526.91670031041,130.417868491923 4541.87693382434,130.487457992048 4520.66024215365,130.388716133763 PathPoint;PointKind.SMOOTHPOINT 4566.29219605931,130.222030472993 4567.56023116739,130.215212582778 4552.60943946365,130.294911368393 PathPoint;PointKind.SMOOTHPOINT 4571.72753145683,129.413757833037 4575.30723642564,129.402002849908 4570.40316021463,129.418224726627 PathPoint;PointKind.SMOOTHPOINT 4579.52080158499,129.413757833037 4580.21823663079,129.416108829663 4575.37458800497,129.40035715227 PathPoint;PointKind.SMOOTHPOINT 4581.46896175353,130.417868491923 4582.26931253036,130.43761686358 4580.70889603349,130.39929561858 PathPoint;PointKind.SMOOTHPOINT 4583.41743664907,129.413757833037 4586.46902970143,129.44220489221 4582.55193738195,129.40576444451 PathPoint;PointKind.SMOOTHPOINT 4593.15886694577,129.413757833037 4596.91418958405,129.647917096969 4589.49859186336,129.185711160333 PathPoint;PointKind.SMOOTHPOINT 4604.84877213801,130.417868491923 4643.42297292906,130.974819592579 4601.30557550192,130.366851865143 PathPoint;PointKind.SMOOTHPOINT 4654.53031843278,131.421979150809 4669.99883606176,131.767105455479 4639.06180080379,131.07685284614 PathPoint;PointKind.SMOOTHPOINT 4684.72931886115,130.417868491923 4698.09325699951,130.755236507728 4671.36506599579,130.080735575781 PathPoint;PointKind.SMOOTHPOINT 4712.97952966698,130.417868491923 4731.61010952752,130.017963965872 4694.34863507944,130.818008117637 PathPoint;PointKind.SMOOTHPOINT 4743.17790064134,131.421979150809 4763.6999898093,131.775098844007 4722.6561262004,131.069094557274 PathPoint;PointKind.SMOOTHPOINT 4787.0149664305,131.421979150809 4821.30415903179,130.531656728613 4752.72545910221,132.312301573006 PathPoint;PointKind.SMOOTHPOINT 4853.25713306586,131.421979150809 4874.90877745916,131.300667724917 4828.77011307347,131.559277353757 PathPoint;PointKind.SMOOTHPOINT 4893.8833539375,131.182412594639 4895.74559363334,131.243068307585 4879.66209943418,130.717855661378 PathPoint;PointKind.SMOOTHPOINT 4900.01643910782,133.430200468581 4906.58793899781,133.583015249259 4897.76865882935,133.377773243826 PathPoint;PointKind.SMOOTHPOINT 4907.21361628619,131.287737243475 4908.18077237632,130.965885805401 4905.03255813304,132.01396010119 PathPoint;PointKind.SMOOTHPOINT 4912.68010965732,133.430200468581 4917.35034370271,131.904873857752 4910.37316070169,134.183694887155 PathPoint;PointKind.SMOOTHPOINT 4933.13736506199,131.421979150809 4947.45303766718,131.614290674801 4925.4687268283,131.319005498599 PathPoint;PointKind.SMOOTHPOINT 5001.21816686772,133.279971784192 5012.03848134176,134.757102964192 4979.86393949531,130.364500868517 PathPoint;PointKind.SMOOTHPOINT 5015.21879773967,151.208672052663 5015.25813861545,159.757130883792 5015.1693855997,140.347302741057 PathPoint;PointKind.SMOOTHPOINT 5015.21879773967,189.05807203066 5015.76484909548,204.801050736111 5014.88959329116,179.580264233346 PathPoint;PointKind.SMOOTHPOINT 5016.91454684922,228.817186567807 5016.72256337542,233.365894839436 5017.35579411195,218.337148908908 PathPoint;PointKind.SMOOTHPOINT 5016.21868543845,240.852173395021 5015.21596519662,243.699700508209 5016.98724878766,238.668332629301 PathPoint;PointKind.SMOOTHPOINT 5016.21868543845,266.74910652737 5015.89609025707,285.905967433168 5016.34520569496,259.220980231845 PathPoint;PointKind.SMOOTHPOINT 5015.94015203794,401.5178722053 5015.87940972574,419.159750885422 5016.00120907715,383.875993525178 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,913.595500264124 5015.36923724865,930.939272572092 5012.61443176316,896.251727956155 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,971.831802582545 5014.13645156526,984.35132981434 5013.84721744654,959.312275350751 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1062.198470487 5014.89368474224,1075.71811168342 5015.03845916511,1048.67882929059 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,1236.90737744227 5014.24692074445,1243.99469187045 5013.73674826736,1229.82006301408 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1256.988885321 5014.95096505738,1269.3946243161 5014.98117884997,1244.58291122623 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,1301.16810861434 5013.55042987967,1333.98872680972 5014.43355385914,1268.34749041897 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1523.06833573995 5015.27796641684,1536.89783829165 5014.65417749051,1509.23883318825 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,1586.32495625313 5014.00426622265,1595.83967469747 5013.96524007388,1565.96908706817 PathPoint;PointKind.SMOOTHPOINT 5014.97614321787,1626.19574313001 5015.00856009952,1627.33386059657 5014.55220594049,1611.46933536556 PathPoint;PointKind.SMOOTHPOINT 5015.07182022777,1629.59058225769 5014.68155874005,1631.39896886226 5015.30849493645,1628.49290193309 PathPoint;PointKind.SMOOTHPOINT 5015.1646646946,1633.07076256288 5015.52628602476,1647.07564946287 5015.13508035602,1631.92253581083 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1662.63454513252 5013.43618397641,1670.24354571197 5015.66791317756,1659.14331514318 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1680.70806679314 5014.58556700315,1688.19152415277 5015.3465769042,1673.22437433384 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1696.77313203632 5015.43407101193,1703.21721378769 5014.49807289542,1690.32905028496 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1717.85875057394 5015.18291886096,1729.22911065504 5014.74922504639,1706.48839049285 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1769.06651337982 5014.10969976974,1790.7090830181 5015.82212941061,1747.42394374155 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1843.36788094143 5015.16372051358,1858.7664386412 5014.76810866676,1827.96955834133 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,1876.50235718636 5015.70064478621,1901.2042787338 5012.28333895261,1851.80067073857 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1948.79573852986 5015.31227166052,1966.3708489058 5014.61987224683,1931.22039305424 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1997.99528001797 5015.01516936665,2002.76051507883 5014.83294243004,1985.14238146463 PathPoint;PointKind.SMOOTHPOINT 5014.38225335713,2011.87086210353 5013.7745155081,2019.46646200222 5014.74072741722,2007.39550492663 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2034.14208823955 5014.13645156526,2044.52785093375 5013.90103576461,2027.6067878191 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2088.36194792242 5015.27796641684,2114.97781582295 5014.65417749051,2061.7460800219 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2216.88341026657 5013.99576859348,2248.02142017685 5015.93637531387,2185.74540035629 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2297.2094417815 5014.35738992363,2312.54898946596 5015.57506871072,2281.86965899738 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2372.51492000199 5013.95328044764,2373.80091515631 5014.52482469095,2354.71999144153 PathPoint;PointKind.SMOOTHPOINT 5013.01791178514,2377.53523819676 5012.97164691522,2383.27660705666 5013.08117191339,2369.65728360331 PathPoint;PointKind.SMOOTHPOINT 5013.76287060887,2383.02152392276 5014.33630321422,2406.96736495535 5013.74178389946,2382.15659226413 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2467.90190610122 5014.95851850553,2487.1518664734 5013.17086911016,2451.54649277474 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2545.21560563949 5014.34196830033,2568.6033200731 5013.64170071148,2521.82765610621 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2614.49665500633 5015.639587747,2636.38231769571 5014.29255616035,2592.61099231694 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2688.79802256794 5013.72164137106,2721.91298554086 5014.26202764075,2655.68329469467 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2752.05487818079 5014.34605975141,2768.15520837336 5013.6379239874,2735.95431288855 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2813.3032773762 5014.77566211491,2840.97403746273 5015.15616706544,2785.63251728968 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2884.59254806082 5014.9418379742,2901.51055487985 5014.99030593315,2867.58920006427 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2932.78797889004 5013.44719942163,2943.38627167922 5014.51192088369,2922.66881921321 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2975.96332662416 5014.6082273476,2988.5416287716 5015.32391655975,2963.38478937706 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3008.0936922102 5014.40522842858,3015.71021597885 5013.41352363196,2997.44109139896 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3052.27291550354 5015.07559695184,3059.07693483832 5014.69131527724,3035.20326940214 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3070.3462020645 5015.4828536979,3087.97091846926 5014.80619063451,3064.88648260037 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3088.41948862546 5013.90827448575,3097.77786579418 5014.07570925306,3079.0613465564 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3125.57017240627 5014.33063812811,3139.14482692373 5013.6530308837,3111.99575298847 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3176.77793521215 5013.70653447476,3189.20647887452 5014.25888037069,3165.14826020322 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3206.90031458008 5014.08326270121,3215.32205469307 5013.8852994143,3197.063509598 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3247.06309523788 5014.0930192384,3249.30665131789 5013.3902338335,3233.71060990155 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3255.0957454093 5015.15081670633,3257.3501160738 5014.82224171183,3253.33884563083 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3260.11606360407 5013.96429589286,3267.56566661229 5013.99828640953,3258.42992882403 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3284.21401411834 5014.38382699216,3299.4750385155 5013.67254395809,3271.76971877857 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3321.36469789915 5014.52860141502,3331.252519508 5013.45538232379,3311.47687629029 PathPoint;PointKind.SMOOTHPOINT 5013.01791178514,3338.43387380122 5014.2698958159,3347.58042617396 5011.76592775437,3329.28732142848 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3366.54803185138 5013.91142175581,3378.20309762386 5014.06847053192,3355.48283113231 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3384.62131841234 5016.0087625253,3390.01027287803 5013.92338138205,3379.23236394664 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3401.69049431441 5014.6692843868,3407.12270711802 5015.26285952055,3396.2582815108 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3421.77200219314 5013.4859108434,3435.0092886948 5016.44654779096,3408.53471569148 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3439.8452887541 5013.85886234577,3457.22456111112 5014.12512139304,3422.46625149674 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3485.02862270633 5014.57046010685,3504.18054651921 5015.3616838005,3465.87669889344 PathPoint;PointKind.SMOOTHPOINT 5015.12491372,3564.71497036196 5015.28857176324,3595.02566455962 5014.96125567676,3534.40451126397 PathPoint;PointKind.SMOOTHPOINT 5014.124867704,3606.54864421743 5013.66819881797,3619.1154264814 5014.58153659003,3593.98209705312 PathPoint;PointKind.SMOOTHPOINT 5015.12491372,3641.41003909699 5014.7610893008,3658.71784115658 5015.46796615679,3625.08025163373 PathPoint;PointKind.SMOOTHPOINT 5015.12491372,3690.21599192836 5014.96912385192,3713.15678190341 5015.28101831509,3667.27520195332 PathPoint;PointKind.SMOOTHPOINT 5016.124959736,3764.91898095598 5016.57376044688,3781.48222238418 5015.67584429812,3748.35573952779 PathPoint;PointKind.SMOOTHPOINT 5016.21868543845,3799.7024680819 5016.23977214787,3806.5201231971 5016.18343601376,3788.16307134341 PathPoint;PointKind.SMOOTHPOINT 5015.21879773967,3821.61540233214 5014.63497914313,3822.25534361369 5016.64671416692,3820.04963857935 PathPoint;PointKind.SMOOTHPOINT 5011.26582654148,3825.9861401592 5009.95152656348,3825.9703884818 5012.606563588,3826.00212693625 PathPoint;PointKind.SMOOTHPOINT 5006.21823481563,3827.59163575497 5002.52869012165,3829.42047603019 5007.42584233852,3826.99307201403 PathPoint;PointKind.SMOOTHPOINT 4982.21715332086,3828.58775302532 4975.71615228026,3829.32761166347 4986.61829577592,3828.0865205447 PathPoint;PointKind.SMOOTHPOINT 4961.21604964943,3828.58775302532 4943.06511374638,3830.74502752917 4966.36876019536,3827.9753184043 PathPoint;PointKind.SMOOTHPOINT 4793.83384174739,3828.4220077632 4779.55278911289,3830.2849374895 4808.11520910889,3826.55884293725 PathPoint;PointKind.SMOOTHPOINT 4641.86664788327,3828.4220077632 4619.65856614297,3830.026092761 4664.07410016957,3826.81768766575 PathPoint;PointKind.SMOOTHPOINT 4479.18331418418,3828.4220077632 4450.43835252457,3829.19078365985 4507.9285905708,3827.65323186656 PathPoint;PointKind.SMOOTHPOINT 4394.43205231269,3828.4220077632 4380.23471706185,3829.33584015166 4408.62970229054,3827.50817537475 PathPoint;PointKind.SMOOTHPOINT 4360.33704627424,3828.4220077632 4351.54074117724,3828.27224927814 4370.2534647864,3828.59057422127 PathPoint;PointKind.SMOOTHPOINT 4328.18988567733,3828.4220077632 4326.92845983638,3828.38650771415 4338.09119729319,3828.70107106269 PathPoint;PointKind.SMOOTHPOINT 4320.39693027617,3828.4220077632 4311.1725964507,3828.86117393291 4321.43899139379,3828.3724017344 PathPoint;PointKind.SMOOTHPOINT 4294.09487963888,3828.4220077632 4288.08013182291,3828.66463061499 4304.47237321517,3828.00329526415 PathPoint;PointKind.SMOOTHPOINT 4270.37894081175,3828.6350080575 4269.21759815878,3828.62819016729 4280.06151715829,3828.6909617772 PathPoint;PointKind.SMOOTHPOINT 4266.82378454943,3828.61149809124 4265.90037551316,3827.98448729114 4268.43392791328,3829.70518172157 PathPoint;PointKind.SMOOTHPOINT 4263.44865213466,3828.58516692904 4257.86508031721,3828.53861719584 4264.5929995293,3828.59457091554 PathPoint;PointKind.SMOOTHPOINT 4245.38741342839,3828.4220077632 4224.45554969833,3828.241686322 4251.82704270277,3828.47749128357 PathPoint;PointKind.SMOOTHPOINT 4197.65402730216,3828.4220077632 4176.52703282824,3827.68849681595 4218.78070704907,3829.15551871046 PathPoint;PointKind.SMOOTHPOINT 4156.73951649281,3828.4220077632 4149.42431668711,3828.69425317247 4175.48811898069,3827.72376176534 PathPoint;PointKind.SMOOTHPOINT 4140.17889615222,3828.4220077632 4135.31825226807,3828.7255214276 4143.28871370074,3828.22781544191 PathPoint;PointKind.SMOOTHPOINT 4126.54083079144,3829.42611842209 4112.78883425441,3829.13976703307 4134.92736132634,3829.60056237173 PathPoint;PointKind.SMOOTHPOINT 4098.29030525861,3828.4220077632 4079.18794961574,3828.22969623921 4117.39297562849,3828.61408418753 PathPoint;PointKind.SMOOTHPOINT 4051.53099921665,3828.4220077632 4019.39863078903,3828.86587592616 4083.65109329103,3827.97813960025 PathPoint;PointKind.SMOOTHPOINT 3960.93494211254,3828.4220077632 3903.3937182913,3828.60679609799 4018.57530494074,3828.23674922909 PathPoint;PointKind.SMOOTHPOINT 3856.70113437466,3828.4220077632 3833.05884166698,3827.90032161194 3880.34342708233,3828.94369391447 PathPoint;PointKind.SMOOTHPOINT 3799.22631795173,3828.4220077632 3784.35515218056,3828.44551772946 3814.0974837229,3828.39849779695 PathPoint;PointKind.SMOOTHPOINT 3773.89834739871,3828.4220077632 3759.11089901119,3828.4377594406 3788.68548105922,3828.40625608581 PathPoint;PointKind.SMOOTHPOINT 3746.62190195014,3829.42611842209 3733.98089174509,3829.20630023758 3759.26354160921,3829.64570150694 PathPoint;PointKind.SMOOTHPOINT 3713.50097599597,3829.42611842209 3703.09767480518,3830.01433777787 3723.90459191376,3828.83766396665 PathPoint;PointKind.SMOOTHPOINT 3670.63830501809,3829.42611842209 3636.73496772643,3829.527211277 3704.46107219615,3829.32502556718 PathPoint;PointKind.SMOOTHPOINT 3564.45570765765,3829.42611842209 3541.25057076163,3829.03256158693 3588.74602327115,3829.83777793127 PathPoint;PointKind.SMOOTHPOINT 3473.86028000756,3829.42611842209 3438.01004145539,3829.50652250669 3509.54056597636,3829.34594943715 PathPoint;PointKind.SMOOTHPOINT 3328.71133200632,3829.42611842209 3311.06647712928,3829.54366825338 3346.35681633737,3829.30833349114 PathPoint;PointKind.SMOOTHPOINT 3262.46916537096,3829.42611842209 3242.66024759911,3829.1395319334 3293.12483468537,3829.86928128606 PathPoint;PointKind.SMOOTHPOINT 3190.38220350298,3829.42611842209 3188.6493166067,3829.43904890353 3201.71520827016,3829.34054214491 PathPoint;PointKind.SMOOTHPOINT 3184.53740827036,3829.42611842209 3183.81479506407,3829.9092482287 3186.26337117251,3828.27130887949 PathPoint;PointKind.SMOOTHPOINT 3178.8518649029,3829.50299601175 3170.33094593634,3830.11496043345 3180.31660438987,3829.39790646258 PathPoint;PointKind.SMOOTHPOINT 3153.36464248473,3829.42611842209 3116.07736042213,3829.11273057187 3161.76753882395,3829.49664832086 PathPoint;PointKind.SMOOTHPOINT 3070.56154078177,3829.42611842209 3052.39518325542,3829.52791657599 3088.72789830813,3829.32408516853 PathPoint;PointKind.SMOOTHPOINT 3026.72478971962,3829.42611842209 2998.5963782652,3829.60643986329 3054.85351590104,3829.24556188123 PathPoint;PointKind.SMOOTHPOINT 2922.49098198174,3829.42611842209 2919.73743540427,3829.50111521445 2957.01999656177,3828.48477937311 PathPoint;PointKind.SMOOTHPOINT 2914.22750970628,3829.60549946464 2913.66194527609,3829.61490345114 2916.98483300782,3829.56012522976 PathPoint;PointKind.SMOOTHPOINT 2911.77515687376,3829.42611842209 2910.94585121236,3829.43810850488 2912.34166548497,3829.4178899339 PathPoint;PointKind.SMOOTHPOINT 2909.82668197822,3828.4220077632 2908.68768494269,3829.16398229831 2911.38174811598,3827.40896331714 PathPoint;PointKind.SMOOTHPOINT 2905.99078922634,3829.70306582461 2905.42207752609,3829.70729761854 2907.34254171808,3829.69295653912 PathPoint;PointKind.SMOOTHPOINT 2904.28370994457,3829.71435060841 2875.56990625858,3829.88244686716 2904.85336582584,3829.71105921314 PathPoint;PointKind.SMOOTHPOINT 2808.51511449314,3829.42611842209 2763.47988299129,3830.06135771039 2845.65541904383,3828.9020812742 PathPoint;PointKind.SMOOTHPOINT 2607.84013969153,3828.4220077632 2562.02469994124,3828.21417966148 2653.65589416882,3828.62983586493 PathPoint;PointKind.SMOOTHPOINT 2465.61406139711,3828.4220077632 2424.18213938953,3830.16339096395 2507.04598340468,3826.68062456246 PathPoint;PointKind.SMOOTHPOINT 2382.81158914816,3827.41789710432 2337.66179701604,3828.13965306844 2427.96106655328,3826.69614114019 PathPoint;PointKind.SMOOTHPOINT 2281.49970693608,3828.4220077632 2234.43228315502,3828.72387572996 2328.56713071714,3828.11990469679 PathPoint;PointKind.SMOOTHPOINT 2193.82620481178,3828.4220077632 2163.56709152522,3827.973437607 2254.42153950144,3829.32008847427 PathPoint;PointKind.SMOOTHPOINT 2120.76484813253,3828.4220077632 2100.70761075277,3828.14835175596 2140.77109973728,3828.6947233718 PathPoint;PointKind.SMOOTHPOINT 2063.2900317096,3828.4220077632 2024.94652581412,3828.16551403133 2084.24014960602,3828.5621271621 PathPoint;PointKind.SMOOTHPOINT 1982.43540490219,3828.4220077632 1927.97441429088,3828.09239803626 2036.89671024051,3828.75138239048 PathPoint;PointKind.SMOOTHPOINT 1849.95107163147,3827.41789710432 1802.34074376468,3827.70119219773 1899.65401936266,3827.12214172879 PathPoint;PointKind.SMOOTHPOINT 1722.33745350911,3826.41378644543 1676.4099709446,3826.87058508983 1770.68644565951,3825.93300763545 PathPoint;PointKind.SMOOTHPOINT 1618.06241653341,3827.59163575497 1576.34503713118,3828.34465997421 1659.77948120863,3826.83861153572 PathPoint;PointKind.SMOOTHPOINT 1472.79953735592,3828.38979910943 1439.56436549848,3829.06453514104 1506.03502394036,3827.71529817748 PathPoint;PointKind.SMOOTHPOINT 1353.95326944598,3828.38979910943 1305.22282816403,3828.10368282007 1402.68339600092,3828.67615049845 PathPoint;PointKind.SMOOTHPOINT 1232.18413182922,3828.38979910943 1179.88657465871,3828.23721942841 1306.8644442285,3828.60797159631 PathPoint;PointKind.SMOOTHPOINT 1135.4099835929,3828.06606687406 1134.81105810005,3828.06818277102 1161.05362533317,3827.98143099553 PathPoint;PointKind.SMOOTHPOINT 1133.59841494507,3828.07264966461 1132.19410304329,3828.07805695685 1134.20741170211,3828.07029866798 PathPoint;PointKind.SMOOTHPOINT 1128.87247421958,3828.38979910943 1126.90920715474,3829.18467106862 1130.56759387511,3827.70377829402 PathPoint;PointKind.SMOOTHPOINT 1122.72554106099,3828.13142458025 1114.82400484268,3828.18526240298 1125.001332043,3828.11590800252 PathPoint;PointKind.SMOOTHPOINT 1094.77746818114,3828.38979910943 1036.39686743429,3829.03303178625 1105.79354285305,3828.26848768354 PathPoint;PointKind.SMOOTHPOINT 989.568950904972,3828.38979910943 931.10463277447,3828.76642876889 1048.03326903547,3828.01340454964 PathPoint;PointKind.SMOOTHPOINT 860.006857887062,3828.38979910943 808.917222966441,3829.04102517478 911.096492807682,3827.73880814374 PathPoint;PointKind.SMOOTHPOINT 810.636261874446,3826.39756456871 800.253417939059,3826.43024342181 838.818806373934,3826.30893199592 PathPoint;PointKind.SMOOTHPOINT 783.360131152888,3826.39756456871 775.181635169106,3826.87622748173 788.256024461735,3826.11121317969 PathPoint;PointKind.SMOOTHPOINT 764.851035916753,3827.4016752276 759.313728969218,3828.10697421534 772.339650302888,3826.44811099617 PathPoint;PointKind.SMOOTHPOINT 746.022178042293,3826.59575358427 734.418822776763,3826.7055451267 764.145417968795,3826.42389573092 PathPoint;PointKind.SMOOTHPOINT 723.021298973305,3828.58775302532 717.089009632957,3828.70530285661 728.95390304066,3828.46996809437 PathPoint;PointKind.SMOOTHPOINT 709.324379662362,3828.40578588649 692.862898328732,3827.43317858239 725.786175722998,3829.37862829025 PathPoint;PointKind.SMOOTHPOINT 678.048068691675,3829.42611842209 666.33927987906,3828.778889051 689.75685750429,3830.07311269351 PathPoint;PointKind.SMOOTHPOINT 654.018032312329,3827.59163575497 638.237620220171,3827.03868134857 669.798759131493,3828.14459016136 PathPoint;PointKind.SMOOTHPOINT 626.418047501365,3826.41378644543 607.285163338891,3828.7003657637 645.550931663838,3824.12720712716 PathPoint;PointKind.SMOOTHPOINT 600.015598949089,3827.59163575497 591.188765332483,3827.20489681002 610.845355233316,3828.06630197372 PathPoint;PointKind.SMOOTHPOINT 582.581296439215,3826.41378644543 581.03158066056,3826.14412713245 589.410243020301,3827.60245033944 PathPoint;PointKind.SMOOTHPOINT 574.014427329751,3828.58775302532 570.609395849395,3828.33807718366 576.617219671238,3828.77865395134 PathPoint;PointKind.SMOOTHPOINT 562.013886582365,3828.58775302532 557.112642914412,3829.06923713429 565.296803984305,3828.26543138792 PathPoint;PointKind.SMOOTHPOINT 546.013165585849,3827.59163575497 542.150521038441,3828.68061739204 549.530554607428,3826.60022047786 PathPoint;PointKind.SMOOTHPOINT 538.012805087591,3827.59163575497 535.994460796666,3827.85964937031 540.872414666158,3827.2119497999 PathPoint;PointKind.SMOOTHPOINT 533.873830228717,3830.42999398131 530.319932874416,3829.93205289597 535.256425967067,3830.62395120294 PathPoint;PointKind.SMOOTHPOINT 522.184239763481,3829.42611842209 514.269170283911,3829.40260845583 527.882686938204,3829.4430455978 PathPoint;PointKind.SMOOTHPOINT 509.519939759965,3830.42999398131 499.900308814676,3829.66145318433 519.13988543226,3831.19876987795 PathPoint;PointKind.SMOOTHPOINT 490.037079166568,3829.42611842209 470.957383868146,3829.85352960866 509.11677446499,3828.99847213585 PathPoint;PointKind.SMOOTHPOINT 463.735028529278,3830.42999398131 453.061062113133,3830.67332213209 474.408680218417,3830.1869009302 PathPoint;PointKind.SMOOTHPOINT 449.122568357224,3829.42611842209 444.655333230857,3828.88092230456 453.590118210599,3829.97131453962 PathPoint;PointKind.SMOOTHPOINT 441.008276682713,3829.58387029568 435.3457083867,3829.92899660035 446.67053025172,3829.23874399101 PathPoint;PointKind.CORNERPOINT 436.45889780772,3830.42999398131 436.45889780772,3830.42999398131 436.45889780772,3830.42999398131 PathPoint;PointKind.SMOOTHPOINT 424.007353260412,3830.57975246638 423.315268573722,3831.82084358515 425.149497566005,3828.53109400664 PathPoint;PointKind.SMOOTHPOINT 399.00638406686,3829.58387029568 353.566728362003,3826.8757572824 408.100735638758,3830.1260101176 PathPoint;PointKind.SMOOTHPOINT 315.66415500224,3830.42999398131 302.63319803647,3829.46937676001 340.668271465854,3832.27341043562 PathPoint;PointKind.SMOOTHPOINT 272.000503793515,3826.59575358427 263.761265497532,3818.92515689322 276.672311473929,3830.94533244169 PathPoint;PointKind.SMOOTHPOINT 266.000233419821,3804.68281933403 263.659923401527,3781.96231774282 267.039461994379,3814.77682334697 PathPoint;PointKind.SMOOTHPOINT 264.033819084923,3745.08387937128 262.982316157123,3733.03502166398 265.042833866883,3756.63949798649 PathPoint;PointKind.CORNERPOINT 263.059739000654,3561.33821158571 263.059739000654,3561.33821158571 263.059739000654,3561.33821158571 PathPoint;PointKind.CORNERPOINT 263.059739000654,3111.51332848085 263.059739000654,3111.51332848085 263.059739000654,3111.51332848085 PathPoint;PointKind.CORNERPOINT 263.059739000654,2498.02405036948 263.059739000654,2498.02405036948 263.059739000654,2498.02405036948 PathPoint;PointKind.SMOOTHPOINT 264.033819084923,2486.97930332106 264.152156439264,2478.49949359141 263.916111184595,2495.45911305072 PathPoint;PointKind.SMOOTHPOINT 263.059739000654,2468.9060167601 262.717630744887,2453.19759770505 263.402476710434,2484.61420071549 PathPoint;PointKind.SMOOTHPOINT 264.033819084923,2443.80419068661 263.601069451363,2436.22551796363 264.245630360113,2447.50583487395 PathPoint;PointKind.SMOOTHPOINT 263.059739000654,2383.55966705041 262.893563141367,2356.89489842007 263.233468308091,2411.38112602066 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,2109.44756646004 268.040923328189,2060.3380681427 267.820299696825,2158.55682967772 PathPoint;PointKind.SMOOTHPOINT 265.008528623204,2015.06445592004 264.441390557985,2000.90957543533 265.575351961417,2029.21957150441 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1967.8731357497 266.899408476608,1940.05308737743 267.013654379868,1995.6929490223 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,1914.65715162605 267.458678366671,1897.45067752103 270.351019553886,1931.86362573107 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1881.52267538112 267.036629451323,1869.22672792844 266.87674813216,1893.8186228338 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1856.42084930762 264.441390557985,1843.7092456515 271.420147194034,1869.13268806341 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1822.28249750348 266.773832401124,1803.98539606374 269.087390623889,1840.57936384355 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1760.02975254951 270.148964815889,1730.24497629705 265.712258209125,1789.81476390164 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1659.62244825552 267.438221111267,1653.2968567341 269.28661281883,1677.04051205686 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1620.46354315694 267.356077362642,1598.98577838214 266.556985493835,1641.94130793175 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1516.03979622741 265.792198868706,1494.88764448528 268.12086398777,1537.1921830692 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1407.59984176199 268.36855414167,1381.26256696162 267.493298337356,1433.93711656235 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1318.23728451642 267.036629451323,1294.79056006749 268.825223027703,1341.68400896534 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1236.90737744227 267.938951778172,1233.62091925904 267.900240356406,1249.38764303041 PathPoint;PointKind.SMOOTHPOINT 267.989308099168,1229.09736665131 268.029907882971,1226.59261484616 267.955317582496,1231.23442258417 PathPoint;PointKind.SMOOTHPOINT 265.008528623204,1223.85440907608 265.076509656549,1221.97831376868 264.903724530131,1226.72168456092 PathPoint;PointKind.SMOOTHPOINT 265.982608707473,1209.797330051 266.942211349455,1206.08863287377 265.125292342514,1213.10894389812 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,1202.76879053846 269.696387380936,1180.61252813745 268.725769293736,1207.77899944774 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1167.62632807543 266.345174218645,1159.05718047399 268.127473254901,1184.04592360979 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1121.43888346431 268.531268003889,1100.94642137539 267.321457391957,1142.22663072944 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,1087.3002965605 267.261029806762,1071.25639028695 270.334968476568,1101.25534233202 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1036.09253375462 267.063066519846,1016.37190385795 268.798156505168,1055.81316365129 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,980.868563412856 268.96559127248,958.40243965656 268.844106648077,1003.33468716915 PathPoint;PointKind.SMOOTHPOINT 269.879243771553,907.571071410471 270.762053024016,879.151048699296 268.996119792084,935.991094121646 PathPoint;PointKind.SMOOTHPOINT 269.879243771553,826.241164336323 270.773383196241,798.895782182809 268.98478961986,853.586546489837 PathPoint;PointKind.SMOOTHPOINT 270.853323855822,759.972211846477 272.333484966101,735.035190636448 269.372848018536,784.909468156168 PathPoint;PointKind.SMOOTHPOINT 270.853323855822,704.748241504713 270.289962514678,680.477727838103 271.41637046996,729.01852007166 PathPoint;PointKind.SMOOTHPOINT 271.827403940091,654.544589357717 271.454452437713,637.910582931082 272.200355442468,671.178360684689 PathPoint;PointKind.SMOOTHPOINT 271.827403940091,630.446638843442 272.459690495598,624.346978097762 271.194802657577,636.546534688783 PathPoint;PointKind.SMOOTHPOINT 271.827403940091,606.348923428829 270.910289443949,589.883718559928 272.744518436232,622.814128297731 PathPoint;PointKind.SMOOTHPOINT 272.801484024359,559.157368158828 272.211685614692,535.79316369147 273.391282434026,582.521807725848 PathPoint;PointKind.SMOOTHPOINT 272.801484024359,530.039334549449 270.080669055538,523.716799323642 275.52229899318,536.361869775255 PathPoint;PointKind.SMOOTHPOINT 269.879243771553,512.970158647375 266.400880898747,505.686536000935 273.356977190347,520.253546194153 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,478.831571743566 269.195656714031,463.238586622843 268.604284669333,494.954001304423 PathPoint;PointKind.SMOOTHPOINT 265.906383734001,440.137949300038 264.782178867763,409.721930453545 266.302310307833,450.84227203704 PathPoint;PointKind.SMOOTHPOINT 265.906383734001,379.37951822424 265.61463179923,350.582160554622 266.249750897793,413.340369783138 PathPoint;PointKind.SMOOTHPOINT 265.906383734001,294.716130659604 265.628479787504,264.731284594286 266.183658226486,324.701211824584 PathPoint;PointKind.SMOOTHPOINT 264.906337718001,236.945819144911 264.614603456426,217.918916378591 265.211289095451,256.83619091308 PathPoint;PointKind.SMOOTHPOINT 263.906291702,190.131946020936 263.212119272469,170.22775982724 264.561571729428,208.926185914306 PathPoint";
	
	mask645[1] = "PointKind.SMOOTHPOINT 265.000030994036,142.244321918427 266.186551807507,132.514957482151 262.393147201468,163.618877941357 PathPoint;PointKind.SMOOTHPOINT 276.000684042644,132.283854513833 281.883246516008,130.232374858147 270.117492115266,134.335099069858 PathPoint;PointKind.SMOOTHPOINT 348.810888570926,132.377894378866 366.505470314948,132.16606958288 331.116306826904,132.589719174852 PathPoint;PointKind.SMOOTHPOINT 942.031324976615,131.287737243475 977.465809153556,131.205452361572 906.596526072667,131.370022125379 PathPoint;PointKind.SMOOTHPOINT 1491.05653626006,130.29185507278 1502.73133455601,130.080030276794 1479.38205269113,130.503679868766 PathPoint;PointKind.SMOOTHPOINT 1535.30054406827,131.421979150809 1541.85158670286,131.454422904246 1524.24229597752,131.367200929428 PathPoint;PointKind.SMOOTHPOINT 1545.04228909197,129.413757833037 1548.46179801461,128.824833178271 1540.07117602864,130.26999080416 PathPoint;PointKind.SMOOTHPOINT 1568.0601634193,131.287737243475 1571.988271184,131.227081530529 1562.65850381144,131.370727424367 PathPoint;PointKind.SMOOTHPOINT 1580.11137521469,130.417868491923 1584.0955043865,131.504264032713 1574.5108081389,128.890661083793 PathPoint;PointKind.SMOOTHPOINT 1605.43934576771,132.426089809695 1620.91541684484,132.379069877179 1594.5497913523,132.459238862119 PathPoint;PointKind.SMOOTHPOINT 1857.74434175963,133.430200468581 1868.95837971846,133.928376653592 1846.53030380081,132.932024283571 PathPoint;PointKind.CORNERPOINT 1889.89118762954,133.430200468581 1889.89118762954,133.430200468581 1889.89118762954,133.430200468581 PathPoint;PointKind.SMOOTHPOINT 1895.73629758917,134.434311127467 1897.24415467599,134.560324546611 1889.8892992675,133.94553892896 PathPoint;PointKind.SMOOTHPOINT 1903.54656297566,132.268337936103 1908.37353107015,132.069678721222 1897.41190417031,132.520834973716 PathPoint;PointKind.SMOOTHPOINT 1916.19355299384,133.430200468581 1927.82208641987,134.497082737377 1904.5643901138,132.363318199786 PathPoint;PointKind.SMOOTHPOINT 1970.74581443695,133.430200468581 1979.69602104,133.351677181279 1961.79560783391,133.508488656221 PathPoint;PointKind.SMOOTHPOINT 2015.55664558337,133.430200468581 2029.47639161472,133.308653943027 2001.63689955202,133.551746994136 PathPoint;PointKind.SMOOTHPOINT 2065.23850660515,133.430200468581 1879.69875353292,133.267511502075 2050.97319032096,133.417505086802 PathPoint;PointKind.SMOOTHPOINT 2562.05491373383,134.434311127467 2582.96789384352,134.215903540929 2428.76487932718,135.825630930625 PathPoint;PointKind.SMOOTHPOINT 2612.71116956688,133.430200468581 2620.59917252392,133.026064148604 2604.82253715583,133.834101688896 PathPoint;PointKind.SMOOTHPOINT 2640.96138037271,134.434311127467 2650.68392704903,134.104701400528 2631.23883369638,134.763685754744 PathPoint;PointKind.SMOOTHPOINT 2698.43619679564,134.434311127467 2705.96698460061,134.340036162772 2690.90540899067,134.5283509925 PathPoint;PointKind.SMOOTHPOINT 2716.94497730476,134.434311127467 2725.98645473962,134.798950704131 2707.90381459692,134.069436451141 PathPoint;PointKind.SMOOTHPOINT 2758.83356819838,135.438186686691 2777.12927852429,135.956111243358 2740.53785787246,134.920497229686 PathPoint;PointKind.SMOOTHPOINT 2799.74807900772,135.438186686691 2807.31663405344,135.285371906013 2792.179209235,135.591236567031 PathPoint;PointKind.SMOOTHPOINT 2821.17909976965,133.430200468581 2835.22158933343,133.106233133544 2810.67351230184,133.672588220703 PathPoint;PointKind.SMOOTHPOINT 2853.32626036657,134.434311127467 2858.3678722793,134.642139229189 2848.28401899983,134.226247926083 PathPoint;PointKind.SMOOTHPOINT 2866.13627897397,134.0238271166 2872.51516593615,133.498614470393 2859.10968383297,134.602407386213 PathPoint;PointKind.SMOOTHPOINT 2882.55055125666,135.438186686691 2885.15995286528,135.661531366143 2878.89184980929,135.125269035794 PathPoint;PointKind.SMOOTHPOINT 2900.08525168152,134.434311127467 2903.01252756643,133.882297119726 2893.04449382525,135.761918922065 PathPoint;PointKind.SMOOTHPOINT 2906.90444172542,131.421979150809 2914.82989719619,130.697872190058 2903.13180910179,131.766635256154 PathPoint;PointKind.SMOOTHPOINT 2918.59434691766,135.438186686691 2925.90797308833,135.606988244424 2911.28040601998,135.26962022862 PathPoint;PointKind.SMOOTHPOINT 2954.63782785165,134.434311127467 2964.73301130334,134.783199026738 2944.54232967294,134.085188128534 PathPoint;PointKind.SMOOTHPOINT 2983.86211874174,134.434311127467 3000.55618333297,134.257751280868 2967.16868360452,134.610635874403 PathPoint;PointKind.SMOOTHPOINT 3556.6627522565,135.438186686691 3589.20930142431,136.387519124195 3524.11620308868,134.489089348849 PathPoint;PointKind.SMOOTHPOINT 3657.97431974158,135.438186686691 3662.59797419004,135.712783092586 3639.98169152266,134.370128919582 PathPoint;PointKind.SMOOTHPOINT 3673.5608599979,137.446408004462 3678.35761429978,137.866060902171 3668.76379096901,137.026755106754 PathPoint;PointKind.SMOOTHPOINT 3698.88883055092,138.450518663348 3703.1848541859,137.171811598567 3696.11136472098,139.277129076985 PathPoint;PointKind.SMOOTHPOINT 3716.42353097578,135.438186686691 3720.35352710252,135.427137002549 3711.11817783183,135.453233065096 PathPoint;PointKind.SMOOTHPOINT 3727.13904135675,137.446408004462 3730.71371069346,137.472033867684 3720.03691173426,137.395391377682 PathPoint;PointKind.SMOOTHPOINT 3739.80302663326,136.442297345576 3741.06508192822,136.417611881005 3731.98866979568,136.595817425242 PathPoint;PointKind.SMOOTHPOINT 3746.62190195014,137.446408004462 3748.51624380062,136.756625594448 3744.47829631074,138.227409083558 PathPoint;PointKind.SMOOTHPOINT 3750.51853701422,137.446408004462 3757.2511771314,137.52634188974 3749.67916008862,137.436533818634 PathPoint;PointKind.SMOOTHPOINT 3769.02763225036,136.442297345576 3785.85482636522,135.465693347213 3763.60929211118,136.756860694111 PathPoint;PointKind.SMOOTHPOINT 3790.4589677393,133.430200468581 3791.86359436808,133.430670667906 3779.07749501316,133.426203774317 PathPoint;PointKind.SMOOTHPOINT 3797.27784305618,133.430200468581 3804.52852382561,133.932138248193 3796.25718337499,133.359435470144 PathPoint;PointKind.SMOOTHPOINT 3807.01958807989,134.434311127467 3812.85305314028,134.838212347782 3801.90590368273,134.080015935957 PathPoint;PointKind.SMOOTHPOINT 3819,133 3822.88058398676,133.114493535677 3817.13398358009,132.944986678956 PathPoint;PointKind.SMOOTHPOINT 3826.50244867329,131.421979150809 3827.63515116869,132.384712269081 3824.87153332702,130.035596440566 PathPoint;PointKind.SMOOTHPOINT 3832.3472439059,133.430200468581 3838.12374337817,133.675644516316 3828.45784756297,133.264925405786 PathPoint;PointKind.SMOOTHPOINT 3841.11459411833,130.417868491923 3848.49934859241,130.983518280095 3839.9752823558,130.330646517106 PathPoint;PointKind.SMOOTHPOINT 3862.54592960727,133.430200468581 3870.57902171418,132.963527638357 3854.51315222738,133.896873298806 PathPoint;PointKind.SMOOTHPOINT 3882.02910492768,133.430200468581 3893.4599897938,134.36354612903 3870.59790533455,132.49661970847 PathPoint;PointKind.SMOOTHPOINT 3906.38268066942,134.434311127467 3913.39605727616,134.465579382591 3899.3696187897,134.402807772681 PathPoint;PointKind.SMOOTHPOINT 3922.94330101001,131.421979150809 3933.97700039428,130.455014238611 3907.65858395266,132.761341928537 PathPoint;PointKind.SMOOTHPOINT 3943,132 3953.13326541945,131.650641901404 3936.4687851668,132.224990377091 PathPoint;PointKind.CORNERPOINT 3956.0645416912,133.430200468581 3956.0645416912,133.430200468581 3956.0645416912,133.430200468581 PathPoint;PointKind.SMOOTHPOINT 3966.78036679917,131.421979150809 3974.27653463345,130.759233201992 3959.28356951087,132.084960199289 PathPoint;PointKind.SMOOTHPOINT 3980.41811743294,132.426089809695 3988.17960013348,132.376013581565 3970.07178183028,132.492858113868 PathPoint;PointKind.SMOOTHPOINT 3994.05649752073,131.421979150809 3995.70189030928,131.113058194177 3989.11559824999,132.349682419356 PathPoint;PointKind.SMOOTHPOINT 3999.90129275335,129.413757833037 4007.99858916952,129.001157925207 3996.55542995016,129.584440188072 PathPoint;PointKind.SMOOTHPOINT 4013.53935811412,131.421979150809 4016.25891417492,131.855973127935 4009.37929654583,130.758292803342 PathPoint;PointKind.SMOOTHPOINT 4026.20334339063,131.421979150809 4038.52459095737,132.1514934038 4021.33231351528,131.133511864822 PathPoint;PointKind.SMOOTHPOINT 4059.32458407182,132.426089809695 4066.90950492186,132.508139591936 4041.21896885766,132.230016691102 PathPoint;PointKind.SMOOTHPOINT 4082.70407972929,131.421979150809 4084.95469255081,131.162664222982 4074.9750139104,132.312536672668 PathPoint;PointKind.SMOOTHPOINT 4089.52295504618,129.413757833037 4094.05785647889,129.286804015243 4087.40452756728,129.473238047671 PathPoint;PointKind.SMOOTHPOINT 4102.1872550497,131.421979150809 4105.17149652273,131.887241383058 4098.25127910984,130.808604131134 PathPoint;PointKind.SMOOTHPOINT 4110.95429053512,131.421979150809 4126.13735076946,131.088607829269 4107.94864762567,131.488042155995 PathPoint;PointKind.SMOOTHPOINT 4157,132 4166.03927434581,131.839662030119 4142.62736180669,132.254848034238 PathPoint;PointKind.SMOOTHPOINT 4178.17148143577,133.253640621982 4179.03572179486,133.195806104987 4170.55886460918,133.762866491134 PathPoint;PointKind.SMOOTHPOINT 4180.76294360503,133.080607270322 4181.20765286483,132.490507117243 4179.58995605283,134.635556438637 PathPoint;PointKind.SMOOTHPOINT 4184.01564721437,132.426089809695 4186.92529838693,132.23801007963 4183.28988673802,132.473109742212 PathPoint;PointKind.SMOOTHPOINT 4191.80891734253,132.426089809695 4204.43482065129,131.814125387995 4188.78061408863,132.572791999146 PathPoint;PointKind.SMOOTHPOINT 4216.16249308428,133.430200468581 4222.8362792513,133.480041597049 4206.17022536362,133.355673875543 PathPoint;PointKind.SMOOTHPOINT 4235.64566840468,131.421979150809 4237.63726090008,131.01314083758 4229.76782683641,132.628980818503 PathPoint;PointKind.SMOOTHPOINT 4239.57629398543,129.591258078287 4240.77666278718,129.496748013929 4237.01000997667,129.793443788107 PathPoint;PointKind.SMOOTHPOINT 4243.43893853284,129.413757833037 4247.57319248662,129.351691522116 4242.05854588354,129.434681703007 PathPoint;PointKind.SMOOTHPOINT 4255.12852899808,129.413757833037 4257.0710240805,129.777927210376 4251.46132992154,128.726326419649 PathPoint;PointKind.SMOOTHPOINT 4259.99924414643,131.421979150809 4265.76787544354,133.047693317561 4258.11906501124,130.89206451135 PathPoint;PointKind.SMOOTHPOINT 4274.61170431848,131.421979150809 4286.80359908565,131.417982456546 4268.33195636326,131.424095047773 PathPoint;PointKind.SMOOTHPOINT 4291.17232465907,130.417868491923 4301.68231830497,130.139510491427 4280.66201628617,130.696461592083 PathPoint;PointKind.SMOOTHPOINT 4306.75855018839,134.434311127467 4309.04032098353,134.353436843539 4297.67552878872,134.755927465879 PathPoint;PointKind.SMOOTHPOINT 4310.65549997948,132.426089809695 4311.56726411651,132.268808135428 4309.12844454527,132.689166332124 PathPoint;PointKind.SMOOTHPOINT 4315.52621512783,133.430200468581 4316.34765261407,133.365312961709 4314.32112542099,133.525415831927 PathPoint;PointKind.SMOOTHPOINT 4318.44845538063,131.421979150809 4319.2406232553,131.333111478354 4317.45612113,131.533416390873 PathPoint;PointKind.SMOOTHPOINT 4322.34509044471,133.430200468581 4323.02553023217,133.410216997262 4321.37824908159,133.458412428091 PathPoint;PointKind.SMOOTHPOINT 4324.29325061325,131.421979150809 4325.3774851497,131.320651196237 4323.53853525232,131.492509049584 PathPoint;PointKind.SMOOTHPOINT 4331.11244065714,131.421979150809 4332.48842712836,131.854092330634 4329.21809880667,130.827177004478 PathPoint;PointKind.SMOOTHPOINT 4333.06060082568,133.430200468581 4335.10664109315,133.460998524379 4331.89107527054,133.412567993888 PathPoint;PointKind.SMOOTHPOINT 4338.9057107853,131.421979150809 4341.33980945145,130.913928779971 4336.58428438738,131.90651955539 PathPoint;PointKind.SMOOTHPOINT 4348.647141082,131.421979150809 4352.0439896602,131.378720812894 4344.65923518612,131.47299577759 PathPoint;PointKind.SMOOTHPOINT 4358.38888610571,129.413757833037 4369.07512687509,129.363211405582 4354.90171087672,129.430449909081 PathPoint;PointKind.SMOOTHPOINT 4381.76838176318,129.413757833037 4383.10219481557,129.461247964879 4370.95341764825,129.029840084042 PathPoint;PointKind.SMOOTHPOINT 4386.63909691153,131.421979150809 4409.43288561042,132.321470459847 4385.2571306272,131.36743602909 PathPoint;PointKind.SMOOTHPOINT 4447.03615358727,131.421979150809 4448.97078049454,131.445254017405 4433.38077824114,131.25717428734 PathPoint;PointKind.SMOOTHPOINT 4452.88126354689,129.413757833037 4453.59537912402,128.120474589176 4451.98617994118,131.035240205863 PathPoint;PointKind.SMOOTHPOINT 4457.75197869524,131.421979150809 4459.50595230094,132.667066963841 4456.37630695103,130.445610252108 PathPoint;PointKind.SMOOTHPOINT 4463.59677392786,129.413757833037 4466.51460800258,130.668484732235 4461.92274098174,128.693882666213 PathPoint;PointKind.SMOOTHPOINT 4471.88007400471,131.903463259776 4472.95423727696,131.780741235909 4468.58173497947,132.27985781957 PathPoint;PointKind.SMOOTHPOINT 4478.20923409991,129.413757833037 4483.46769291993,129.21274762153 4475.66970188668,129.510853993684 PathPoint;PointKind.SMOOTHPOINT 4493.79545962923,131.421979150809 4500.85982201097,131.72619811419 4489.992613213,131.25811468599 PathPoint;PointKind.SMOOTHPOINT 4512.30424013836,130.417868491923 4515.76592247983,130.219679476367 4501.3111405379,131.04770048798 PathPoint;PointKind.SMOOTHPOINT 4526.91670031041,130.417868491923 4541.87693382434,130.487457992048 4520.66024215365,130.388716133763 PathPoint;PointKind.SMOOTHPOINT 4566.29219605931,130.222030472993 4567.56023116739,130.215212582778 4552.60943946365,130.294911368393 PathPoint;PointKind.SMOOTHPOINT 4571.72753145683,129.413757833037 4575.30723642564,129.402002849908 4570.40316021463,129.418224726627 PathPoint;PointKind.SMOOTHPOINT 4579.52080158499,129.413757833037 4580.21823663079,129.416108829663 4575.37458800497,129.40035715227 PathPoint;PointKind.SMOOTHPOINT 4581.46896175353,130.417868491923 4582.26931253036,130.43761686358 4580.70889603349,130.39929561858 PathPoint;PointKind.SMOOTHPOINT 4583.41743664907,129.413757833037 4586.46902970143,129.44220489221 4582.55193738195,129.40576444451 PathPoint;PointKind.SMOOTHPOINT 4593.15886694577,129.413757833037 4596.91418958405,129.647917096969 4589.49859186336,129.185711160333 PathPoint;PointKind.SMOOTHPOINT 4604.84877213801,130.417868491923 4643.42297292906,130.974819592579 4601.30557550192,130.366851865143 PathPoint;PointKind.SMOOTHPOINT 4654.53031843278,131.421979150809 4669.99883606176,131.767105455479 4639.06180080379,131.07685284614 PathPoint;PointKind.SMOOTHPOINT 4684.72931886115,130.417868491923 4698.09325699951,130.755236507728 4671.36506599579,130.080735575781 PathPoint;PointKind.SMOOTHPOINT 4712.97952966698,130.417868491923 4731.61010952752,130.017963965872 4694.34863507944,130.818008117637 PathPoint;PointKind.SMOOTHPOINT 4743.17790064134,131.421979150809 4763.6999898093,131.775098844007 4722.6561262004,131.069094557274 PathPoint;PointKind.SMOOTHPOINT 4787.0149664305,131.421979150809 4821.30415903179,130.531656728613 4752.72545910221,132.312301573006 PathPoint;PointKind.SMOOTHPOINT 4853.25713306586,131.421979150809 4874.90877745916,131.300667724917 4828.77011307347,131.559277353757 PathPoint;PointKind.SMOOTHPOINT 4893.8833539375,131.182412594639 4895.74559363334,131.243068307585 4879.66209943418,130.717855661378 PathPoint;PointKind.SMOOTHPOINT 4900.01643910782,133.430200468581 4906.58793899781,133.583015249259 4897.76865882935,133.377773243826 PathPoint;PointKind.SMOOTHPOINT 4907.21361628619,131.287737243475 4908.18077237632,130.965885805401 4905.03255813304,132.01396010119 PathPoint;PointKind.SMOOTHPOINT 4916,131 4920.67023404538,129.474673389171 4913.69305104437,131.753494418574 PathPoint;PointKind.SMOOTHPOINT 4943,131 4957.31567260518,131.192311523992 4935.3313617663,130.897026347789 PathPoint;PointKind.SMOOTHPOINT 5001.21816686772,133.279971784192 5012.03848134176,134.757102964192 4979.86393949531,130.364500868517 PathPoint;PointKind.SMOOTHPOINT 5015.21879773967,151.208672052663 5015.25813861545,159.757130883792 5015.1693855997,140.347302741057 PathPoint;PointKind.SMOOTHPOINT 5015.21879773967,189.05807203066 5015.76484909548,204.801050736111 5014.88959329116,179.580264233346 PathPoint;PointKind.SMOOTHPOINT 5016.91454684922,228.817186567807 5016.72256337542,233.365894839436 5017.35579411195,218.337148908908 PathPoint;PointKind.SMOOTHPOINT 5016.21868543845,240.852173395021 5015.21596519662,243.699700508209 5016.98724878766,238.668332629301 PathPoint;PointKind.SMOOTHPOINT 5016.21868543845,266.74910652737 5015.89609025707,285.905967433168 5016.34520569496,259.220980231845 PathPoint;PointKind.SMOOTHPOINT 5015.94015203794,401.5178722053 5015.87940972574,419.159750885422 5016.00120907715,383.875993525178 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,913.595500264124 5015.36923724865,930.939272572092 5012.61443176316,896.251727956155 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,971.831802582545 5014.13645156526,984.35132981434 5013.84721744654,959.312275350751 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1062.198470487 5014.89368474224,1075.71811168342 5015.03845916511,1048.67882929059 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,1236.90737744227 5014.24692074445,1243.99469187045 5013.73674826736,1229.82006301408 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1256.988885321 5014.95096505738,1269.3946243161 5014.98117884997,1244.58291122623 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,1301.16810861434 5013.55042987967,1333.98872680972 5014.43355385914,1268.34749041897 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1523.06833573995 5015.27796641684,1536.89783829165 5014.65417749051,1509.23883318825 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,1586.32495625313 5014.00426622265,1595.83967469747 5013.96524007388,1565.96908706817 PathPoint;PointKind.SMOOTHPOINT 5014.97614321787,1626.19574313001 5015.00856009952,1627.33386059657 5014.55220594049,1611.46933536556 PathPoint;PointKind.SMOOTHPOINT 5015.07182022777,1629.59058225769 5014.68155874005,1631.39896886226 5015.30849493645,1628.49290193309 PathPoint;PointKind.SMOOTHPOINT 5015.1646646946,1633.07076256288 5015.52628602476,1647.07564946287 5015.13508035602,1631.92253581083 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1662.63454513252 5013.43618397641,1670.24354571197 5015.66791317756,1659.14331514318 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1680.70806679314 5014.58556700315,1688.19152415277 5015.3465769042,1673.22437433384 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1696.77313203632 5015.43407101193,1703.21721378769 5014.49807289542,1690.32905028496 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1717.85875057394 5015.18291886096,1729.22911065504 5014.74922504639,1706.48839049285 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1769.06651337982 5014.10969976974,1790.7090830181 5015.82212941061,1747.42394374155 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1843.36788094143 5015.16372051358,1858.7664386412 5014.76810866676,1827.96955834133 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,1876.50235718636 5015.70064478621,1901.2042787338 5012.28333895261,1851.80067073857 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1948.79573852986 5015.31227166052,1966.3708489058 5014.61987224683,1931.22039305424 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1997.99528001797 5015.01516936665,2002.76051507883 5014.83294243004,1985.14238146463 PathPoint;PointKind.SMOOTHPOINT 5014.38225335713,2011.87086210353 5013.7745155081,2019.46646200222 5014.74072741722,2007.39550492663 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2034.14208823955 5014.13645156526,2044.52785093375 5013.90103576461,2027.6067878191 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2088.36194792242 5015.27796641684,2114.97781582295 5014.65417749051,2061.7460800219 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2216.88341026657 5013.99576859348,2248.02142017685 5015.93637531387,2185.74540035629 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2297.2094417815 5014.35738992363,2312.54898946596 5015.57506871072,2281.86965899738 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2372.51492000199 5013.95328044764,2373.80091515631 5014.52482469095,2354.71999144153 PathPoint;PointKind.SMOOTHPOINT 5013.01791178514,2377.53523819676 5012.97164691522,2383.27660705666 5013.08117191339,2369.65728360331 PathPoint;PointKind.SMOOTHPOINT 5013.76287060887,2383.02152392276 5014.33630321422,2406.96736495535 5013.74178389946,2382.15659226413 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2467.90190610122 5014.95851850553,2487.1518664734 5013.17086911016,2451.54649277474 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2545.21560563949 5014.34196830033,2568.6033200731 5013.64170071148,2521.82765610621 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2614.49665500633 5015.639587747,2636.38231769571 5014.29255616035,2592.61099231694 PathPoint;PointKind.SMOOTHPOINT 5016,2684 5015.72964950165,2717.11496297293 5016.27003577134,2650.88527212673 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2752.05487818079 5014.34605975141,2768.15520837336 5013.6379239874,2735.95431288855 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2813.3032773762 5014.77566211491,2840.97403746273 5015.15616706544,2785.63251728968 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2884.59254806082 5014.9418379742,2901.51055487985 5014.99030593315,2867.58920006427 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2932.78797889004 5013.44719942163,2943.38627167922 5014.51192088369,2922.66881921321 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2975.96332662416 5014.6082273476,2988.5416287716 5015.32391655975,2963.38478937706 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3008.0936922102 5014.40522842858,3015.71021597885 5013.41352363196,2997.44109139896 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3052.27291550354 5015.07559695184,3059.07693483832 5014.69131527724,3035.20326940214 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3070.3462020645 5015.4828536979,3087.97091846926 5014.80619063451,3064.88648260037 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3088.41948862546 5013.90827448575,3097.77786579418 5014.07570925306,3079.0613465564 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3125.57017240627 5014.33063812811,3139.14482692373 5013.6530308837,3111.99575298847 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3176.77793521215 5013.70653447476,3189.20647887452 5014.25888037069,3165.14826020322 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3206.90031458008 5014.08326270121,3215.32205469307 5013.8852994143,3197.063509598 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3247.06309523788 5014.0930192384,3249.30665131789 5013.3902338335,3233.71060990155 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3255.0957454093 5015.15081670633,3257.3501160738 5014.82224171183,3253.33884563083 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3260.11606360407 5013.96429589286,3267.56566661229 5013.99828640953,3258.42992882403 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3284.21401411834 5014.38382699216,3299.4750385155 5013.67254395809,3271.76971877857 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3321.36469789915 5014.52860141502,3331.252519508 5013.45538232379,3311.47687629029 PathPoint;PointKind.SMOOTHPOINT 5013.01791178514,3338.43387380122 5014.2698958159,3347.58042617396 5011.76592775437,3329.28732142848 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3366.54803185138 5013.91142175581,3378.20309762386 5014.06847053192,3355.48283113231 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3384.62131841234 5016.0087625253,3390.01027287803 5013.92338138205,3379.23236394664 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3401.69049431441 5014.6692843868,3407.12270711802 5015.26285952055,3396.2582815108 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3421.77200219314 5013.4859108434,3435.0092886948 5016.44654779096,3408.53471569148 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3439.8452887541 5013.85886234577,3457.22456111112 5014.12512139304,3422.46625149674 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3485.02862270633 5014.57046010685,3504.18054651921 5015.3616838005,3465.87669889344 PathPoint;PointKind.SMOOTHPOINT 5015.12491372,3564.71497036196 5015.28857176324,3595.02566455962 5014.96125567676,3534.40451126397 PathPoint;PointKind.SMOOTHPOINT 5014.124867704,3606.54864421743 5013.66819881797,3619.1154264814 5014.58153659003,3593.98209705312 PathPoint;PointKind.SMOOTHPOINT 5015.12491372,3641.41003909699 5014.7610893008,3658.71784115658 5015.46796615679,3625.08025163373 PathPoint;PointKind.SMOOTHPOINT 5015.12491372,3690.21599192836 5014.96912385192,3713.15678190341 5015.28101831509,3667.27520195332 PathPoint;PointKind.SMOOTHPOINT 5016.124959736,3764.91898095598 5016.57376044688,3781.48222238418 5015.67584429812,3748.35573952779 PathPoint;PointKind.SMOOTHPOINT 5016.21868543845,3799.7024680819 5016.23977214787,3806.5201231971 5016.18343601376,3788.16307134341 PathPoint;PointKind.SMOOTHPOINT 5015.21879773967,3821.61540233214 5014.63497914313,3822.25534361369 5016.64671416692,3820.04963857935 PathPoint;PointKind.SMOOTHPOINT 5011.26582654148,3825.9861401592 5009.95152656348,3825.9703884818 5012.606563588,3826.00212693625 PathPoint;PointKind.SMOOTHPOINT 5006.21823481563,3827.59163575497 5002.52869012165,3829.42047603019 5007.42584233852,3826.99307201403 PathPoint;PointKind.SMOOTHPOINT 4982.21715332086,3828.58775302532 4975.71615228026,3829.32761166347 4986.61829577592,3828.0865205447 PathPoint;PointKind.SMOOTHPOINT 4953,3828 4927.80756334625,3828.79472119198 4958.18639814871,3827.83636510699 PathPoint;PointKind.SMOOTHPOINT 4793.83384174739,3828.4220077632 4779.55278911289,3830.2849374895 4808.11520910889,3826.55884293725 PathPoint;PointKind.SMOOTHPOINT 4641.86664788327,3828.4220077632 4619.65856614297,3830.026092761 4664.07410016957,3826.81768766575 PathPoint;PointKind.SMOOTHPOINT 4479.18331418418,3828.4220077632 4450.43835252457,3829.19078365985 4507.9285905708,3827.65323186656 PathPoint;PointKind.SMOOTHPOINT 4394.43205231269,3828.4220077632 4380.23471706185,3829.33584015166 4408.62970229054,3827.50817537475 PathPoint;PointKind.SMOOTHPOINT 4360.33704627424,3828.4220077632 4351.54074117724,3828.27224927814 4370.2534647864,3828.59057422127 PathPoint;PointKind.SMOOTHPOINT 4335,3825 4333.73857415905,3824.96449995095 4344.90131161586,3825.27906329948 PathPoint;PointKind.SMOOTHPOINT 4320.39693027617,3828.4220077632 4311.1725964507,3828.86117393291 4321.43899139379,3828.3724017344 PathPoint;PointKind.SMOOTHPOINT 4294.09487963888,3828.4220077632 4288.08013182291,3828.66463061499 4304.47237321517,3828.00329526415 PathPoint;PointKind.SMOOTHPOINT 4270.37894081175,3828.6350080575 4269.21759815878,3828.62819016729 4280.06151715829,3828.6909617772 PathPoint;PointKind.SMOOTHPOINT 4266.82378454943,3828.61149809124 4265.90037551316,3827.98448729114 4268.43392791328,3829.70518172157 PathPoint;PointKind.SMOOTHPOINT 4263.44865213466,3828.58516692904 4257.86508031721,3828.53861719584 4264.5929995293,3828.59457091554 PathPoint;PointKind.SMOOTHPOINT 4245.38741342839,3828.4220077632 4224.45554969833,3828.241686322 4251.82704270277,3828.47749128357 PathPoint;PointKind.SMOOTHPOINT 4197.65402730216,3828.4220077632 4176.52703282824,3827.68849681595 4218.78070704907,3829.15551871046 PathPoint;PointKind.SMOOTHPOINT 4156.73951649281,3828.4220077632 4149.42431668711,3828.69425317247 4175.48811898069,3827.72376176534 PathPoint;PointKind.SMOOTHPOINT 4140.17889615222,3828.4220077632 4135.31825226807,3828.7255214276 4143.28871370074,3828.22781544191 PathPoint;PointKind.SMOOTHPOINT 4126.54083079144,3829.42611842209 4112.78883425441,3829.13976703307 4134.92736132634,3829.60056237173 PathPoint;PointKind.SMOOTHPOINT 4098.29030525861,3828.4220077632 4079.18794961574,3828.22969623921 4117.39297562849,3828.61408418753 PathPoint;PointKind.SMOOTHPOINT 4051.53099921665,3828.4220077632 4019.39863078903,3828.86587592616 4083.65109329103,3827.97813960025 PathPoint;PointKind.SMOOTHPOINT 3960.93494211254,3828.4220077632 3903.3937182913,3828.60679609799 4018.57530494074,3828.23674922909 PathPoint;PointKind.SMOOTHPOINT 3856.70113437466,3828.4220077632 3833.05884166698,3827.90032161194 3880.34342708233,3828.94369391447 PathPoint;PointKind.SMOOTHPOINT 3799.22631795173,3828.4220077632 3784.35515218056,3828.44551772946 3814.0974837229,3828.39849779695 PathPoint;PointKind.SMOOTHPOINT 3773.89834739871,3828.4220077632 3759.11089901119,3828.4377594406 3788.68548105922,3828.40625608581 PathPoint;PointKind.SMOOTHPOINT 3746.62190195014,3829.42611842209 3733.98089174509,3829.20630023758 3759.26354160921,3829.64570150694 PathPoint;PointKind.SMOOTHPOINT 3713.50097599597,3829.42611842209 3703.09767480518,3830.01433777787 3723.90459191376,3828.83766396665 PathPoint;PointKind.SMOOTHPOINT 3670.63830501809,3829.42611842209 3636.73496772643,3829.527211277 3704.46107219615,3829.32502556718 PathPoint;PointKind.SMOOTHPOINT 3564.45570765765,3829.42611842209 3541.25057076163,3829.03256158693 3588.74602327115,3829.83777793127 PathPoint;PointKind.SMOOTHPOINT 3473.86028000756,3829.42611842209 3438.01004145539,3829.50652250669 3509.54056597636,3829.34594943715 PathPoint;PointKind.SMOOTHPOINT 3328.71133200632,3829.42611842209 3311.06647712928,3829.54366825338 3346.35681633737,3829.30833349114 PathPoint;PointKind.SMOOTHPOINT 3262.46916537096,3829.42611842209 3242.66024759911,3829.1395319334 3293.12483468537,3829.86928128606 PathPoint;PointKind.SMOOTHPOINT 3190.38220350298,3829.42611842209 3188.6493166067,3829.43904890353 3201.71520827016,3829.34054214491 PathPoint;PointKind.SMOOTHPOINT 3184.53740827036,3829.42611842209 3183.81479506407,3829.9092482287 3186.26337117251,3828.27130887949 PathPoint;PointKind.SMOOTHPOINT 3178.8518649029,3829.50299601175 3170.33094593634,3830.11496043345 3180.31660438987,3829.39790646258 PathPoint;PointKind.SMOOTHPOINT 3153.36464248473,3829.42611842209 3116.07736042213,3829.11273057187 3161.76753882395,3829.49664832086 PathPoint;PointKind.SMOOTHPOINT 3070.56154078177,3829.42611842209 3052.39518325542,3829.52791657599 3088.72789830813,3829.32408516853 PathPoint;PointKind.SMOOTHPOINT 3026.72478971962,3829.42611842209 2998.5963782652,3829.60643986329 3054.85351590104,3829.24556188123 PathPoint;PointKind.SMOOTHPOINT 2922.49098198174,3829.42611842209 2919.73743540427,3829.50111521445 2957.01999656177,3828.48477937311 PathPoint;PointKind.SMOOTHPOINT 2914.22750970628,3829.60549946464 2913.66194527609,3829.61490345114 2916.98483300782,3829.56012522976 PathPoint;PointKind.SMOOTHPOINT 2911.77515687376,3829.42611842209 2910.94585121236,3829.43810850488 2912.34166548497,3829.4178899339 PathPoint;PointKind.SMOOTHPOINT 2909.82668197822,3828.4220077632 2908.68768494269,3829.16398229831 2911.38174811598,3827.40896331714 PathPoint;PointKind.SMOOTHPOINT 2905.99078922634,3829.70306582461 2905.42207752609,3829.70729761854 2907.34254171808,3829.69295653912 PathPoint;PointKind.SMOOTHPOINT 2904.28370994457,3829.71435060841 2875.56990625858,3829.88244686716 2904.85336582584,3829.71105921314 PathPoint;PointKind.SMOOTHPOINT 2808.51511449314,3829.42611842209 2763.47988299129,3830.06135771039 2845.65541904383,3828.9020812742 PathPoint;PointKind.SMOOTHPOINT 2607.84013969153,3828.4220077632 2562.02469994124,3828.21417966148 2653.65589416882,3828.62983586493 PathPoint;PointKind.SMOOTHPOINT 2465.61406139711,3828.4220077632 2424.18213938953,3830.16339096395 2507.04598340468,3826.68062456246 PathPoint;PointKind.SMOOTHPOINT 2382.81158914816,3827.41789710432 2337.66179701604,3828.13965306844 2427.96106655328,3826.69614114019 PathPoint;PointKind.SMOOTHPOINT 2281.49970693608,3828.4220077632 2234.43228315502,3828.72387572996 2328.56713071714,3828.11990469679 PathPoint;PointKind.SMOOTHPOINT 2193.82620481178,3828.4220077632 2163.56709152522,3827.973437607 2254.42153950144,3829.32008847427 PathPoint;PointKind.SMOOTHPOINT 2126,3826 2105.94276262024,3825.72634399276 2146.00625160475,3826.27271560859 PathPoint;PointKind.SMOOTHPOINT 2063.2900317096,3828.4220077632 2024.94652581412,3828.16551403133 2084.24014960602,3828.5621271621 PathPoint;PointKind.SMOOTHPOINT 1982.43540490219,3828.4220077632 1927.97441429088,3828.09239803626 2036.89671024051,3828.75138239048 PathPoint;PointKind.SMOOTHPOINT 1849.95107163147,3827.41789710432 1802.34074376468,3827.70119219773 1899.65401936266,3827.12214172879 PathPoint;PointKind.SMOOTHPOINT 1722.33745350911,3826.41378644543 1676.4099709446,3826.87058508983 1770.68644565951,3825.93300763545 PathPoint;PointKind.SMOOTHPOINT 1618.06241653341,3827.59163575497 1576.34503713118,3828.34465997421 1659.77948120863,3826.83861153572 PathPoint;PointKind.SMOOTHPOINT 1472.79953735592,3828.38979910943 1439.56436549848,3829.06453514104 1506.03502394036,3827.71529817748 PathPoint;PointKind.SMOOTHPOINT 1353.95326944598,3828.38979910943 1305.22282816403,3828.10368282007 1402.68339600092,3828.67615049845 PathPoint;PointKind.SMOOTHPOINT 1232.18413182922,3828.38979910943 1179.88657465871,3828.23721942841 1306.8644442285,3828.60797159631 PathPoint;PointKind.SMOOTHPOINT 1135.4099835929,3828.06606687406 1134.81105810005,3828.06818277102 1161.05362533317,3827.98143099553 PathPoint;PointKind.SMOOTHPOINT 1133.59841494507,3828.07264966461 1132.19410304329,3828.07805695685 1134.20741170211,3828.07029866798 PathPoint;PointKind.SMOOTHPOINT 1128.87247421958,3828.38979910943 1126.90920715474,3829.18467106862 1130.56759387511,3827.70377829402 PathPoint;PointKind.SMOOTHPOINT 1122.72554106099,3828.13142458025 1114.82400484268,3828.18526240298 1125.001332043,3828.11590800252 PathPoint;PointKind.SMOOTHPOINT 1094.77746818114,3828.38979910943 1036.39686743429,3829.03303178625 1105.79354285305,3828.26848768354 PathPoint;PointKind.SMOOTHPOINT 989.568950904972,3828.38979910943 931.10463277447,3828.76642876889 1048.03326903547,3828.01340454964 PathPoint;PointKind.SMOOTHPOINT 860.006857887062,3828.38979910943 808.917222966441,3829.04102517478 911.096492807682,3827.73880814374 PathPoint;PointKind.SMOOTHPOINT 810.636261874446,3826.39756456871 800.253417939059,3826.43024342181 838.818806373934,3826.30893199592 PathPoint;PointKind.SMOOTHPOINT 783.360131152888,3826.39756456871 775.181635169106,3826.87622748173 788.256024461735,3826.11121317969 PathPoint;PointKind.SMOOTHPOINT 769,3829 763.462693052465,3829.70529898774 776.488614386135,3828.04643576857 PathPoint;PointKind.SMOOTHPOINT 746.022178042293,3826.59575358427 734.418822776763,3826.7055451267 764.145417968795,3826.42389573092 PathPoint;PointKind.SMOOTHPOINT 723.021298973305,3828.58775302532 717.089009632957,3828.70530285661 728.95390304066,3828.46996809437 PathPoint;PointKind.SMOOTHPOINT 702,3828 685.53851866637,3827.0273926959 718.461796060636,3828.97284240376 PathPoint;PointKind.SMOOTHPOINT 678.048068691675,3829.42611842209 666.33927987906,3828.778889051 689.75685750429,3830.07311269351 PathPoint;PointKind.SMOOTHPOINT 654.018032312329,3827.59163575497 638.237620220171,3827.03868134857 669.798759131493,3828.14459016136 PathPoint;PointKind.SMOOTHPOINT 626.418047501365,3826.41378644543 607.285163338891,3828.7003657637 645.550931663838,3824.12720712716 PathPoint;PointKind.SMOOTHPOINT 600.015598949089,3827.59163575497 591.188765332483,3827.20489681002 610.845355233316,3828.06630197372 PathPoint;PointKind.SMOOTHPOINT 582.581296439215,3826.41378644543 581.03158066056,3826.14412713245 589.410243020301,3827.60245033944 PathPoint;PointKind.SMOOTHPOINT 574.014427329751,3828.58775302532 570.609395849395,3828.33807718366 576.617219671238,3828.77865395134 PathPoint;PointKind.SMOOTHPOINT 562.013886582365,3828.58775302532 557.112642914412,3829.06923713429 565.296803984305,3828.26543138792 PathPoint;PointKind.SMOOTHPOINT 552,3825 548.137355452592,3826.08898163708 555.517389021579,3824.00858472289 PathPoint;PointKind.SMOOTHPOINT 538.012805087591,3827.59163575497 535.994460796666,3827.85964937031 540.872414666158,3827.2119497999 PathPoint;PointKind.SMOOTHPOINT 533.873830228717,3830.42999398131 530.319932874416,3829.93205289597 535.256425967067,3830.62395120294 PathPoint;PointKind.SMOOTHPOINT 522.184239763481,3829.42611842209 514.269170283911,3829.40260845583 527.882686938204,3829.4430455978 PathPoint;PointKind.SMOOTHPOINT 509.519939759965,3830.42999398131 499.900308814676,3829.66145318433 519.13988543226,3831.19876987795 PathPoint;PointKind.SMOOTHPOINT 490.037079166568,3829.42611842209 470.957383868146,3829.85352960866 509.11677446499,3828.99847213585 PathPoint;PointKind.SMOOTHPOINT 463.735028529278,3830.42999398131 453.061062113133,3830.67332213209 474.408680218417,3830.1869009302 PathPoint;PointKind.SMOOTHPOINT 449.122568357224,3829.42611842209 444.655333230857,3828.88092230456 453.590118210599,3829.97131453962 PathPoint;PointKind.SMOOTHPOINT 441.008276682713,3829.58387029568 435.3457083867,3829.92899660035 446.67053025172,3829.23874399101 PathPoint;PointKind.CORNERPOINT 436.45889780772,3830.42999398131 436.45889780772,3830.42999398131 436.45889780772,3830.42999398131 PathPoint;PointKind.SMOOTHPOINT 424.007353260412,3830.57975246638 423.315268573722,3831.82084358515 425.149497566005,3828.53109400664 PathPoint;PointKind.SMOOTHPOINT 388,3829 342.560344295143,3826.29188698672 397.094351571898,3829.54213982191 PathPoint;PointKind.SMOOTHPOINT 315.66415500224,3830.42999398131 302.63319803647,3829.46937676001 340.668271465854,3832.27341043562 PathPoint;PointKind.SMOOTHPOINT 272.000503793515,3826.59575358427 263.761265497532,3818.92515689322 276.672311473929,3830.94533244169 PathPoint;PointKind.SMOOTHPOINT 266,3796 263.659689981706,3773.27949840879 267.039228574557,3806.09400401294 PathPoint;PointKind.SMOOTHPOINT 264.033819084923,3745.08387937128 262.982316157123,3733.03502166398 265.042833866883,3756.63949798649 PathPoint;PointKind.CORNERPOINT 263.059739000654,3561.33821158571 263.059739000654,3561.33821158571 263.059739000654,3561.33821158571 PathPoint;PointKind.CORNERPOINT 263.059739000654,3111.51332848085 263.059739000654,3111.51332848085 263.059739000654,3111.51332848085 PathPoint;PointKind.CORNERPOINT 263.059739000654,2498.02405036948 263.059739000654,2498.02405036948 263.059739000654,2498.02405036948 PathPoint;PointKind.SMOOTHPOINT 266,2484 266.118337354341,2475.52019027034 265.882292099672,2492.47980972966 PathPoint;PointKind.SMOOTHPOINT 263.059739000654,2468.9060167601 262.717630744887,2453.19759770505 263.402476710434,2484.61420071549 PathPoint;PointKind.SMOOTHPOINT 264.033819084923,2443.80419068661 263.601069451363,2436.22551796363 264.245630360113,2447.50583487395 PathPoint;PointKind.SMOOTHPOINT 263.059739000654,2383.55966705041 262.893563141367,2356.89489842007 263.233468308091,2411.38112602066 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,2109.44756646004 268.040923328189,2060.3380681427 267.820299696825,2158.55682967772 PathPoint;PointKind.SMOOTHPOINT 265.008528623204,2015.06445592004 264.441390557985,2000.90957543533 265.575351961417,2029.21957150441 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1967.8731357497 266.899408476608,1940.05308737743 267.013654379868,1995.6929490223 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,1914.65715162605 267.458678366671,1897.45067752103 270.351019553886,1931.86362573107 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1881.52267538112 267.036629451323,1869.22672792844 266.87674813216,1893.8186228338 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1856.42084930762 264.441390557985,1843.7092456515 271.420147194034,1869.13268806341 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1822.28249750348 266.773832401124,1803.98539606374 269.087390623889,1840.57936384355 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1760.02975254951 270.148964815889,1730.24497629705 265.712258209125,1789.81476390164 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1659.62244825552 267.438221111267,1653.2968567341 269.28661281883,1677.04051205686 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1620.46354315694 267.356077362642,1598.98577838214 266.556985493835,1641.94130793175 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1516.03979622741 265.792198868706,1494.88764448528 268.12086398777,1537.1921830692 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1407.59984176199 268.36855414167,1381.26256696162 267.493298337356,1433.93711656235 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1318.23728451642 267.036629451323,1294.79056006749 268.825223027703,1341.68400896534 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1236.90737744227 267.938951778172,1233.62091925904 267.900240356406,1249.38764303041 PathPoint;PointKind.SMOOTHPOINT 267.989308099168,1229.09736665131 268.029907882971,1226.59261484616 267.955317582496,1231.23442258417 PathPoint;PointKind.SMOOTHPOINT 265.008528623204,1223.85440907608 265.076509656549,1221.97831376868 264.903724530131,1226.72168456092 PathPoint;PointKind.SMOOTHPOINT 265.982608707473,1209.797330051 266.942211349455,1206.08863287377 265.125292342514,1213.10894389812 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,1202.76879053846 269.696387380936,1180.61252813745 268.725769293736,1207.77899944774 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1167.62632807543 266.345174218645,1159.05718047399 268.127473254901,1184.04592360979 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1121.43888346431 268.531268003889,1100.94642137539 267.321457391957,1142.22663072944 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,1087.3002965605 267.261029806762,1071.25639028695 270.334968476568,1101.25534233202 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1036.09253375462 267.063066519846,1016.37190385795 268.798156505168,1055.81316365129 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,980.868563412856 268.96559127248,958.40243965656 268.844106648077,1003.33468716915 PathPoint;PointKind.SMOOTHPOINT 269.879243771553,907.571071410471 270.762053024016,879.151048699296 268.996119792084,935.991094121646 PathPoint;PointKind.SMOOTHPOINT 269.879243771553,826.241164336323 270.773383196241,798.895782182809 268.98478961986,853.586546489837 PathPoint;PointKind.SMOOTHPOINT 270.853323855822,759.972211846477 272.333484966101,735.035190636448 269.372848018536,784.909468156168 PathPoint;PointKind.SMOOTHPOINT 268,706 267.436638658856,681.72948633339 268.563046614138,730.270278566947 PathPoint;PointKind.SMOOTHPOINT 271.827403940091,654.544589357717 271.454452437713,637.910582931082 272.200355442468,671.178360684689 PathPoint;PointKind.SMOOTHPOINT 271.827403940091,630.446638843442 272.459690495598,624.346978097762 271.194802657577,636.546534688783 PathPoint;PointKind.SMOOTHPOINT 268,596 267.082885503858,579.534795131099 268.917114496142,612.465204868901 PathPoint;PointKind.SMOOTHPOINT 272.801484024359,559.157368158828 272.211685614692,535.79316369147 273.391282434026,582.521807725848 PathPoint;PointKind.SMOOTHPOINT 272.801484024359,530.039334549449 270.080669055538,523.716799323642 275.52229899318,536.361869775255 PathPoint;PointKind.SMOOTHPOINT 267,505 263.521637127193,497.71637735356 270.477733418794,512.283387546777 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,478.831571743566 269.195656714031,463.238586622843 268.604284669333,494.954001304423 PathPoint;PointKind.SMOOTHPOINT 265.906383734001,440.137949300038 264.782178867763,409.721930453545 266.302310307833,450.84227203704 PathPoint;PointKind.SMOOTHPOINT 265.052589990398,378.988274443956 265.411651384715,350.489146492041 264.624728259256,412.948166580912 PathPoint;PointKind.SMOOTHPOINT 263,299 262.727780568009,269.015101788648 263.272199982122,328.982755813416 PathPoint;PointKind.SMOOTHPOINT 264,234 263.708265738425,214.97309723368 264.30495137745,253.890371768169 PathPoint;PointKind.SMOOTHPOINT 263.906291702,190.131946020936 263.212119272469,170.22775982724 264.561571729428,208.926185914306 PathPoint";
	
	mask645[2] = "PointKind.SMOOTHPOINT 265.000030994036,142.244321918427 266.186551807507,132.514957482151 262.393147201468,163.618877941357 PathPoint;PointKind.SMOOTHPOINT 274,133 279.882562473365,130.948520344313 268.116808072623,135.051244556024 PathPoint;PointKind.SMOOTHPOINT 347,132 364.694581744022,131.788175204014 329.305418255978,132.211824795986 PathPoint;PointKind.SMOOTHPOINT 942.031324976615,131.287737243475 977.465809153556,131.205452361572 906.596526072667,131.370022125379 PathPoint;PointKind.SMOOTHPOINT 1491.05653626006,130.29185507278 1502.73133455601,130.080030276794 1479.38205269113,130.503679868766 PathPoint;PointKind.SMOOTHPOINT 1535.30054406827,131.421979150809 1541.85158670286,131.454422904246 1524.24229597752,131.367200929428 PathPoint;PointKind.SMOOTHPOINT 1545.04228909197,129.413757833037 1548.46179801461,128.824833178271 1540.07117602864,130.26999080416 PathPoint;PointKind.SMOOTHPOINT 1568.0601634193,131.287737243475 1571.988271184,131.227081530529 1562.65850381144,131.370727424367 PathPoint;PointKind.SMOOTHPOINT 1580.11137521469,130.417868491923 1584.0955043865,131.504264032713 1574.5108081389,128.890661083793 PathPoint;PointKind.SMOOTHPOINT 1605.43934576771,132.426089809695 1620.91541684484,132.379069877179 1594.5497913523,132.459238862119 PathPoint;PointKind.SMOOTHPOINT 1857.74434175963,133.430200468581 1868.95837971846,133.928376653592 1846.53030380081,132.932024283571 PathPoint;PointKind.CORNERPOINT 1889.89118762954,133.430200468581 1889.89118762954,133.430200468581 1889.89118762954,133.430200468581 PathPoint;PointKind.SMOOTHPOINT 1895.73629758917,134.434311127467 1897.24415467599,134.560324546611 1889.8892992675,133.94553892896 PathPoint;PointKind.SMOOTHPOINT 1903.54656297566,132.268337936103 1908.37353107015,132.069678721222 1897.41190417031,132.520834973716 PathPoint;PointKind.SMOOTHPOINT 1916.19355299384,133.430200468581 1927.82208641987,134.497082737377 1904.5643901138,132.363318199786 PathPoint;PointKind.SMOOTHPOINT 1970.74581443695,133.430200468581 1979.69602104,133.351677181279 1961.79560783391,133.508488656221 PathPoint;PointKind.SMOOTHPOINT 2015.55664558337,133.430200468581 2029.47639161472,133.308653943027 2001.63689955202,133.551746994136 PathPoint;PointKind.SMOOTHPOINT 2065.23850660515,133.430200468581 1879.69875353292,133.267511502075 2050.97319032096,133.417505086802 PathPoint;PointKind.SMOOTHPOINT 2562.05491373383,134.434311127467 2582.96789384352,134.215903540929 2428.76487932718,135.825630930625 PathPoint;PointKind.SMOOTHPOINT 2612.71116956688,133.430200468581 2620.59917252392,133.026064148604 2604.82253715583,133.834101688896 PathPoint;PointKind.SMOOTHPOINT 2640.96138037271,134.434311127467 2650.68392704903,134.104701400528 2631.23883369638,134.763685754744 PathPoint;PointKind.SMOOTHPOINT 2698.43619679564,134.434311127467 2705.96698460061,134.340036162772 2690.90540899067,134.5283509925 PathPoint;PointKind.SMOOTHPOINT 2716.94497730476,134.434311127467 2725.98645473962,134.798950704131 2707.90381459692,134.069436451141 PathPoint;PointKind.SMOOTHPOINT 2758.83356819838,135.438186686691 2777.12927852429,135.956111243358 2740.53785787246,134.920497229686 PathPoint;PointKind.SMOOTHPOINT 2799.74807900772,135.438186686691 2807.31663405344,135.285371906013 2792.179209235,135.591236567031 PathPoint;PointKind.SMOOTHPOINT 2821.17909976965,133.430200468581 2835.22158933343,133.106233133544 2810.67351230184,133.672588220703 PathPoint;PointKind.SMOOTHPOINT 2853.32626036657,134.434311127467 2858.3678722793,134.642139229189 2848.28401899983,134.226247926083 PathPoint;PointKind.SMOOTHPOINT 2866.13627897397,134.0238271166 2872.51516593615,133.498614470393 2859.10968383297,134.602407386213 PathPoint;PointKind.SMOOTHPOINT 2882.55055125666,135.438186686691 2885.15995286528,135.661531366143 2878.89184980929,135.125269035794 PathPoint;PointKind.SMOOTHPOINT 2900.08525168152,134.434311127467 2903.01252756643,133.882297119726 2893.04449382525,135.761918922065 PathPoint;PointKind.SMOOTHPOINT 2906.90444172542,131.421979150809 2914.82989719619,130.697872190058 2903.13180910179,131.766635256154 PathPoint;PointKind.SMOOTHPOINT 2924,134 2931.31362617067,134.168801557734 2916.68605910232,133.831433541929 PathPoint;PointKind.SMOOTHPOINT 2954.63782785165,134.434311127467 2964.73301130334,134.783199026738 2944.54232967294,134.085188128534 PathPoint;PointKind.SMOOTHPOINT 2983.86211874174,134.434311127467 3000.55618333297,134.257751280868 2967.16868360452,134.610635874403 PathPoint;PointKind.SMOOTHPOINT 3556.6627522565,135.438186686691 3589.20930142431,136.387519124195 3524.11620308868,134.489089348849 PathPoint;PointKind.SMOOTHPOINT 3657.97431974158,135.438186686691 3662.59797419004,135.712783092586 3639.98169152266,134.370128919582 PathPoint;PointKind.SMOOTHPOINT 3673.5608599979,137.446408004462 3678.35761429978,137.866060902171 3668.76379096901,137.026755106754 PathPoint;PointKind.SMOOTHPOINT 3698.88883055092,138.450518663348 3703.1848541859,137.171811598567 3696.11136472098,139.277129076985 PathPoint;PointKind.SMOOTHPOINT 3716.42353097578,135.438186686691 3720.35352710252,135.427137002549 3711.11817783183,135.453233065096 PathPoint;PointKind.SMOOTHPOINT 3727.13904135675,137.446408004462 3730.71371069346,137.472033867684 3720.03691173426,137.395391377682 PathPoint;PointKind.SMOOTHPOINT 3739.80302663326,136.442297345576 3741.06508192822,136.417611881005 3731.98866979568,136.595817425242 PathPoint;PointKind.SMOOTHPOINT 3746.62190195014,137.446408004462 3748.51624380062,136.756625594448 3744.47829631074,138.227409083558 PathPoint;PointKind.SMOOTHPOINT 3750.51853701422,137.446408004462 3757.2511771314,137.52634188974 3749.67916008862,137.436533818634 PathPoint;PointKind.SMOOTHPOINT 3769.02763225036,136.442297345576 3785.85482636522,135.465693347213 3763.60929211118,136.756860694111 PathPoint;PointKind.SMOOTHPOINT 3790.4589677393,133.430200468581 3791.86359436808,133.430670667906 3779.07749501316,133.426203774317 PathPoint;PointKind.SMOOTHPOINT 3797.27784305618,133.430200468581 3804.52852382561,133.932138248193 3796.25718337499,133.359435470144 PathPoint;PointKind.SMOOTHPOINT 3807.01958807989,134.434311127467 3812.85305314028,134.838212347782 3801.90590368273,134.080015935957 PathPoint;PointKind.SMOOTHPOINT 3818.70917854512,130.417868491923 3822.58976253189,130.532362027601 3816.84316212521,130.362855170879 PathPoint;PointKind.SMOOTHPOINT 3826.50244867329,131.421979150809 3827.63515116869,132.384712269081 3824.87153332702,130.035596440566 PathPoint;PointKind.SMOOTHPOINT 3832.3472439059,133.430200468581 3838.12374337817,133.675644516316 3828.45784756297,133.264925405786 PathPoint;PointKind.SMOOTHPOINT 3841.11459411833,130.417868491923 3848.49934859241,130.983518280095 3839.9752823558,130.330646517106 PathPoint;PointKind.SMOOTHPOINT 3862.54592960727,133.430200468581 3870.57902171418,132.963527638357 3854.51315222738,133.896873298806 PathPoint;PointKind.SMOOTHPOINT 3882.02910492768,133.430200468581 3893.4599897938,134.36354612903 3870.59790533455,132.49661970847 PathPoint;PointKind.SMOOTHPOINT 3906.38268066942,134.434311127467 3913.39605727616,134.465579382591 3899.3696187897,134.402807772681 PathPoint;PointKind.SMOOTHPOINT 3922.94330101001,131.421979150809 3933.97700039428,130.455014238611 3907.65858395266,132.761341928537 PathPoint;PointKind.SMOOTHPOINT 3941,130 3951.13326541945,129.650641901404 3934.4687851668,130.224990377091 PathPoint;PointKind.CORNERPOINT 3956.0645416912,133.430200468581 3956.0645416912,133.430200468581 3956.0645416912,133.430200468581 PathPoint;PointKind.SMOOTHPOINT 3966.78036679917,131.421979150809 3974.27653463345,130.759233201992 3959.28356951087,132.084960199289 PathPoint;PointKind.SMOOTHPOINT 3980.41811743294,132.426089809695 3988.17960013348,132.376013581565 3970.07178183028,132.492858113868 PathPoint;PointKind.SMOOTHPOINT 3994.05649752073,131.421979150809 3995.70189030928,131.113058194177 3989.11559824999,132.349682419356 PathPoint;PointKind.SMOOTHPOINT 3999.90129275335,129.413757833037 4007.99858916952,129.001157925207 3996.55542995016,129.584440188072 PathPoint;PointKind.SMOOTHPOINT 4013.53935811412,131.421979150809 4016.25891417492,131.855973127935 4009.37929654583,130.758292803342 PathPoint;PointKind.SMOOTHPOINT 4026.20334339063,131.421979150809 4038.52459095737,132.1514934038 4021.33231351528,131.133511864822 PathPoint;PointKind.SMOOTHPOINT 4059.32458407182,132.426089809695 4066.90950492186,132.508139591936 4041.21896885766,132.230016691102 PathPoint;PointKind.SMOOTHPOINT 4082.70407972929,131.421979150809 4084.95469255081,131.162664222982 4074.9750139104,132.312536672668 PathPoint;PointKind.SMOOTHPOINT 4089.52295504618,129.413757833037 4094.05785647889,129.286804015243 4087.40452756728,129.473238047671 PathPoint;PointKind.SMOOTHPOINT 4102.1872550497,131.421979150809 4105.17149652273,131.887241383058 4098.25127910984,130.808604131134 PathPoint;PointKind.SMOOTHPOINT 4110.95429053512,131.421979150809 4126.13735076946,131.088607829269 4107.94864762567,131.488042155995 PathPoint;PointKind.SMOOTHPOINT 4153.816961513,134.434311127467 4162.85623585881,134.273973157587 4139.44432331969,134.689159161706 PathPoint;PointKind.SMOOTHPOINT 4178.17148143577,133.253640621982 4179.03572179486,133.195806104987 4170.55886460918,133.762866491134 PathPoint;PointKind.SMOOTHPOINT 4180.76294360503,133.080607270322 4181.20765286483,132.490507117243 4179.58995605283,134.635556438637 PathPoint;PointKind.SMOOTHPOINT 4184.01564721437,132.426089809695 4186.92529838693,132.23801007963 4183.28988673802,132.473109742212 PathPoint;PointKind.SMOOTHPOINT 4191.80891734253,132.426089809695 4204.43482065129,131.814125387995 4188.78061408863,132.572791999146 PathPoint;PointKind.SMOOTHPOINT 4216.16249308428,133.430200468581 4222.8362792513,133.480041597049 4206.17022536362,133.355673875543 PathPoint;PointKind.SMOOTHPOINT 4235.64566840468,131.421979150809 4237.63726090008,131.01314083758 4229.76782683641,132.628980818503 PathPoint;PointKind.SMOOTHPOINT 4239.57629398543,129.591258078287 4240.77666278718,129.496748013929 4237.01000997667,129.793443788107 PathPoint;PointKind.SMOOTHPOINT 4243.43893853284,129.413757833037 4247.57319248662,129.351691522116 4242.05854588354,129.434681703007 PathPoint;PointKind.SMOOTHPOINT 4255.12852899808,129.413757833037 4257.0710240805,129.777927210376 4251.46132992154,128.726326419649 PathPoint;PointKind.SMOOTHPOINT 4259.99924414643,131.421979150809 4265.76787544354,133.047693317561 4258.11906501124,130.89206451135 PathPoint;PointKind.SMOOTHPOINT 4274.61170431848,131.421979150809 4286.80359908565,131.417982456546 4268.33195636326,131.424095047773 PathPoint;PointKind.SMOOTHPOINT 4291.17232465907,130.417868491923 4301.68231830497,130.139510491427 4280.66201628617,130.696461592083 PathPoint;PointKind.SMOOTHPOINT 4303,131 4305.28177079514,130.919125716072 4293.91697860033,131.321616338412 PathPoint;PointKind.SMOOTHPOINT 4310.65549997948,132.426089809695 4311.56726411651,132.268808135428 4309.12844454527,132.689166332124 PathPoint;PointKind.SMOOTHPOINT 4315.52621512783,133.430200468581 4316.34765261407,133.365312961709 4314.32112542099,133.525415831927 PathPoint;PointKind.SMOOTHPOINT 4318.44845538063,131.421979150809 4319.2406232553,131.333111478354 4317.45612113,131.533416390873 PathPoint;PointKind.SMOOTHPOINT 4322.34509044471,133.430200468581 4323.02553023217,133.410216997262 4321.37824908159,133.458412428091 PathPoint;PointKind.SMOOTHPOINT 4324.29325061325,131.421979150809 4325.3774851497,131.320651196237 4323.53853525232,131.492509049584 PathPoint;PointKind.SMOOTHPOINT 4331.11244065714,131.421979150809 4332.48842712836,131.854092330634 4329.21809880667,130.827177004478 PathPoint;PointKind.SMOOTHPOINT 4333.06060082568,133.430200468581 4335.10664109315,133.460998524379 4331.89107527054,133.412567993888 PathPoint;PointKind.SMOOTHPOINT 4338.9057107853,131.421979150809 4341.33980945145,130.913928779971 4336.58428438738,131.90651955539 PathPoint;PointKind.SMOOTHPOINT 4348.647141082,131.421979150809 4352.0439896602,131.378720812894 4344.65923518612,131.47299577759 PathPoint;PointKind.SMOOTHPOINT 4358.38888610571,129.413757833037 4369.07512687509,129.363211405582 4354.90171087672,129.430449909081 PathPoint;PointKind.SMOOTHPOINT 4381.76838176318,129.413757833037 4383.10219481557,129.461247964879 4370.95341764825,129.029840084042 PathPoint;PointKind.SMOOTHPOINT 4386.63909691153,131.421979150809 4409.43288561042,132.321470459847 4385.2571306272,131.36743602909 PathPoint;PointKind.SMOOTHPOINT 4434,129 4435.93462690727,129.023274866596 4420.34462465388,128.83519513653 PathPoint;PointKind.SMOOTHPOINT 4448,129 4448.71411557713,127.706716756139 4447.10491639429,130.621482372825 PathPoint;PointKind.SMOOTHPOINT 4457.75197869524,131.421979150809 4459.50595230094,132.667066963841 4456.37630695103,130.445610252108 PathPoint;PointKind.SMOOTHPOINT 4463.59677392786,129.413757833037 4466.51460800258,130.668484732235 4461.92274098174,128.693882666213 PathPoint;PointKind.SMOOTHPOINT 4471.88007400471,131.903463259776 4472.95423727696,131.780741235909 4468.58173497947,132.27985781957 PathPoint;PointKind.SMOOTHPOINT 4478.20923409991,129.413757833037 4483.46769291993,129.21274762153 4475.66970188668,129.510853993684 PathPoint;PointKind.SMOOTHPOINT 4493.79545962923,131.421979150809 4500.85982201097,131.72619811419 4489.992613213,131.25811468599 PathPoint;PointKind.SMOOTHPOINT 4512.30424013836,130.417868491923 4515.76592247983,130.219679476367 4501.3111405379,131.04770048798 PathPoint;PointKind.SMOOTHPOINT 4526.91670031041,130.417868491923 4541.87693382434,130.487457992048 4520.66024215365,130.388716133763 PathPoint;PointKind.SMOOTHPOINT 4566.29219605931,130.222030472993 4567.56023116739,130.215212582778 4552.60943946365,130.294911368393 PathPoint;PointKind.SMOOTHPOINT 4571.72753145683,129.413757833037 4575.30723642564,129.402002849908 4570.40316021463,129.418224726627 PathPoint;PointKind.SMOOTHPOINT 4579.52080158499,129.413757833037 4580.21823663079,129.416108829663 4575.37458800497,129.40035715227 PathPoint;PointKind.SMOOTHPOINT 4581.46896175353,130.417868491923 4582.26931253036,130.43761686358 4580.70889603349,130.39929561858 PathPoint;PointKind.SMOOTHPOINT 4583.41743664907,129.413757833037 4586.46902970143,129.44220489221 4582.55193738195,129.40576444451 PathPoint;PointKind.SMOOTHPOINT 4593.15886694577,129.413757833037 4596.91418958405,129.647917096969 4589.49859186336,129.185711160333 PathPoint;PointKind.SMOOTHPOINT 4614,130 4652.57420079105,130.556951100656 4610.45680336391,129.94898337322 PathPoint;PointKind.SMOOTHPOINT 4654.53031843278,131.421979150809 4669.99883606176,131.767105455479 4639.06180080379,131.07685284614 PathPoint;PointKind.SMOOTHPOINT 4684.72931886115,130.417868491923 4698.09325699951,130.755236507728 4671.36506599579,130.080735575781 PathPoint;PointKind.SMOOTHPOINT 4712.97952966698,130.417868491923 4731.61010952752,130.017963965872 4694.34863507944,130.818008117637 PathPoint;PointKind.SMOOTHPOINT 4743.17790064134,131.421979150809 4763.6999898093,131.775098844007 4722.6561262004,131.069094557274 PathPoint;PointKind.SMOOTHPOINT 4787.0149664305,131.421979150809 4821.30415903179,130.531656728613 4752.72545910221,132.312301573006 PathPoint;PointKind.SMOOTHPOINT 4853.25713306586,131.421979150809 4874.90877745916,131.300667724917 4828.77011307347,131.559277353757 PathPoint;PointKind.SMOOTHPOINT 4893.8833539375,131.182412594639 4900.32288401456,131.392156962528 4879.66209943418,130.717855661378 PathPoint;PointKind.SMOOTHPOINT 4912.68010965732,133.430200468581 4917.35034370271,131.904873857752 4914.27569450715,132.90905140901 PathPoint;PointKind.SMOOTHPOINT 4933.13736506199,131.421979150809 4939.15416183623,131.502806603987 4925.4687268283,131.319005498599 PathPoint;PointKind.SMOOTHPOINT 4964,134 4975.63245922087,129.669115486644 4954.39846694532,137.574749760255 PathPoint;PointKind.SMOOTHPOINT 5001.21816686772,133.279971784192 5012.03848134176,134.757102964192 4988.83900129744,131.589856916018 PathPoint;PointKind.SMOOTHPOINT 5015.21879773967,151.208672052663 5015.25813861545,159.757130883792 5015.1693855997,140.347302741057 PathPoint;PointKind.SMOOTHPOINT 5015.21879773967,189.05807203066 5016.15576510709,216.516359473307 5014.89537687049,179.580065111844 PathPoint;PointKind.SMOOTHPOINT 5016.21868543845,266.74910652737 5015.89609025707,285.905967433168 5016.1972454322,268.024815882611 PathPoint;PointKind.SMOOTHPOINT 5015.94015203794,401.5178722053 5015.87940972574,419.159750885422 5016.00120907715,383.875993525178 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,913.595500264124 5015.36923724865,930.939272572092 5012.61443176316,896.251727956155 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,971.831802582545 5014.13645156526,984.35132981434 5013.84721744654,959.312275350751 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1062.198470487 5014.89368474224,1075.71811168342 5015.03845916511,1048.67882929059 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,1236.90737744227 5014.24692074445,1243.99469187045 5013.73674826736,1229.82006301408 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1256.988885321 5014.95096505738,1269.3946243161 5014.98117884997,1244.58291122623 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,1301.16810861434 5013.55042987967,1333.98872680972 5014.43355385914,1268.34749041897 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1523.06833573995 5015.27796641684,1536.89783829165 5014.65417749051,1509.23883318825 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,1586.32495625313 5014.00426622265,1595.83967469747 5013.96524007388,1565.96908706817 PathPoint;PointKind.SMOOTHPOINT 5014.97614321787,1626.19574313001 5015.00856009952,1627.33386059657 5014.55220594049,1611.46933536556 PathPoint;PointKind.SMOOTHPOINT 5015.07182022777,1629.59058225769 5014.68155874005,1631.39896886226 5015.30849493645,1628.49290193309 PathPoint;PointKind.SMOOTHPOINT 5015.1646646946,1633.07076256288 5015.52628602476,1647.07564946287 5015.13508035602,1631.92253581083 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1662.63454513252 5013.43618397641,1670.24354571197 5015.66791317756,1659.14331514318 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1680.70806679314 5014.58556700315,1688.19152415277 5015.3465769042,1673.22437433384 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1696.77313203632 5015.43407101193,1703.21721378769 5014.49807289542,1690.32905028496 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1717.85875057394 5015.18291886096,1729.22911065504 5014.74922504639,1706.48839049285 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1769.06651337982 5014.10969976974,1790.7090830181 5015.82212941061,1747.42394374155 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1843.36788094143 5015.16372051358,1858.7664386412 5014.76810866676,1827.96955834133 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,1876.50235718636 5015.70064478621,1901.2042787338 5012.28333895261,1851.80067073857 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1948.79573852986 5015.31227166052,1966.3708489058 5014.61987224683,1931.22039305424 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,1997.99528001797 5015.01516936665,2002.76051507883 5014.83294243004,1985.14238146463 PathPoint;PointKind.SMOOTHPOINT 5014.38225335713,2011.87086210353 5013.7745155081,2019.46646200222 5014.74072741722,2007.39550492663 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2034.14208823955 5014.13645156526,2044.52785093375 5013.90103576461,2027.6067878191 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2088.36194792242 5015.27796641684,2114.97781582295 5014.65417749051,2061.7460800219 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2216.88341026657 5013.99576859348,2248.02142017685 5015.93637531387,2185.74540035629 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2297.2094417815 5014.35738992363,2312.54898946596 5015.57506871072,2281.86965899738 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2372.51492000199 5013.95328044764,2373.80091515631 5014.52482469095,2354.71999144153 PathPoint;PointKind.SMOOTHPOINT 5013.01791178514,2377.53523819676 5012.97164691522,2383.27660705666 5013.08117191339,2369.65728360331 PathPoint;PointKind.SMOOTHPOINT 5013.76287060887,2383.02152392276 5014.33630321422,2406.96736495535 5013.74178389946,2382.15659226413 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2467.90190610122 5014.95851850553,2487.1518664734 5013.17086911016,2451.54649277474 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2545.21560563949 5014.34196830033,2568.6033200731 5013.64170071148,2521.82765610621 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2614.49665500633 5015.639587747,2636.38231769571 5014.29255616035,2592.61099231694 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2688.79802256794 5013.72164137106,2721.91298554086 5014.26202764075,2655.68329469467 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2752.05487818079 5014.34605975141,2768.15520837336 5013.6379239874,2735.95431288855 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2813.3032773762 5014.77566211491,2840.97403746273 5015.15616706544,2785.63251728968 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2884.59254806082 5014.9418379742,2901.51055487985 5014.99030593315,2867.58920006427 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,2932.78797889004 5013.44719942163,2943.38627167922 5014.51192088369,2922.66881921321 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,2975.96332662416 5014.6082273476,2988.5416287716 5015.32391655975,2963.38478937706 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3008.0936922102 5014.40522842858,3015.71021597885 5013.41352363196,2997.44109139896 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3052.27291550354 5015.07559695184,3059.07693483832 5014.69131527724,3035.20326940214 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3070.3462020645 5015.4828536979,3087.97091846926 5014.80619063451,3064.88648260037 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3088.41948862546 5013.90827448575,3097.77786579418 5014.07570925306,3079.0613465564 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3125.57017240627 5014.33063812811,3139.14482692373 5013.6530308837,3111.99575298847 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3176.77793521215 5013.70653447476,3189.20647887452 5014.25888037069,3165.14826020322 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3206.90031458008 5014.08326270121,3215.32205469307 5013.8852994143,3197.063509598 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3247.06309523788 5014.0930192384,3249.30665131789 5013.3902338335,3233.71060990155 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3255.0957454093 5015.15081670633,3257.3501160738 5014.82224171183,3253.33884563083 PathPoint;PointKind.SMOOTHPOINT 5013,3263 5012.97230402345,3270.44960300822 5013.00629454012,3261.31386521996 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3284.21401411834 5014.38382699216,3299.4750385155 5013.67254395809,3271.76971877857 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3321.36469789915 5014.52860141502,3331.252519508 5013.45538232379,3311.47687629029 PathPoint;PointKind.SMOOTHPOINT 5013.01791178514,3338.43387380122 5014.2698958159,3347.58042617396 5011.76592775437,3329.28732142848 PathPoint;PointKind.SMOOTHPOINT 5013.99199186941,3366.54803185138 5013.91142175581,3378.20309762386 5014.06847053192,3355.48283113231 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3384.62131841234 5016.0087625253,3390.01027287803 5013.92338138205,3379.23236394664 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3401.69049431441 5014.6692843868,3407.12270711802 5015.26285952055,3396.2582815108 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3421.77200219314 5013.4859108434,3435.0092886948 5016.44654779096,3408.53471569148 PathPoint;PointKind.SMOOTHPOINT 5013,3445 5012.86687047637,3462.37927235702 5013.13312952363,3427.62096274264 PathPoint;PointKind.SMOOTHPOINT 5014.96607195368,3485.02862270633 5014.57046010685,3504.18054651921 5015.3616838005,3465.87669889344 PathPoint;PointKind.SMOOTHPOINT 5015.12491372,3564.71497036196 5015.28857176324,3595.02566455962 5014.96125567676,3534.40451126397 PathPoint;PointKind.SMOOTHPOINT 5014.124867704,3606.54864421743 5013.66819881797,3619.1154264814 5014.58153659003,3593.98209705312 PathPoint;PointKind.SMOOTHPOINT 5015.12491372,3641.41003909699 5014.7610893008,3658.71784115658 5015.46796615679,3625.08025163373 PathPoint;PointKind.SMOOTHPOINT 5015.12491372,3690.21599192836 5014.96912385192,3713.15678190341 5015.28101831509,3667.27520195332 PathPoint;PointKind.SMOOTHPOINT 5016.124959736,3764.91898095598 5016.57376044688,3781.48222238418 5015.67584429812,3748.35573952779 PathPoint;PointKind.SMOOTHPOINT 5016.21868543845,3799.7024680819 5016.23977214787,3806.5201231971 5016.18343601376,3788.16307134341 PathPoint;PointKind.SMOOTHPOINT 5015.21879773967,3821.61540233214 5014.63497914313,3822.25534361369 5016.64671416692,3820.04963857935 PathPoint;PointKind.SMOOTHPOINT 5011.26582654148,3825.9861401592 5009.95152656348,3825.9703884818 5012.606563588,3826.00212693625 PathPoint;PointKind.SMOOTHPOINT 5006.21823481563,3827.59163575497 5002.52869012165,3829.42047603019 5007.42584233852,3826.99307201403 PathPoint;PointKind.SMOOTHPOINT 4982.21715332086,3828.58775302532 4975.71615228026,3829.32761166347 4986.61829577592,3828.0865205447 PathPoint;PointKind.SMOOTHPOINT 4948,3830 4922.013206665,3830.00034722558 4953.1889789098,3829.99990602259 PathPoint;PointKind.SMOOTHPOINT 4793.83384174739,3828.4220077632 4779.55278911289,3830.2849374895 4808.11520910889,3826.55884293725 PathPoint;PointKind.SMOOTHPOINT 4641.86664788327,3828.4220077632 4619.65856614297,3830.026092761 4664.07410016957,3826.81768766575 PathPoint;PointKind.SMOOTHPOINT 4479.18331418418,3828.4220077632 4450.43835252457,3829.19078365985 4507.9285905708,3827.65323186656 PathPoint;PointKind.SMOOTHPOINT 4394.43205231269,3828.4220077632 4380.23471706185,3829.33584015166 4408.62970229054,3827.50817537475 PathPoint;PointKind.SMOOTHPOINT 4360.33704627424,3828.4220077632 4351.54074117724,3828.27224927814 4370.2534647864,3828.59057422127 PathPoint;PointKind.SMOOTHPOINT 4328.18988567733,3828.4220077632 4326.92845983638,3828.38650771415 4338.09119729319,3828.70107106269 PathPoint;PointKind.SMOOTHPOINT 4320.39693027617,3828.4220077632 4311.1725964507,3828.86117393291 4321.43899139379,3828.3724017344 PathPoint;PointKind.SMOOTHPOINT 4294.09487963888,3828.4220077632 4288.08013182291,3828.66463061499 4304.47237321517,3828.00329526415 PathPoint;PointKind.SMOOTHPOINT 4270.37894081175,3828.6350080575 4269.21759815878,3828.62819016729 4280.06151715829,3828.6909617772 PathPoint;PointKind.SMOOTHPOINT 4266.82378454943,3828.61149809124 4265.90037551316,3827.98448729114 4268.43392791328,3829.70518172157 PathPoint;PointKind.SMOOTHPOINT 4263.44865213466,3828.58516692904 4257.86508031721,3828.53861719584 4264.5929995293,3828.59457091554 PathPoint;PointKind.SMOOTHPOINT 4245.38741342839,3828.4220077632 4224.45554969833,3828.241686322 4251.82704270277,3828.47749128357 PathPoint;PointKind.SMOOTHPOINT 4197.65402730216,3828.4220077632 4176.52703282824,3827.68849681595 4218.78070704907,3829.15551871046 PathPoint;PointKind.SMOOTHPOINT 4156.73951649281,3828.4220077632 4149.42431668711,3828.69425317247 4175.48811898069,3827.72376176534 PathPoint;PointKind.SMOOTHPOINT 4140.17889615222,3828.4220077632 4135.31825226807,3828.7255214276 4143.28871370074,3828.22781544191 PathPoint;PointKind.SMOOTHPOINT 4126.54083079144,3829.42611842209 4112.78883425441,3829.13976703307 4134.92736132634,3829.60056237173 PathPoint;PointKind.SMOOTHPOINT 4098.29030525861,3828.4220077632 4079.18794961574,3828.22969623921 4117.39297562849,3828.61408418753 PathPoint;PointKind.SMOOTHPOINT 4051.53099921665,3828.4220077632 4019.39863078903,3828.86587592616 4083.65109329103,3827.97813960025 PathPoint;PointKind.SMOOTHPOINT 3960.93494211254,3828.4220077632 3903.3937182913,3828.60679609799 4018.57530494074,3828.23674922909 PathPoint;PointKind.SMOOTHPOINT 3856.70113437466,3828.4220077632 3833.05884166698,3827.90032161194 3880.34342708233,3828.94369391447 PathPoint;PointKind.SMOOTHPOINT 3799.22631795173,3828.4220077632 3784.35515218056,3828.44551772946 3814.0974837229,3828.39849779695 PathPoint;PointKind.SMOOTHPOINT 3773.89834739871,3828.4220077632 3759.11089901119,3828.4377594406 3788.68548105922,3828.40625608581 PathPoint;PointKind.SMOOTHPOINT 3746.62190195014,3829.42611842209 3733.98089174509,3829.20630023758 3759.26354160921,3829.64570150694 PathPoint;PointKind.SMOOTHPOINT 3713.50097599597,3829.42611842209 3703.09767480518,3830.01433777787 3723.90459191376,3828.83766396665 PathPoint;PointKind.SMOOTHPOINT 3670.63830501809,3829.42611842209 3636.73496772643,3829.527211277 3704.46107219615,3829.32502556718 PathPoint;PointKind.SMOOTHPOINT 3564.45570765765,3829.42611842209 3541.25057076163,3829.03256158693 3588.74602327115,3829.83777793127 PathPoint;PointKind.SMOOTHPOINT 3473.86028000756,3829.42611842209 3438.01004145539,3829.50652250669 3509.54056597636,3829.34594943715 PathPoint;PointKind.SMOOTHPOINT 3328.71133200632,3829.42611842209 3311.06647712928,3829.54366825338 3346.35681633737,3829.30833349114 PathPoint;PointKind.SMOOTHPOINT 3262.46916537096,3829.42611842209 3242.66024759911,3829.1395319334 3293.12483468537,3829.86928128606 PathPoint;PointKind.SMOOTHPOINT 3190.38220350298,3829.42611842209 3188.6493166067,3829.43904890353 3201.71520827016,3829.34054214491 PathPoint;PointKind.SMOOTHPOINT 3184.53740827036,3829.42611842209 3183.81479506407,3829.9092482287 3186.26337117251,3828.27130887949 PathPoint;PointKind.SMOOTHPOINT 3178.8518649029,3829.50299601175 3170.33094593634,3830.11496043345 3180.31660438987,3829.39790646258 PathPoint;PointKind.SMOOTHPOINT 3153.36464248473,3829.42611842209 3116.07736042213,3829.11273057187 3161.76753882395,3829.49664832086 PathPoint;PointKind.SMOOTHPOINT 3070.56154078177,3829.42611842209 3052.39518325542,3829.52791657599 3088.72789830813,3829.32408516853 PathPoint;PointKind.SMOOTHPOINT 3026.72478971962,3829.42611842209 2998.5963782652,3829.60643986329 3054.85351590104,3829.24556188123 PathPoint;PointKind.SMOOTHPOINT 2922.49098198174,3829.42611842209 2919.73743540427,3829.50111521445 2957.01999656177,3828.48477937311 PathPoint;PointKind.SMOOTHPOINT 2914.22750970628,3829.60549946464 2913.66194527609,3829.61490345114 2916.98483300782,3829.56012522976 PathPoint;PointKind.SMOOTHPOINT 2911.77515687376,3829.42611842209 2910.94585121236,3829.43810850488 2912.34166548497,3829.4178899339 PathPoint;PointKind.SMOOTHPOINT 2909.82668197822,3828.4220077632 2908.68768494269,3829.16398229831 2911.38174811598,3827.40896331714 PathPoint;PointKind.SMOOTHPOINT 2905.99078922634,3829.70306582461 2905.42207752609,3829.70729761854 2907.34254171808,3829.69295653912 PathPoint;PointKind.SMOOTHPOINT 2904.28370994457,3829.71435060841 2875.56990625858,3829.88244686716 2904.85336582584,3829.71105921314 PathPoint;PointKind.SMOOTHPOINT 2808.51511449314,3829.42611842209 2763.47988299129,3830.06135771039 2845.65541904383,3828.9020812742 PathPoint;PointKind.SMOOTHPOINT 2607.84013969153,3828.4220077632 2562.02469994124,3828.21417966148 2653.65589416882,3828.62983586493 PathPoint;PointKind.SMOOTHPOINT 2465.61406139711,3828.4220077632 2424.18213938953,3830.16339096395 2507.04598340468,3826.68062456246 PathPoint;PointKind.SMOOTHPOINT 2382.81158914816,3827.41789710432 2337.66179701604,3828.13965306844 2427.96106655328,3826.69614114019 PathPoint;PointKind.SMOOTHPOINT 2281.49970693608,3828.4220077632 2234.43228315502,3828.72387572996 2328.56713071714,3828.11990469679 PathPoint;PointKind.SMOOTHPOINT 2193.82620481178,3828.4220077632 2163.56709152522,3827.973437607 2254.42153950144,3829.32008847427 PathPoint;PointKind.SMOOTHPOINT 2120.76484813253,3828.4220077632 2100.70761075277,3828.14835175596 2140.77109973728,3828.6947233718 PathPoint;PointKind.SMOOTHPOINT 2063.2900317096,3828.4220077632 2024.94652581412,3828.16551403133 2084.24014960602,3828.5621271621 PathPoint;PointKind.SMOOTHPOINT 1982.43540490219,3828.4220077632 1927.97441429088,3828.09239803626 2036.89671024051,3828.75138239048 PathPoint;PointKind.SMOOTHPOINT 1849.95107163147,3827.41789710432 1802.34074376468,3827.70119219773 1899.65401936266,3827.12214172879 PathPoint;PointKind.SMOOTHPOINT 1722.33745350911,3826.41378644543 1676.4099709446,3826.87058508983 1770.68644565951,3825.93300763545 PathPoint;PointKind.SMOOTHPOINT 1618.06241653341,3827.59163575497 1576.34503713118,3828.34465997421 1659.77948120863,3826.83861153572 PathPoint;PointKind.SMOOTHPOINT 1472.79953735592,3828.38979910943 1439.56436549848,3829.06453514104 1506.03502394036,3827.71529817748 PathPoint;PointKind.SMOOTHPOINT 1353.95326944598,3828.38979910943 1305.22282816403,3828.10368282007 1402.68339600092,3828.67615049845 PathPoint;PointKind.SMOOTHPOINT 1232.18413182922,3828.38979910943 1179.88657465871,3828.23721942841 1306.8644442285,3828.60797159631 PathPoint;PointKind.SMOOTHPOINT 1135.4099835929,3828.06606687406 1134.81105810005,3828.06818277102 1161.05362533317,3827.98143099553 PathPoint;PointKind.SMOOTHPOINT 1133.59841494507,3828.07264966461 1132.19410304329,3828.07805695685 1134.20741170211,3828.07029866798 PathPoint;PointKind.SMOOTHPOINT 1128.87247421958,3828.38979910943 1126.90920715474,3829.18467106862 1130.56759387511,3827.70377829402 PathPoint;PointKind.SMOOTHPOINT 1116,3827 1108.0984637817,3827.05383782273 1118.27579098202,3826.98448342227 PathPoint;PointKind.SMOOTHPOINT 1094.77746818114,3828.38979910943 1036.39686743429,3829.03303178625 1105.79354285305,3828.26848768354 PathPoint;PointKind.SMOOTHPOINT 989.568950904972,3828.38979910943 931.10463277447,3828.76642876889 1048.03326903547,3828.01340454964 PathPoint;PointKind.SMOOTHPOINT 860.006857887062,3828.38979910943 808.917222966441,3829.04102517478 911.096492807682,3827.73880814374 PathPoint;PointKind.SMOOTHPOINT 816,3825 805.617156064614,3825.0326788531 844.182544499488,3824.91136742721 PathPoint;PointKind.SMOOTHPOINT 783.360131152888,3826.39756456871 775.181635169106,3826.87622748173 788.256024461735,3826.11121317969 PathPoint;PointKind.SMOOTHPOINT 764.851035916753,3827.4016752276 759.313728969218,3828.10697421534 772.339650302888,3826.44811099617 PathPoint;PointKind.SMOOTHPOINT 746.022178042293,3826.59575358427 734.418822776763,3826.7055451267 764.145417968795,3826.42389573092 PathPoint;PointKind.SMOOTHPOINT 723.021298973305,3828.58775302532 717.089009632957,3828.70530285661 728.95390304066,3828.46996809437 PathPoint;PointKind.SMOOTHPOINT 709.324379662362,3828.40578588649 692.862898328732,3827.43317858239 725.786175722998,3829.37862829025 PathPoint;PointKind.SMOOTHPOINT 678.048068691675,3829.42611842209 666.33927987906,3828.778889051 689.75685750429,3830.07311269351 PathPoint;PointKind.SMOOTHPOINT 654.018032312329,3827.59163575497 638.237620220171,3827.03868134857 669.798759131493,3828.14459016136 PathPoint;PointKind.SMOOTHPOINT 626.418047501365,3826.41378644543 607.285163338891,3828.7003657637 645.550931663838,3824.12720712716 PathPoint;PointKind.SMOOTHPOINT 600.015598949089,3827.59163575497 591.188765332483,3827.20489681002 610.845355233316,3828.06630197372 PathPoint;PointKind.SMOOTHPOINT 582.581296439215,3826.41378644543 581.03158066056,3826.14412713245 589.410243020301,3827.60245033944 PathPoint;PointKind.SMOOTHPOINT 574.014427329751,3828.58775302532 570.609395849395,3828.33807718366 576.617219671238,3828.77865395134 PathPoint;PointKind.SMOOTHPOINT 562.013886582365,3828.58775302532 557.112642914412,3829.06923713429 565.296803984305,3828.26543138792 PathPoint;PointKind.SMOOTHPOINT 546.013165585849,3827.59163575497 542.150521038441,3828.68061739204 549.530554607428,3826.60022047786 PathPoint;PointKind.SMOOTHPOINT 538.012805087591,3827.59163575497 535.994460796666,3827.85964937031 540.872414666158,3827.2119497999 PathPoint;PointKind.SMOOTHPOINT 533.873830228717,3830.42999398131 530.319932874416,3829.93205289597 535.256425967067,3830.62395120294 PathPoint;PointKind.SMOOTHPOINT 522.184239763481,3829.42611842209 514.269170283911,3829.40260845583 527.882686938204,3829.4430455978 PathPoint;PointKind.SMOOTHPOINT 509.519939759965,3830.42999398131 499.900308814676,3829.66145318433 519.13988543226,3831.19876987795 PathPoint;PointKind.SMOOTHPOINT 490.037079166568,3829.42611842209 470.957383868146,3829.85352960866 509.11677446499,3828.99847213585 PathPoint;PointKind.SMOOTHPOINT 463.735028529278,3830.42999398131 453.061062113133,3830.67332213209 474.408680218417,3830.1869009302 PathPoint;PointKind.SMOOTHPOINT 449.122568357224,3829.42611842209 444.655333230857,3828.88092230456 453.590118210599,3829.97131453962 PathPoint;PointKind.SMOOTHPOINT 441.008276682713,3829.58387029568 435.3457083867,3829.92899660035 446.67053025172,3829.23874399101 PathPoint;PointKind.CORNERPOINT 436.45889780772,3830.42999398131 436.45889780772,3830.42999398131 436.45889780772,3830.42999398131 PathPoint;PointKind.SMOOTHPOINT 424.007353260412,3830.57975246638 423.315268573722,3831.82084358515 425.149497566005,3828.53109400664 PathPoint;PointKind.SMOOTHPOINT 382,3830 339.285391621992,3830.47207564544 391.109941619942,3829.89945259307 PathPoint;PointKind.SMOOTHPOINT 315.66415500224,3830.42999398131 302.63319803647,3829.46937676001 340.668271465854,3832.27341043562 PathPoint;PointKind.SMOOTHPOINT 272.000503793515,3826.59575358427 263.761265497532,3818.92515689322 276.672311473929,3830.94533244169 PathPoint;PointKind.SMOOTHPOINT 265.853497431667,3804.10876599952 264.265382661671,3774.6555169302 266.399847915343,3814.24140702703 PathPoint;PointKind.SMOOTHPOINT 264.033819084923,3745.08387937128 263.012537292087,3733.03242244867 264.99832627893,3756.46537758429 PathPoint;PointKind.CORNERPOINT 263.059739000654,3561.33821158571 263.059739000654,3561.33821158571 263.059739000654,3561.33821158571 PathPoint;PointKind.CORNERPOINT 263.059739000654,3111.51332848085 263.059739000654,3111.51332848085 263.059739000654,3111.51332848085 PathPoint;PointKind.CORNERPOINT 263.059739000654,2498.02405036948 263.059739000654,2498.02405036948 263.059739000654,2498.02405036948 PathPoint;PointKind.SMOOTHPOINT 267,2483 267.118337354341,2474.52019027034 266.882292099672,2491.47980972966 PathPoint;PointKind.SMOOTHPOINT 263.059739000654,2468.9060167601 262.717630744887,2453.19759770505 263.402476710434,2484.61420071549 PathPoint;PointKind.SMOOTHPOINT 264.033819084923,2443.80419068661 263.601069451363,2436.22551796363 264.245630360113,2447.50583487395 PathPoint;PointKind.SMOOTHPOINT 263.059739000654,2383.55966705041 262.893563141367,2356.89489842007 263.233468308091,2411.38112602066 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,2109.44756646004 268.040923328189,2060.3380681427 267.820299696825,2158.55682967772 PathPoint;PointKind.SMOOTHPOINT 265.008528623204,2015.06445592004 264.441390557985,2000.90957543533 265.575351961417,2029.21957150441 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1967.8731357497 266.899408476608,1940.05308737743 267.013654379868,1995.6929490223 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,1914.65715162605 267.458678366671,1897.45067752103 270.351019553886,1931.86362573107 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1881.52267538112 267.036629451323,1869.22672792844 266.87674813216,1893.8186228338 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1856.42084930762 264.441390557985,1843.7092456515 271.420147194034,1869.13268806341 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1822.28249750348 266.773832401124,1803.98539606374 269.087390623889,1840.57936384355 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1760.02975254951 270.148964815889,1730.24497629705 265.712258209125,1789.81476390164 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1659.62244825552 267.438221111267,1653.2968567341 269.28661281883,1677.04051205686 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1620.46354315694 267.356077362642,1598.98577838214 266.556985493835,1641.94130793175 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1516.03979622741 265.792198868706,1494.88764448528 268.12086398777,1537.1921830692 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1407.59984176199 268.36855414167,1381.26256696162 267.493298337356,1433.93711656235 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1318.23728451642 267.036629451323,1294.79056006749 268.825223027703,1341.68400896534 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1236.90737744227 267.938951778172,1233.62091925904 267.900240356406,1249.38764303041 PathPoint;PointKind.SMOOTHPOINT 267.989308099168,1229.09736665131 268.029907882971,1226.59261484616 267.955317582496,1231.23442258417 PathPoint;PointKind.SMOOTHPOINT 265.008528623204,1223.85440907608 265.076509656549,1221.97831376868 264.903724530131,1226.72168456092 PathPoint;PointKind.SMOOTHPOINT 265.982608707473,1209.797330051 266.942211349455,1206.08863287377 265.125292342514,1213.10894389812 PathPoint;PointKind.SMOOTHPOINT 267,1193 267.791538420658,1170.84373759899 266.820920333458,1198.01020890928 PathPoint;PointKind.SMOOTHPOINT 266.956688791741,1167.62632807543 266.345174218645,1159.05718047399 268.127473254901,1184.04592360979 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1121.43888346431 268.531268003889,1100.94642137539 267.321457391957,1142.22663072944 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,1087.3002965605 267.261029806762,1071.25639028695 270.334968476568,1101.25534233202 PathPoint;PointKind.SMOOTHPOINT 267.93076887601,1036.09253375462 267.063066519846,1016.37190385795 268.798156505168,1055.81316365129 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,980.868563412856 268.96559127248,958.40243965656 268.844106648077,1003.33468716915 PathPoint;PointKind.SMOOTHPOINT 269.879243771553,907.571071410471 270.762053024016,879.151048699296 268.996119792084,935.991094121646 PathPoint;PointKind.SMOOTHPOINT 269.879243771553,826.241164336323 270.773383196241,798.895782182809 268.98478961986,853.586546489837 PathPoint;PointKind.SMOOTHPOINT 270.853323855822,759.972211846477 272.333484966101,735.035190636448 269.372848018536,784.909468156168 PathPoint;PointKind.SMOOTHPOINT 270.853323855822,704.748241504713 270.289962514678,680.477727838103 271.41637046996,729.01852007166 PathPoint;PointKind.SMOOTHPOINT 271.827403940091,654.544589357717 271.454452437713,637.910582931082 272.200355442468,671.178360684689 PathPoint;PointKind.SMOOTHPOINT 271.827403940091,630.446638843442 272.459690495598,624.346978097762 271.194802657577,636.546534688783 PathPoint;PointKind.SMOOTHPOINT 271.827403940091,606.348923428829 270.910289443949,589.883718559928 272.744518436232,622.814128297731 PathPoint;PointKind.SMOOTHPOINT 272.801484024359,559.157368158828 272.211685614692,535.79316369147 273.391282434026,582.521807725848 PathPoint;PointKind.SMOOTHPOINT 272.801484024359,530.039334549449 270.080669055538,523.716799323642 275.52229899318,536.361869775255 PathPoint;PointKind.SMOOTHPOINT 269.879243771553,512.970158647375 266.400880898747,505.686536000935 273.356977190347,520.253546194153 PathPoint;PointKind.SMOOTHPOINT 268.904848960279,478.831571743566 269.195656714031,463.238586622843 268.604284669333,494.954001304423 PathPoint;PointKind.SMOOTHPOINT 265.906383734001,440.137949300038 264.782178867763,409.721930453545 266.302310307833,450.84227203704 PathPoint;PointKind.SMOOTHPOINT 265.906383734001,379.37951822424 265.61463179923,350.582160554622 266.249750897793,413.340369783138 PathPoint;PointKind.SMOOTHPOINT 265.906383734001,294.716130659604 265.628479787504,264.731284594286 266.183658226486,324.701211824584 PathPoint;PointKind.SMOOTHPOINT 264.906337718001,236.945819144911 264.614603456426,217.918916378591 265.211289095451,256.83619091308 PathPoint;PointKind.SMOOTHPOINT 263.906291702,190.131946020936 263.212119272469,170.22775982724 264.561571729428,208.926185914306 PathPoint";
	
	subshadow645[0] = "PointKind.SMOOTHPOINT 261.96875,169.390625 261.997889616368,162.901068927689 261.941673146529,175.397048932221 PathPoint;PointKind.SMOOTHPOINT 266.96875,134.390625 271.366475934354,130.54422124582 261.096003774259,139.527002394554 PathPoint;PointKind.SMOOTHPOINT 315.96875,131.390625 341.751589034647,131.313915374971 298.730645149995,131.441864463366 PathPoint;PointKind.SMOOTHPOINT 4904.96875,131.390625 4910.39156150818,131.390625 4899.54593849182,131.390625 PathPoint;PointKind.SMOOTHPOINT 4973.35960006714,130.605212688446 4978.82705758963,130.441797288238 4960.88230430284,130.978310472006 PathPoint;PointKind.SMOOTHPOINT 5009.96875,136.390625 5016.64115632399,144.457932583796 5006.31965890265,131.978754902213 PathPoint;PointKind.SMOOTHPOINT 5014.96875,159.390625 5015.0673673917,186.12891619052 5014.94785051523,153.729853008676 PathPoint;PointKind.CORNERPOINT 5018.07804679871,434.281162261963 5018.07804679871,434.281162261963 5018.07804679871,434.281162261963 PathPoint;PointKind.SMOOTHPOINT 5015.91758659647,2670.47697458426 5015.91421369627,2673.9681128593 5016.80505529368,1751.89778381325 PathPoint;PointKind.SMOOTHPOINT 5015,2679 5014.27510102899,2682.04286688174 5016.0866840898,2674.43848845147 PathPoint;PointKind.SMOOTHPOINT 5015.89843224133,2690.3027916491 5015.43293722132,3172.11588559804 5015.9014451071,2687.18430892942 PathPoint;PointKind.CORNERPOINT 5015.07820701599,3539.28126955032 5015.07820701599,3539.28126955032 5015.07820701599,3539.28126955032 PathPoint;PointKind.CORNERPOINT 5014.96875,3781.390625 5014.96875,3781.390625 5014.96875,3781.390625 PathPoint;PointKind.SMOOTHPOINT 5011.96875,3823.390625 5006.90147887244,3831.36852136338 5016.35416696547,3816.48662555232 PathPoint;PointKind.CORNERPOINT 4987.96875,3828.390625 4987.96875,3828.390625 4987.96875,3828.390625 PathPoint;PointKind.CORNERPOINT 331.96875,3829.390625 331.96875,3829.390625 331.96875,3829.390625 PathPoint;PointKind.SMOOTHPOINT 270.96875,3826.390625 268.337111560965,3821.87088959728 272.907514644594,3829.72034783935 PathPoint;PointKind.CORNERPOINT 261.96875,3810.390625 261.96875,3810.390625 261.96875,3810.390625 PathPoint;PointKind.CORNERPOINT 261.96875,3537.390625 261.96875,3537.390625 261.96875,3537.390625 PathPoint;PointKind.SMOOTHPOINT 261.96875,2192.28571423177 261.96875,2188.77252840114 261.96875,2895.18312293264 PathPoint;PointKind.SMOOTHPOINT 263,2177 263,2170.65822178099 263,2180.51614547038 PathPoint;PointKind.SMOOTHPOINT 261.96875,2162.7026849236 261.96875,2157.79126129749 261.96875,2169.05342873496 PathPoint;PointKind.SMOOTHPOINT 263,2146 263,2142.03147410405 263,2150.91633400424 PathPoint;PointKind.SMOOTHPOINT 261.96875,2136.05086915631 261.96875,2000.23069097195 261.96875,2140.02236257836 PathPoint;PointKind.SMOOTHPOINT 261.96875,1727.71152520569 261.96875,1722.56550208278 261.96875,1862.73577673928 PathPoint;PointKind.SMOOTHPOINT 261.96875,1712.28445132379 261.96875,1708.50759123317 261.96875,1717.42306762858 PathPoint;PointKind.SMOOTHPOINT 264,1699 261.949373472777,1686.46699785639 264.175295926587,1700.07137218529 PathPoint;PointKind.SMOOTHPOINT 264,1681 264,1675.9839071506 264,1687.30681703762 PathPoint;PointKind.SMOOTHPOINT 261.96875,1666.9849310732 261.96875,1663.27259628069 261.96875,1671.99262153509 PathPoint;PointKind.SMOOTHPOINT 261.96875,1655.85511856596 261.96875,1290.60086496079 261.96875,1659.56262951992 PathPoint;PointKind.SMOOTHPOINT 261.96875,715.526691606678 261.96875,711.078605778938 261.96875,949.181870545737 PathPoint;PointKind.SMOOTHPOINT 265,701 265,696.407004302049 265,705.369398267908 PathPoint;PointKind.SMOOTHPOINT 261.96875,688.653241709053 261.96875,683.001693184762 261.96875,693.157977985502 PathPoint;PointKind.SMOOTHPOINT 261.96875,671.90988846265 261.96875,667.167667010733 261.96875,677.420132746454 PathPoint;PointKind.SMOOTHPOINT 265,658 261.610306842989,654.084199295374 269.501031303082,663.199627438754 PathPoint;PointKind.SMOOTHPOINT 261.96875,642.507251103635 261.96875,493.838773853988 261.96875,647.551237803369 PathPoint;PointKind.CORNERPOINT 261.96875,404.390625 261.96875,404.390625 261.96875,404.390625 PathPoint";
	
	
} else if (mask_variant_645 == 4) {
	
	mask645[0] = "PointKind.SMOOTHPOINT 267,125 270.5058041117,120.633147869655 263.937306425684,128.815513966305 PathPoint;PointKind.SMOOTHPOINT 351.776847839355,122.499961853027 212.227334976196,124.180526733398 314.21181678772,122.95149564743 PathPoint;PointKind.SMOOTHPOINT 942.050399780273,120.013339519501 977.48514175415,119.930963516235 772.805242538452,120.408933162689 PathPoint;PointKind.SMOOTHPOINT 1493.42516899109,121.021914482117 1505.1003742218,120.809483528137 1481.75090789795,121.235053539276 PathPoint;PointKind.SMOOTHPOINT 1535.31435012817,125.055742263794 1541.86540603638,125.088315010071 1524.25629615784,125.000510215759 PathPoint;PointKind.SMOOTHPOINT 1545.05627632141,123.038828372955 1548.47562789917,122.447090148926 1540.08539199829,123.898701667786 PathPoint;PointKind.SMOOTHPOINT 1563.56514930725,122.030725479126 1567.49339103699,121.969592571259 1558.16310882568,122.114045619965 PathPoint;PointKind.SMOOTHPOINT 1580.12563705444,124.047403335571 1584.10989761353,125.138354301453 1574.52501296997,122.513179779053 PathPoint;PointKind.SMOOTHPOINT 1605.45401573181,126.064081192017 1620.9303188324,126.016874313354 1594.56464767456,126.097362041473 PathPoint;PointKind.SMOOTHPOINT 1849.82640266418,123.994767665863 1861.04023933411,124.495160579681 1838.61225128174,123.494610786438 PathPoint;PointKind.CORNERPOINT 1881.97365760803,123.994767665863 1881.97365760803,123.994767665863 1881.97365760803,123.994767665863 PathPoint;PointKind.SMOOTHPOINT 1887.81849861145,125.002870559692 1889.32691574097,125.1296210289 1881.97176933289,124.512155056 PathPoint;PointKind.SMOOTHPOINT 1895.62934875488,122.827577590942 1900.45640945435,122.628128528595 1889.49465751648,123.081314563751 PathPoint;PointKind.SMOOTHPOINT 1908.27638626099,123.994767665863 1919.90501403809,125.0661277771 1896.64681434631,122.92293548584 PathPoint;PointKind.SMOOTHPOINT 1962.82896995544,123.994767665863 1971.7797088623,123.915696144104 1953.87917518616,124.073367118835 PathPoint;PointKind.SMOOTHPOINT 2007.64057159424,123.994767665863 2021.55999183655,123.872737884521 1993.72052192688,124.116797447205 PathPoint;PointKind.SMOOTHPOINT 2057.32297897339,123.994767665863 1871.78074836731,123.831195831299 2043.05737495422,123.982021808624 PathPoint;PointKind.SMOOTHPOINT 2559.10408973694,122.951023578644 2580.01768112183,122.731511592865 2425.81295013428,124.348583221436 PathPoint;PointKind.SMOOTHPOINT 2609.7611618042,121.942684650421 2617.64911651611,121.53694152832 2601.87257766724,122.348427772522 PathPoint;PointKind.SMOOTHPOINT 2638.01164627075,122.951023578644 2647.73468971252,122.619867324829 2628.28923225403,123.281707763672 PathPoint;PointKind.SMOOTHPOINT 2695.48727989197,122.951023578644 2703.01803588867,122.856137752533 2687.95620918274,123.045201301575 PathPoint;PointKind.SMOOTHPOINT 2713.99615287781,122.951023578644 2723.03784370422,123.317348957062 2704.95446205139,122.584698200226 PathPoint;PointKind.SMOOTHPOINT 2755.88533401489,123.95959854126 2774.1811466217,124.479582309723 2737.58952140808,123.439614772797 PathPoint;PointKind.SMOOTHPOINT 2796.80016517639,123.95959854126 2804.36868667603,123.805940151215 2789.23101425171,124.113020896912 PathPoint;PointKind.SMOOTHPOINT 2818.23145866394,121.942684650421 2832.2739315033,121.617193222046 2807.72572517395,122.186036109924 PathPoint;PointKind.SMOOTHPOINT 2850.37902832031,122.951023578644 2855.42072296143,123.15967798233 2845.33670425415,122.741897106171 PathPoint;PointKind.SMOOTHPOINT 2863.18940162659,122.538907527924 2869.56799507141,122.011370658875 2856.16250038147,123.119788169861 PathPoint;PointKind.SMOOTHPOINT 2879.6032333374,123.95959854126 2882.21282958984,124.183595180511 2875.94470024109,123.64520072937 PathPoint;PointKind.SMOOTHPOINT 2897.13838577271,122.951023578644 2900.0658416748,122.396814823151 2890.09763717651,124.284617900848 PathPoint;PointKind.SMOOTHPOINT 2904.32704925537,121.88273191452 2912.25276947021,121.155745983124 2900.55459022522,122.2292304039 PathPoint;PointKind.SMOOTHPOINT 2915.64788818359,123.95959854126 2922.96149253845,124.129071235657 2908.33365440369,123.789889812469 PathPoint;PointKind.SMOOTHPOINT 2951.69159889221,122.951023578644 2961.78694725037,123.301298618317 2941.59562110901,122.600512504578 PathPoint;PointKind.SMOOTHPOINT 2980.91611862183,122.951023578644 2997.61004447937,122.773761749268 2964.22250747681,123.12828540802 PathPoint;PointKind.SMOOTHPOINT 3556.6987323761,129.089334011078 3589.24567222595,130.042912960052 3524.15179252625,128.135755062103 PathPoint;PointKind.SMOOTHPOINT 3657.01932907104,126.011209487915 3661.64340019226,126.286897659302 3639.02658462524,124.938433170319 PathPoint;PointKind.SMOOTHPOINT 3672.6060962677,128.028123378754 3681.72552108765,128.829696178436 3667.80893325806,127.606801986694 PathPoint;PointKind.SMOOTHPOINT 3715.46931266785,126.011209487915 3719.39944267273,126.000115871429 3713.29087257385,126.017582416534 PathPoint;PointKind.SMOOTHPOINT 3726.1846446991,128.028123378754 3729.75946426392,128.053615093231 3719.08284187317,127.977139949799 PathPoint;PointKind.SMOOTHPOINT 3740.83262443542,129.067618846893 3742.09493637085,129.042599201202 3733.01894187927,129.221749305725 PathPoint;PointKind.SMOOTHPOINT 3747.65181541443,128.016085624695 3749.54669952393,127.323560714722 3745.50830841064,128.800427913666 PathPoint;PointKind.SMOOTHPOINT 3751.54890060425,128.016085624695 3758.28123092651,128.096573352814 3750.70924758911,128.006408214569 PathPoint;PointKind.SMOOTHPOINT 3770.22205352783,129.092638492584 3788.5122013092,128.026707172394 3764.803647995,129.408452510834 PathPoint;PointKind.SMOOTHPOINT 3797.31659889221,127.072656154633 3804.56757545471,127.576825618744 3798.51817131042,127.156212329865 PathPoint;PointKind.SMOOTHPOINT 3807.05852508545,128.080995082855 3821.28730773926,129.07021522522 3801.94476127625,127.725291252136 PathPoint;PointKind.SMOOTHPOINT 3824.77432250977,126.002712249756 3826.24277114868,125.964710712433 3815.19164085388,126.248896121979 PathPoint;PointKind.SMOOTHPOINT 3832.38627433777,127.072656154633 3838.16282272339,127.319076061249 3828.49674224854,126.906723976135 PathPoint;PointKind.SMOOTHPOINT 3842.62796401978,126.002712249756 3850.01300811768,126.571083068848 3841.48838996887,125.915143489838 PathPoint;PointKind.SMOOTHPOINT 3862.58545875549,127.072656154633 3870.61849594116,126.604127883911 3854.55242156982,127.541184425354 PathPoint;PointKind.SMOOTHPOINT 3882.06868171692,127.072656154633 3893.49998474121,128.009948730469 3870.63769340515,126.134655475616 PathPoint;PointKind.SMOOTHPOINT 3906.42239570618,128.080995082855 3913.43576431274,128.112387657166 3899.40934181213,128.049366474152 PathPoint;PointKind.SMOOTHPOINT 3922.98351287842,125.055742263794 3934.01733398438,124.084460735321 3907.69855499268,126.400666236877 PathPoint;PointKind.SMOOTHPOINT 3937.59593009949,128.080995082855 3947.72904396057,127.730247974396 3931.0643863678,128.306879997253 PathPoint;PointKind.CORNERPOINT 3956.10480308533,127.072656154633 3956.10480308533,127.072656154633 3956.10480308533,127.072656154633 PathPoint;PointKind.SMOOTHPOINT 3966.82107925415,125.055742263794 3974.31721687317,124.390125274658 3959.32399749756,125.721595287323 PathPoint;PointKind.SMOOTHPOINT 3980.45883178711,126.064081192017 3988.22027206421,126.013569831848 3970.112657547,126.131114959717 PathPoint;PointKind.SMOOTHPOINT 3994.09721374512,125.055742263794 3995.74284553528,124.745357036591 3989.15622711182,125.987370014191 PathPoint;PointKind.SMOOTHPOINT 3999.94205474854,123.038828372955 4008.03960800171,122.624588012695 3996.59634590149,123.210189342499 PathPoint;PointKind.SMOOTHPOINT 4013.58075141907,125.055742263794 4016.29986763,125.491461753845 4009.42025184631,124.389181137085 PathPoint;PointKind.SMOOTHPOINT 4026.24446868896,125.055742263794 4038.56609344482,125.78839302063 4021.37366294861,124.765892028809 PathPoint;PointKind.SMOOTHPOINT 4059.36638832092,126.064081192017 4066.95127487183,126.146457195282 4041.26034736633,125.867228507996 PathPoint;PointKind.SMOOTHPOINT 4082.74606704712,125.055742263794 4084.61829185486,124.839062690735 4075.01672744751,125.950076580048 PathPoint;PointKind.SMOOTHPOINT 4102.22929000854,125.055742263794 4105.21339416504,125.522854328156 4095.69050788879,124.032533168793 PathPoint;PointKind.SMOOTHPOINT 4110.99655151367,125.055742263794 4126.17985725403,124.720809459686 4107.99073219299,125.121831893921 PathPoint;PointKind.SMOOTHPOINT 4154.07251358032,127.033002376556 4163.11200141907,126.871790885925 4139.69959259033,127.288863658905 PathPoint;PointKind.SMOOTHPOINT 4178.21442604065,126.895394325256 4178.72803688049,126.860933303833 4170.60121536255,127.40688085556 PathPoint;PointKind.SMOOTHPOINT 4184.05863761902,126.064081192017 4186.96846961975,125.875017642975 4182.91686058044,126.138432025909 PathPoint;PointKind.SMOOTHPOINT 4191.85154914856,126.064081192017 4204.47813034058,125.449447631836 4188.82338523865,126.211366653442 PathPoint;PointKind.SMOOTHPOINT 4216.20557785034,127.072656154633 4222.87968635559,127.122695446014 4206.2134552002,126.997833251953 PathPoint;PointKind.SMOOTHPOINT 4235.68943023682,125.055742263794 4240.02774238586,124.161643981934 4229.81122970581,126.267778873444 PathPoint;PointKind.SMOOTHPOINT 4255.17233848572,123.038828372955 4257.1147441864,123.404681682587 4245.63875198364,121.244022846222 PathPoint;PointKind.SMOOTHPOINT 4260.04282951355,125.055742263794 4265.81182479858,126.688392162323 4258.16305160522,124.523484706879 PathPoint;PointKind.SMOOTHPOINT 4274.65587615967,125.055742263794 4286.84752464294,125.051729679108 4268.37610244751,125.05763053894 PathPoint;PointKind.SMOOTHPOINT 4291.21636390686,124.047403335571 4301.72650337219,123.767702579498 4280.705909729,124.327104091644 PathPoint;PointKind.SMOOTHPOINT 4307.81084060669,127.033002376556 4309.88920211792,126.95912361145 4298.72760772705,127.356133460999 PathPoint;PointKind.SMOOTHPOINT 4315.57070732117,127.072656154633 4317.60154724121,126.911680698395 4313.07126045227,127.270925045013 PathPoint;PointKind.SMOOTHPOINT 4322.38958358765,127.072656154633 4323.06999206543,127.052357196808 4320.02326011658,127.141814231873 PathPoint;PointKind.SMOOTHPOINT 4324.33765411377,125.055742263794 4325.4221534729,124.953775405884 4323.58297348022,125.126316547394 PathPoint;PointKind.SMOOTHPOINT 4331.1571598053,125.055742263794 4332.53308296204,125.489809513092 4329.26259040833,124.458339214325 PathPoint;PointKind.SMOOTHPOINT 4333.10523033142,127.072656154633 4335.15086174011,127.10381269455 4331.93607330322,127.054953575134 PathPoint;PointKind.SMOOTHPOINT 4338.95070075989,125.055742263794 4341.38437271118,124.545435905457 4336.62906646729,125.542209148407 PathPoint;PointKind.SMOOTHPOINT 4348.69199752808,125.055742263794 4352.0890045166,125.012075901031 4344.70364570618,125.106961727142 PathPoint;PointKind.SMOOTHPOINT 4358.43360900879,123.038828372955 4369.12030220032,122.987844944 4354.94627952576,123.05558681488 PathPoint;PointKind.SMOOTHPOINT 4381.81360244751,123.038828372955 4383.14735412598,123.086271286011 4370.9981918335,122.653148174286 PathPoint;PointKind.SMOOTHPOINT 4386.68440818787,125.055742263794 4409.4780921936,125.959045886993 4385.30250549316,125.000746250153 PathPoint;PointKind.SMOOTHPOINT 4447.08183288574,125.055742263794 4447.3584651947,125.058810710907 4433.42645645142,124.89004611969 PathPoint;PointKind.SMOOTHPOINT 4463.64295005798,123.038828372955 4466.56096458435,124.299252033234 4469.86104011536,125.724427700043 PathPoint;PointKind.SMOOTHPOINT 4471.92649841309,125.539140701294 4473.00061225891,125.415930747986 4468.6279964447,125.917267799377 PathPoint;PointKind.SMOOTHPOINT 4478.25536727905,123.038828372955 4483.51389884949,122.836782932281 4475.71563720703,123.136310577393 PathPoint;PointKind.SMOOTHPOINT 4493.84181976318,125.055742263794 4500.90648651123,125.361170768738 4490.03914833069,124.890990257263 PathPoint;PointKind.SMOOTHPOINT 4512.35100746155,124.047403335571 4515.81253051758,123.848190307617 4501.35778427124,124.67973947525 PathPoint;PointKind.SMOOTHPOINT 4526.96342468262,124.047403335571 4541.92359924316,124.117269515991 4520.70693969727,124.017899036407 PathPoint;PointKind.SMOOTHPOINT 4566.33962631226,123.85055065155 4567.60760307312,123.843941688538 4552.65624046326,123.923721313477 PathPoint;PointKind.SMOOTHPOINT 4571.77471160889,123.038828372955 4575.3545665741,123.026790618896 4570.45040130615,123.043076992035 PathPoint;PointKind.SMOOTHPOINT 4579.56793785095,123.038828372955 4580.26534080505,123.041188716888 4575.42191505432,123.025138378143 PathPoint;PointKind.SMOOTHPOINT 4581.5163230896,124.047403335571 4582.31663703918,124.066994190216 4580.75629234314,124.028520584106 PathPoint;PointKind.SMOOTHPOINT 4583.46470832825,123.038828372955 4586.51647567749,123.067152500153 4582.59924888611,123.030803203583 PathPoint;PointKind.SMOOTHPOINT 4593.20631980896,123.038828372955 4596.96178436279,123.273682594299 4589.54558372498,122.809638977051 PathPoint;PointKind.SMOOTHPOINT 4604.89663124084,124.047403335571 4643.47094535828,124.606568813324 4601.35296821594,123.996183872223 PathPoint;PointKind.SMOOTHPOINT 4654.57840919495,125.055742263794 4670.04715919495,125.402240753174 4639.10965919495,124.709007740021 PathPoint;PointKind.SMOOTHPOINT 4684.7779083252,124.047403335571 4698.14186096191,124.385876655579 4671.41332626343,123.708693981171 PathPoint;PointKind.SMOOTHPOINT 4713.02807807922,124.047403335571 4731.65905952454,123.645672798157 4694.39678192139,124.449133872986 PathPoint;PointKind.SMOOTHPOINT 4743.22694778442,125.055742263794 4763.74935150146,125.410265922546 4722.70485877991,124.701218605042 PathPoint;PointKind.SMOOTHPOINT 4787.06451416016,125.055742263794 4821.35433197021,124.161643981934 4752.7746963501,125.949840545654 PathPoint;PointKind.SMOOTHPOINT 4853.30772399902,125.055742263794 4884.95427131653,124.877536296844 4828.81994247437,125.193586349487 PathPoint;PointKind.SMOOTHPOINT 4896.09981536865,126.042366027832 4903.9972114563,126.226944923401 4903.91223907471,126.225056648254 PathPoint;PointKind.SMOOTHPOINT 4908.76321792603,126.042366027832 4913.43386650085,124.51073884964 4905.29697418213,127.179815769196 PathPoint;PointKind.SMOOTHPOINT 4933.18868637085,125.055742263794 4950.55106163025,125.289888381958 4925.51977157593,124.952123165131 PathPoint;PointKind.SMOOTHPOINT 5012,127 5015.13158103279,131.863910185881 5008.919161393,122.214982298368 PathPoint;PointKind.SMOOTHPOINT 5015.81520462036,183.006828784943 5015.69939041138,185.76583480835 5016.06823348999,176.983939170837 PathPoint;PointKind.SMOOTHPOINT 5016,255 5015.677734375,274.239871501923 5016.16333580017,245.213778018951 PathPoint;PointKind.SMOOTHPOINT 5015.99238395691,396.31826877594 5015.93132972717,414.036426544189 5016.05312347412,378.60011100769 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,910.608179569244 5015.4211807251,928.02657365799 5012.6665019989,893.189313411713 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,969.095849990845 5014.18876647949,981.669402122498 5013.89923095703,956.522297859192 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1059.8529624939 5014.94596481323,1073.43107700348 5015.09041786194,1046.27508401871 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1235.31691789627 5014.29891586304,1242.43453502655 5013.78876686096,1228.19859266281 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1255.48487663269 5015.00292778015,1267.94418811798 5015.0331401825,1243.02532911301 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1299.8548579216 5013.60277175903,1332.81729698181 5014.48585510254,1266.89265489578 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1522.71381139755 5015.32991409302,1536.60278320312 5014.70615386963,1508.82436752319 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1586.24364852905 5014.05627250671,1595.79950094223 5014.01756286621,1565.80000162125 PathPoint;PointKind.SMOOTHPOINT 5015.0281047821,1626.28664731979 5015.06083488464,1627.4297618866 5014.60450172424,1611.49673223495 PathPoint;PointKind.SMOOTHPOINT 5015.123462677,1629.69640016556 5014.73353385925,1631.51268482208 5015.36075592041,1628.5938835144 PathPoint;PointKind.SMOOTHPOINT 5015.21693229675,1633.1915974617 5015.57822227478,1647.25712299347 5015.18703460693,1632.03833341599 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1662.88307189941 5013.48821640015,1670.52492141724 5015.71984291077,1659.37654495239 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1681.03435277939 5014.63786125183,1688.55039596558 5015.39883613586,1673.51878166199 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1697.16919183731 5015.48601150513,1703.64101886749 5014.55005645752,1690.69736480713 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1718.34548950195 5015.23487091064,1729.76506948471 5014.801197052,1706.92638158798 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1769.7745513916 5014.16170120239,1791.51072263718 5015.87405204773,1748.03885221481 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1844.39729690552 5015.21598815918,1859.86227035522 5014.81976509094,1828.93232345581 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1877.67460584641 5015.75257301331,1902.4832367897 5012.33542442322,1852.8662109375 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1950.28067350388 5015.3645324707,1967.93156147003 5014.67185020447,1932.62907743454 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1999.69258546829 5015.06744384766,2004.47818279266 5014.8849105835,1986.78386449814 PathPoint;PointKind.SMOOTHPOINT 5014.43424224854,2013.62782001495 5013.82684707642,2021.25645160675 5014.79301452637,2009.13325309753 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2035.99514722824 5014.18876647949,2046.42574310303 5013.95304679871,2029.43197488785 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2090.44946193695 5015.32991409302,2117.18035697937 5014.70615386963,2063.71856689453 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2219.52628612518 5014.04777526855,2250.79871892929 5015.98860740662,2188.25338125229 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2300.19930124283 5014.40937995911,2315.60503005981 5015.62700271606,2284.79310035706 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2375.82991361618 5014.00528907776,2377.12149381638 5014.57680702209,2357.95809745789 PathPoint;PointKind.SMOOTHPOINT 5013.0699634552,2380.87208032608 5013.02370071411,2386.63816452026 5013.13322067261,2372.95997142792 PathPoint;PointKind.SMOOTHPOINT 5013.81488800049,2386.38183116913 5014.38829421997,2410.43113946915 5013.79380226135,2385.51322460175 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2471.62895679474 5015.01048088074,2490.96206188202 5013.22291374207,2455.20285129547 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2549.27695512772 5014.39395904541,2572.76544570923 5013.69372367859,2525.78752040863 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2618.85682582855 5015.69151878357,2640.83705663681 5014.3448638916,2596.87683105469 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2693.47957134247 5013.77366065979,2726.73728942871 5014.31402206421,2660.22138118744 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2757.00940847397 5014.39805030823,2773.1791806221 5013.6899471283,2740.83940029144 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2818.52233171463 5014.82763290405,2846.31278514862 5015.20843505859,2790.73211431503 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2890.11982440948 5014.99380111694,2907.11076021194 5015.0422668457,2873.04297208786 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2938.52316141129 5013.4992313385,2949.16760444641 5014.56390380859,2928.36046457291 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2981.88503980637 5014.65989112854,2994.51783657074 5015.37617683411,2969.25224304199 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3014.15424585342 5014.45721626282,3021.80388450623 5013.46555709839,3003.45575094223 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3058.52446317673 5015.12723922729,3065.35789489746 5014.74328994751,3041.38104915619 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3076.67550802231 5015.53479194641,3094.37643527985 5014.85816001892,3071.1926651001 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3094.82726097107 5013.96028518677,3104.2259144783 5014.12771224976,3085.42860746384 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3132.13816165924 5014.38262939453,3145.77174425125 5013.70505332947,3118.50528717041 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3183.56745958328 5013.75855445862,3196.04966640472 5014.31087493896,3171.88729763031 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3213.8197517395 5014.13558006287,3222.27780818939 5013.93699645996,3203.94053220749 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3254.15590524673 5014.1450214386,3256.40908956528 5013.44258308411,3240.74608325958 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3262.22356081009 5015.20277023315,3264.48760271072 5014.87421035767,3260.4589676857 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3267.26572751999 5014.01630401611,3274.74730968475 5014.05029296875,3265.57218074799 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3291.46751403809 5014.43581581116,3306.79440736771 5013.72488021851,3278.9692568779 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3328.77865076065 5014.58058357239,3338.70908975601 5013.50741386414,3318.8479757309 PathPoint;PointKind.SMOOTHPOINT 5013.0699634552,3345.9218287468 5014.32188987732,3355.10781526566 5011.81803703308,3336.73560619354 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3374.15744304657 5013.96343231201,3385.86262464523 5014.12047386169,3363.04423570633 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3392.30872392654 5016.06067657471,3397.72075653076 5013.97539138794,3386.89645528793 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3409.4516658783 5014.7212600708,3414.90736484528 5015.31480789185,3403.99573087692 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3429.61986064911 5013.537940979,3442.91449785233 5016.49875640869,3416.3249874115 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3447.77114152908 5013.91087532043,3465.22564888 5014.17743682861,3430.31710624695 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3493.149933815 5014.62244033813,3512.38414049149 5015.41362762451,3473.91501903534 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3569.78864908218 5014.20733451843,3600.23047685623 5013.88066291809,3539.34752941132 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3628.27655553818 5013.58735084534,3640.89778661728 5014.50096130371,3615.65603256226 PathPoint;PointKind.SMOOTHPOINT 5012.09592819214,3654.49549198151 5011.73212051392,3671.87800884247 5012.43865013123,3638.09511423111 PathPoint;PointKind.SMOOTHPOINT 5013.30348014832,3698.84989500046 5013.14769744873,3721.88968420029 5013.4592628479,3675.80986976624 PathPoint;PointKind.SMOOTHPOINT 5014.98247146606,3777.50410795212 5015.43125152588,3794.13863182068 5014.53369140625,3760.86934804916 PathPoint;PointKind.SMOOTHPOINT 5014.79112625122,3806.78818702698 5013.9543056488,3813.61666202545 5015.90646743774,3797.6841044426 PathPoint;PointKind.SMOOTHPOINT 5012,3834 5007.49841918592,3836.31059812335 5014.79530247387,3832.56535754933 PathPoint;PointKind.SMOOTHPOINT 4943.59434127808,3834.96266841888 4925.44298171997,3837.12946414948 4947.75767326355,3834.46557998657 PathPoint;PointKind.SMOOTHPOINT 4791.89975738525,3834.94850635529 4777.61841773987,3836.81955099106 4806.18109703064,3833.07746171951 PathPoint;PointKind.SMOOTHPOINT 4642.06827163696,3834.96266841888 4619.8143196106,3835.59996128082 4666.39429092407,3834.26565885544 PathPoint;PointKind.SMOOTHPOINT 4479.22940254211,3838.02639484406 4450.48418998718,3838.79869937897 4507.97524452209,3837.25409030914 PathPoint;PointKind.SMOOTHPOINT 4394.47763442993,3838.02639484406 4380.27969360352,3838.94409656525 4408.67526054382,3837.10892915726 PathPoint;PointKind.SMOOTHPOINT 4360.38167953491,3838.02639484406 4351.58546447754,3837.87580490112 4370.29858589172,3838.19563150406 PathPoint;PointKind.SMOOTHPOINT 4328.23410987854,3838.02639484406 4326.97305679321,3837.99051761627 4338.13559532166,3838.30656766891 PathPoint;PointKind.SMOOTHPOINT 4320.441198349,3838.02639484406 4311.21697425842,3838.46754312515 4321.48352622986,3837.97659158707 PathPoint;PointKind.SMOOTHPOINT 4294.13878440857,3838.02639484406 4288.12462806702,3838.26998233795 4304.51674461365,3837.60601758957 PathPoint;PointKind.SMOOTHPOINT 4270.42267799377,3838.24024200439 4269.26170349121,3838.23363304138 4280.10543823242,3838.2966542244 PathPoint;PointKind.SMOOTHPOINT 4266.86800003052,3838.21663856506 4265.94431877136,3837.58689880371 4268.47806930542,3839.31514263153 PathPoint;PointKind.SMOOTHPOINT 4263.49270820618,3838.19020271301 4257.90907859802,3838.14346790314 4264.63668823242,3838.19964408875 PathPoint;PointKind.SMOOTHPOINT 4245.43135643005,3838.02639484406 4224.4988822937,3837.84535646439 4251.87100410461,3838.08209896088 PathPoint;PointKind.SMOOTHPOINT 4197.69733428955,3838.02639484406 4176.57005310059,3837.28973150253 4218.82430076599,3838.76329421997 PathPoint;PointKind.SMOOTHPOINT 4156.78218841553,3838.02639484406 4149.46669578552,3838.2999587059 4175.53087234497,3837.32513666153 PathPoint;PointKind.SMOOTHPOINT 4140.22138595581,3838.02639484406 4135.36096572876,3838.33111524582 4143.33137512207,3837.83119440079 PathPoint;PointKind.SMOOTHPOINT 4126.5830039978,3839.03520584106 4112.83101081848,3838.74724388123 4134.96977806091,3839.21010732651 PathPoint;PointKind.SMOOTHPOINT 4098.33251953125,3838.02639484406 4079.22978401184,3837.83331871033 4117.43525505066,3838.21923494339 PathPoint;PointKind.SMOOTHPOINT 4051.57253265381,3838.02639484406 4019.43975448608,3838.47202777863 4083.69272232056,3837.58076190948 PathPoint;PointKind.SMOOTHPOINT 3960.97529411316,3838.02639484406 3903.43357086182,3838.2119178772 4018.61646652222,3837.84039974213 PathPoint;PointKind.SMOOTHPOINT 3856.73998832703,3838.02639484406 3833.09783935547,3837.50239849091 3880.38308143616,3838.5506272316 PathPoint;PointKind.SMOOTHPOINT 3799.26529884338,3838.02639484406 3784.39387321472,3838.04999828339 3814.136095047,3838.00279140472 PathPoint;PointKind.SMOOTHPOINT 3773.93692016602,3838.02639484406 3759.14920806885,3838.04220914841 3788.72431755066,3838.0105805397 PathPoint;PointKind.SMOOTHPOINT 3746.65984153748,3839.03520584106 3734.01909828186,3838.81404161453 3759.30184364319,3839.25542593002 PathPoint;PointKind.SMOOTHPOINT 3713.53918075562,3839.03520584106 3703.13541412354,3839.62552785873 3723.94231796265,3838.44370365143 PathPoint;PointKind.SMOOTHPOINT 3670.67564964294,3839.03520584106 3636.77198410034,3839.13646459579 3704.4987487793,3838.93347501755 PathPoint;PointKind.SMOOTHPOINT 3564.49195861816,3839.03520584106 3541.28631591797,3838.63984823227 3588.78241539001,3839.44826602936 PathPoint;PointKind.SMOOTHPOINT 3473.89534950256,3839.03520584106 3438.04518699646,3839.11545753479 3509.57588195801,3838.95448207855 PathPoint;PointKind.SMOOTHPOINT 3328.74489784241,3839.03520584106 3311.09991073608,3839.15298700333 3346.39051437378,3838.91671657562 PathPoint;PointKind.SMOOTHPOINT 3262.50200271606,3839.03520584106 3242.69305229187,3838.74700784683 3293.15783500671,3839.48013067245 PathPoint;PointKind.SMOOTHPOINT 3190.4142665863,3839.03520584106 3188.68145942688,3839.0479516983 3201.74737930298,3838.94905328751 PathPoint;PointKind.SMOOTHPOINT 3184.56942558289,3839.03520584106 3183.84684562683,3839.52002048492 3186.29530906677,3837.87509679794 PathPoint;PointKind.SMOOTHPOINT 3178.88382911682,3839.11215305328 3170.36267280579,3839.72702264786 3180.34850120544,3839.00664567947 PathPoint;PointKind.SMOOTHPOINT 3153.39589118958,3839.03520584106 3116.10843658447,3838.72033596039 3161.79903030396,3839.10578012466 PathPoint;PointKind.SMOOTHPOINT 3070.59250831604,3839.03520584106 3052.42572784424,3839.13717269897 3088.75897407532,3838.93253087997 PathPoint;PointKind.SMOOTHPOINT 3026.75462722778,3839.03520584106 2998.6262512207,3839.21624422073 3054.88426208496,3838.85369539261 PathPoint;PointKind.SMOOTHPOINT 2922.52026557922,3839.03520584106 2919.7665309906,3839.11050081253 2957.04957962036,3838.08941602707 PathPoint;PointKind.SMOOTHPOINT 2914.25622940063,3839.21530008316 2913.69069099426,3839.22474145889 2917.01405525208,3839.16974544525 PathPoint;PointKind.SMOOTHPOINT 2911.80430412292,3839.03520584106 2910.97503662109,3839.04724359512 2912.37078666687,3839.0269446373 PathPoint;PointKind.SMOOTHPOINT 2909.85560417175,3838.02639484406 2908.7166595459,3838.77179145813 2911.41091346741,3837.00885057449 PathPoint;PointKind.SMOOTHPOINT 2906.01957321167,3839.31301832199 2905.45120239258,3839.31726694107 2907.37157821655,3839.30263280869 PathPoint;PointKind.SMOOTHPOINT 2904.31257247925,3839.32434797287 2875.59851646423,3839.49311256409 2904.88220214844,3839.32127952576 PathPoint;PointKind.SMOOTHPOINT 2808.54303359985,3839.03520584106 2763.50735664368,3839.6727347374 2845.68383216858,3838.50884914398 PathPoint;PointKind.SMOOTHPOINT 2607.86596298218,3838.02639484406 2562.05011367798,3837.81774044037 2653.68181228638,3838.23504924774 PathPoint;PointKind.SMOOTHPOINT 2465.63824653625,3838.02639484406 2424.20571327209,3839.77540969849 2507.07077980042,3836.27761602402 PathPoint;PointKind.SMOOTHPOINT 2382.8345489502,3837.01781988144 2337.68463134766,3837.74291753769 2427.98478126526,3836.29319429398 PathPoint;PointKind.SMOOTHPOINT 2281.52166366577,3838.02639484406 2234.45388793945,3838.32946300507 2328.58975410461,3837.72309064865 PathPoint;PointKind.SMOOTHPOINT 2193.84716033936,3838.02639484406 2163.58818054199,3837.57580518723 2254.44316864014,3838.92828226089 PathPoint;PointKind.SMOOTHPOINT 2120.78538894653,3838.02639484406 2100.72781562805,3837.75165081024 2140.79166412354,3838.30043077469 PathPoint;PointKind.SMOOTHPOINT 2063.30975532532,3838.02639484406 2024.96549606323,3837.76888132095 2084.26016807556,3838.16730737686 PathPoint;PointKind.SMOOTHPOINT 1982.45444297791,3838.02639484406 1927.992811203,3837.69547462463 2036.91607475281,3838.35731506348 PathPoint;PointKind.SMOOTHPOINT 1849.9683380127,3837.01781988144 1802.35768318176,3837.30247735977 1899.67151641846,3836.72112464905 PathPoint;PointKind.SMOOTHPOINT 1722.35335350037,3836.00948095322 1676.42546653748,3836.46833181381 1770.70295333862,3835.5267906189 PathPoint;PointKind.SMOOTHPOINT 1621.79074287415,3837.56778001785 1580.07276535034,3838.32379817963 1663.50777626038,3836.81152582169 PathPoint;PointKind.SMOOTHPOINT 1478.81306648254,3836.04465007782 1445.57753562927,3836.72230482101 1512.04891204834,3835.36699533463 PathPoint;PointKind.SMOOTHPOINT 1359.96565818787,3836.04465007782 1311.23462677002,3835.75739622116 1408.69606018066,3836.33213996887 PathPoint;PointKind.SMOOTHPOINT 1238.19519996643,3836.04465007782 1115.43056488037,3835.6854057312 1312.87616729736,3836.26392602921 PathPoint;PointKind.SMOOTHPOINT 1130.73534965515,3835.78524827957 1122.83354759216,3835.83906412125 1129.15391921997,3835.79610586166 PathPoint;PointKind.SMOOTHPOINT 1102.78698921204,3836.04465007782 1044.40592765808,3836.69067621231 1113.80318641663,3835.92285633087 PathPoint;PointKind.SMOOTHPOINT 997.577648162842,3836.04465007782 939.112558364868,3836.4227771759 1056.04242324829,3835.66652297974 PathPoint;PointKind.SMOOTHPOINT 871.010971069336,3834.96266841888 819.920539855957,3835.61695575714 922.10108757019,3834.30908918381 PathPoint;PointKind.SMOOTHPOINT 810.507173538208,3834.96266841888 796.82599067688,3835.00609874725 838.690624237061,3834.873919487 PathPoint;PointKind.SMOOTHPOINT 766.865358352661,3835.99272251129 758.296995162964,3837.08886623383 771.158981323242,3835.44370651245 PathPoint;PointKind.SMOOTHPOINT 733.142023086548,3837.0227766037 727.210006713867,3837.14079380035 738.151302337646,3836.92269802094 PathPoint;PointKind.SMOOTHPOINT 705.328989028931,3836.00948095322 684.662761688232,3834.78328227997 721.790657043457,3836.98689937592 PathPoint;PointKind.SMOOTHPOINT 659.543352127075,3836.00948095322 643.762407302856,3835.45432806015 671.736574172974,3836.43859148026 PathPoint;PointKind.SMOOTHPOINT 626.421747207642,3836.00948095322 601.370944976807,3839.0163230896 645.555009841919,3833.7131023407 PathPoint;PointKind.SMOOTHPOINT 582.584810256958,3836.00948095322 582.332725524902,3835.96557855606 586.507701873779,3836.69539690018 PathPoint;PointKind.SMOOTHPOINT 563.534002304077,3837.0227766037 558.632669448853,3837.5061750412 568.096075057983,3836.57289505005 PathPoint;PointKind.SMOOTHPOINT 543.696727752686,3839.08264875412 536.357002258301,3841.16069555283 547.214269638062,3838.08681964874 PathPoint;PointKind.SMOOTHPOINT 522.187070846558,3839.03520584106 514.272050857544,3839.01136636734 528.13136100769,3839.05267238617 PathPoint;PointKind.SMOOTHPOINT 506.997785568237,3838.05259466171 497.378597259521,3837.28099822998 516.617918014526,3838.82489919662 PathPoint;PointKind.SMOOTHPOINT 490.039501190186,3839.03520584106 470.959424972534,3839.46408033371 509.119262695312,3838.60562324524 PathPoint;PointKind.SMOOTHPOINT 462.745428085327,3835.9393787384 452.071323394775,3836.18367433548 473.419218063354,3835.69531917572 PathPoint;PointKind.SMOOTHPOINT 446.494617462158,3837.0227766037 441.629791259766,3836.4265537262 450.96227645874,3837.57014036179 PathPoint;PointKind.SMOOTHPOINT 426.701402664185,3836.94771766663 426.009349822998,3838.19397926331 426.370639801025,3837.54346847534 PathPoint;PointKind.SMOOTHPOINT 400.868854522705,3837.0227766037 355.428771972656,3834.30271625519 409.963102340698,3837.56707191467 PathPoint;PointKind.SMOOTHPOINT 312.593250274658,3835.99272251129 299.561948776245,3835.02804994583 337.597789764404,3837.84394025803 PathPoint;PointKind.SMOOTHPOINT 270,3834 266.735095022272,3830.80904956443 273.306160921865,3837.23152508566 PathPoint;PointKind.SMOOTHPOINT 266.967487335205,3820.54309129715 266.442546844482,3817.63845205307 268.017997741699,3826.35567426682 PathPoint;PointKind.SMOOTHPOINT 265.975513458252,3749.52246665955 265.495576858521,3730.42634010315 266.292114257812,3762.103099823 PathPoint;PointKind.CORNERPOINT 263.059701919556,3569.78864908218 263.059701919556,3569.78864908218 263.059701919556,3569.78864908218 PathPoint;PointKind.CORNERPOINT 263.059701919556,3118.02094459534 263.059701919556,3118.02094459534 263.059701919556,3118.02094459534 PathPoint;PointKind.CORNERPOINT 263.059701919556,2501.88101291656 263.059701919556,2501.88101291656 263.059701919556,2501.88101291656 PathPoint;PointKind.SMOOTHPOINT 264.034051895142,2490.78881263733 264.152383804321,2482.27245569229 263.916034698486,2499.30540561676 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2472.63729572296 262.717609405518,2456.86099290848 263.402423858643,2488.41336250305 PathPoint;PointKind.SMOOTHPOINT 264.034051895142,2447.42740631104 263.600692749023,2439.81553316116 264.245538711548,2451.14471197128 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2386.9228219986 262.893533706665,2360.14259576797 263.233737945557,2414.86386537552 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,2111.62599563599 268.040971755981,2062.30448484421 267.820358276367,2160.94774246216 PathPoint;PointKind.SMOOTHPOINT 265.008401870728,2016.83552742004 264.441289901733,2002.61917591095 265.575199127197,2031.05164289474 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1969.44005727768 266.898880004883,1941.50019407272 267.013750076294,1997.38015651703 PathPoint;PointKind.SMOOTHPOINT 268.905172348022,1915.99431753159 267.45906829834,1898.71353149414 270.350961685181,1933.27510356903 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1882.71653652191 267.037038803101,1870.3674530983 266.876850128174,1895.06585597992 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1857.5061750412 264.441289901733,1844.73978281021 271.420040130615,1870.27327537537 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1823.22076320648 266.773624420166,1804.84430551529 269.087390899658,1841.59651279449 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1760.69902896881 270.148916244507,1730.78544616699 265.711784362793,1790.61261177063 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1659.85781908035 267.438297271729,1653.5049533844 269.286603927612,1677.35103607178 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1620.52976846695 267.356157302856,1598.95929336548 266.556787490845,1642.10024356842 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1515.65473079681 265.792036056519,1494.41139936447 268.120908737183,1536.89853429794 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1406.74657344818 268.368902206421,1380.29537916183 267.493371963501,1433.19753170013 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1316.99803590775 267.037038803101,1293.44982862473 268.825550079346,1340.54577112198 PathPoint;PointKind.SMOOTHPOINT 267.463788986206,1237.72258043289 267.475433349609,1233.00496101379 267.433261871338,1250.25647878647 PathPoint;PointKind.SMOOTHPOINT 265.008401870728,1222.20709562302 265.076694488525,1220.32306909561 264.925003051758,1224.51008319855 PathPoint;PointKind.SMOOTHPOINT 265.982437133789,1208.08964252472 266.941995620728,1204.36478376389 265.125160217285,1211.41536712646 PathPoint;PointKind.SMOOTHPOINT 267.463788986206,1197.70932197571 268.254976272583,1175.45717954636 267.284717559814,1202.7411031723 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1165.73610305786 266.344985961914,1157.13028907776 268.127517700195,1182.22711801529 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1119.3496799469 268.605251312256,1098.89210700989 267.242546081543,1140.22456169128 PathPoint;PointKind.SMOOTHPOINT 267.463788986206,1084.8518371582 267.30076789856,1068.64996433258 267.605409622192,1098.8670873642 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1033.63426208496 267.063159942627,1013.82861614227 268.798484802246,1053.43990802765 PathPoint;PointKind.SMOOTHPOINT 268.905172348022,978.171844482422 268.96559715271,955.608608722687 268.844118118286,1000.73508024216 PathPoint;PointKind.SMOOTHPOINT 269.879522323608,904.557673931122 270.76229095459,876.014978885651 268.996124267578,933.100368976593 PathPoint;PointKind.SMOOTHPOINT 269.879522323608,822.876791954041 270.773305892944,795.413010120392 268.985109329224,850.339865684509 PathPoint;PointKind.SMOOTHPOINT 266.885976791382,756.321229934692 268.366069793701,731.27632856369 265.405254364014,781.366131305695 PathPoint;PointKind.SMOOTHPOINT 266.885976791382,700.858340263367 266.322641372681,676.48330450058 267.448997497559,725.233612060547 PathPoint;PointKind.SMOOTHPOINT 266.471815109253,650.862951278687 266.099195480347,634.157145023346 266.845064163208,667.568757534027 PathPoint;PointKind.SMOOTHPOINT 266.471815109253,625.213329792023 267.104072570801,619.087529182434 265.839557647705,631.339838504791 PathPoint;PointKind.SMOOTHPOINT 265.480155944824,600.58974981308 265.597858428955,584.026980400085 265.36434173584,616.879427433014 PathPoint;PointKind.SMOOTHPOINT 265.480155944824,555.447227954865 264.890069961548,531.981868743896 266.069927215576,578.912115097046 PathPoint;PointKind.SMOOTHPOINT 266.471815109253,528.77156496048 265.944356918335,521.847496032715 266.947031021118,535.005941390991 PathPoint;PointKind.SMOOTHPOINT 265.91194152832,508.252151012421 264.619417190552,500.21045923233 267.26300239563,516.662528514862 PathPoint;PointKind.SMOOTHPOINT 264.937591552734,473.966031074524 265.228385925293,458.305621147156 264.637041091919,490.157990455627 PathPoint;PointKind.SMOOTHPOINT 264.937591552734,440.68825006485 263.813123703003,410.140914916992 265.333499908447,451.439144611359 PathPoint;PointKind.SMOOTHPOINT 264.983854293823,381.486339569092 264.691801071167,352.564573287964 265.327205657959,415.594017505646 PathPoint;PointKind.SMOOTHPOINT 264.983854293823,283.638045787811 264.694633483887,252.309200763702 265.260801315308,313.752493858337 PathPoint;PointKind.SMOOTHPOINT 264,178 263.768686294556,165.756187915802 264.332336425781,195.616662979126 PathPoint;PointKind.SMOOTHPOINT 263.967487335205,144.542269706726 263.938533782959,139.705452919006 264.020988464355,153.524794578552 PathPoint";
	
	mask645[1] = "PointKind.SMOOTHPOINT 266,125 269.203698795939,120.678958631213 263.440229766208,128.452532144666 PathPoint;PointKind.SMOOTHPOINT 351.776847839355,122.499961853027 212.227334976196,124.180526733398 314.21181678772,122.95149564743 PathPoint;PointKind.SMOOTHPOINT 942.050399780273,120.013339519501 977.48514175415,119.930963516235 772.805242538452,120.408933162689 PathPoint;PointKind.SMOOTHPOINT 1493.42516899109,121.021914482117 1505.1003742218,120.809483528137 1481.75090789795,121.235053539276 PathPoint;PointKind.SMOOTHPOINT 1535.31435012817,125.055742263794 1537.27721214294,125.088315010071 1524.25755500793,124.872107505798 PathPoint;PointKind.SMOOTHPOINT 1542.00010299683,122.999882698059 1545.41662216187,122.392330169678 1540.10805130005,123.33646774292 PathPoint;PointKind.SMOOTHPOINT 1563.56514930725,122.030725479126 1567.49339103699,121.969592571259 1558.16310882568,122.114045619965 PathPoint;PointKind.SMOOTHPOINT 1580.12563705444,124.047403335571 1584.10989761353,125.138354301453 1574.52501296997,122.513179779053 PathPoint;PointKind.SMOOTHPOINT 1605.45401573181,126.064081192017 1620.9303188324,126.016874313354 1594.56464767456,126.097362041473 PathPoint;PointKind.SMOOTHPOINT 1849.82640266418,123.994767665863 1861.04023933411,124.495160579681 1838.61225128174,123.494610786438 PathPoint;PointKind.CORNERPOINT 1876.99994087219,123.999960422516 1876.99994087219,123.999960422516 1876.99994087219,123.999960422516 PathPoint;PointKind.SMOOTHPOINT 1887.81849861145,125.002870559692 1889.32691574097,125.1296210289 1881.97176933289,124.512155056 PathPoint;PointKind.SMOOTHPOINT 1895.62934875488,122.827577590942 1900.45640945435,122.628128528595 1889.49465751648,123.081314563751 PathPoint;PointKind.SMOOTHPOINT 1908.27638626099,123.994767665863 1919.90501403809,125.0661277771 1896.64681434631,122.92293548584 PathPoint;PointKind.SMOOTHPOINT 1962.82896995544,123.994767665863 1971.7797088623,123.915696144104 1953.87917518616,124.073367118835 PathPoint;PointKind.SMOOTHPOINT 2007.64057159424,123.994767665863 2021.55999183655,123.872737884521 1993.72052192688,124.116797447205 PathPoint;PointKind.SMOOTHPOINT 2057.32297897339,123.994767665863 1871.78074836731,123.831195831299 2043.05737495422,123.982021808624 PathPoint;PointKind.SMOOTHPOINT 2559.10408973694,122.951023578644 2580.01768112183,122.731511592865 2425.81295013428,124.348583221436 PathPoint;PointKind.SMOOTHPOINT 2609.7611618042,121.942684650421 2617.64911651611,121.53694152832 2601.87257766724,122.348427772522 PathPoint;PointKind.SMOOTHPOINT 2638.01164627075,122.951023578644 2647.73468971252,122.619867324829 2628.28923225403,123.281707763672 PathPoint;PointKind.SMOOTHPOINT 2695.48727989197,122.951023578644 2703.01803588867,122.856137752533 2687.95620918274,123.045201301575 PathPoint;PointKind.SMOOTHPOINT 2713.99615287781,122.951023578644 2723.03784370422,123.317348957062 2704.95446205139,122.584698200226 PathPoint;PointKind.SMOOTHPOINT 2755.88533401489,123.95959854126 2774.1811466217,124.479582309723 2737.58952140808,123.439614772797 PathPoint;PointKind.SMOOTHPOINT 2796.80016517639,123.95959854126 2804.36868667603,123.805940151215 2789.23101425171,124.113020896912 PathPoint;PointKind.SMOOTHPOINT 2818.23145866394,121.942684650421 2832.2739315033,121.617193222046 2807.72572517395,122.186036109924 PathPoint;PointKind.SMOOTHPOINT 2850.37902832031,122.951023578644 2855.42072296143,123.15967798233 2845.33670425415,122.741897106171 PathPoint;PointKind.SMOOTHPOINT 2863.18940162659,122.538907527924 2869.56799507141,122.011370658875 2856.16250038147,123.119788169861 PathPoint;PointKind.SMOOTHPOINT 2879.6032333374,123.95959854126 2882.21282958984,124.183595180511 2875.94470024109,123.64520072937 PathPoint;PointKind.SMOOTHPOINT 2897.13838577271,122.951023578644 2900.0658416748,122.396814823151 2890.09763717651,124.284617900848 PathPoint;PointKind.SMOOTHPOINT 2904.32704925537,121.88273191452 2912.25276947021,121.155745983124 2900.55459022522,122.2292304039 PathPoint;PointKind.SMOOTHPOINT 2915.64788818359,123.95959854126 2922.96149253845,124.129071235657 2908.33365440369,123.789889812469 PathPoint;PointKind.SMOOTHPOINT 2951.69159889221,122.951023578644 2961.78694725037,123.301298618317 2941.59562110901,122.600512504578 PathPoint;PointKind.SMOOTHPOINT 2980.91611862183,122.951023578644 2997.61004447937,122.773761749268 2964.22250747681,123.12828540802 PathPoint;PointKind.SMOOTHPOINT 3556.6987323761,129.089334011078 3589.24567222595,130.042912960052 3524.15179252625,128.135755062103 PathPoint;PointKind.SMOOTHPOINT 3657.01932907104,126.011209487915 3661.64340019226,126.286897659302 3639.02658462524,124.938433170319 PathPoint;PointKind.SMOOTHPOINT 3672.6060962677,128.028123378754 3681.72552108765,128.829696178436 3667.80893325806,127.606801986694 PathPoint;PointKind.SMOOTHPOINT 3715.46931266785,126.011209487915 3719.39944267273,126.000115871429 3713.29087257385,126.017582416534 PathPoint;PointKind.SMOOTHPOINT 3726.1846446991,128.028123378754 3729.75946426392,128.053615093231 3719.08284187317,127.977139949799 PathPoint;PointKind.SMOOTHPOINT 3740.83262443542,129.067618846893 3742.09493637085,129.042599201202 3733.01894187927,129.221749305725 PathPoint;PointKind.SMOOTHPOINT 3747.65181541443,128.016085624695 3749.54669952393,127.323560714722 3745.50830841064,128.800427913666 PathPoint;PointKind.SMOOTHPOINT 3751.54890060425,128.016085624695 3758.28123092651,128.096573352814 3750.70924758911,128.006408214569 PathPoint;PointKind.SMOOTHPOINT 3770.22205352783,129.092638492584 3788.5122013092,128.026707172394 3764.803647995,129.408452510834 PathPoint;PointKind.SMOOTHPOINT 3797.31659889221,127.072656154633 3804.56757545471,127.576825618744 3798.51817131042,127.156212329865 PathPoint;PointKind.SMOOTHPOINT 3807.05852508545,128.080995082855 3821.28730773926,129.07021522522 3801.94476127625,127.725291252136 PathPoint;PointKind.SMOOTHPOINT 3824.77432250977,126.002712249756 3826.24277114868,125.964710712433 3815.19164085388,126.248896121979 PathPoint;PointKind.SMOOTHPOINT 3832.38627433777,127.072656154633 3838.16282272339,127.319076061249 3828.49674224854,126.906723976135 PathPoint;PointKind.SMOOTHPOINT 3844.00011062622,126.999957561493 3851.38515472412,127.568328380585 3842.86053657532,126.912388801575 PathPoint;PointKind.SMOOTHPOINT 3862.58545875549,127.072656154633 3870.61849594116,126.604127883911 3854.55242156982,127.541184425354 PathPoint;PointKind.SMOOTHPOINT 3882.06868171692,127.072656154633 3893.49998474121,128.009948730469 3870.63769340515,126.134655475616 PathPoint;PointKind.SMOOTHPOINT 3906.42239570618,128.080995082855 3913.43576431274,128.112387657166 3899.40934181213,128.049366474152 PathPoint;PointKind.SMOOTHPOINT 3924.00003433228,126.000115871429 3935.03385543823,125.028834342957 3908.71507644653,127.345039844513 PathPoint;PointKind.SMOOTHPOINT 3937.59593009949,128.080995082855 3947.72904396057,127.730247974396 3931.0643863678,128.306879997253 PathPoint;PointKind.CORNERPOINT 3956.10480308533,127.072656154633 3956.10480308533,127.072656154633 3956.10480308533,127.072656154633 PathPoint;PointKind.SMOOTHPOINT 3966.82107925415,125.055742263794 3974.31721687317,124.390125274658 3959.32399749756,125.721595287323 PathPoint;PointKind.SMOOTHPOINT 3980.45883178711,126.064081192017 3988.22027206421,126.013569831848 3970.112657547,126.131114959717 PathPoint;PointKind.SMOOTHPOINT 3994.09721374512,125.055742263794 3995.74284553528,124.745357036591 3989.15622711182,125.987370014191 PathPoint;PointKind.SMOOTHPOINT 3999.94205474854,123.038828372955 4008.03960800171,122.624588012695 3996.59634590149,123.210189342499 PathPoint;PointKind.SMOOTHPOINT 4013.58075141907,125.055742263794 4016.29986763,125.491461753845 4009.42025184631,124.389181137085 PathPoint;PointKind.SMOOTHPOINT 4026.24446868896,125.055742263794 4038.56609344482,125.78839302063 4021.37366294861,124.765892028809 PathPoint;PointKind.SMOOTHPOINT 4059.36638832092,126.064081192017 4066.95127487183,126.146457195282 4041.26034736633,125.867228507996 PathPoint;PointKind.SMOOTHPOINT 4082.74606704712,125.055742263794 4084.61829185486,124.839062690735 4075.01672744751,125.950076580048 PathPoint;PointKind.SMOOTHPOINT 4102.22929000854,125.055742263794 4105.21339416504,125.522854328156 4095.69050788879,124.032533168793 PathPoint;PointKind.SMOOTHPOINT 4110.99655151367,125.055742263794 4126.17985725403,124.720809459686 4107.99073219299,125.121831893921 PathPoint;PointKind.SMOOTHPOINT 4154.07251358032,127.033002376556 4163.11200141907,126.871790885925 4139.69959259033,127.288863658905 PathPoint;PointKind.SMOOTHPOINT 4178.21442604065,126.895394325256 4178.72803688049,126.860933303833 4170.60121536255,127.40688085556 PathPoint;PointKind.SMOOTHPOINT 4184.05863761902,126.064081192017 4186.96846961975,125.875017642975 4182.91686058044,126.138432025909 PathPoint;PointKind.SMOOTHPOINT 4191.85154914856,126.064081192017 4204.47813034058,125.449447631836 4188.82338523865,126.211366653442 PathPoint;PointKind.SMOOTHPOINT 4216.20557785034,127.072656154633 4222.87968635559,127.122695446014 4206.2134552002,126.997833251953 PathPoint;PointKind.SMOOTHPOINT 4235.68943023682,125.055742263794 4240.02774238586,124.161643981934 4229.81122970581,126.267778873444 PathPoint;PointKind.SMOOTHPOINT 4255.17233848572,123.038828372955 4257.1147441864,123.404681682587 4245.63875198364,121.244022846222 PathPoint;PointKind.SMOOTHPOINT 4260.04282951355,125.055742263794 4265.81182479858,126.688392162323 4258.16305160522,124.523484706879 PathPoint;PointKind.SMOOTHPOINT 4274.65587615967,125.055742263794 4286.84752464294,125.051729679108 4268.37610244751,125.05763053894 PathPoint;PointKind.SMOOTHPOINT 4291.21636390686,124.047403335571 4301.72650337219,123.767702579498 4280.705909729,124.327104091644 PathPoint;PointKind.SMOOTHPOINT 4307.81084060669,127.033002376556 4309.88920211792,126.95912361145 4298.72760772705,127.356133460999 PathPoint;PointKind.SMOOTHPOINT 4315.57070732117,127.072656154633 4317.60154724121,126.911680698395 4313.07126045227,127.270925045013 PathPoint;PointKind.SMOOTHPOINT 4322.38958358765,127.072656154633 4323.06999206543,127.052357196808 4320.02326011658,127.141814231873 PathPoint;PointKind.SMOOTHPOINT 4324.33765411377,125.055742263794 4325.4221534729,124.953775405884 4323.58297348022,125.126316547394 PathPoint;PointKind.SMOOTHPOINT 4331.1571598053,125.055742263794 4332.53308296204,125.489809513092 4329.26259040833,124.458339214325 PathPoint;PointKind.SMOOTHPOINT 4333.10523033142,127.072656154633 4335.15086174011,127.10381269455 4331.93607330322,127.054953575134 PathPoint;PointKind.SMOOTHPOINT 4338.95070075989,125.055742263794 4341.38437271118,124.545435905457 4336.62906646729,125.542209148407 PathPoint;PointKind.SMOOTHPOINT 4348.69199752808,125.055742263794 4352.0890045166,125.012075901031 4344.70364570618,125.106961727142 PathPoint;PointKind.SMOOTHPOINT 4358.43360900879,123.038828372955 4369.12030220032,122.987844944 4354.94627952576,123.05558681488 PathPoint;PointKind.SMOOTHPOINT 4381.81360244751,123.038828372955 4383.14735412598,123.086271286011 4370.9981918335,122.653148174286 PathPoint;PointKind.SMOOTHPOINT 4386.68440818787,125.055742263794 4409.4780921936,125.959045886993 4385.30250549316,125.000746250153 PathPoint;PointKind.SMOOTHPOINT 4447.08183288574,125.055742263794 4447.3584651947,125.058810710907 4433.42645645142,124.89004611969 PathPoint;PointKind.SMOOTHPOINT 4463.64295005798,123.038828372955 4466.56096458435,124.299252033234 4469.86104011536,125.724427700043 PathPoint;PointKind.SMOOTHPOINT 4471.92649841309,125.539140701294 4473.00061225891,125.415930747986 4468.6279964447,125.917267799377 PathPoint;PointKind.SMOOTHPOINT 4478.25536727905,123.038828372955 4483.51389884949,122.836782932281 4475.71563720703,123.136310577393 PathPoint;PointKind.SMOOTHPOINT 4493.84181976318,125.055742263794 4500.90648651123,125.361170768738 4490.03914833069,124.890990257263 PathPoint;PointKind.SMOOTHPOINT 4512.35100746155,124.047403335571 4515.81253051758,123.848190307617 4501.35778427124,124.67973947525 PathPoint;PointKind.SMOOTHPOINT 4526.96342468262,124.047403335571 4541.92359924316,124.117269515991 4520.70693969727,124.017899036407 PathPoint;PointKind.SMOOTHPOINT 4566.33962631226,123.85055065155 4567.60760307312,123.843941688538 4552.65624046326,123.923721313477 PathPoint;PointKind.SMOOTHPOINT 4571.77471160889,123.038828372955 4575.3545665741,123.026790618896 4570.45040130615,123.043076992035 PathPoint;PointKind.SMOOTHPOINT 4579.56793785095,123.038828372955 4580.26534080505,123.041188716888 4575.42191505432,123.025138378143 PathPoint;PointKind.SMOOTHPOINT 4581.5163230896,124.047403335571 4582.31663703918,124.066994190216 4580.75629234314,124.028520584106 PathPoint;PointKind.SMOOTHPOINT 4583.46470832825,123.038828372955 4586.51647567749,123.067152500153 4582.59924888611,123.030803203583 PathPoint;PointKind.SMOOTHPOINT 4593.20631980896,123.038828372955 4596.96178436279,123.273682594299 4589.54558372498,122.809638977051 PathPoint;PointKind.SMOOTHPOINT 4604.89663124084,124.047403335571 4643.47094535828,124.606568813324 4601.35296821594,123.996183872223 PathPoint;PointKind.SMOOTHPOINT 4654.57840919495,125.055742263794 4670.04715919495,125.402240753174 4639.10965919495,124.709007740021 PathPoint;PointKind.SMOOTHPOINT 4684.7779083252,124.047403335571 4698.14186096191,124.385876655579 4671.41332626343,123.708693981171 PathPoint;PointKind.SMOOTHPOINT 4713.02807807922,124.047403335571 4731.65905952454,123.645672798157 4694.39678192139,124.449133872986 PathPoint;PointKind.SMOOTHPOINT 4743.22694778442,125.055742263794 4763.74935150146,125.410265922546 4722.70485877991,124.701218605042 PathPoint;PointKind.SMOOTHPOINT 4787.06451416016,125.055742263794 4821.35433197021,124.161643981934 4752.7746963501,125.949840545654 PathPoint;PointKind.SMOOTHPOINT 4853.30772399902,125.055742263794 4884.95427131653,124.877536296844 4828.81994247437,125.193586349487 PathPoint;PointKind.SMOOTHPOINT 4896.09981536865,126.042366027832 4903.9972114563,126.226944923401 4903.91223907471,126.225056648254 PathPoint;PointKind.SMOOTHPOINT 4908.76321792603,126.042366027832 4913.43386650085,124.51073884964 4905.29697418213,127.179815769196 PathPoint;PointKind.SMOOTHPOINT 4933.18868637085,125.055742263794 4947.08985328674,125.243153572083 4925.51977157593,124.952123165131 PathPoint;PointKind.SMOOTHPOINT 5003,125 5007.29540216243,125.228089598374 4986.58880934176,124.127921592142 PathPoint;PointKind.SMOOTHPOINT 5012,126 5014.05570220947,127.463649272919 5010.54539871216,124.96404504776 PathPoint;PointKind.SMOOTHPOINT 5014,139 5014.99136947073,153.879566233039 5013.66912805355,134.032329001863 PathPoint;PointKind.SMOOTHPOINT 5015.81520462036,182.006828784943 5015.69939041138,184.76583480835 5016.00560569763,177.47142791748 PathPoint;PointKind.SMOOTHPOINT 5016,256 5015.677734375,275.239871501923 5016.16333580017,246.213778018951 PathPoint;PointKind.SMOOTHPOINT 5015.99238395691,396.31826877594 5015.93132972717,414.036426544189 5016.05312347412,378.60011100769 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,910.608179569244 5015.4211807251,928.02657365799 5012.6665019989,893.189313411713 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,969.095849990845 5014.18876647949,981.669402122498 5013.89923095703,956.522297859192 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1059.8529624939 5014.94596481323,1073.43107700348 5015.09041786194,1046.27508401871 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1235.31691789627 5014.29891586304,1242.43453502655 5013.78876686096,1228.19859266281 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1255.48487663269 5015.00292778015,1267.94418811798 5015.0331401825,1243.02532911301 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1299.8548579216 5013.60277175903,1332.81729698181 5014.48585510254,1266.89265489578 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1522.71381139755 5015.32991409302,1536.60278320312 5014.70615386963,1508.82436752319 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1586.24364852905 5014.05627250671,1595.79950094223 5014.01756286621,1565.80000162125 PathPoint;PointKind.SMOOTHPOINT 5015.0281047821,1626.28664731979 5015.06083488464,1627.4297618866 5014.60450172424,1611.49673223495 PathPoint;PointKind.SMOOTHPOINT 5015.123462677,1629.69640016556 5014.73353385925,1631.51268482208 5015.36075592041,1628.5938835144 PathPoint;PointKind.SMOOTHPOINT 5015.21693229675,1633.1915974617 5015.57822227478,1647.25712299347 5015.18703460693,1632.03833341599 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1662.88307189941 5013.48821640015,1670.52492141724 5015.71984291077,1659.37654495239 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1681.03435277939 5014.63786125183,1688.55039596558 5015.39883613586,1673.51878166199 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1697.16919183731 5015.48601150513,1703.64101886749 5014.55005645752,1690.69736480713 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1718.34548950195 5015.23487091064,1729.76506948471 5014.801197052,1706.92638158798 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1769.7745513916 5014.16170120239,1791.51072263718 5015.87405204773,1748.03885221481 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1844.39729690552 5015.21598815918,1859.86227035522 5014.81976509094,1828.93232345581 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1877.67460584641 5015.75257301331,1902.4832367897 5012.33542442322,1852.8662109375 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1950.28067350388 5015.3645324707,1967.93156147003 5014.67185020447,1932.62907743454 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1999.69258546829 5015.06744384766,2004.47818279266 5014.8849105835,1986.78386449814 PathPoint;PointKind.SMOOTHPOINT 5014.43424224854,2013.62782001495 5013.82684707642,2021.25645160675 5014.79301452637,2009.13325309753 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2035.99514722824 5014.18876647949,2046.42574310303 5013.95304679871,2029.43197488785 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2090.44946193695 5015.32991409302,2117.18035697937 5014.70615386963,2063.71856689453 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2219.52628612518 5014.04777526855,2250.79871892929 5015.98860740662,2188.25338125229 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2300.19930124283 5014.40937995911,2315.60503005981 5015.62700271606,2284.79310035706 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2375.82991361618 5014.00528907776,2377.12149381638 5014.57680702209,2357.95809745789 PathPoint;PointKind.SMOOTHPOINT 5013.0699634552,2380.87208032608 5013.02370071411,2386.63816452026 5013.13322067261,2372.95997142792 PathPoint;PointKind.SMOOTHPOINT 5013.81488800049,2386.38183116913 5014.38829421997,2410.43113946915 5013.79380226135,2385.51322460175 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2471.62895679474 5015.01048088074,2490.96206188202 5013.22291374207,2455.20285129547 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2549.27695512772 5014.39395904541,2572.76544570923 5013.69372367859,2525.78752040863 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2618.85682582855 5015.69151878357,2640.83705663681 5014.3448638916,2596.87683105469 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2693.47957134247 5013.77366065979,2726.73728942871 5014.31402206421,2660.22138118744 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2757.00940847397 5014.39805030823,2773.1791806221 5013.6899471283,2740.83940029144 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2818.52233171463 5014.82763290405,2846.31278514862 5015.20843505859,2790.73211431503 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2890.11982440948 5014.99380111694,2907.11076021194 5015.0422668457,2873.04297208786 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2938.52316141129 5013.4992313385,2949.16760444641 5014.56390380859,2928.36046457291 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2981.88503980637 5014.65989112854,2994.51783657074 5015.37617683411,2969.25224304199 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3014.15424585342 5014.45721626282,3021.80388450623 5013.46555709839,3003.45575094223 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3058.52446317673 5015.12723922729,3065.35789489746 5014.74328994751,3041.38104915619 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3076.67550802231 5015.53479194641,3094.37643527985 5014.85816001892,3071.1926651001 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3094.82726097107 5013.96028518677,3104.2259144783 5014.12771224976,3085.42860746384 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3132.13816165924 5014.38262939453,3145.77174425125 5013.70505332947,3118.50528717041 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3183.56745958328 5013.75855445862,3196.04966640472 5014.31087493896,3171.88729763031 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3213.8197517395 5014.13558006287,3222.27780818939 5013.93699645996,3203.94053220749 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3254.15590524673 5014.1450214386,3256.40908956528 5013.44258308411,3240.74608325958 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3262.22356081009 5015.20277023315,3264.48760271072 5014.87421035767,3260.4589676857 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3267.26572751999 5014.01630401611,3274.74730968475 5014.05029296875,3265.57218074799 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3291.46751403809 5014.43581581116,3306.79440736771 5013.72488021851,3278.9692568779 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3328.77865076065 5014.58058357239,3338.70908975601 5013.50741386414,3318.8479757309 PathPoint;PointKind.SMOOTHPOINT 5013.0699634552,3345.9218287468 5014.32188987732,3355.10781526566 5011.81803703308,3336.73560619354 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3374.15744304657 5013.96343231201,3385.86262464523 5014.12047386169,3363.04423570633 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3392.30872392654 5016.06067657471,3397.72075653076 5013.97539138794,3386.89645528793 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3409.4516658783 5014.7212600708,3414.90736484528 5015.31480789185,3403.99573087692 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3429.61986064911 5013.537940979,3442.91449785233 5016.49875640869,3416.3249874115 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3447.77114152908 5013.91087532043,3465.22564888 5014.17743682861,3430.31710624695 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3493.149933815 5014.62244033813,3512.38414049149 5015.41362762451,3473.91501903534 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3569.78864908218 5014.20733451843,3600.23047685623 5013.88066291809,3539.34752941132 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3628.27655553818 5013.58735084534,3640.89778661728 5014.50096130371,3615.65603256226 PathPoint;PointKind.SMOOTHPOINT 5012.09592819214,3654.49549198151 5011.73212051392,3671.87800884247 5012.43865013123,3638.09511423111 PathPoint;PointKind.SMOOTHPOINT 5013.30348014832,3698.84989500046 5013.14769744873,3721.88968420029 5013.4592628479,3675.80986976624 PathPoint;PointKind.SMOOTHPOINT 5014.98247146606,3777.50410795212 5015.43125152588,3794.13863182068 5014.53369140625,3760.86934804916 PathPoint;PointKind.SMOOTHPOINT 5014.79112625122,3806.78818702698 5013.9543056488,3813.61666202545 5015.90646743774,3797.6841044426 PathPoint;PointKind.SMOOTHPOINT 5012,3834 5008.57850014832,3836.36199492932 5014.553355617,3832.23747585015 PathPoint;PointKind.SMOOTHPOINT 4943.59434127808,3834.96266841888 4925.44298171997,3837.12946414948 4947.75767326355,3834.46557998657 PathPoint;PointKind.SMOOTHPOINT 4791.89975738525,3834.94850635529 4777.61841773987,3836.81955099106 4806.18109703064,3833.07746171951 PathPoint;PointKind.SMOOTHPOINT 4642.06827163696,3834.96266841888 4619.8143196106,3835.59996128082 4666.39429092407,3834.26565885544 PathPoint;PointKind.SMOOTHPOINT 4479.22940254211,3838.02639484406 4450.48418998718,3838.79869937897 4507.97524452209,3837.25409030914 PathPoint;PointKind.SMOOTHPOINT 4394.47763442993,3838.02639484406 4380.27969360352,3838.94409656525 4408.67526054382,3837.10892915726 PathPoint;PointKind.SMOOTHPOINT 4360.38167953491,3838.02639484406 4351.58546447754,3837.87580490112 4370.29858589172,3838.19563150406 PathPoint;PointKind.SMOOTHPOINT 4328.23410987854,3838.02639484406 4326.97305679321,3837.99051761627 4338.13559532166,3838.30656766891 PathPoint;PointKind.SMOOTHPOINT 4320.441198349,3838.02639484406 4311.21697425842,3838.46754312515 4321.48352622986,3837.97659158707 PathPoint;PointKind.SMOOTHPOINT 4294.13878440857,3838.02639484406 4288.12462806702,3838.26998233795 4304.51674461365,3837.60601758957 PathPoint;PointKind.SMOOTHPOINT 4270.42267799377,3838.24024200439 4269.26170349121,3838.23363304138 4280.10543823242,3838.2966542244 PathPoint;PointKind.SMOOTHPOINT 4266.86800003052,3838.21663856506 4265.94431877136,3837.58689880371 4268.47806930542,3839.31514263153 PathPoint;PointKind.SMOOTHPOINT 4263.49270820618,3838.19020271301 4257.90907859802,3838.14346790314 4264.63668823242,3838.19964408875 PathPoint;PointKind.SMOOTHPOINT 4245.43135643005,3838.02639484406 4224.4988822937,3837.84535646439 4251.87100410461,3838.08209896088 PathPoint;PointKind.SMOOTHPOINT 4197.69733428955,3838.02639484406 4176.57005310059,3837.28973150253 4218.82430076599,3838.76329421997 PathPoint;PointKind.SMOOTHPOINT 4156.78218841553,3838.02639484406 4149.46669578552,3838.2999587059 4175.53087234497,3837.32513666153 PathPoint;PointKind.SMOOTHPOINT 4140.22138595581,3838.02639484406 4135.36096572876,3838.33111524582 4143.33137512207,3837.83119440079 PathPoint;PointKind.SMOOTHPOINT 4126.5830039978,3839.03520584106 4112.83101081848,3838.74724388123 4134.96977806091,3839.21010732651 PathPoint;PointKind.SMOOTHPOINT 4098.33251953125,3838.02639484406 4079.22978401184,3837.83331871033 4117.43525505066,3838.21923494339 PathPoint;PointKind.SMOOTHPOINT 4051.57253265381,3838.02639484406 4019.43975448608,3838.47202777863 4083.69272232056,3837.58076190948 PathPoint;PointKind.SMOOTHPOINT 3960.97529411316,3838.02639484406 3903.43357086182,3838.2119178772 4018.61646652222,3837.84039974213 PathPoint;PointKind.SMOOTHPOINT 3856.73998832703,3838.02639484406 3833.09783935547,3837.50239849091 3880.38308143616,3838.5506272316 PathPoint;PointKind.SMOOTHPOINT 3799.26529884338,3838.02639484406 3784.39387321472,3838.04999828339 3814.136095047,3838.00279140472 PathPoint;PointKind.SMOOTHPOINT 3773.93692016602,3838.02639484406 3759.14920806885,3838.04220914841 3788.72431755066,3838.0105805397 PathPoint;PointKind.SMOOTHPOINT 3746.65984153748,3839.03520584106 3734.01909828186,3838.81404161453 3759.30184364319,3839.25542593002 PathPoint;PointKind.SMOOTHPOINT 3713.53918075562,3839.03520584106 3703.13541412354,3839.62552785873 3723.94231796265,3838.44370365143 PathPoint;PointKind.SMOOTHPOINT 3670.67564964294,3839.03520584106 3636.77198410034,3839.13646459579 3704.4987487793,3838.93347501755 PathPoint;PointKind.SMOOTHPOINT 3564.49195861816,3839.03520584106 3541.28631591797,3838.63984823227 3588.78241539001,3839.44826602936 PathPoint;PointKind.SMOOTHPOINT 3473.89534950256,3839.03520584106 3438.04518699646,3839.11545753479 3509.57588195801,3838.95448207855 PathPoint;PointKind.SMOOTHPOINT 3328.74489784241,3839.03520584106 3311.09991073608,3839.15298700333 3346.39051437378,3838.91671657562 PathPoint;PointKind.SMOOTHPOINT 3262.50200271606,3839.03520584106 3242.69305229187,3838.74700784683 3293.15783500671,3839.48013067245 PathPoint;PointKind.SMOOTHPOINT 3190.4142665863,3839.03520584106 3188.68145942688,3839.0479516983 3201.74737930298,3838.94905328751 PathPoint;PointKind.SMOOTHPOINT 3184.56942558289,3839.03520584106 3183.84684562683,3839.52002048492 3186.29530906677,3837.87509679794 PathPoint;PointKind.SMOOTHPOINT 3178.88382911682,3839.11215305328 3170.36267280579,3839.72702264786 3180.34850120544,3839.00664567947 PathPoint;PointKind.SMOOTHPOINT 3153.39589118958,3839.03520584106 3116.10843658447,3838.72033596039 3161.79903030396,3839.10578012466 PathPoint;PointKind.SMOOTHPOINT 3070.59250831604,3839.03520584106 3052.42572784424,3839.13717269897 3088.75897407532,3838.93253087997 PathPoint;PointKind.SMOOTHPOINT 3026.75462722778,3839.03520584106 2998.6262512207,3839.21624422073 3054.88426208496,3838.85369539261 PathPoint;PointKind.SMOOTHPOINT 2922.52026557922,3839.03520584106 2919.7665309906,3839.11050081253 2957.04957962036,3838.08941602707 PathPoint;PointKind.SMOOTHPOINT 2914.25622940063,3839.21530008316 2913.69069099426,3839.22474145889 2917.01405525208,3839.16974544525 PathPoint;PointKind.SMOOTHPOINT 2911.80430412292,3839.03520584106 2910.97503662109,3839.04724359512 2912.37078666687,3839.0269446373 PathPoint;PointKind.SMOOTHPOINT 2909.85560417175,3838.02639484406 2908.7166595459,3838.77179145813 2911.41091346741,3837.00885057449 PathPoint;PointKind.SMOOTHPOINT 2906.01957321167,3839.31301832199 2905.45120239258,3839.31726694107 2907.37157821655,3839.30263280869 PathPoint;PointKind.SMOOTHPOINT 2904.31257247925,3839.32434797287 2875.59851646423,3839.49311256409 2904.88220214844,3839.32127952576 PathPoint;PointKind.SMOOTHPOINT 2808.54303359985,3839.03520584106 2763.50735664368,3839.6727347374 2845.68383216858,3838.50884914398 PathPoint;PointKind.SMOOTHPOINT 2607.86596298218,3838.02639484406 2562.05011367798,3837.81774044037 2653.68181228638,3838.23504924774 PathPoint;PointKind.SMOOTHPOINT 2465.63824653625,3838.02639484406 2424.20571327209,3839.77540969849 2507.07077980042,3836.27761602402 PathPoint;PointKind.SMOOTHPOINT 2382.8345489502,3837.01781988144 2337.68463134766,3837.74291753769 2427.98478126526,3836.29319429398 PathPoint;PointKind.SMOOTHPOINT 2281.52166366577,3838.02639484406 2234.45388793945,3838.32946300507 2328.58975410461,3837.72309064865 PathPoint;PointKind.SMOOTHPOINT 2193.84716033936,3838.02639484406 2163.58818054199,3837.57580518723 2254.44316864014,3838.92828226089 PathPoint;PointKind.SMOOTHPOINT 2120.78538894653,3838.02639484406 2100.72781562805,3837.75165081024 2140.79166412354,3838.30043077469 PathPoint;PointKind.SMOOTHPOINT 2063.30975532532,3838.02639484406 2024.96549606323,3837.76888132095 2084.26016807556,3838.16730737686 PathPoint;PointKind.SMOOTHPOINT 1982.45444297791,3838.02639484406 1927.992811203,3837.69547462463 2036.91607475281,3838.35731506348 PathPoint;PointKind.SMOOTHPOINT 1849.9683380127,3837.01781988144 1802.35768318176,3837.30247735977 1899.67151641846,3836.72112464905 PathPoint;PointKind.SMOOTHPOINT 1722.35335350037,3836.00948095322 1676.42546653748,3836.46833181381 1770.70295333862,3835.5267906189 PathPoint;PointKind.SMOOTHPOINT 1621.79074287415,3837.56778001785 1580.07276535034,3838.32379817963 1663.50777626038,3836.81152582169 PathPoint;PointKind.SMOOTHPOINT 1478.81306648254,3836.04465007782 1445.57753562927,3836.72230482101 1512.04891204834,3835.36699533463 PathPoint;PointKind.SMOOTHPOINT 1359.96565818787,3836.04465007782 1311.23462677002,3835.75739622116 1408.69606018066,3836.33213996887 PathPoint;PointKind.SMOOTHPOINT 1238.19519996643,3836.04465007782 1115.43056488037,3835.6854057312 1312.87616729736,3836.26392602921 PathPoint;PointKind.SMOOTHPOINT 1130.73534965515,3835.78524827957 1122.83354759216,3835.83906412125 1129.15391921997,3835.79610586166 PathPoint;PointKind.SMOOTHPOINT 1102.78698921204,3836.04465007782 1044.40592765808,3836.69067621231 1113.80318641663,3835.92285633087 PathPoint;PointKind.SMOOTHPOINT 997.577648162842,3836.04465007782 939.112558364868,3836.4227771759 1056.04242324829,3835.66652297974 PathPoint;PointKind.SMOOTHPOINT 871.010971069336,3834.96266841888 819.920539855957,3835.61695575714 922.10108757019,3834.30908918381 PathPoint;PointKind.SMOOTHPOINT 810.507173538208,3834.96266841888 796.82599067688,3835.00609874725 838.690624237061,3834.873919487 PathPoint;PointKind.SMOOTHPOINT 766.865358352661,3835.99272251129 758.296995162964,3837.08886623383 771.158981323242,3835.44370651245 PathPoint;PointKind.SMOOTHPOINT 733.142023086548,3837.0227766037 727.210006713867,3837.14079380035 738.151302337646,3836.92269802094 PathPoint;PointKind.SMOOTHPOINT 705.328989028931,3836.00948095322 684.662761688232,3834.78328227997 721.790657043457,3836.98689937592 PathPoint;PointKind.SMOOTHPOINT 650.543203353882,3836.00948095322 634.762258529663,3835.45432806015 662.73642539978,3836.43859148026 PathPoint;PointKind.SMOOTHPOINT 617.421598434448,3836.00948095322 592.370796203613,3839.0163230896 636.554861068726,3833.7131023407 PathPoint;PointKind.SMOOTHPOINT 576.000080108643,3833.99988412857 575.747995376587,3833.95598173141 579.922971725464,3834.68580007553 PathPoint;PointKind.SMOOTHPOINT 563.534002304077,3837.0227766037 558.632669448853,3837.5061750412 568.096075057983,3836.57289505005 PathPoint;PointKind.SMOOTHPOINT 543.696727752686,3839.08264875412 536.357002258301,3841.16069555283 547.214269638062,3838.08681964874 PathPoint;PointKind.SMOOTHPOINT 522.187070846558,3839.03520584106 514.272050857544,3839.01136636734 528.13136100769,3839.05267238617 PathPoint;PointKind.SMOOTHPOINT 506.997785568237,3838.05259466171 497.378597259521,3837.28099822998 516.617918014526,3838.82489919662 PathPoint;PointKind.SMOOTHPOINT 490.039501190186,3839.03520584106 470.959424972534,3839.46408033371 509.119262695312,3838.60562324524 PathPoint;PointKind.SMOOTHPOINT 467.745580673218,3835.9393787384 457.071475982666,3836.18367433548 478.419370651245,3835.69531917572 PathPoint;PointKind.SMOOTHPOINT 451.494770050049,3837.0227766037 446.629943847656,3836.4265537262 455.962429046631,3837.57014036179 PathPoint;PointKind.SMOOTHPOINT 426.701402664185,3836.94771766663 426.009349822998,3838.19397926331 426.370639801025,3837.54346847534 PathPoint;PointKind.SMOOTHPOINT 400.868854522705,3837.0227766037 355.428771972656,3834.30271625519 409.963102340698,3837.56707191467 PathPoint;PointKind.SMOOTHPOINT 312.593250274658,3835.99272251129 301.433544158936,3835.1666021347 337.597789764404,3837.84394025803 PathPoint;PointKind.SMOOTHPOINT 275,3835 273.592058056147,3834.80417145584 279.217674692441,3835.58705411634 PathPoint;PointKind.SMOOTHPOINT 271.00005531311,3833.99996471405 269.47779083252,3833.41507148743 271.857332229614,3834.32946872711 PathPoint;PointKind.SMOOTHPOINT 268.064102172852,3832.06353855133 267.35103620237,3829.91621697152 268.427611744389,3833.15785668191 PathPoint;PointKind.SMOOTHPOINT 266.967487335205,3820.54309129715 266.442546844482,3817.63845205307 267.724685668945,3824.73270177841 PathPoint;PointKind.SMOOTHPOINT 265.975513458252,3749.52246665955 265.495576858521,3730.42634010315 266.292114257812,3762.103099823 PathPoint;PointKind.CORNERPOINT 263.059701919556,3569.78864908218 263.059701919556,3569.78864908218 263.059701919556,3569.78864908218 PathPoint;PointKind.CORNERPOINT 263.059701919556,3118.02094459534 263.059701919556,3118.02094459534 263.059701919556,3118.02094459534 PathPoint;PointKind.CORNERPOINT 263.059701919556,2501.88101291656 263.059701919556,2501.88101291656 263.059701919556,2501.88101291656 PathPoint;PointKind.SMOOTHPOINT 264.034051895142,2490.78881263733 264.152383804321,2482.27245569229 263.916034698486,2499.30540561676 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2472.63729572296 262.717609405518,2456.86099290848 263.402423858643,2488.41336250305 PathPoint;PointKind.SMOOTHPOINT 264.034051895142,2447.42740631104 263.600692749023,2439.81553316116 264.245538711548,2451.14471197128 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2386.9228219986 262.893533706665,2360.14259576797 263.233737945557,2414.86386537552 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,2111.62599563599 268.040971755981,2062.30448484421 267.820358276367,2160.94774246216 PathPoint;PointKind.SMOOTHPOINT 265.008401870728,2016.83552742004 264.441289901733,2002.61917591095 265.575199127197,2031.05164289474 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1969.44005727768 266.898880004883,1941.50019407272 267.013750076294,1997.38015651703 PathPoint;PointKind.SMOOTHPOINT 268.905172348022,1915.99431753159 267.45906829834,1898.71353149414 270.350961685181,1933.27510356903 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1882.71653652191 267.037038803101,1870.3674530983 266.876850128174,1895.06585597992 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1857.5061750412 264.441289901733,1844.73978281021 271.420040130615,1870.27327537537 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1823.22076320648 266.773624420166,1804.84430551529 269.087390899658,1841.59651279449 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1760.69902896881 270.148916244507,1730.78544616699 265.711784362793,1790.61261177063 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1659.85781908035 267.438297271729,1653.5049533844 269.286603927612,1677.35103607178 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1620.52976846695 267.356157302856,1598.95929336548 266.556787490845,1642.10024356842 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1515.65473079681 265.792036056519,1494.41139936447 268.120908737183,1536.89853429794 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1406.74657344818 268.368902206421,1380.29537916183 267.493371963501,1433.19753170013 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1316.99803590775 267.037038803101,1293.44982862473 268.825550079346,1340.54577112198 PathPoint;PointKind.SMOOTHPOINT 267.463788986206,1237.72258043289 267.475433349609,1233.00496101379 267.433261871338,1250.25647878647 PathPoint;PointKind.SMOOTHPOINT 265.008401870728,1222.20709562302 265.076694488525,1220.32306909561 264.925003051758,1224.51008319855 PathPoint;PointKind.SMOOTHPOINT 265.982437133789,1208.08964252472 266.941995620728,1204.36478376389 265.125160217285,1211.41536712646 PathPoint;PointKind.SMOOTHPOINT 267.463788986206,1197.70932197571 268.254976272583,1175.45717954636 267.284717559814,1202.7411031723 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1165.73610305786 266.344985961914,1157.13028907776 268.127517700195,1182.22711801529 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1119.3496799469 268.605251312256,1098.89210700989 267.242546081543,1140.22456169128 PathPoint;PointKind.SMOOTHPOINT 267.463788986206,1084.8518371582 267.30076789856,1068.64996433258 267.605409622192,1098.8670873642 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1033.63426208496 267.063159942627,1013.82861614227 268.798484802246,1053.43990802765 PathPoint;PointKind.SMOOTHPOINT 268.905172348022,978.171844482422 268.96559715271,955.608608722687 268.844118118286,1000.73508024216 PathPoint;PointKind.SMOOTHPOINT 269.879522323608,904.557673931122 270.76229095459,876.014978885651 268.996124267578,933.100368976593 PathPoint;PointKind.SMOOTHPOINT 269.879522323608,822.876791954041 270.773305892944,795.413010120392 268.985109329224,850.339865684509 PathPoint;PointKind.SMOOTHPOINT 266.885976791382,756.321229934692 268.366069793701,731.27632856369 265.405254364014,781.366131305695 PathPoint;PointKind.SMOOTHPOINT 266.885976791382,700.858340263367 266.322641372681,676.48330450058 267.448997497559,725.233612060547 PathPoint;PointKind.SMOOTHPOINT 266.471815109253,650.862951278687 266.099195480347,634.157145023346 266.845064163208,667.568757534027 PathPoint;PointKind.SMOOTHPOINT 266.471815109253,625.213329792023 267.104072570801,619.087529182434 265.839557647705,631.339838504791 PathPoint;PointKind.SMOOTHPOINT 265.480155944824,600.58974981308 265.597858428955,584.026980400085 265.36434173584,616.879427433014 PathPoint;PointKind.SMOOTHPOINT 265.480155944824,555.447227954865 264.890069961548,531.981868743896 266.069927215576,578.912115097046 PathPoint;PointKind.SMOOTHPOINT 266.471815109253,528.77156496048 265.944356918335,521.847496032715 266.947031021118,535.005941390991 PathPoint;PointKind.SMOOTHPOINT 265.91194152832,508.252151012421 264.619417190552,500.21045923233 267.26300239563,516.662528514862 PathPoint;PointKind.SMOOTHPOINT 264.937591552734,473.966031074524 265.228385925293,458.305621147156 264.637041091919,490.157990455627 PathPoint;PointKind.SMOOTHPOINT 264.937591552734,440.68825006485 263.813123703003,410.140914916992 265.333499908447,451.439144611359 PathPoint;PointKind.SMOOTHPOINT 264.983854293823,381.486339569092 264.691801071167,352.564573287964 265.327205657959,415.594017505646 PathPoint;PointKind.SMOOTHPOINT 264.983854293823,283.638045787811 264.694633483887,252.309200763702 265.260801315308,313.752493858337 PathPoint;PointKind.SMOOTHPOINT 263,180 262.768686294556,167.756187915802 263.332336425781,197.616662979126 PathPoint;PointKind.SMOOTHPOINT 263.000061035156,143.999940395355 262.97341487785,139.15961792289 263.049510300326,152.982488486736 PathPoint";
	
	mask645[2] = "PointKind.SMOOTHPOINT 268.000053405762,124.000115871429 268.835615158081,122.95991230011 267.268346786499,124.910972595215 PathPoint;PointKind.SMOOTHPOINT 272.909960764809,122.812106582102 282.133458231093,121.129797721932 269.937899289433,123.354192203231 PathPoint;PointKind.SMOOTHPOINT 351.776847839355,122.499961853027 458.852602243441,121.198387039136 321.362377760691,122.869669341455 PathPoint;PointKind.SMOOTHPOINT 774.080142974854,120.726635456085 775.587930679321,120.719082355499 549.821662902832,121.869041919708 PathPoint;PointKind.SMOOTHPOINT 777.999887466431,122.000041007996 779.228210449219,120.67777633667 776.978645324707,123.099253177643 PathPoint;PointKind.SMOOTHPOINT 783.174390792847,120.68060874939 847.476768493652,120.356061458588 781.651182174683,120.688161849976 PathPoint;PointKind.SMOOTHPOINT 942.050399780273,120.013339519501 977.48514175415,119.930963516235 904.430923461914,120.101380348206 PathPoint;PointKind.SMOOTHPOINT 1493.42516899109,121.021914482117 1505.1003742218,120.809483528137 1481.75090789795,121.235053539276 PathPoint;PointKind.SMOOTHPOINT 1535.31435012817,125.055742263794 1537.27721214294,125.088315010071 1524.25755500793,124.872107505798 PathPoint;PointKind.SMOOTHPOINT 1542.00010299683,122.999882698059 1545.41662216187,122.392330169678 1540.10805130005,123.33646774292 PathPoint;PointKind.SMOOTHPOINT 1563.56514930725,122.030725479126 1567.49339103699,121.969592571259 1558.16310882568,122.114045619965 PathPoint;PointKind.SMOOTHPOINT 1580.12563705444,124.047403335571 1584.10989761353,125.138354301453 1574.52501296997,122.513179779053 PathPoint;PointKind.SMOOTHPOINT 1605.45401573181,126.064081192017 1620.9303188324,126.016874313354 1594.56464767456,126.097362041473 PathPoint;PointKind.SMOOTHPOINT 1849.82640266418,123.994767665863 1861.04023933411,124.495160579681 1838.61225128174,123.494610786438 PathPoint;PointKind.CORNERPOINT 1876.99994087219,123.999960422516 1876.99994087219,123.999960422516 1876.99994087219,123.999960422516 PathPoint;PointKind.SMOOTHPOINT 1887.81849861145,125.002870559692 1889.32691574097,125.1296210289 1881.97176933289,124.512155056 PathPoint;PointKind.SMOOTHPOINT 1895.62934875488,122.827577590942 1900.45640945435,122.628128528595 1889.49465751648,123.081314563751 PathPoint;PointKind.SMOOTHPOINT 1908.27638626099,123.994767665863 1919.90501403809,125.0661277771 1896.64681434631,122.92293548584 PathPoint;PointKind.SMOOTHPOINT 1962.82896995544,123.994767665863 1971.7797088623,123.915696144104 1953.87917518616,124.073367118835 PathPoint;PointKind.SMOOTHPOINT 2007.64057159424,123.994767665863 2021.55999183655,123.872737884521 1993.72052192688,124.116797447205 PathPoint;PointKind.SMOOTHPOINT 2057.32297897339,123.994767665863 1871.78074836731,123.831195831299 2043.05737495422,123.982021808624 PathPoint;PointKind.SMOOTHPOINT 2559.10408973694,122.951023578644 2580.01768112183,122.731511592865 2425.81295013428,124.348583221436 PathPoint;PointKind.SMOOTHPOINT 2609.7611618042,121.942684650421 2617.64911651611,121.53694152832 2601.87257766724,122.348427772522 PathPoint;PointKind.SMOOTHPOINT 2638.01164627075,122.951023578644 2647.73468971252,122.619867324829 2628.28923225403,123.281707763672 PathPoint;PointKind.SMOOTHPOINT 2695.48727989197,122.951023578644 2703.01803588867,122.856137752533 2687.95620918274,123.045201301575 PathPoint;PointKind.SMOOTHPOINT 2713.99615287781,122.951023578644 2723.03784370422,123.317348957062 2704.95446205139,122.584698200226 PathPoint;PointKind.SMOOTHPOINT 2755.88533401489,123.95959854126 2774.1811466217,124.479582309723 2737.58952140808,123.439614772797 PathPoint;PointKind.SMOOTHPOINT 2796.80016517639,123.95959854126 2804.36868667603,123.805940151215 2789.23101425171,124.113020896912 PathPoint;PointKind.SMOOTHPOINT 2818.23145866394,121.942684650421 2832.2739315033,121.617193222046 2807.72572517395,122.186036109924 PathPoint;PointKind.SMOOTHPOINT 2850.37902832031,122.951023578644 2855.42072296143,123.15967798233 2845.33670425415,122.741897106171 PathPoint;PointKind.SMOOTHPOINT 2863.18940162659,122.538907527924 2869.56799507141,122.011370658875 2856.16250038147,123.119788169861 PathPoint;PointKind.SMOOTHPOINT 2879.6032333374,123.95959854126 2882.21282958984,124.183595180511 2875.94470024109,123.64520072937 PathPoint;PointKind.SMOOTHPOINT 2897.13838577271,122.951023578644 2900.0658416748,122.396814823151 2890.09763717651,124.284617900848 PathPoint;PointKind.SMOOTHPOINT 2904.32704925537,121.88273191452 2912.25276947021,121.155745983124 2900.55459022522,122.2292304039 PathPoint;PointKind.SMOOTHPOINT 2915.64788818359,123.95959854126 2922.96149253845,124.129071235657 2908.33365440369,123.789889812469 PathPoint;PointKind.SMOOTHPOINT 2951.69159889221,122.951023578644 2961.78694725037,123.301298618317 2941.59562110901,122.600512504578 PathPoint;PointKind.SMOOTHPOINT 2980.91611862183,122.951023578644 2997.61004447937,122.773761749268 2964.22250747681,123.12828540802 PathPoint;PointKind.SMOOTHPOINT 3556.6987323761,129.089334011078 3589.24567222595,130.042912960052 3524.15179252625,128.135755062103 PathPoint;PointKind.SMOOTHPOINT 3657.01932907104,126.011209487915 3661.64340019226,126.286897659302 3639.02658462524,124.938433170319 PathPoint;PointKind.SMOOTHPOINT 3672.6060962677,128.028123378754 3681.72552108765,128.829696178436 3667.80893325806,127.606801986694 PathPoint;PointKind.SMOOTHPOINT 3715.46931266785,126.011209487915 3719.39944267273,126.000115871429 3713.29087257385,126.017582416534 PathPoint;PointKind.SMOOTHPOINT 3726.1846446991,128.028123378754 3729.75946426392,128.053615093231 3719.08284187317,127.977139949799 PathPoint;PointKind.SMOOTHPOINT 3740.83262443542,129.067618846893 3742.09493637085,129.042599201202 3733.01894187927,129.221749305725 PathPoint;PointKind.SMOOTHPOINT 3747.65181541443,128.016085624695 3749.54669952393,127.323560714722 3745.50830841064,128.800427913666 PathPoint;PointKind.SMOOTHPOINT 3751.54890060425,128.016085624695 3758.28123092651,128.096573352814 3750.70924758911,128.006408214569 PathPoint;PointKind.SMOOTHPOINT 3770.22205352783,129.092638492584 3788.5122013092,128.026707172394 3764.803647995,129.408452510834 PathPoint;PointKind.SMOOTHPOINT 3797.31659889221,127.072656154633 3804.56757545471,127.576825618744 3798.51817131042,127.156212329865 PathPoint;PointKind.SMOOTHPOINT 3807.05852508545,128.080995082855 3821.28730773926,129.07021522522 3801.94476127625,127.725291252136 PathPoint;PointKind.SMOOTHPOINT 3824.77432250977,126.002712249756 3826.24277114868,125.964710712433 3815.19164085388,126.248896121979 PathPoint;PointKind.SMOOTHPOINT 3832.38627433777,127.072656154633 3838.16282272339,127.319076061249 3828.49674224854,126.906723976135 PathPoint;PointKind.SMOOTHPOINT 3844.00011062622,126.999957561493 3851.38515472412,127.568328380585 3842.86053657532,126.912388801575 PathPoint;PointKind.SMOOTHPOINT 3862.58545875549,127.072656154633 3870.61849594116,126.604127883911 3854.55242156982,127.541184425354 PathPoint;PointKind.SMOOTHPOINT 3882.06868171692,127.072656154633 3893.49998474121,128.009948730469 3870.63769340515,126.134655475616 PathPoint;PointKind.SMOOTHPOINT 3906.42239570618,128.080995082855 3913.43576431274,128.112387657166 3899.40934181213,128.049366474152 PathPoint;PointKind.SMOOTHPOINT 3924.00003433228,126.000115871429 3935.03385543823,125.028834342957 3908.71507644653,127.345039844513 PathPoint;PointKind.SMOOTHPOINT 3937.59593009949,128.080995082855 3947.72904396057,127.730247974396 3931.0643863678,128.306879997253 PathPoint;PointKind.CORNERPOINT 3956.10480308533,127.072656154633 3956.10480308533,127.072656154633 3956.10480308533,127.072656154633 PathPoint;PointKind.SMOOTHPOINT 3966.82107925415,125.055742263794 3974.31721687317,124.390125274658 3959.32399749756,125.721595287323 PathPoint;PointKind.SMOOTHPOINT 3980.45883178711,126.064081192017 3988.22027206421,126.013569831848 3970.112657547,126.131114959717 PathPoint;PointKind.SMOOTHPOINT 3994.09721374512,125.055742263794 3995.74284553528,124.745357036591 3989.15622711182,125.987370014191 PathPoint;PointKind.SMOOTHPOINT 3999.94205474854,123.038828372955 4008.03960800171,122.624588012695 3996.59634590149,123.210189342499 PathPoint;PointKind.SMOOTHPOINT 4013.58075141907,125.055742263794 4016.29986763,125.491461753845 4009.42025184631,124.389181137085 PathPoint;PointKind.SMOOTHPOINT 4026.24446868896,125.055742263794 4038.56609344482,125.78839302063 4021.37366294861,124.765892028809 PathPoint;PointKind.SMOOTHPOINT 4059.36638832092,126.064081192017 4066.95127487183,126.146457195282 4041.26034736633,125.867228507996 PathPoint;PointKind.SMOOTHPOINT 4082.74606704712,125.055742263794 4084.61829185486,124.839062690735 4075.01672744751,125.950076580048 PathPoint;PointKind.SMOOTHPOINT 4102.22929000854,125.055742263794 4105.21339416504,125.522854328156 4095.69050788879,124.032533168793 PathPoint;PointKind.SMOOTHPOINT 4110.99655151367,125.055742263794 4126.17985725403,124.720809459686 4107.99073219299,125.121831893921 PathPoint;PointKind.SMOOTHPOINT 4154.07251358032,127.033002376556 4163.11200141907,126.871790885925 4139.69959259033,127.288863658905 PathPoint;PointKind.SMOOTHPOINT 4178.21442604065,126.895394325256 4178.72803688049,126.860933303833 4170.60121536255,127.40688085556 PathPoint;PointKind.SMOOTHPOINT 4184.05863761902,126.064081192017 4186.96846961975,125.875017642975 4182.91686058044,126.138432025909 PathPoint;PointKind.SMOOTHPOINT 4191.85154914856,126.064081192017 4204.47813034058,125.449447631836 4188.82338523865,126.211366653442 PathPoint;PointKind.SMOOTHPOINT 4216.20557785034,127.072656154633 4222.87968635559,127.122695446014 4206.2134552002,126.997833251953 PathPoint;PointKind.SMOOTHPOINT 4235.68943023682,125.055742263794 4240.02774238586,124.161643981934 4229.81122970581,126.267778873444 PathPoint;PointKind.SMOOTHPOINT 4255.17233848572,123.038828372955 4257.1147441864,123.404681682587 4245.63875198364,121.244022846222 PathPoint;PointKind.SMOOTHPOINT 4260.04282951355,125.055742263794 4265.81182479858,126.688392162323 4258.16305160522,124.523484706879 PathPoint;PointKind.SMOOTHPOINT 4274.65587615967,125.055742263794 4286.84752464294,125.051729679108 4268.37610244751,125.05763053894 PathPoint;PointKind.SMOOTHPOINT 4291.21636390686,124.047403335571 4301.72650337219,123.767702579498 4280.705909729,124.327104091644 PathPoint;PointKind.SMOOTHPOINT 4307.81084060669,127.033002376556 4309.88920211792,126.95912361145 4298.72760772705,127.356133460999 PathPoint;PointKind.SMOOTHPOINT 4315.57070732117,127.072656154633 4317.60154724121,126.911680698395 4313.07126045227,127.270925045013 PathPoint;PointKind.SMOOTHPOINT 4322.38958358765,127.072656154633 4323.06999206543,127.052357196808 4320.02326011658,127.141814231873 PathPoint;PointKind.SMOOTHPOINT 4324.33765411377,125.055742263794 4325.4221534729,124.953775405884 4323.58297348022,125.126316547394 PathPoint;PointKind.SMOOTHPOINT 4331.1571598053,125.055742263794 4332.53308296204,125.489809513092 4329.26259040833,124.458339214325 PathPoint;PointKind.SMOOTHPOINT 4333.10523033142,127.072656154633 4335.15086174011,127.10381269455 4331.93607330322,127.054953575134 PathPoint;PointKind.SMOOTHPOINT 4338.95070075989,125.055742263794 4341.38437271118,124.545435905457 4336.62906646729,125.542209148407 PathPoint;PointKind.SMOOTHPOINT 4348.69199752808,125.055742263794 4352.0890045166,125.012075901031 4344.70364570618,125.106961727142 PathPoint;PointKind.SMOOTHPOINT 4358.43360900879,123.038828372955 4369.12030220032,122.987844944 4354.94627952576,123.05558681488 PathPoint;PointKind.SMOOTHPOINT 4381.81360244751,123.038828372955 4383.14735412598,123.086271286011 4370.9981918335,122.653148174286 PathPoint;PointKind.SMOOTHPOINT 4386.68440818787,125.055742263794 4409.4780921936,125.959045886993 4385.30250549316,125.000746250153 PathPoint;PointKind.SMOOTHPOINT 4447.08183288574,125.055742263794 4447.3584651947,125.058810710907 4433.42645645142,124.89004611969 PathPoint;PointKind.SMOOTHPOINT 4463.64295005798,123.038828372955 4466.56096458435,124.299252033234 4469.86104011536,125.724427700043 PathPoint;PointKind.SMOOTHPOINT 4471.92649841309,125.539140701294 4473.00061225891,125.415930747986 4468.6279964447,125.917267799377 PathPoint;PointKind.SMOOTHPOINT 4478.25536727905,123.038828372955 4483.51389884949,122.836782932281 4475.71563720703,123.136310577393 PathPoint;PointKind.SMOOTHPOINT 4493.84181976318,125.055742263794 4500.90648651123,125.361170768738 4490.03914833069,124.890990257263 PathPoint;PointKind.SMOOTHPOINT 4512.35100746155,124.047403335571 4515.81253051758,123.848190307617 4501.35778427124,124.67973947525 PathPoint;PointKind.SMOOTHPOINT 4526.96342468262,124.047403335571 4541.92359924316,124.117269515991 4520.70693969727,124.017899036407 PathPoint;PointKind.SMOOTHPOINT 4566.33962631226,123.85055065155 4567.60760307312,123.843941688538 4552.65624046326,123.923721313477 PathPoint;PointKind.SMOOTHPOINT 4571.77471160889,123.038828372955 4575.3545665741,123.026790618896 4570.45040130615,123.043076992035 PathPoint;PointKind.SMOOTHPOINT 4579.56793785095,123.038828372955 4580.26534080505,123.041188716888 4575.42191505432,123.025138378143 PathPoint;PointKind.SMOOTHPOINT 4581.5163230896,124.047403335571 4582.31663703918,124.066994190216 4580.75629234314,124.028520584106 PathPoint;PointKind.SMOOTHPOINT 4583.46470832825,123.038828372955 4586.51647567749,123.067152500153 4582.59924888611,123.030803203583 PathPoint;PointKind.SMOOTHPOINT 4593.20631980896,123.038828372955 4596.96178436279,123.273682594299 4589.54558372498,122.809638977051 PathPoint;PointKind.SMOOTHPOINT 4604.89663124084,124.047403335571 4643.47094535828,124.606568813324 4601.35296821594,123.996183872223 PathPoint;PointKind.SMOOTHPOINT 4654.57840919495,125.055742263794 4670.04715919495,125.402240753174 4639.10965919495,124.709007740021 PathPoint;PointKind.SMOOTHPOINT 4684.7779083252,124.047403335571 4698.14186096191,124.385876655579 4671.41332626343,123.708693981171 PathPoint;PointKind.SMOOTHPOINT 4713.02807807922,124.047403335571 4731.65905952454,123.645672798157 4694.39678192139,124.449133872986 PathPoint;PointKind.SMOOTHPOINT 4743.22694778442,125.055742263794 4763.74935150146,125.410265922546 4722.70485877991,124.701218605042 PathPoint;PointKind.SMOOTHPOINT 4787.06451416016,125.055742263794 4821.35433197021,124.161643981934 4752.7746963501,125.949840545654 PathPoint;PointKind.SMOOTHPOINT 4853.30772399902,125.055742263794 4884.95427131653,124.877536296844 4828.81994247437,125.193586349487 PathPoint;PointKind.SMOOTHPOINT 4896.09981536865,126.042366027832 4903.9972114563,126.226944923401 4903.91223907471,126.225056648254 PathPoint;PointKind.SMOOTHPOINT 4908.76321792603,126.042366027832 4913.43386650085,124.51073884964 4905.29697418213,127.179815769196 PathPoint;PointKind.SMOOTHPOINT 4933.18868637085,125.055742263794 4947.07223670003,125.203141846708 4925.51950379284,124.974319696332 PathPoint;PointKind.SMOOTHPOINT 4997.88083728688,124.729351330671 5001.94210596518,124.982127568347 4980.86321986912,123.670162775119 PathPoint;PointKind.SMOOTHPOINT 5012,127 5014.05570220947,128.463649272919 5010.54508399963,125.96404504776 PathPoint;PointKind.SMOOTHPOINT 5014,142 5014.53722824855,157.135821517862 5013.83594514288,137.37518050021 PathPoint;PointKind.SMOOTHPOINT 5015.81520462036,182.006828784943 5015.69939041138,184.76583480835 5016.00560569763,177.47142791748 PathPoint;PointKind.SMOOTHPOINT 5016,258 5015.677734375,277.239871501923 5016.16333580017,248.213778018951 PathPoint;PointKind.SMOOTHPOINT 5015.99238395691,396.31826877594 5015.93132972717,414.036426544189 5016.05312347412,378.60011100769 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,910.608179569244 5015.4211807251,928.02657365799 5012.6665019989,893.189313411713 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,969.095849990845 5014.18876647949,981.669402122498 5013.89923095703,956.522297859192 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1059.8529624939 5014.94596481323,1073.43107700348 5015.09041786194,1046.27508401871 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1235.31691789627 5014.29891586304,1242.43453502655 5013.78876686096,1228.19859266281 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1255.48487663269 5015.00292778015,1267.94418811798 5015.0331401825,1243.02532911301 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1299.8548579216 5013.60277175903,1332.81729698181 5014.48585510254,1266.89265489578 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1522.71381139755 5015.32991409302,1536.60278320312 5014.70615386963,1508.82436752319 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1586.24364852905 5014.05627250671,1595.79950094223 5014.01756286621,1565.80000162125 PathPoint;PointKind.SMOOTHPOINT 5015.0281047821,1626.28664731979 5015.06083488464,1627.4297618866 5014.60450172424,1611.49673223495 PathPoint;PointKind.SMOOTHPOINT 5015.123462677,1629.69640016556 5014.73353385925,1631.51268482208 5015.36075592041,1628.5938835144 PathPoint;PointKind.SMOOTHPOINT 5015.21693229675,1633.1915974617 5015.57822227478,1647.25712299347 5015.18703460693,1632.03833341599 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1662.88307189941 5013.48821640015,1670.52492141724 5015.71984291077,1659.37654495239 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1681.03435277939 5014.63786125183,1688.55039596558 5015.39883613586,1673.51878166199 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1697.16919183731 5015.48601150513,1703.64101886749 5014.55005645752,1690.69736480713 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1718.34548950195 5015.23487091064,1729.76506948471 5014.801197052,1706.92638158798 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1769.7745513916 5014.16170120239,1791.51072263718 5015.87405204773,1748.03885221481 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1844.39729690552 5015.21598815918,1859.86227035522 5014.81976509094,1828.93232345581 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1877.67460584641 5015.75257301331,1902.4832367897 5012.33542442322,1852.8662109375 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1950.28067350388 5015.3645324707,1967.93156147003 5014.67185020447,1932.62907743454 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1999.69258546829 5015.06744384766,2004.47818279266 5014.8849105835,1986.78386449814 PathPoint;PointKind.SMOOTHPOINT 5014.43424224854,2013.62782001495 5013.82684707642,2021.25645160675 5014.79301452637,2009.13325309753 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2035.99514722824 5014.18876647949,2046.42574310303 5013.95304679871,2029.43197488785 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2090.44946193695 5015.32991409302,2117.18035697937 5014.70615386963,2063.71856689453 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2219.52628612518 5014.04777526855,2250.79871892929 5015.98860740662,2188.25338125229 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2300.19930124283 5014.40937995911,2315.60503005981 5015.62700271606,2284.79310035706 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2375.82991361618 5014.00528907776,2377.12149381638 5014.57680702209,2357.95809745789 PathPoint;PointKind.SMOOTHPOINT 5013.0699634552,2380.87208032608 5013.02370071411,2386.63816452026 5013.13322067261,2372.95997142792 PathPoint;PointKind.SMOOTHPOINT 5013.81488800049,2386.38183116913 5014.38829421997,2410.43113946915 5013.79380226135,2385.51322460175 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2471.62895679474 5015.01048088074,2490.96206188202 5013.22291374207,2455.20285129547 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2549.27695512772 5014.39395904541,2572.76544570923 5013.69372367859,2525.78752040863 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2618.85682582855 5015.69151878357,2640.83705663681 5014.3448638916,2596.87683105469 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2693.47957134247 5013.77366065979,2726.73728942871 5014.31402206421,2660.22138118744 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2757.00940847397 5014.39805030823,2773.1791806221 5013.6899471283,2740.83940029144 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2818.52233171463 5014.82763290405,2846.31278514862 5015.20843505859,2790.73211431503 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2890.11982440948 5014.99380111694,2907.11076021194 5015.0422668457,2873.04297208786 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2938.52316141129 5013.4992313385,2949.16760444641 5014.56390380859,2928.36046457291 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2981.88503980637 5014.65989112854,2994.51783657074 5015.37617683411,2969.25224304199 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3014.15424585342 5014.45721626282,3021.80388450623 5013.46555709839,3003.45575094223 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3058.52446317673 5015.12723922729,3065.35789489746 5014.74328994751,3041.38104915619 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3076.67550802231 5015.53479194641,3094.37643527985 5014.85816001892,3071.1926651001 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3094.82726097107 5013.96028518677,3104.2259144783 5014.12771224976,3085.42860746384 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3132.13816165924 5014.38262939453,3145.77174425125 5013.70505332947,3118.50528717041 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3183.56745958328 5013.75855445862,3196.04966640472 5014.31087493896,3171.88729763031 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3213.8197517395 5014.13558006287,3222.27780818939 5013.93699645996,3203.94053220749 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3254.15590524673 5014.1450214386,3256.40908956528 5013.44258308411,3240.74608325958 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3262.22356081009 5015.20277023315,3264.48760271072 5014.87421035767,3260.4589676857 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3267.26572751999 5014.01630401611,3274.74730968475 5014.05029296875,3265.57218074799 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3291.46751403809 5014.43581581116,3306.79440736771 5013.72488021851,3278.9692568779 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3328.77865076065 5014.58058357239,3338.70908975601 5013.50741386414,3318.8479757309 PathPoint;PointKind.SMOOTHPOINT 5013.0699634552,3345.9218287468 5014.32188987732,3355.10781526566 5011.81803703308,3336.73560619354 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3374.15744304657 5013.96343231201,3385.86262464523 5014.12047386169,3363.04423570633 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3392.30872392654 5016.06067657471,3397.72075653076 5013.97539138794,3386.89645528793 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3409.4516658783 5014.7212600708,3414.90736484528 5015.31480789185,3403.99573087692 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3429.61986064911 5013.537940979,3442.91449785233 5016.49875640869,3416.3249874115 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3447.77114152908 5013.91087532043,3465.22564888 5014.17743682861,3430.31710624695 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3493.149933815 5014.62244033813,3512.38414049149 5015.41362762451,3473.91501903534 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3569.78864908218 5014.20733451843,3600.23047685623 5013.88066291809,3539.34752941132 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3628.27655553818 5013.58735084534,3640.89778661728 5014.50096130371,3615.65603256226 PathPoint;PointKind.SMOOTHPOINT 5012.09592819214,3654.49549198151 5011.73212051392,3671.87800884247 5012.43865013123,3638.09511423111 PathPoint;PointKind.SMOOTHPOINT 5013.30348014832,3698.84989500046 5013.14769744873,3721.88968420029 5013.4592628479,3675.80986976624 PathPoint;PointKind.SMOOTHPOINT 5014.98247146606,3777.50410795212 5015.43125152588,3794.13863182068 5014.53369140625,3760.86934804916 PathPoint;PointKind.SMOOTHPOINT 5014.79112625122,3806.78818702698 5014.156665802,3811.96442127228 5015.90646743774,3797.6841044426 PathPoint;PointKind.SMOOTHPOINT 5013.71245002747,3830.0483546257 5013.41894772878,3832.04034139053 5014.37047775086,3825.58155430334 PathPoint;PointKind.SMOOTHPOINT 5010.99994277954,3832.99996471405 5010.48318481445,3833.22820997238 5012.204662323,3832.46817922592 PathPoint;PointKind.SMOOTHPOINT 5008.64148712158,3834.51152896881 4998.67622971796,3835.20385442456 5009.72557674143,3834.43624002929 PathPoint;PointKind.SMOOTHPOINT 4943.59434127808,3834.96266841888 4925.44298171997,3837.12946414948 4947.43131637573,3834.50452566147 PathPoint;PointKind.SMOOTHPOINT 4791.89975738525,3834.94850635529 4777.61841773987,3836.81955099106 4806.18109703064,3833.07746171951 PathPoint;PointKind.SMOOTHPOINT 4642.06827163696,3834.96266841888 4619.8143196106,3835.59996128082 4666.39429092407,3834.26565885544 PathPoint;PointKind.SMOOTHPOINT 4479.22940254211,3838.02639484406 4450.48418998718,3838.79869937897 4507.97524452209,3837.25409030914 PathPoint;PointKind.SMOOTHPOINT 4394.47763442993,3838.02639484406 4380.27969360352,3838.94409656525 4408.67526054382,3837.10892915726 PathPoint;PointKind.SMOOTHPOINT 4360.38167953491,3838.02639484406 4351.58546447754,3837.87580490112 4370.29858589172,3838.19563150406 PathPoint;PointKind.SMOOTHPOINT 4328.23410987854,3838.02639484406 4326.97305679321,3837.99051761627 4338.13559532166,3838.30656766891 PathPoint;PointKind.SMOOTHPOINT 4320.441198349,3838.02639484406 4311.21697425842,3838.46754312515 4321.48352622986,3837.97659158707 PathPoint;PointKind.SMOOTHPOINT 4294.13878440857,3838.02639484406 4288.12462806702,3838.26998233795 4304.51674461365,3837.60601758957 PathPoint;PointKind.SMOOTHPOINT 4270.42267799377,3838.24024200439 4269.26170349121,3838.23363304138 4280.10543823242,3838.2966542244 PathPoint;PointKind.SMOOTHPOINT 4266.86800003052,3838.21663856506 4265.94431877136,3837.58689880371 4268.47806930542,3839.31514263153 PathPoint;PointKind.SMOOTHPOINT 4263.49270820618,3838.19020271301 4257.90907859802,3838.14346790314 4264.63668823242,3838.19964408875 PathPoint;PointKind.SMOOTHPOINT 4245.43135643005,3838.02639484406 4224.4988822937,3837.84535646439 4251.87100410461,3838.08209896088 PathPoint;PointKind.SMOOTHPOINT 4197.69733428955,3838.02639484406 4176.57005310059,3837.28973150253 4218.82430076599,3838.76329421997 PathPoint;PointKind.SMOOTHPOINT 4156.78218841553,3838.02639484406 4149.46669578552,3838.2999587059 4175.53087234497,3837.32513666153 PathPoint;PointKind.SMOOTHPOINT 4140.22138595581,3838.02639484406 4135.36096572876,3838.33111524582 4143.33137512207,3837.83119440079 PathPoint;PointKind.SMOOTHPOINT 4126.5830039978,3839.03520584106 4112.83101081848,3838.74724388123 4134.96977806091,3839.21010732651 PathPoint;PointKind.SMOOTHPOINT 4098.33251953125,3838.02639484406 4079.22978401184,3837.83331871033 4117.43525505066,3838.21923494339 PathPoint;PointKind.SMOOTHPOINT 4051.57253265381,3838.02639484406 4019.43975448608,3838.47202777863 4083.69272232056,3837.58076190948 PathPoint;PointKind.SMOOTHPOINT 3960.97529411316,3838.02639484406 3903.43357086182,3838.2119178772 4018.61646652222,3837.84039974213 PathPoint;PointKind.SMOOTHPOINT 3856.73998832703,3838.02639484406 3833.09783935547,3837.50239849091 3880.38308143616,3838.5506272316 PathPoint;PointKind.SMOOTHPOINT 3799.26529884338,3838.02639484406 3784.39387321472,3838.04999828339 3814.136095047,3838.00279140472 PathPoint;PointKind.SMOOTHPOINT 3773.93692016602,3838.02639484406 3759.14920806885,3838.04220914841 3788.72431755066,3838.0105805397 PathPoint;PointKind.SMOOTHPOINT 3746.65984153748,3839.03520584106 3734.01909828186,3838.81404161453 3759.30184364319,3839.25542593002 PathPoint;PointKind.SMOOTHPOINT 3713.53918075562,3839.03520584106 3703.13541412354,3839.62552785873 3723.94231796265,3838.44370365143 PathPoint;PointKind.SMOOTHPOINT 3670.67564964294,3839.03520584106 3636.77198410034,3839.13646459579 3704.4987487793,3838.93347501755 PathPoint;PointKind.SMOOTHPOINT 3564.49195861816,3839.03520584106 3541.28631591797,3838.63984823227 3588.78241539001,3839.44826602936 PathPoint;PointKind.SMOOTHPOINT 3473.89534950256,3839.03520584106 3438.04518699646,3839.11545753479 3509.57588195801,3838.95448207855 PathPoint;PointKind.SMOOTHPOINT 3328.74489784241,3839.03520584106 3311.09991073608,3839.15298700333 3346.39051437378,3838.91671657562 PathPoint;PointKind.SMOOTHPOINT 3262.50200271606,3839.03520584106 3242.69305229187,3838.74700784683 3293.15783500671,3839.48013067245 PathPoint;PointKind.SMOOTHPOINT 3190.4142665863,3839.03520584106 3188.68145942688,3839.0479516983 3201.74737930298,3838.94905328751 PathPoint;PointKind.SMOOTHPOINT 3184.56942558289,3839.03520584106 3183.84684562683,3839.52002048492 3186.29530906677,3837.87509679794 PathPoint;PointKind.SMOOTHPOINT 3178.88382911682,3839.11215305328 3170.36267280579,3839.72702264786 3180.34850120544,3839.00664567947 PathPoint;PointKind.SMOOTHPOINT 3153.39589118958,3839.03520584106 3116.10843658447,3838.72033596039 3161.79903030396,3839.10578012466 PathPoint;PointKind.SMOOTHPOINT 3070.59250831604,3839.03520584106 3052.42572784424,3839.13717269897 3088.75897407532,3838.93253087997 PathPoint;PointKind.SMOOTHPOINT 3026.75462722778,3839.03520584106 2998.6262512207,3839.21624422073 3054.88426208496,3838.85369539261 PathPoint;PointKind.SMOOTHPOINT 2922.52026557922,3839.03520584106 2919.7665309906,3839.11050081253 2957.04957962036,3838.08941602707 PathPoint;PointKind.SMOOTHPOINT 2914.25622940063,3839.21530008316 2913.69069099426,3839.22474145889 2917.01405525208,3839.16974544525 PathPoint;PointKind.SMOOTHPOINT 2911.80430412292,3839.03520584106 2910.97503662109,3839.04724359512 2912.37078666687,3839.0269446373 PathPoint;PointKind.SMOOTHPOINT 2909.85560417175,3838.02639484406 2908.7166595459,3838.77179145813 2911.41091346741,3837.00885057449 PathPoint;PointKind.SMOOTHPOINT 2906.01957321167,3839.31301832199 2905.45120239258,3839.31726694107 2907.37157821655,3839.30263280869 PathPoint;PointKind.SMOOTHPOINT 2904.31257247925,3839.32434797287 2875.59851646423,3839.49311256409 2904.88220214844,3839.32127952576 PathPoint;PointKind.SMOOTHPOINT 2808.54303359985,3839.03520584106 2763.50735664368,3839.6727347374 2845.68383216858,3838.50884914398 PathPoint;PointKind.SMOOTHPOINT 2607.86596298218,3838.02639484406 2562.05011367798,3837.81774044037 2653.68181228638,3838.23504924774 PathPoint;PointKind.SMOOTHPOINT 2465.63824653625,3838.02639484406 2424.20571327209,3839.77540969849 2507.07077980042,3836.27761602402 PathPoint;PointKind.SMOOTHPOINT 2382.8345489502,3837.01781988144 2337.68463134766,3837.74291753769 2427.98478126526,3836.29319429398 PathPoint;PointKind.SMOOTHPOINT 2281.52166366577,3838.02639484406 2260.25276184082,3838.16329479218 2328.58975410461,3837.72309064865 PathPoint;PointKind.SMOOTHPOINT 2245.16984939575,3838.45267295837 2243.23279380798,3838.47627639771 2252.67637252808,3838.36061954498 PathPoint;PointKind.SMOOTHPOINT 2238.99991035461,3837.00011730194 2237.29385375977,3836.50444507599 2242.05419540405,3837.887134552 PathPoint;PointKind.SMOOTHPOINT 2233.21455001831,3838.49539518356 2225.44996261597,3838.46282243729 2235.43107032776,3838.5046005249 PathPoint;PointKind.SMOOTHPOINT 2193.84716033936,3838.02639484406 2163.58818054199,3837.57580518723 2214.18923377991,3838.32922697067 PathPoint;PointKind.SMOOTHPOINT 2120.78538894653,3838.02639484406 2100.72781562805,3837.75165081024 2140.79166412354,3838.30043077469 PathPoint;PointKind.SMOOTHPOINT 2063.30975532532,3838.02639484406 2024.96549606323,3837.76888132095 2084.26016807556,3838.16730737686 PathPoint;PointKind.SMOOTHPOINT 1982.45444297791,3838.02639484406 1927.992811203,3837.69547462463 2036.91607475281,3838.35731506348 PathPoint;PointKind.SMOOTHPOINT 1849.9683380127,3837.01781988144 1802.35768318176,3837.30247735977 1899.67151641846,3836.72112464905 PathPoint;PointKind.SMOOTHPOINT 1722.35335350037,3836.00948095322 1676.42546653748,3836.46833181381 1770.70295333862,3835.5267906189 PathPoint;PointKind.SMOOTHPOINT 1621.79074287415,3837.56778001785 1580.07276535034,3838.32379817963 1663.50777626038,3836.81152582169 PathPoint;PointKind.SMOOTHPOINT 1478.81306648254,3836.04465007782 1445.57753562927,3836.72230482101 1512.04891204834,3835.36699533463 PathPoint;PointKind.SMOOTHPOINT 1359.96565818787,3836.04465007782 1311.23462677002,3835.75739622116 1408.69606018066,3836.33213996887 PathPoint;PointKind.SMOOTHPOINT 1238.19519996643,3836.04465007782 1115.43056488037,3835.6854057312 1312.87616729736,3836.26392602921 PathPoint;PointKind.SMOOTHPOINT 1130.73534965515,3835.78524827957 1122.83354759216,3835.83906412125 1129.15391921997,3835.79610586166 PathPoint;PointKind.SMOOTHPOINT 1102.78698921204,3836.04465007782 1044.40592765808,3836.69067621231 1113.80318641663,3835.92285633087 PathPoint;PointKind.SMOOTHPOINT 997.577648162842,3836.04465007782 939.112558364868,3836.4227771759 1056.04242324829,3835.66652297974 PathPoint;PointKind.SMOOTHPOINT 871.010971069336,3834.96266841888 819.920539855957,3835.61695575714 922.10108757019,3834.30908918381 PathPoint;PointKind.SMOOTHPOINT 810.507173538208,3834.96266841888 796.82599067688,3835.00609874725 838.690624237061,3834.873919487 PathPoint;PointKind.SMOOTHPOINT 766.865358352661,3835.99272251129 758.296995162964,3837.08886623383 771.158981323242,3835.44370651245 PathPoint;PointKind.SMOOTHPOINT 733.142023086548,3837.0227766037 727.210006713867,3837.14079380035 738.151302337646,3836.92269802094 PathPoint;PointKind.SMOOTHPOINT 705.328989028931,3836.00948095322 684.662761688232,3834.78328227997 721.790657043457,3836.98689937592 PathPoint;PointKind.SMOOTHPOINT 650.543203353882,3836.00948095322 634.762258529663,3835.45432806015 662.73642539978,3836.43859148026 PathPoint;PointKind.SMOOTHPOINT 617.421598434448,3836.00948095322 592.370796203613,3839.0163230896 636.554861068726,3833.7131023407 PathPoint;PointKind.SMOOTHPOINT 576.000080108643,3833.99988412857 575.747995376587,3833.95598173141 579.922971725464,3834.68580007553 PathPoint;PointKind.SMOOTHPOINT 563.534002304077,3837.0227766037 558.632669448853,3837.5061750412 568.096075057983,3836.57289505005 PathPoint;PointKind.SMOOTHPOINT 543.696727752686,3839.08264875412 536.357002258301,3841.16069555283 547.214269638062,3838.08681964874 PathPoint;PointKind.SMOOTHPOINT 522.187070846558,3839.03520584106 514.272050857544,3839.01136636734 528.13136100769,3839.05267238617 PathPoint;PointKind.SMOOTHPOINT 506.997785568237,3838.05259466171 497.378597259521,3837.28099822998 516.617918014526,3838.82489919662 PathPoint;PointKind.SMOOTHPOINT 490.039501190186,3839.03520584106 470.959424972534,3839.46408033371 509.119262695312,3838.60562324524 PathPoint;PointKind.SMOOTHPOINT 467.745580673218,3835.9393787384 457.071475982666,3836.18367433548 478.419370651245,3835.69531917572 PathPoint;PointKind.SMOOTHPOINT 451.494770050049,3837.0227766037 446.629943847656,3836.4265537262 455.962429046631,3837.57014036179 PathPoint;PointKind.SMOOTHPOINT 426.701402664185,3836.94771766663 426.009349822998,3838.19397926331 426.370639801025,3837.54346847534 PathPoint;PointKind.SMOOTHPOINT 400.868854522705,3837.0227766037 355.428771972656,3834.30271625519 409.963102340698,3837.56707191467 PathPoint;PointKind.SMOOTHPOINT 312.593250274658,3835.99272251129 301.433544158936,3835.1666021347 337.597789764404,3837.84394025803 PathPoint;PointKind.SMOOTHPOINT 276,3835 274.594298660036,3834.78868724886 282.467106518044,3835.97282326003 PathPoint;PointKind.SMOOTHPOINT 272.00005531311,3833.99996471405 270.47779083252,3833.41507148743 272.857332229614,3834.32946872711 PathPoint;PointKind.SMOOTHPOINT 269.064102172852,3832.06353855133 267.464733123779,3829.55307674408 269.683771133423,3833.03600025177 PathPoint;PointKind.SMOOTHPOINT 266.967487335205,3820.54309129715 266.442546844482,3817.63845205307 267.724685668945,3824.73270177841 PathPoint;PointKind.SMOOTHPOINT 265.975513458252,3749.52246665955 265.495576858521,3730.42634010315 266.292114257812,3762.103099823 PathPoint;PointKind.CORNERPOINT 263.059701919556,3569.78864908218 263.059701919556,3569.78864908218 263.059701919556,3569.78864908218 PathPoint;PointKind.CORNERPOINT 263.059701919556,3118.02094459534 263.059701919556,3118.02094459534 263.059701919556,3118.02094459534 PathPoint;PointKind.CORNERPOINT 263.059701919556,2501.88101291656 263.059701919556,2501.88101291656 263.059701919556,2501.88101291656 PathPoint;PointKind.SMOOTHPOINT 264.034051895142,2490.78881263733 264.152383804321,2482.27245569229 263.916034698486,2499.30540561676 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2472.63729572296 262.717609405518,2456.86099290848 263.402423858643,2488.41336250305 PathPoint;PointKind.SMOOTHPOINT 264.034051895142,2447.42740631104 263.600692749023,2439.81553316116 264.245538711548,2451.14471197128 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2386.9228219986 262.893533706665,2360.14259576797 263.233737945557,2414.86386537552 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,2111.62599563599 268.040971755981,2062.30448484421 267.820358276367,2160.94774246216 PathPoint;PointKind.SMOOTHPOINT 265.008401870728,2016.83552742004 264.441289901733,2002.61917591095 265.575199127197,2031.05164289474 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1969.44005727768 266.898880004883,1941.50019407272 267.013750076294,1997.38015651703 PathPoint;PointKind.SMOOTHPOINT 268.905172348022,1915.99431753159 267.45906829834,1898.71353149414 270.350961685181,1933.27510356903 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1882.71653652191 267.037038803101,1870.3674530983 266.876850128174,1895.06585597992 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1857.5061750412 264.441289901733,1844.73978281021 271.420040130615,1870.27327537537 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1823.22076320648 266.773624420166,1804.84430551529 269.087390899658,1841.59651279449 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1760.69902896881 270.148916244507,1730.78544616699 265.711784362793,1790.61261177063 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1659.85781908035 267.438297271729,1653.5049533844 269.286603927612,1677.35103607178 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1620.52976846695 267.356157302856,1598.95929336548 266.556787490845,1642.10024356842 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1515.65473079681 265.792036056519,1494.41139936447 268.120908737183,1536.89853429794 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1406.74657344818 268.368902206421,1380.29537916183 267.493371963501,1433.19753170013 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1316.99803590775 267.037038803101,1293.44982862473 268.825550079346,1340.54577112198 PathPoint;PointKind.SMOOTHPOINT 267.463788986206,1237.72258043289 267.475433349609,1233.00496101379 267.433261871338,1250.25647878647 PathPoint;PointKind.SMOOTHPOINT 265.008401870728,1222.20709562302 265.076694488525,1220.32306909561 264.925003051758,1224.51008319855 PathPoint;PointKind.SMOOTHPOINT 265.982437133789,1208.08964252472 266.941995620728,1204.36478376389 265.125160217285,1211.41536712646 PathPoint;PointKind.SMOOTHPOINT 267.463788986206,1197.70932197571 268.254976272583,1175.45717954636 267.284717559814,1202.7411031723 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1165.73610305786 266.344985961914,1157.13028907776 268.127517700195,1182.22711801529 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1119.3496799469 268.605251312256,1098.89210700989 267.242546081543,1140.22456169128 PathPoint;PointKind.SMOOTHPOINT 267.463788986206,1084.8518371582 267.30076789856,1068.64996433258 267.605409622192,1098.8670873642 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1033.63426208496 267.063159942627,1013.82861614227 268.798484802246,1053.43990802765 PathPoint;PointKind.SMOOTHPOINT 268.905172348022,978.171844482422 268.96559715271,955.608608722687 268.844118118286,1000.73508024216 PathPoint;PointKind.SMOOTHPOINT 269.879522323608,904.557673931122 270.76229095459,876.014978885651 268.996124267578,933.100368976593 PathPoint;PointKind.SMOOTHPOINT 269.879522323608,822.876791954041 270.773305892944,795.413010120392 268.985109329224,850.339865684509 PathPoint;PointKind.SMOOTHPOINT 266.885976791382,756.321229934692 268.366069793701,731.27632856369 265.405254364014,781.366131305695 PathPoint;PointKind.SMOOTHPOINT 266.885976791382,700.858340263367 266.322641372681,676.48330450058 267.448997497559,725.233612060547 PathPoint;PointKind.SMOOTHPOINT 266.471815109253,650.862951278687 266.099195480347,634.157145023346 266.845064163208,667.568757534027 PathPoint;PointKind.SMOOTHPOINT 266.471815109253,625.213329792023 267.104072570801,619.087529182434 265.839557647705,631.339838504791 PathPoint;PointKind.SMOOTHPOINT 265.480155944824,600.58974981308 265.597858428955,584.026980400085 265.36434173584,616.879427433014 PathPoint;PointKind.SMOOTHPOINT 265.480155944824,555.447227954865 264.890069961548,531.981868743896 266.069927215576,578.912115097046 PathPoint;PointKind.SMOOTHPOINT 266.471815109253,528.77156496048 265.944356918335,521.847496032715 266.947031021118,535.005941390991 PathPoint;PointKind.SMOOTHPOINT 265.91194152832,508.252151012421 264.619417190552,500.21045923233 267.26300239563,516.662528514862 PathPoint;PointKind.SMOOTHPOINT 264.937591552734,473.966031074524 265.228385925293,458.305621147156 264.637041091919,490.157990455627 PathPoint;PointKind.SMOOTHPOINT 264.937591552734,440.68825006485 263.813123703003,410.140914916992 265.333499908447,451.439144611359 PathPoint;PointKind.SMOOTHPOINT 264.983854293823,381.486339569092 264.691801071167,352.564573287964 265.327205657959,415.594017505646 PathPoint;PointKind.SMOOTHPOINT 264.983854293823,283.638045787811 264.694633483887,252.309200763702 265.260801315308,313.752493858337 PathPoint;PointKind.SMOOTHPOINT 264,181 263.768686294556,168.756187915802 264.332336425781,198.616662979126 PathPoint;PointKind.SMOOTHPOINT 263.000061035156,145.999940395355 262.975828170776,141.969417095184 263.053562164307,154.982465267181 PathPoint;PointKind.SMOOTHPOINT 264.879678726196,126.972260951996 265.424865863145,125.870419133717 263.74772419925,129.26079720968 PathPoint";
	
	subshadow645[0] = "PointKind.SMOOTHPOINT 265.9375,125.375 267.722549438477,122.907024383545 265.618354208466,125.816450958508 PathPoint;PointKind.CORNERPOINT 277,122 277,122 277,122 PathPoint;PointKind.SMOOTHPOINT 301.760249206845,120.379101284124 309.294354940775,120.057657901711 287.074862193329,121.005654804923 PathPoint;PointKind.SMOOTHPOINT 317.566549170387,120.382027986458 320.097512244373,120.382496867983 311.634821845237,120.380929085656 PathPoint;PointKind.SMOOTHPOINT 328.421875,120.375 336.551405412859,120.832161741018 324.371600226411,120.147233994701 PathPoint;PointKind.SMOOTHPOINT 343.421875,119.375 378.008865796582,119.381414261239 339.783637747092,119.374325277983 PathPoint;PointKind.SMOOTHPOINT 482.57955976099,120.412714213853 486.903354579157,120.413520791322 420.094497832211,120.401058007853 PathPoint;PointKind.SMOOTHPOINT 495.735690660513,120.415168944596 507.486642544253,117.309883920995 491.436538271531,121.551255081257 PathPoint;PointKind.SMOOTHPOINT 523.512944080658,120.420355201988 973.724537689593,120.504450977274 514.006738253518,120.418579521929 PathPoint;PointKind.SMOOTHPOINT 2915.13366860804,120.882913223748 2920.19104445714,120.883933278933 1973.92981150179,120.693075667046 PathPoint;PointKind.SMOOTHPOINT 2930.30059113604,120.885973478329 2936.91261924205,117.961878211237 2925.67852654588,122.930029700652 PathPoint;PointKind.SMOOTHPOINT 2943.27499754274,120.888593164307 2960.78075322387,120.892128921846 2938.95155238236,120.887719928436 PathPoint;PointKind.SMOOTHPOINT 2995.72061781661,120.89919995945 3002.27287003227,120.900526880264 2978.26393793641,120.895664742687 PathPoint;PointKind.SMOOTHPOINT 3015.36596421957,120.903180431288 3027.07023322577,120.723073236662 3008.82216276462,121.003877512124 PathPoint;PointKind.SMOOTHPOINT 3043.3234744337,120.908852128837 3169.13469793593,120.934394085907 3034.01271307537,120.906961875644 PathPoint;PointKind.SMOOTHPOINT 3414.55550162517,120.98503602992 3453.28989772833,120.993079209137 3293.37395381222,120.959872738247 PathPoint;PointKind.SMOOTHPOINT 3533.421875,122.375 3562.45780335077,122.38108051992 3495.36080726568,122.367029492643 PathPoint;PointKind.SMOOTHPOINT 3627.421875,122.375 3651.95134770111,122.376968516826 3598.83757148274,122.372706078597 PathPoint;PointKind.SMOOTHPOINT 3700.44963630269,122.37701199614 3730.30599020017,120.411216235682 3676.84637879105,123.931092702334 PathPoint;PointKind.SMOOTHPOINT 3797.421875,121.375 3830.73974264509,119.504614906796 3768.17892337626,123.016629091662 PathPoint;PointKind.SMOOTHPOINT 3896.421875,122.375 3958.06536866353,122.184656919291 3864.13099396308,122.474707940126 PathPoint;PointKind.SMOOTHPOINT 4077.421875,121.375 4192.15563307054,122.890919310668 4017.50241344231,120.583314358497 PathPoint;PointKind.SMOOTHPOINT 4399.421875,122.375 4733.94701508591,122.53040955914 4303.95530784169,122.330649320972 PathPoint;PointKind.SMOOTHPOINT 4989.421875,121.375 4989.82982008576,121.375122209714 4943.98492410347,121.361388273845 PathPoint;PointKind.SMOOTHPOINT 4996.421875,122.375 4997.74401485631,122.376121640403 4996.04120047337,122.374685213175 PathPoint;PointKind.SMOOTHPOINT 5002.421875,122.375 5006.84037339297,122.937643276247 5000.37300298297,122.114100490314 PathPoint;PointKind.SMOOTHPOINT 5012.421875,125.375 5015.9255695343,127.935737133026 5009.8688325424,123.509240700201 PathPoint;PointKind.CORNERPOINT 5016.421875,132.375 5016.421875,132.375 5016.421875,132.375 PathPoint;PointKind.SMOOTHPOINT 5016.43857467124,134.200432517997 5015.81509393078,135.989243755843 5017.0620554117,132.411621280151 PathPoint;PointKind.SMOOTHPOINT 5016.46730077195,135.871200857572 5016.5202042617,137.671809367901 5016.45555874335,135.471552427408 PathPoint;PointKind.SMOOTHPOINT 5015.421875,146.375 5015.46748394905,148.28301869911 5015.30358766218,141.426531395653 PathPoint;PointKind.CORNERPOINT 4971.421875,192.375 4971.421875,192.375 4971.421875,192.375 PathPoint;PointKind.SMOOTHPOINT 4969.421875,3796.375 4969.42012335888,3799.30748489247 4970.54614007774,1914.20272000728 PathPoint;PointKind.SMOOTHPOINT 5015.421875,3813.375 5015.4202732539,3816.05138968538 5015.42325617426,3811.06716822044 PathPoint;PointKind.SMOOTHPOINT 5015.421875,3819.375 5014.9323451203,3823.05526325536 5015.66721525918,3817.53054314793 PathPoint;PointKind.CORNERPOINT 5016.421875,3825.375 5016.421875,3825.375 5016.421875,3825.375 PathPoint;PointKind.SMOOTHPOINT 5015.421875,3834.375 5013.82910717584,3837.47453875714 5016.32272464092,3832.6225269032 PathPoint;PointKind.CORNERPOINT 5007.421875,3837.375 5007.421875,3837.375 5007.421875,3837.375 PathPoint;PointKind.SMOOTHPOINT 4988.77182781693,3838.3510897266 4983.84664684832,3838.79642366777 4999.75436065881,3837.35805116302 PathPoint;PointKind.SMOOTHPOINT 4971.23869094548,3838.33031093861 4952.14352631748,3838.30789158821 4977.97273094618,3838.33821727538 PathPoint;PointKind.SMOOTHPOINT 4893.36678571012,3838.24178641608 4888.02882505501,3838.23589054457 4925.97080679794,3838.27779813133 PathPoint;PointKind.SMOOTHPOINT 4876.83857550776,3838.22363059839 4870.1762398466,3839.64291957243 4884.06395718157,3836.68439495126 PathPoint;PointKind.SMOOTHPOINT 4855.67637970849,3838.200666339 4850.24428138236,3838.57485350875 4865.32272871533,3837.53618277914 PathPoint;PointKind.SMOOTHPOINT 4838.94407295002,3838.18272372901 4834.23030379211,3839.25261552319 4847.20732486117,3836.30720010517 PathPoint;PointKind.SMOOTHPOINT 4824.16238792831,3838.16702483911 4814.30471124738,3838.15660212327 4829.18277382497,3838.17233299207 PathPoint;PointKind.SMOOTHPOINT 4799.421875,3837.375 4793.9171299027,3837.36928420838 4809.98535978518,3837.38596847843 PathPoint;PointKind.SMOOTHPOINT 4776.72936694979,3838.1175696053 4188.12094313858,3837.5123183496 4782.42191788092,3838.12342311242 PathPoint;PointKind.SMOOTHPOINT 1482.43999506043,3838.12365915764 1473.9467135512,3838.13831966426 2602.61912208633,3836.19008454498 PathPoint;PointKind.SMOOTHPOINT 1457.04103908667,3838.16820391744 1449.51397783292,3837.6437870802 1470.31737827291,3839.09317789752 PathPoint;PointKind.SMOOTHPOINT 1434.47128829828,3838.20899001738 1429.78688055746,3837.6972671488 1444.19018626294,3839.27067862801 PathPoint;PointKind.SMOOTHPOINT 1420.36105995174,3838.23507911904 1257.76836112497,3838.53836249935 1425.05557406473,3838.22632246441 PathPoint;PointKind.SMOOTHPOINT 969.421875,3839.375 936.457935635194,3839.48633276969 1105.89127974497,3838.91408673838 PathPoint;PointKind.SMOOTHPOINT 867.421875,3838.375 859.39093611952,3838.40682403572 898.514110553757,3838.25179144002 PathPoint;PointKind.SMOOTHPOINT 841.947100187885,3839.62307014145 835.308020162255,3838.25587532851 850.452310817227,3841.37455977713 PathPoint;PointKind.SMOOTHPOINT 822.763413793669,3839.69186657285 819.579701583503,3839.42650423068 828.596964657235,3840.17809290806 PathPoint;PointKind.SMOOTHPOINT 813.287696214938,3839.97885393726 808.867391619732,3839.47946008305 817.346367085133,3840.43739140796 PathPoint;PointKind.SMOOTHPOINT 800.273794622379,3840.16293192612 625.749963891544,3840.24440143429 804.4863385391,3840.16096546756 PathPoint;PointKind.SMOOTHPOINT 395.634736578303,3840.33485246614 390.219580296217,3840.33715322424 486.376230014675,3840.2962987817 PathPoint;PointKind.SMOOTHPOINT 381.421875,3840.375 376.517023212831,3841.7083733971 387.360893754389,3838.76049053965 PathPoint;PointKind.SMOOTHPOINT 365.197757109197,3840.3477843417 351.296826713422,3840.35369048302 369.923240366047,3840.3457766076 PathPoint;PointKind.SMOOTHPOINT 328.245066455185,3840.36348457233 322.049890221676,3840.36611674048 338.954704805243,3840.35893432743 PathPoint;PointKind.SMOOTHPOINT 311.312605912847,3840.37067873142 304.296721504409,3839.03027477409 316.310584948355,3841.32555633314 PathPoint;PointKind.SMOOTHPOINT 294.421875,3839.375 283.211940495581,3839.19155809092 298.392274999064,3839.43997252552 PathPoint;PointKind.CORNERPOINT 281.421875,3839.375 281.421875,3839.375 281.421875,3839.375 PathPoint;PointKind.SMOOTHPOINT 271.04613494873,3836.33122062683 269.922296524048,3835.07504558563 273.237163543701,3838.78007745743 PathPoint;PointKind.SMOOTHPOINT 267.937404632568,3832.37504816055 267.083274841309,3831.12477397919 268.940078735352,3833.84247398376 PathPoint;PointKind.SMOOTHPOINT 266.035596847534,3827.13390445709 266.034689711653,3825.45211842697 266.036855697632,3829.53106975555 PathPoint;PointKind.SMOOTHPOINT 266.029095061625,3818.65473681929 266.027278894892,3816.54734100627 266.032505019658,3822.61149428566 PathPoint;PointKind.SMOOTHPOINT 307.421875,3786.375 307.17632444358,3518.18981971096 307.424378408875,3789.10917079617 PathPoint;PointKind.SMOOTHPOINT 307.421875,172.375 307.428589320575,170.912889551527 306.748017517703,319.968591815043 PathPoint;PointKind.SMOOTHPOINT 264,139 263.905129220661,138.630529629805 264.318587993153,140.24072791001 PathPoint;PointKind.SMOOTHPOINT 263.576961089965,134.897193177017 263.841328314875,133.22676411142 263.344930263978,136.363301678083 PathPoint;PointKind.SMOOTHPOINT 264.685982440547,129.347030004093 265.612175295835,127.572055978352 263.829994904244,130.987461189266 PathPoint";
	
} else if (mask_variant_645 == 3) {
	
	mask645[0] = "PointKind.SMOOTHPOINT 272.918621753659,179.82846736908 277.308512797768,174.522414207458 268.529043513529,185.134992599487 PathPoint;PointKind.SMOOTHPOINT 351.776817714256,176.427447795868 212.227455297109,178.059153556824 314.211875048007,176.865763664246 PathPoint;PointKind.SMOOTHPOINT 942.050438626049,174.013051986694 977.485186193938,173.933036327362 772.805343247417,174.397079944611 PathPoint;PointKind.SMOOTHPOINT 1493.42532070428,174.99235868454 1505.10041642398,174.786064624786 1481.75085059253,175.19912481308 PathPoint;PointKind.SMOOTHPOINT 1535.31446557901,178.908877372742 1541.86551931542,178.940505981445 1524.25621930629,178.85529756546 PathPoint;PointKind.SMOOTHPOINT 1545.05643270725,176.950500011444 1548.4756930039,176.375992298126 1540.08535186978,177.785589694977 PathPoint;PointKind.SMOOTHPOINT 1563.56504415658,175.971665382385 1567.49323652739,175.912420749664 1558.16323223976,176.052625179291 PathPoint;PointKind.SMOOTHPOINT 1580.12551242345,177.92980670929 1584.11000951051,178.989129066467 1574.52506997983,176.440193653107 PathPoint;PointKind.SMOOTHPOINT 1605.45387622733,179.887948036194 1620.93016590229,179.842157363892 1594.56454410338,179.920284748077 PathPoint;PointKind.SMOOTHPOINT 1849.82635450662,177.878823280334 1861.04037716099,178.364582061768 1838.61233185226,177.393064498901 PathPoint;PointKind.CORNERPOINT 1881.97353225311,177.878823280334 1881.97353225311,177.878823280334 1881.97353225311,177.878823280334 PathPoint;PointKind.SMOOTHPOINT 1887.81858740846,178.857657909393 1889.32692819617,178.980631828308 1881.97165542923,178.381104469299 PathPoint;PointKind.SMOOTHPOINT 1895.62930276911,176.745386123657 1900.45649377615,176.551837921143 1889.49459112902,176.991806030273 PathPoint;PointKind.SMOOTHPOINT 1908.2762804522,177.878823280334 1919.90508118298,178.919026851654 1896.64685411346,176.838147640228 PathPoint;PointKind.SMOOTHPOINT 1962.8289816209,177.878823280334 1971.77955468177,177.802112102509 1953.879034168,177.955062389374 PathPoint;PointKind.SMOOTHPOINT 2007.64065407331,177.878823280334 2021.56011834378,177.760334014893 1993.72056419487,177.997312545776 PathPoint;PointKind.SMOOTHPOINT 2057.32299728585,177.878823280334 1871.78081459084,177.719972133636 2043.0572590104,177.866313457489 PathPoint;PointKind.SMOOTHPOINT 2559.10405967765,176.865291595459 2580.01782092306,176.6521525383 2425.81296647238,178.222253322601 PathPoint;PointKind.SMOOTHPOINT 2609.76110008939,175.886220932007 2617.6490780329,175.492279529572 2601.87249653791,176.280162334442 PathPoint;PointKind.SMOOTHPOINT 2638.01167866696,176.865291595459 2647.73456475247,176.54381275177 2628.28910538543,177.186534404755 PathPoint;PointKind.SMOOTHPOINT 2695.48722021732,176.865291595459 2703.01797601659,176.773238182068 2687.95615161408,176.956872940063 PathPoint;PointKind.SMOOTHPOINT 2713.99614447064,176.865291595459 2723.03774348945,177.220995426178 2704.95454545183,176.50958776474 PathPoint;PointKind.SMOOTHPOINT 2755.88528934536,177.844598293304 2774.18119408884,178.349475860596 2737.58938460188,177.339720726013 PathPoint;PointKind.SMOOTHPOINT 2796.80004982488,177.844598293304 2804.36865490563,177.695424556732 2789.23113194015,177.993535995483 PathPoint;PointKind.SMOOTHPOINT 2818.23150165587,175.886220932007 2832.27389789016,175.570170879364 2807.72566721041,176.122491359711 PathPoint;PointKind.SMOOTHPOINT 2850.37899220633,176.865291595459 2855.42076674309,177.068045139313 2845.33659206161,176.662302017212 PathPoint;PointKind.SMOOTHPOINT 2863.18925356656,176.465213298798 2869.56795231043,175.953018665314 2856.16242497778,177.029099464417 PathPoint;PointKind.SMOOTHPOINT 2879.60332957116,177.844598293304 2882.21274036565,178.062222003937 2875.94477423042,177.539405822754 PathPoint;PointKind.SMOOTHPOINT 2897.13849503722,176.865291595459 2900.06571467458,176.327133178711 2890.09759026938,178.160176277161 PathPoint;PointKind.SMOOTHPOINT 2904.32704328324,175.828156471252 2912.25287050824,175.122177600861 2900.55462729407,176.16450548172 PathPoint;PointKind.SMOOTHPOINT 2915.64773209451,177.844598293304 2922.96140193221,178.009114265442 2908.33374945283,177.679846286774 PathPoint;PointKind.SMOOTHPOINT 2951.6915090099,176.865291595459 2961.78694463464,177.205417156219 2941.59576058119,176.524930000305 PathPoint;PointKind.SMOOTHPOINT 2980.91615917871,176.865291595459 2997.6101947447,176.693222522736 2964.2224364167,177.037360668182 PathPoint;PointKind.SMOOTHPOINT 3556.69882295003,182.825396060944 3589.24576418193,183.751358985901 3524.15188171813,181.89966917038 PathPoint;PointKind.SMOOTHPOINT 3657.01943833556,179.836728572845 3661.64330675611,180.10439157486 3639.02664064793,178.795108795166 PathPoint;PointKind.SMOOTHPOINT 3672.60614781517,181.795105934143 3681.7256350248,182.573311328888 3667.80898599014,181.386058330536 PathPoint;PointKind.SMOOTHPOINT 3715.46936428113,179.836728572845 3719.39943347581,179.825870990753 3713.29099736997,179.842865467072 PathPoint;PointKind.SMOOTHPOINT 3726.18477739265,181.795105934143 3729.75950126696,181.819889545441 3719.08287584886,181.745538711548 PathPoint;PointKind.SMOOTHPOINT 3740.83276213068,182.804388999939 3742.09492618676,182.780077457428 3733.01891873023,182.954034805298 PathPoint;PointKind.SMOOTHPOINT 3747.65188887727,181.783304214478 3749.54654257929,181.110842227936 3745.5082432078,182.544987201691 PathPoint;PointKind.SMOOTHPOINT 3751.54880085015,181.783304214478 3758.2812808945,181.861431598663 3750.70923496998,181.773862838745 PathPoint;PointKind.SMOOTHPOINT 3770.22194719255,182.82870054245 3788.5122214644,181.793689727783 3764.80355666482,183.13530921936 PathPoint;PointKind.SMOOTHPOINT 3797.31671506697,180.867254734039 3804.56751130486,181.356790065765 3798.51819515109,180.948450565338 PathPoint;PointKind.SMOOTHPOINT 3807.05836939124,181.846325397491 3821.28719679714,182.806985378265 3801.94464993926,181.501007080078 PathPoint;PointKind.SMOOTHPOINT 3824.77433555727,179.82846736908 3826.24263743565,179.791646003723 3815.19158565445,180.067570209503 PathPoint;PointKind.SMOOTHPOINT 3832.38642039114,180.867254734039 3838.16297147504,181.106593608856 3828.49670290977,180.706279277802 PathPoint;PointKind.SMOOTHPOINT 3842.62793547416,179.82846736908 3850.01292461912,180.38031578064 3841.48839057793,179.743494987488 PathPoint;PointKind.SMOOTHPOINT 3862.58545495515,180.867254734039 3870.61857394502,180.41241645813 3854.55233596529,181.322329044342 PathPoint;PointKind.SMOOTHPOINT 3882.06876360368,180.867254734039 3893.49987221961,181.777403354645 3870.63765498775,179.956634044647 PathPoint;PointKind.SMOOTHPOINT 3906.42243020837,181.846325397491 3913.43580822604,181.876773834229 3899.40936499468,181.815640926361 PathPoint;PointKind.SMOOTHPOINT 3922.98352408319,178.908877372742 3934.01737164554,177.965919971466 3907.69867044351,180.214855670929 PathPoint;PointKind.SMOOTHPOINT 3937.5958491676,181.846325397491 3947.72913407382,181.505727767944 3931.06450208188,182.065601348877 PathPoint;PointKind.CORNERPOINT 3956.10477342091,180.867254734039 3956.10477342091,180.867254734039 3956.10477342091,180.867254734039 PathPoint;PointKind.SMOOTHPOINT 3966.82112494436,178.908877372742 3974.31715950194,178.262615203857 3959.32415197485,179.555375576019 PathPoint;PointKind.SMOOTHPOINT 3980.45875282958,179.887948036194 3988.2203579655,179.839088916779 3970.1127612175,179.953093528748 PathPoint;PointKind.SMOOTHPOINT 3994.09731912673,178.908877372742 3995.7429808613,178.607697486877 3989.15626747127,179.813597202301 PathPoint;PointKind.SMOOTHPOINT 3999.9420614781,176.950500011444 4008.03961808768,176.548297405243 3996.59631011657,177.116904258728 PathPoint;PointKind.SMOOTHPOINT 4013.58062777525,178.908877372742 4016.29983276645,179.332087039948 4009.42033485188,178.261671066284 PathPoint;PointKind.SMOOTHPOINT 4026.24449687321,178.908877372742 4038.56615841793,179.62028503418 4021.37351330909,178.627524375916 PathPoint;PointKind.SMOOTHPOINT 4059.36637181889,179.887948036194 4066.95124270656,179.967963695526 4041.26033909079,179.696996212006 PathPoint;PointKind.SMOOTHPOINT 4082.74596683234,178.908877372742 4084.61841145184,178.698570728302 4075.01658050628,179.777247905731 PathPoint;PointKind.SMOOTHPOINT 4102.22927548087,178.908877372742 4105.21342544245,179.362535476685 4095.69042109964,177.915408611298 PathPoint;PointKind.SMOOTHPOINT 4110.99654540992,178.908877372742 4126.17973775636,178.583858013153 4107.99081197377,178.973078727722 PathPoint;PointKind.SMOOTHPOINT 4154.07246858173,180.82878112793 4163.11187797269,180.672290325165 4139.69943854142,181.077325344086 PathPoint;PointKind.SMOOTHPOINT 4178.2143668925,180.695185661316 4178.72799102635,180.661668777466 4170.6013436467,181.191802024841 PathPoint;PointKind.SMOOTHPOINT 4184.05848363592,179.887948036194 4186.96849905442,179.704549312592 4182.91674911183,179.960174560547 PathPoint;PointKind.SMOOTHPOINT 4191.85168197373,179.887948036194 4204.47801459419,179.291253089905 4188.82342665109,180.03098487854 PathPoint;PointKind.SMOOTHPOINT 4216.2056613824,180.867254734039 4222.87964708264,180.915877819061 4206.2134510708,180.7945561409 PathPoint;PointKind.SMOOTHPOINT 4235.6892828349,178.908877372742 4240.02787402642,178.040742874146 4229.81138326173,180.085744857788 PathPoint;PointKind.SMOOTHPOINT 4255.17227867945,176.950500011444 4257.11479139029,177.305731773376 4245.63863900136,175.207858085632 PathPoint;PointKind.SMOOTHPOINT 4260.04294943959,178.908877372742 4265.81168042402,180.494320392609 4258.16299752459,178.392198085785 PathPoint;PointKind.SMOOTHPOINT 4274.65590013195,178.908877372742 4286.84743522132,178.905100822449 4268.37604744551,178.910765647888 PathPoint;PointKind.SMOOTHPOINT 4291.21636839882,177.92980670929 4301.72658209998,177.658367156982 4280.70584189368,178.20148229599 PathPoint;PointKind.SMOOTHPOINT 4307.81093229942,180.82878112793 4309.88920193724,180.757026672363 4298.72773035138,181.142470836639 PathPoint;PointKind.SMOOTHPOINT 4315.57066061147,180.867254734039 4317.60169684842,180.710999965668 4313.07135681765,181.059858798981 PathPoint;PointKind.SMOOTHPOINT 4322.38947455407,180.867254734039 4323.07013601282,180.847663879395 4320.02311245142,180.934524536133 PathPoint;PointKind.SMOOTHPOINT 4324.33761773654,178.908877372742 4325.42210913243,178.809978961945 4323.58282173473,178.977563381195 PathPoint;PointKind.SMOOTHPOINT 4331.1570572871,178.908877372742 4332.53308199161,179.330434799194 4329.26271638906,178.328940868378 PathPoint;PointKind.SMOOTHPOINT 4333.10520046957,180.867254734039 4335.15093849354,180.897467136383 4331.93593919531,180.850024223328 PathPoint;PointKind.SMOOTHPOINT 4338.9505684289,178.908877372742 4341.38449619107,178.413441181183 4336.62893729527,179.381418228149 PathPoint;PointKind.SMOOTHPOINT 4348.69190994918,178.908877372742 4352.08896116331,178.866627216339 4344.70365921437,178.95868062973 PathPoint;PointKind.SMOOTHPOINT 4358.43356427345,176.950500011444 4369.12019941888,176.901168823242 4354.94642551331,176.966786384583 PathPoint;PointKind.SMOOTHPOINT 4381.81347209088,176.950500011444 4383.14726825819,176.996762752533 4370.99827451,176.576149463654 PathPoint;PointKind.SMOOTHPOINT 4386.684455655,178.908877372742 4409.47816881541,179.785981178284 4385.30248767489,178.855533599854 PathPoint;PointKind.SMOOTHPOINT 4447.08189917508,178.908877372742 4447.3584178927,178.911945819855 4433.42644146305,178.748137950897 PathPoint;PointKind.SMOOTHPOINT 4463.64299304991,176.950500011444 4466.5608285679,178.174338340759 4469.86091054847,179.558207988739 PathPoint;PointKind.SMOOTHPOINT 4471.92635522314,179.378349781036 4473.00052408771,179.258680343628 4468.62815006644,179.745383262634 PathPoint;PointKind.SMOOTHPOINT 4478.25531813431,176.950500011444 4483.51386582866,176.754355430603 4475.71566262718,177.045149803162 PathPoint;PointKind.SMOOTHPOINT 4493.84171480995,178.908877372742 4500.90639268021,179.205572605133 4490.03926963878,178.74908208847 PathPoint;PointKind.SMOOTHPOINT 4512.35095186724,177.92980670929 4515.81244070108,177.736494541168 4501.35776882219,178.543968200684 PathPoint;PointKind.SMOOTHPOINT 4526.96327695165,177.92980670929 4541.9237528649,177.997784614563 4520.70688456364,177.901246547699 PathPoint;PointKind.SMOOTHPOINT 4566.33966746145,177.738854885101 4567.60746198915,177.732245922089 4552.65637019527,177.809901237488 PathPoint;PointKind.SMOOTHPOINT 4571.77463660007,176.950500011444 4575.35467814203,176.938934326172 4570.45053735611,176.954748630524 PathPoint;PointKind.SMOOTHPOINT 4579.56783493789,176.950500011444 4580.26538781151,176.952860355377 4575.42193099755,176.937282085419 PathPoint;PointKind.SMOOTHPOINT 4581.51629092433,177.92980670929 4582.31675630711,177.948925495148 4580.75617725487,177.911632061005 PathPoint;PointKind.SMOOTHPOINT 4583.46474691077,176.950500011444 4586.51646253186,176.978116035461 4582.59921830033,176.942710876465 PathPoint;PointKind.SMOOTHPOINT 4593.20640123504,176.950500011444 4596.96192580933,177.178745269775 4589.54565626645,176.728155612946 PathPoint;PointKind.SMOOTHPOINT 4604.89651154574,177.92980670929 4643.47087265288,178.472921848297 4601.35306806935,177.880239486694 PathPoint;PointKind.SMOOTHPOINT 4654.57854195431,178.908877372742 4670.04701152979,179.245462417603 4639.10975957485,178.572292327881 PathPoint;PointKind.SMOOTHPOINT 4684.77788932231,177.92980670929 4698.14181372572,178.258602619171 4671.41333931094,177.601010799408 PathPoint;PointKind.SMOOTHPOINT 4713.0281550959,177.92980670929 4731.6590729011,177.539877891541 4694.39692448672,178.319971561432 PathPoint;PointKind.SMOOTHPOINT 4743.22687685594,178.908877372742 4763.74932032338,179.253251552582 4722.70474619249,178.564739227295 PathPoint;PointKind.SMOOTHPOINT 4787.06447771711,178.908877372742 4821.35436272113,178.040742874146 4752.7745927131,179.777011871338 PathPoint;PointKind.SMOOTHPOINT 4853.30760200051,178.908877372742 4884.95429338027,178.735864162445 4828.82005529272,179.042708873749 PathPoint;PointKind.SMOOTHPOINT 4896.09981196319,179.866940975189 4903.99717402608,180.046091079712 4903.91209134374,180.044438838959 PathPoint;PointKind.SMOOTHPOINT 4908.76336825717,179.866940975189 4913.43384447062,178.379688262939 4905.29687455966,180.971345901489 PathPoint;PointKind.SMOOTHPOINT 4933.18866697309,178.908877372742 4950.55116464263,179.136414527893 4925.51965181502,178.808326721191 PathPoint;PointKind.SMOOTHPOINT 5006.08137824634,181.828622817993 5011.91360843855,188.430740833282 5000.24946085811,175.226740837097 PathPoint;PointKind.SMOOTHPOINT 5011.8150751851,234.20654296875 5011.69933771279,236.885533332825 5012.06813360427,228.358554840088 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,305.217254161835 5013.72161543833,323.898432254791 5014.20740001803,295.715217590332 PathPoint;PointKind.SMOOTHPOINT 5015.99225952335,442.296116352081 5015.93126274741,459.499955177307 5016.0532562993,425.092277526855 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,941.654963493347 5015.42107945733,958.567771911621 5012.66652761648,924.74191904068 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,998.444602489471 5014.18863177928,1010.65324544907 5013.89928809852,986.23619556427 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,1086.56686306 5014.94593021292,1099.75080013275 5015.09044565131,1073.38316202164 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,1256.93672418594 5014.29905158394,1263.84781122208 5013.78886829386,1250.02516508102 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,1276.51908159256 5015.00286053714,1288.6167883873 5015.03320252312,1264.42137479782 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,1319.60102319717 5013.60274992623,1351.6065788269 5014.48579555952,1287.59570360184 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,1535.9898018837 5015.33005349938,1549.4756269455 5014.70600956088,1522.50374078751 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,1597.67526626587 5014.05631569608,1606.95377826691 5014.01752800265,1577.82524585724 PathPoint;PointKind.SMOOTHPOINT 5015.02819765945,1636.55579566956 5015.06072927329,1637.6656293869 5014.60434826764,1622.19522714615 PathPoint;PointKind.SMOOTHPOINT 5015.12360287311,1639.86641407013 5014.73353631105,1641.63006305695 5015.36070828934,1638.79599809647 PathPoint;PointKind.SMOOTHPOINT 5015.21681845891,1643.26011657715 5015.57810705489,1656.91730260849 5015.18710208089,1642.14036941528 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,1672.08959341049 5013.48826366985,1679.5095705986 5015.71980725747,1668.68503332138 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,1689.7140455246 5014.63781829341,1697.01175689697 5015.39887037481,1682.41657018661 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,1705.3803563118 5015.486142685,1711.6642999649 5014.54992037526,1699.09641265869 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,1725.94202041626 5015.23496108971,1737.02997207642 5014.80110197055,1714.8543047905 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,1775.87792873383 5014.16173063707,1796.98294401169 5015.87401961921,1754.77314949036 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,1848.33411455154 5015.21588004697,1863.35015058517 5014.81987020931,1833.31807851791 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,1880.64533472061 5015.75265167528,1904.73382472992 5012.33558100649,1856.5570807457 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,1951.14337921143 5015.36446193709,1968.2818365097 5014.67191392714,1934.00444984436 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,1999.12091016769 5015.06729815685,2003.76748323441 5014.88493343698,1986.58701181412 PathPoint;PointKind.SMOOTHPOINT 5014.43418290295,2012.65158176422 5013.82671757534,2020.0585770607 5014.79296906709,2008.2875418663 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,2034.36957836151 5014.18863177928,2044.49734210968 5013.95309038294,2027.99688577652 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,2087.24293470383 5015.33005349938,2113.19774866104 5014.70600956088,2061.28812074661 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,2212.57224082947 5014.04786998864,2242.9368853569 5015.9885058756,2182.20736026764 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,2290.90308666229 5014.40947138859,2305.86176633835 5015.62690447564,2275.94417095184 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,2364.33810710907 5014.00532864747,2365.59215784073 5014.57682151747,2346.98509454727 PathPoint;PointKind.SMOOTHPOINT 5013.07004474965,2369.23393249512 5013.02374976073,2374.83243227005 5013.13323115345,2361.55148506165 PathPoint;PointKind.SMOOTHPOINT 5013.81483102413,2374.5836520195 5014.38820071801,2397.93477058411 5013.79387315753,2373.7403011322 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,2457.35595703125 5015.01036783264,2476.12777233124 5013.22300589548,2441.40664100647 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,2532.74959087372 5014.39383118963,2555.55617809296 5013.69377588418,2509.94205951691 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,2600.3094792366 5015.69165489934,2621.65147304535 5014.3447209649,2578.96748542786 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,2672.76566505432 5013.77354089888,2705.05776643753 5014.31406617494,2640.47309160233 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,2734.45112943649 5014.39789764136,2750.15142917633 5013.69002223643,2718.75059366226 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,2794.17821645737 5014.82769030879,2821.16166830063 5015.20837275147,2767.19476461411 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,2863.69695425034 5014.99378922174,2880.19457817078 5015.04227383852,2847.11601018906 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,2910.69517850876 5013.49921180912,2921.03041648865 5014.56399655432,2900.82752466202 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,2952.79804944992 5014.66002737593,2965.06404876709 5015.37603568432,2940.53205013275 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,2984.13043498993 5014.45733039741,2991.55796527863 5013.46542897936,2973.74256134033 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,3027.21237659454 5015.12735652086,3033.8475394249 5014.7432332344,3010.5667591095 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,3044.83659267426 5015.53494010576,3062.02367305756 5014.85803229477,3039.51283693314 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,3062.46128082275 5013.96028487446,3071.58707857132 5014.12763500333,3053.33548307419 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,3098.68901968002 5014.38257024638,3111.92677259445 5013.70503682743,3085.45197486877 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,3148.62516403198 5013.75852630788,3160.74505805969 5014.31093813515,3137.2841835022 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,3177.99917221069 5014.13545510281,3186.21175289154 5013.93713738,3168.40673446655 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,3217.16435909271 5014.14515202617,3219.35216188431 5013.44259428888,3204.14375782013 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,3224.99763250351 5015.20274227985,3227.1960568428 5014.87429810169,3223.28425884247 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,3229.89345788956 5014.01627678674,3237.15788841248 5014.05037242047,3228.24900627136 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,3253.39257001877 5014.43574692285,3268.274538517 5013.72474347812,3241.25733375549 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,3289.62054491043 5014.58057516522,3299.26278591156 5013.50734471258,3279.9783039093 PathPoint;PointKind.SMOOTHPOINT 5013.07004474965,3306.26592636108 5014.32188627442,3315.1854300499 5011.81789042091,3297.34642267227 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,3333.68179321289 5013.96341291425,3345.04732131958 5014.12044051181,3322.89124488831 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,3351.306245327 5016.0607635948,3356.56107902527 5013.97529946546,3346.05117559433 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,3367.95139074326 5014.72133695586,3373.24871063232 5015.3147261044,3362.65383481979 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,3387.53422021866 5013.53799950254,3400.44270515442 5016.49868916568,3374.62526321411 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,3405.15843629837 5013.91086184575,3422.10617780685 5014.17737083603,3388.21116685867 PathPoint;PointKind.SMOOTHPOINT 5015.01818793212,3449.21968460083 5014.62249089843,3467.89566993713 5015.41357216183,3430.54322719574 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,3523.63353967667 5014.20740001803,3553.19141864777 5013.88051985976,3494.07613277435 PathPoint;PointKind.SMOOTHPOINT 5014.04411634089,3580.42341470718 5013.58742253125,3592.67808437347 5014.50081015052,3568.16921710968 PathPoint;PointKind.SMOOTHPOINT 5012.09597315842,3605.88114023209 5011.73218213061,3622.75901556015 5012.43880631963,3589.956843853 PathPoint;PointKind.SMOOTHPOINT 5013.30339651814,3648.94773960114 5013.1476201365,3671.31860733032 5013.45917289978,3626.57663583755 PathPoint;PointKind.SMOOTHPOINT 5014.98252827849,3725.31855583191 5015.43140198864,3741.47015333176 5014.53365456834,3709.16672229767 PathPoint;PointKind.SMOOTHPOINT 5014.79109224322,3753.75243902206 5013.95434159886,3760.38264513016 5015.90655123305,3744.91271495819 PathPoint;PointKind.SMOOTHPOINT 5010.04867111455,3779.10890579224 5003.45882968472,3781.93376541138 5015.02725924752,3776.97491884232 PathPoint;PointKind.SMOOTHPOINT 4943.5944041452,3781.10882520676 4925.44301484011,3783.21283578873 4947.75782510836,3780.62637090683 PathPoint;PointKind.SMOOTHPOINT 4791.89980162761,3781.09513521194 4777.6184231532,3782.91189193726 4806.18118010201,3779.27837848663 PathPoint;PointKind.SMOOTHPOINT 4642.06825961014,3781.10882520676 4619.81444611783,3781.72770738602 4666.39439946465,3780.43211460114 PathPoint;PointKind.SMOOTHPOINT 4479.22938972555,3784.08380270004 4450.48426805685,3784.83368396759 4507.9751370022,3783.3339214325 PathPoint;PointKind.SMOOTHPOINT 4394.47765399282,3784.08380270004 4380.27979418086,3784.97483253479 4408.6752010008,3783.1927728653 PathPoint;PointKind.SMOOTHPOINT 4360.38170745591,3784.08380270004 4351.5853467568,3783.93746137619 4370.29853200853,3784.24808263779 PathPoint;PointKind.SMOOTHPOINT 4328.23421690545,3784.08380270004 4326.97299126131,3784.04886960983 4338.13571406308,3784.35571432114 PathPoint;PointKind.SMOOTHPOINT 4320.44133137161,3784.08380270004 4311.21705482895,3784.51196908951 4321.48359423031,3784.03541564941 PathPoint;PointKind.SMOOTHPOINT 4294.1388959765,3784.08380270004 4288.1246138684,3784.32030916214 4304.51679359446,3783.67546319962 PathPoint;PointKind.SMOOTHPOINT 4270.42272388142,3784.29127693176 4269.26159551063,3784.28490400314 4280.1055710576,3784.34603691101 PathPoint;PointKind.SMOOTHPOINT 4266.86801946178,3784.26838159561 4265.9443093112,3783.65705251694 4268.47802154273,3785.33502101898 PathPoint;PointKind.SMOOTHPOINT 4263.49255172222,3784.24265384674 4257.90900069348,3784.19733524323 4264.63678867814,3784.25185918808 PathPoint;PointKind.SMOOTHPOINT 4245.43124996315,3784.08380270004 4224.49903328296,3783.90795707703 4251.87094548296,3784.13785457611 PathPoint;PointKind.SMOOTHPOINT 4197.69736273705,3784.08380270004 4176.56995637384,3783.36838245392 4218.82414349229,3784.79922294617 PathPoint;PointKind.SMOOTHPOINT 4156.78228945355,3784.08380270004 4149.46674279197,3784.34934139252 4175.53082155493,3783.40284347534 PathPoint;PointKind.SMOOTHPOINT 4140.2215083827,3784.08380270004 4135.3608473499,3784.37955379486 4143.33140554392,3783.89426708221 PathPoint;PointKind.SMOOTHPOINT 4126.58294208555,3785.06310939789 4112.83114074793,3784.78364467621 4134.9698423759,3785.23305416107 PathPoint;PointKind.SMOOTHPOINT 4098.33236350798,3784.08380270004 4079.22973730214,3783.89615535736 4117.43530251779,3784.27097797394 PathPoint;PointKind.SMOOTHPOINT 4051.57254787311,3784.08380270004 4019.43975910967,3784.51645374298 4083.69282447738,3783.65091562271 PathPoint;PointKind.SMOOTHPOINT 3960.97544418105,3784.08380270004 3903.4335881871,3784.26389694214 4018.61645903641,3783.90300035477 PathPoint;PointKind.SMOOTHPOINT 3856.74008699582,3784.08380270004 3833.09773663984,3783.57491254807 3880.38306295976,3784.59269285202 PathPoint;PointKind.SMOOTHPOINT 3799.26517105342,3784.08380270004 3784.39384427424,3784.10669803619 3814.13618502862,3784.0606713295 PathPoint;PointKind.SMOOTHPOINT 3773.93680724954,3784.08380270004 3759.14931193678,3784.09914493561 3788.7243025623,3784.06822443008 PathPoint;PointKind.SMOOTHPOINT 3746.65998745922,3785.06310939789 3734.01895305174,3784.84855413437 3759.30196027863,3785.27695655823 PathPoint;PointKind.SMOOTHPOINT 3713.53905092548,3785.06310939789 3703.13550338123,3785.63643693924 3723.94228566575,3784.48883771896 PathPoint;PointKind.SMOOTHPOINT 3670.67552165554,3785.06310939789 3636.77194956584,3785.1615357399 3704.49870312259,3784.96444702148 PathPoint;PointKind.SMOOTHPOINT 3564.49202128785,3785.06310939789 3541.28634528683,3784.67931747437 3588.78250148874,3785.46436786652 PathPoint;PointKind.SMOOTHPOINT 3473.89523039977,3785.06310939789 3438.0450791475,3785.14123678207 3509.57584189531,3784.98474597931 PathPoint;PointKind.SMOOTHPOINT 3328.74479993105,3785.06310939789 3311.09984026829,3785.17758607864 3346.39038520176,3784.94816064835 PathPoint;PointKind.SMOOTHPOINT 3262.50198845163,3785.06310939789 3242.69305086076,3784.78340864182 3293.15771682529,3785.49528837204 PathPoint;PointKind.SMOOTHPOINT 3190.41412181687,3785.06310939789 3188.68150057607,3785.07561922073 3201.74732278731,3784.97955322266 PathPoint;PointKind.SMOOTHPOINT 3184.56937946549,3785.06310939789 3183.84680227354,3785.53399801254 3186.29543182273,3783.93675327301 PathPoint;PointKind.SMOOTHPOINT 3178.88385433953,3785.13793230057 3170.36276114211,3785.73486328125 3180.34840257015,3785.03549337387 PathPoint;PointKind.SMOOTHPOINT 3153.39596050626,3785.06310939789 3116.10847496956,3784.75744485855 3161.79912660352,3785.13179540634 PathPoint;PointKind.SMOOTHPOINT 3070.592367956,3785.06310939789 3052.42565125593,3785.16224384308 3088.75908465607,3784.96350288391 PathPoint;PointKind.SMOOTHPOINT 3026.75476709483,3785.06310939789 2998.62618206914,3785.2389550209 3054.88429053246,3784.88702774048 PathPoint;PointKind.SMOOTHPOINT 2922.52034832154,3785.06310939789 2919.76642208865,3785.13628005981 2957.04952836964,3784.14493560791 PathPoint;PointKind.SMOOTHPOINT 2914.25637999502,3785.23801088333 2913.69083040063,3785.24721622467 2917.01405987566,3785.19387245178 PathPoint;PointKind.SMOOTHPOINT 2911.80430960206,3785.06310939789 2910.9750662532,3785.07491111755 2912.3707976084,3785.05508422852 PathPoint;PointKind.SMOOTHPOINT 2909.85554081164,3784.08380270004 2908.71662152337,3784.80748414993 2911.41080219623,3783.09576272964 PathPoint;PointKind.SMOOTHPOINT 2906.0196256147,3785.33289670944 2905.45126078449,3785.33714532852 2907.37156441281,3785.32298326492 PathPoint;PointKind.SMOOTHPOINT 2904.3126543002,3785.34399032593 2875.59850022545,3785.50779819489 2904.88227034632,3785.34092187881 PathPoint;PointKind.SMOOTHPOINT 2808.54302400807,3785.06310939789 2763.50738390656,3785.68222761154 2845.68380447852,3784.55209493637 PathPoint;PointKind.SMOOTHPOINT 2607.86582077941,3784.08380270004 2562.05004755377,3783.88104915619 2653.68190680902,3784.2863202095 PathPoint;PointKind.SMOOTHPOINT 2465.63823069234,3784.08380270004 2424.20577962725,3785.78183412552 2507.07068175743,3782.38577127457 PathPoint;PointKind.SMOOTHPOINT 2382.83463814208,3783.1044960022 2337.68451178418,3783.80835056305 2427.98476449998,3782.40087747574 PathPoint;PointKind.SMOOTHPOINT 2281.52180853452,3784.08380270004 2234.45388098014,3784.37790155411 2328.5897360889,3783.78923177719 PathPoint;PointKind.SMOOTHPOINT 2193.84723242014,3784.08380270004 2163.58813949212,3783.64619493484 2254.44330646702,3784.95949029922 PathPoint;PointKind.SMOOTHPOINT 2120.78529419414,3784.08380270004 2100.72767743981,3783.81684780121 2140.79161109589,3784.3498134613 PathPoint;PointKind.SMOOTHPOINT 2063.30975264378,3784.08380270004 2024.96561526534,3783.83360624313 2084.26011195476,3784.22046661377 PathPoint;PointKind.SMOOTHPOINT 1982.45430327599,3784.08380270004 1927.99294086921,3783.76232385635 2036.91597848674,3784.40504550934 PathPoint;PointKind.SMOOTHPOINT 1849.96836751318,3783.1044960022 1802.35772505489,3783.38089227676 1899.67166859233,3782.81629800797 PathPoint;PointKind.SMOOTHPOINT 1722.3534153145,3782.12542533875 1676.42534546032,3782.57082223892 1770.70290077166,3781.65666103363 PathPoint;PointKind.SMOOTHPOINT 1621.79068964907,3783.63840579987 1580.07264855096,3784.37247276306 1663.50779233523,3782.90410280228 PathPoint;PointKind.SMOOTHPOINT 1478.81299561988,3782.15941429138 1445.57757282975,3782.81747817993 1512.04904401796,3781.50158643723 PathPoint;PointKind.SMOOTHPOINT 1359.96562615422,3782.15941429138 1311.23451984243,3781.88065767288 1408.69610685806,3782.43864297867 PathPoint;PointKind.SMOOTHPOINT 1238.19510350293,3782.15941429138 1115.43048980574,3781.81055545807 1312.87611512528,3782.37231731415 PathPoint;PointKind.SMOOTHPOINT 1130.7353629001,3781.90756559372 1122.8336215815,3781.95996522903 1129.15382598126,3781.91818714142 PathPoint;PointKind.SMOOTHPOINT 1102.78695296643,3782.15941429138 1044.40584389628,3782.7867937088 1113.80328350594,3782.04116106033 PathPoint;PointKind.SMOOTHPOINT 997.577524189967,3782.15941429138 939.112583653391,3782.52668380737 1056.04246472654,3781.79238080978 PathPoint;PointKind.SMOOTHPOINT 871.011090929565,3781.10882520676 819.920504202657,3781.74422979355 922.101052048514,3780.47436475754 PathPoint;PointKind.SMOOTHPOINT 810.507294056556,3781.10882520676 796.825873614255,3781.15107536316 838.690619778603,3781.0226726532 PathPoint;PointKind.SMOOTHPOINT 766.865508486366,3782.10913896561 758.296869084108,3783.17341804504 771.159055904881,3781.57593727112 PathPoint;PointKind.SMOOTHPOINT 733.142111488687,3783.10921669006 727.210096827116,3783.22369337082 738.151354411615,3783.01197052002 PathPoint;PointKind.SMOOTHPOINT 705.328832874035,3782.12542533875 684.662812380151,3780.93463182449 721.790767887455,3783.07428359985 PathPoint;PointKind.SMOOTHPOINT 659.543401634379,3782.12542533875 643.76244088368,3781.58632278442 671.736500743641,3782.54202604294 PathPoint;PointKind.SMOOTHPOINT 626.421839492683,3782.12542533875 601.370932818357,3785.0449347496 645.555120488482,3779.89560842514 PathPoint;PointKind.SMOOTHPOINT 582.584864239471,3782.12542533875 582.332744232235,3782.08270311356 586.507738942633,3782.79127836227 PathPoint;PointKind.SMOOTHPOINT 563.533850690203,3783.10921669006 558.632525140099,3783.57868909836 568.096096726852,3782.67231702805 PathPoint;PointKind.SMOOTHPOINT 543.696760741202,3785.10937213898 536.357128173225,3787.126994133 547.214241487319,3784.14233922958 PathPoint;PointKind.SMOOTHPOINT 522.187107915412,3785.06310939789 514.271916025705,3785.03997802734 528.131321932172,3785.08010387421 PathPoint;PointKind.SMOOTHPOINT 506.997659489382,3784.10905838013 497.378624324966,3783.35988521576 516.617945869714,3784.85893964767 PathPoint;PointKind.SMOOTHPOINT 490.039617364948,3785.06310939789 470.959513045614,3785.47971010208 509.119408880303,3784.64603662491 PathPoint;PointKind.SMOOTHPOINT 462.745280551791,3782.05721139908 452.071470369509,3782.29442596436 473.419090734073,3781.82023286819 PathPoint;PointKind.SMOOTHPOINT 446.494488224331,3783.10921669006 441.629760739794,3782.53022432327 450.962267459262,3783.6407661438 PathPoint;PointKind.SMOOTHPOINT 426.701503636397,3783.03628206253 426.009268430425,3784.24643039703 426.370557026402,3783.61480236053 PathPoint;PointKind.SMOOTHPOINT 400.868899818047,3783.10921669006 355.428804171429,3780.46822786331 409.963049905363,3783.63769769669 PathPoint;PointKind.SMOOTHPOINT 312.593114455641,3782.10913896561 299.562013486099,3781.17231845856 337.597726141045,3783.90654087067 PathPoint;PointKind.SMOOTHPOINT 271.926720335612,3779.10890579224 267.11110307581,3775.83676099777 277.16681259519,3782.66948461533 PathPoint;PointKind.SMOOTHPOINT 266.967526049357,3767.10797309875 266.442640972257,3764.28759813309 268.017921811514,3772.7517914772 PathPoint;PointKind.SMOOTHPOINT 265.97562463131,3698.14934492111 265.495470523236,3679.60742712021 266.292182258261,3710.36459684372 PathPoint;PointKind.CORNERPOINT 263.059665937196,3523.63353967667 263.059665937196,3523.63353967667 263.059665937196,3523.63353967667 PathPoint;PointKind.CORNERPOINT 263.059665937196,3084.98155832291 263.059665937196,3084.98155832291 263.059665937196,3084.98155832291 PathPoint;PointKind.CORNERPOINT 263.059665937196,2486.72972917557 263.059665937196,2486.72972917557 263.059665937196,2486.72972917557 PathPoint;PointKind.SMOOTHPOINT 264.034050332408,2475.95947980881 264.152290236546,2467.69025087357 263.916123232249,2484.22870874405 PathPoint;PointKind.SMOOTHPOINT 263.059665937196,2458.3350276947 262.71745838395,2443.01663160324 263.402499098401,2473.65295171738 PathPoint;PointKind.SMOOTHPOINT 264.034050332408,2433.85684490204 263.600816821214,2426.4661359787 264.245505822348,2437.46628284454 PathPoint;PointKind.SMOOTHPOINT 263.059665937196,2375.10882854462 262.893567024241,2349.10609960556 263.233584949632,2402.23885774612 PathPoint;PointKind.SMOOTHPOINT 267.930962305296,2107.80459880829 268.041069305975,2059.91510868073 267.820229696659,2155.69432497025 PathPoint;PointKind.SMOOTHPOINT 265.00843472762,2015.76605558395 264.441321113328,2001.96252822876 265.575235537932,2029.56958293915 PathPoint;PointKind.SMOOTHPOINT 266.956577910085,1969.74666595459 266.899021977912,1942.61781692505 267.013821038278,1996.87551498413 PathPoint;PointKind.SMOOTHPOINT 268.905033896529,1917.85261631012 267.458941100682,1901.07340335846 270.350813888397,1934.63159322739 PathPoint;PointKind.SMOOTHPOINT 266.956577910085,1885.54092407227 267.036968532739,1873.55037689209 266.876812895388,1897.53170728683 PathPoint;PointKind.SMOOTHPOINT 267.930962305296,1861.06250524521 264.441321113328,1848.66668701172 271.419977889306,1873.45879554749 PathPoint;PointKind.SMOOTHPOINT 267.930962305296,1827.77245044708 266.773587582252,1809.92943048477 269.087398616403,1845.61476230621 PathPoint;PointKind.SMOOTHPOINT 267.930962305296,1767.06582069397 270.149055321812,1738.02060842514 265.711930876843,1796.1110329628 PathPoint;PointKind.SMOOTHPOINT 267.930962305296,1669.15238142014 267.438296038054,1662.98385858536 269.286654751154,1686.13765239716 PathPoint;PointKind.SMOOTHPOINT 266.956577910085,1630.96602916718 267.356028591525,1610.02175331116 266.556814424666,1651.91030502319 PathPoint;PointKind.SMOOTHPOINT 266.956577910085,1529.13583517075 265.792008695519,1508.50902557373 268.120834320671,1549.76288080215 PathPoint;PointKind.SMOOTHPOINT 267.930962305296,1423.38935852051 268.368887876178,1397.70622014999 267.493349538394,1449.07249689102 PathPoint;PointKind.SMOOTHPOINT 267.930962305296,1336.24640464783 267.036968532739,1313.38198900223 268.825581685812,1359.11058425903 PathPoint;PointKind.SMOOTHPOINT 267.463945964349,1259.27252054214 267.475519711579,1254.69180107117 267.433291174387,1271.44268989563 PathPoint;PointKind.SMOOTHPOINT 265.00843472762,1244.2076253891 265.076625995086,1242.37812280655 264.924916065173,1246.44357919693 PathPoint;PointKind.SMOOTHPOINT 265.982506318852,1230.49992799759 266.941876123062,1226.88317298889 265.125110611862,1233.72911453247 PathPoint;PointKind.SMOOTHPOINT 267.463945964349,1220.42102336884 268.255027227749,1198.81490707397 267.284709284267,1225.30669927597 PathPoint;PointKind.SMOOTHPOINT 266.956577910085,1189.37612771988 266.345046130746,1181.0200381279 268.127403204235,1205.38822889328 PathPoint;PointKind.SMOOTHPOINT 267.930962305296,1144.33628082275 268.605367684454,1124.47257041931 267.242480747075,1164.60502624512 PathPoint;PointKind.SMOOTHPOINT 267.463945964349,1110.83993196487 267.300662287206,1095.10847568512 267.605333362948,1124.4482588768 PathPoint;PointKind.SMOOTHPOINT 267.930962305296,1061.10937356949 267.063244066992,1041.87870740891 268.798367739621,1080.34003973007 PathPoint;PointKind.SMOOTHPOINT 268.905033896529,1007.25718259811 268.965717868494,985.348942279816 268.844037120585,1029.16542291641 PathPoint;PointKind.SMOOTHPOINT 269.87941829174,935.780303478241 270.762151121046,908.06608915329 268.996059854476,963.494281768799 PathPoint;PointKind.SMOOTHPOINT 269.87941829174,856.470623016357 270.773412064297,829.804165363312 268.985111715204,883.136372566223 PathPoint;PointKind.SMOOTHPOINT 266.885884210785,791.847474575043 268.366072640365,767.529559135437 265.405382977226,816.165153980255 PathPoint;PointKind.SMOOTHPOINT 266.885884210785,737.994811534882 266.322524244244,714.32740688324 267.448931373347,761.662216186523 PathPoint;PointKind.SMOOTHPOINT 266.471731742323,689.450798034668 266.099182203094,673.230042457581 266.84490688951,705.671553611755 PathPoint;PointKind.SMOOTHPOINT 266.471731742323,664.545865058899 267.104221388268,658.597798347473 265.839554900357,670.494403839111 PathPoint;PointKind.SMOOTHPOINT 265.480143128255,640.637233257294 265.597757424435,624.555265903473 265.364405655951,656.453897953033 PathPoint;PointKind.SMOOTHPOINT 265.480143128255,596.805174350739 264.890194823482,574.021010398865 266.069778629049,619.588866233826 PathPoint;PointKind.SMOOTHPOINT 266.471731742323,570.903940200806 265.94434423339,564.180972576141 266.946880986729,576.957278251648 PathPoint;PointKind.SMOOTHPOINT 265.911812619553,550.980277061462 264.619306577493,543.172023296356 267.263125809702,559.146595001221 PathPoint;PointKind.SMOOTHPOINT 264.93774102832,517.689514160156 265.228335924998,502.483942508698 264.637136404308,533.411529064178 PathPoint;PointKind.SMOOTHPOINT 264.93774102832,485.378057956696 263.813210723092,455.717504024506 265.33343806201,495.816679000854 PathPoint;PointKind.SMOOTHPOINT 264.983723213263,427.894713878632 264.691877100668,399.812757968903 265.327181982426,461.012227535248 PathPoint;PointKind.SMOOTHPOINT 264.983723213263,332.887330055237 264.694692336481,302.467925548553 265.260867538835,362.127506732941 PathPoint;PointKind.SMOOTHPOINT 264.983723213263,232.832822799683 264.752561072633,220.94447851181 265.316233843154,249.938235282898 PathPoint;PointKind.SMOOTHPOINT 266.967526049357,197.829866409302 266.938435279291,193.133254051208 267.0210155298,206.55157327652 PathPoint";
	
	mask645[1] = "PointKind.SMOOTHPOINT 273.074640274049,179.828467369079 277.464250564576,174.522414207458 271.823972702027,181.340503692626 PathPoint;PointKind.SMOOTHPOINT 351.930269241334,176.427447795867 212.385162353517,178.059153556823 314.366497039796,176.865763664245 PathPoint;PointKind.SMOOTHPOINT 942.184309005738,174.013051986694 977.617792129518,173.933036327362 772.944816589356,174.39707994461 PathPoint;PointKind.SMOOTHPOINT 1493.54082489014,174.992358684539 1505.21571540833,174.786064624786 1481.86719322205,175.199124813079 PathPoint;PointKind.SMOOTHPOINT 1535.42874717712,178.908877372741 1541.9794883728,178.940505981445 1524.37100791931,178.85529756546 PathPoint;PointKind.SMOOTHPOINT 1545.17035865784,176.950500011444 1547.04698944092,176.635158061981 1540.19978904724,177.785589694976 PathPoint;PointKind.SMOOTHPOINT 1554.71968078613,176.23012304306 1557.93226623535,176.094167232513 1550.81158065796,176.395583152771 PathPoint;PointKind.SMOOTHPOINT 1562.11353683472,178.999986648559 1563.42934989929,179.160726070404 1556.28065490723,178.287398815155 PathPoint;PointKind.SMOOTHPOINT 1567.11274528504,176.042003631591 1571.0129776001,176.234135627746 1565.82273864746,175.978510379791 PathPoint;PointKind.SMOOTHPOINT 1580.23846054077,177.929806709289 1584.22272109985,178.989129066467 1576.03012466431,176.810295581817 PathPoint;PointKind.SMOOTHPOINT 1605.56620979309,179.887948036193 1621.04188346863,179.842157363891 1594.67715644837,179.920284748077 PathPoint;PointKind.SMOOTHPOINT 1849.93041419983,177.878823280334 1861.14393615723,178.364582061767 1838.71657752991,177.393064498901 PathPoint;PointKind.CORNERPOINT 1876.1031665802,177.999908924102 1876.1031665802,177.999908924102 1876.1031665802,177.999908924102 PathPoint;PointKind.SMOOTHPOINT 1887.921251297,178.857657909393 1889.42966842651,178.980631828308 1882.07483673096,178.381104469299 PathPoint;PointKind.SMOOTHPOINT 1895.73178672791,176.745386123657 1900.55884742737,176.551837921142 1889.59741020203,176.991806030273 PathPoint;PointKind.SMOOTHPOINT 1908.37850952149,177.878823280334 1920.00682258606,178.919026851654 1896.74925231934,176.838147640228 PathPoint;PointKind.SMOOTHPOINT 1962.9292049408,177.878823280334 1971.87962913513,177.802112102508 1953.97972488403,177.955062389373 PathPoint;PointKind.SMOOTHPOINT 2007.73954772949,177.878823280334 2021.65833854675,177.760334014892 1993.81981277466,177.997312545776 PathPoint;PointKind.SMOOTHPOINT 2057.42038154602,177.878823280334 1871.88413047791,177.719972133636 2043.15509223938,177.866313457489 PathPoint;PointKind.SMOOTHPOINT 2559.18481254578,176.865291595459 2580.09777450562,176.652152538299 2425.89807891846,178.222253322601 PathPoint;PointKind.SMOOTHPOINT 2609.84031105042,175.886220932006 2617.72795104981,175.492279529571 2601.95204162598,176.280162334442 PathPoint;PointKind.SMOOTHPOINT 2638.08985137939,176.865291595459 2647.81258010864,176.54381275177 2628.3677520752,177.186534404754 PathPoint;PointKind.SMOOTHPOINT 2695.56359672546,176.865291595459 2703.09403800964,176.773238182067 2688.03284072876,176.956872940063 PathPoint;PointKind.SMOOTHPOINT 2722.07529449463,175.999989509582 2731.11667060852,176.355693340301 2713.03391838074,175.644285678863 PathPoint;PointKind.SMOOTHPOINT 2755.95976257324,177.844598293304 2774.25494575501,178.349475860595 2737.66426467896,177.339720726013 PathPoint;PointKind.SMOOTHPOINT 2796.87302017212,177.844598293304 2804.44154167175,177.695424556732 2789.30418395996,177.993535995483 PathPoint;PointKind.SMOOTHPOINT 2818.30368423462,175.886220932006 2832.34584236145,175.570170879364 2807.79826545715,176.12249135971 PathPoint;PointKind.SMOOTHPOINT 2850.45030975342,176.865291595459 2855.49168968201,177.068045139312 2845.40798568726,176.662302017211 PathPoint;PointKind.SMOOTHPOINT 2863.26005363464,176.465213298797 2869.63864707947,175.953018665313 2856.23346710205,177.029099464416 PathPoint;PointKind.SMOOTHPOINT 2879.67357063294,177.844598293304 2882.28285217285,178.062222003936 2876.01503753662,177.539405822753 PathPoint;PointKind.SMOOTHPOINT 2890.07009887695,177.000067234039 2892.99724006653,176.461908817291 2883.02935028076,178.294951915741 PathPoint;PointKind.SMOOTHPOINT 2904.39644241333,175.828156471252 2912.32184791565,175.12217760086 2900.62398338318,176.16450548172 PathPoint;PointKind.SMOOTHPOINT 2915.71696662903,177.844598293304 2923.03025627136,178.009114265441 2908.40304756165,177.679846286773 PathPoint;PointKind.SMOOTHPOINT 2951.75941848755,176.865291595458 2961.85445213318,177.205417156219 2941.66375541687,176.524930000304 PathPoint;PointKind.SMOOTHPOINT 2980.98299407959,176.865291595458 2997.67629051209,176.693222522735 2964.29001235962,177.037360668181 PathPoint;PointKind.SMOOTHPOINT 3556.7467250824,182.825396060943 3589.29272079468,183.7513589859 3524.20072937012,181.899669170379 PathPoint;PointKind.SMOOTHPOINT 3657.06385993958,179.836728572845 3661.68793106079,180.104391574859 3639.07174491882,178.795108795165 PathPoint;PointKind.SMOOTHPOINT 3672.65031242371,181.795105934142 3681.76942253113,182.573311328887 3667.85314941406,181.386058330535 PathPoint;PointKind.SMOOTHPOINT 3715.51195526123,179.836728572845 3719.44208526611,179.825870990752 3713.33382987976,179.842865467071 PathPoint;PointKind.SMOOTHPOINT 3726.22697257996,181.795105934142 3729.80179214478,181.81988954544 3719.12548446655,181.745538711547 PathPoint;PointKind.SMOOTHPOINT 3740.87463760376,182.804388999938 3742.13694953919,182.780077457427 3733.06126976013,182.954034805297 PathPoint;PointKind.SMOOTHPOINT 3748.04158592224,183.999903202056 3749.93647003174,183.327441215514 3745.89807891846,184.761586189269 PathPoint;PointKind.SMOOTHPOINT 3751.59059906006,181.783304214477 3758.3226146698,181.861431598662 3750.75094604492,181.773862838744 PathPoint;PointKind.SMOOTHPOINT 3770.26312255859,182.828700542449 3788.55264091492,181.793689727782 3764.84471702576,183.135309219359 PathPoint;PointKind.SMOOTHPOINT 3797.3567237854,180.867254734038 3804.60738563538,181.356790065764 3798.55829620361,180.948450565337 PathPoint;PointKind.SMOOTHPOINT 3807.09833526611,181.846325397491 3821.32648849487,182.806985378264 3801.98457145691,181.501007080077 PathPoint;PointKind.SMOOTHPOINT 3824.81350326538,179.828467369079 3826.2819519043,179.791646003722 3815.23113632202,180.067570209502 PathPoint;PointKind.SMOOTHPOINT 3832.42514038086,180.867254734038 3838.20168876648,181.106593608855 3828.53592300415,180.706279277801 PathPoint;PointKind.SMOOTHPOINT 3842.66651535034,179.828467369079 3850.05124473572,180.380315780639 3841.52694129944,179.743494987487 PathPoint;PointKind.SMOOTHPOINT 3862.62338066101,180.867254734038 3870.65610313416,180.412416458129 3854.59065818787,181.322329044341 PathPoint;PointKind.SMOOTHPOINT 3882.10597419739,180.867254734038 3893.53696250916,181.777403354644 3870.67530059814,179.956634044646 PathPoint;PointKind.SMOOTHPOINT 3906.45874404907,181.846325397491 3913.47211265564,181.876773834228 3899.44600486755,181.81564092636 PathPoint;PointKind.SMOOTHPOINT 3923.01954650879,178.908877372741 3934.05305290222,177.965919971465 3907.73490333557,180.214855670928 PathPoint;PointKind.SMOOTHPOINT 3937.63133430481,181.846325397491 3947.76413345337,181.505727767943 3931.10010528564,182.065601348876 PathPoint;PointKind.CORNERPOINT 3956.1395778656,180.867254734038 3956.1395778656,180.867254734038 3956.1395778656,180.867254734038 PathPoint;PointKind.SMOOTHPOINT 3966.8555393219,178.908877372741 3974.35136222839,178.262615203857 3959.35877227783,179.555375576018 PathPoint;PointKind.SMOOTHPOINT 3980.49297714233,179.887948036193 3988.25410270691,179.839088916778 3970.14711761475,179.953093528747 PathPoint;PointKind.SMOOTHPOINT 3994.13072967529,178.908877372741 3995.77636146545,178.607697486877 3989.19005775452,179.8135972023 PathPoint;PointKind.SMOOTHPOINT 3999.97557067871,176.950500011443 4008.07280921936,176.548297405242 3996.62986183167,177.116904258727 PathPoint;PointKind.SMOOTHPOINT 4013.61363792419,178.908877372741 4016.33275413513,179.332087039947 4009.45345306396,178.261671066283 PathPoint;PointKind.SMOOTHPOINT 4026.27704048157,178.908877372741 4038.5983505249,179.620285034179 4021.40623474121,178.627524375915 PathPoint;PointKind.SMOOTHPOINT 4059.39770126343,179.887948036193 4066.98258781433,179.967963695525 4041.29228973389,179.696996212005 PathPoint;PointKind.SMOOTHPOINT 4082.77675056458,178.908877372741 4084.64897537231,178.698570728301 4075.04772567749,179.77724790573 PathPoint;PointKind.SMOOTHPOINT 4102.25934410095,178.908877372741 4105.24344825745,179.362535476684 4095.72087669373,177.915408611297 PathPoint;PointKind.SMOOTHPOINT 4111.02629089355,178.908877372741 4126.20896720886,178.583858013152 4108.02047157288,178.973078727721 PathPoint;PointKind.SMOOTHPOINT 4154.10099411011,180.828781127929 4163.14016723633,180.672290325164 4139.72838783264,181.077325344085 PathPoint;PointKind.SMOOTHPOINT 4178.24196243286,180.695185661315 4178.75557327271,180.661668777465 4170.62906646729,181.19180202484 PathPoint;PointKind.SMOOTHPOINT 4184.08585929871,179.887948036193 4186.99569129944,179.704549312591 4182.94439697266,179.960174560546 PathPoint;PointKind.SMOOTHPOINT 4191.87877082825,179.887948036193 4204.50472259521,179.291253089904 4188.85060691833,180.030984878539 PathPoint;PointKind.SMOOTHPOINT 4216.23185539246,180.867254734038 4222.90564918518,180.91587781906 4206.24004745483,180.794556140899 PathPoint;PointKind.SMOOTHPOINT 4235.71507835388,178.908877372741 4240.05339050293,178.040742874145 4229.8371925354,180.085744857787 PathPoint;PointKind.SMOOTHPOINT 4255.19735717773,176.950500011443 4257.13976287842,177.305731773376 4245.66408538818,175.207858085631 PathPoint;PointKind.SMOOTHPOINT 4263.02457237244,177.999908924102 4268.79356765747,179.585351943969 4261.14479446411,177.483229637145 PathPoint;PointKind.SMOOTHPOINT 4274.68026542664,178.908877372741 4286.87159919739,178.905100822448 4268.400806427,178.910765647887 PathPoint;PointKind.SMOOTHPOINT 4291.24012374878,177.929806709289 4301.74994850159,177.658367156982 4280.72998428345,178.201482295989 PathPoint;PointKind.SMOOTHPOINT 4307.83397102356,180.828781127929 4309.91233253479,180.757026672362 4298.75105285645,181.142470836638 PathPoint;PointKind.SMOOTHPOINT 4315.59383773804,180.867254734038 4317.62436294556,180.710999965667 4313.09439086914,181.05985879898 PathPoint;PointKind.SMOOTHPOINT 4322.41239929199,180.867254734038 4323.09280776978,180.847663879394 4320.04607582092,180.934524536132 PathPoint;PointKind.SMOOTHPOINT 4324.36046981812,178.908877372741 4331.57588386536,178.250813484191 4323.60578918457,178.977563381194 PathPoint;PointKind.SMOOTHPOINT 4348.71386909485,178.908877372741 4352.11087608337,178.866627216338 4346.66194343567,178.934605121612 PathPoint;PointKind.SMOOTHPOINT 4358.45516586304,176.950500011443 4369.14154434204,176.901168823241 4354.96815109253,176.966786384582 PathPoint;PointKind.SMOOTHPOINT 4381.83452987671,176.950500011443 4383.16828155518,176.996762752532 4371.01943397522,176.576149463653 PathPoint;PointKind.SMOOTHPOINT 4386.70502090454,178.908877372741 4409.49807548523,179.785981178283 4385.32311820984,178.855533599853 PathPoint;PointKind.SMOOTHPOINT 4447.10055732727,178.908877372741 4447.37718963623,178.911945819854 4433.44549560547,178.748137950896 PathPoint;PointKind.SMOOTHPOINT 4463.66104507446,176.950500011443 4466.57905960083,178.174338340758 4469.87913513184,179.558207988738 PathPoint;PointKind.SMOOTHPOINT 4471.94427871704,179.378349781035 4473.01839256287,179.258680343627 4468.64609146118,179.745383262633 PathPoint;PointKind.SMOOTHPOINT 4478.27314758301,176.950500011443 4483.53136444092,176.754355430602 4475.73341751099,177.045149803161 PathPoint;PointKind.SMOOTHPOINT 4493.85897064209,178.908877372741 4500.92332267761,179.205572605132 4490.05629920959,178.74908208847 PathPoint;PointKind.SMOOTHPOINT 4512.36752891541,177.929806709289 4515.82905197144,177.736494541167 4501.37462043762,178.543968200683 PathPoint;PointKind.SMOOTHPOINT 4526.97963142395,177.929806709289 4541.93917655945,177.997784614562 4520.7231464386,177.901246547698 PathPoint;PointKind.SMOOTHPOINT 4566.35425949097,177.7388548851 4567.62223625183,177.732245922088 4552.67150306702,177.809901237487 PathPoint;PointKind.SMOOTHPOINT 4571.7893447876,176.950500011443 4575.36919975281,176.938934326171 4570.46503448486,176.954748630523 PathPoint;PointKind.SMOOTHPOINT 4579.58225631714,176.950500011443 4580.27965927124,176.952860355376 4575.43654823303,176.937282085418 PathPoint;PointKind.SMOOTHPOINT 4581.53064155579,177.929806709289 4582.33095550537,177.948925495147 4580.77061080933,177.911632061004 PathPoint;PointKind.SMOOTHPOINT 4583.47902679443,176.950500011443 4586.53047943115,176.978116035461 4582.61356735229,176.942710876464 PathPoint;PointKind.SMOOTHPOINT 4593.22032356262,176.950500011443 4596.97547340393,177.178745269774 4589.55958747864,176.728155612945 PathPoint;PointKind.SMOOTHPOINT 4604.91000556946,177.929806709289 4643.48306083679,178.472921848296 4601.36665725708,177.880239486693 PathPoint;PointKind.SMOOTHPOINT 4654.59020996094,178.908877372741 4670.05864524841,179.245462417602 4639.12208938599,178.57229232788 PathPoint;PointKind.SMOOTHPOINT 4684.78876495361,177.929806709289 4698.15240287781,178.25860261917 4671.42449760437,177.601010799407 PathPoint;PointKind.SMOOTHPOINT 4713.03799057007,177.929806709289 4731.66834259033,177.53987789154 4694.40732383728,178.319971561431 PathPoint;PointKind.SMOOTHPOINT 4743.2359161377,178.908877372741 4763.75769042969,179.253251552581 4722.71445655823,178.564739227294 PathPoint;PointKind.SMOOTHPOINT 4787.07190895081,178.908877372741 4821.36078262329,178.040742874145 4752.78334999084,179.777011871337 PathPoint;PointKind.SMOOTHPOINT 4853.312915802,178.908877372741 4884.95851898193,178.735864162444 4828.82607841492,179.042708873748 PathPoint;PointKind.SMOOTHPOINT 4896.10374832153,179.866940975188 4904.00082969666,180.046091079711 4903.91585731506,180.044438838958 PathPoint;PointKind.SMOOTHPOINT 4908.76683616638,179.866940975188 4913.43717002869,178.379688262939 4905.30059242249,180.971345901488 PathPoint;PointKind.SMOOTHPOINT 4933.19136047363,178.908877372741 4943.60708618164,179.045305252074 4925.52276039124,178.80832672119 PathPoint;PointKind.SMOOTHPOINT 4982.89894485474,178.014307022094 4989.07014274597,178.129255771636 4965.66088104248,177.692828178405 PathPoint;PointKind.SMOOTHPOINT 4998.80608940125,179.148216247558 4999.66493988037,179.910135269164 4998.09326553345,178.515644073485 PathPoint;PointKind.SMOOTHPOINT 5006.00041770935,181.999983787536 5006.73621559143,182.832949161529 5004.91969490051,180.776617527007 PathPoint;PointKind.SMOOTHPOINT 5008.0287399292,185.78408718109 5011.94628143311,197.964406013488 5007.46320152283,184.025394916534 PathPoint;PointKind.SMOOTHPOINT 5011.81536102295,234.206542968749 5011.69954681396,236.885533332824 5012.03660392761,229.096398353576 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,305.217254161834 5013.72188949585,323.89843225479 5014.20749092102,295.715217590331 PathPoint;PointKind.SMOOTHPOINT 5015.9925403595,442.29611635208 5015.96106910706,451.175966262816 5016.05296516418,425.092277526855 PathPoint;PointKind.SMOOTHPOINT 5014.41614532471,703.772656917571 5014.40292739868,706.27155303955 5015.0760974884,579.423601627349 PathPoint;PointKind.SMOOTHPOINT 5013.00025367737,711.00003004074 5011.86571502686,712.484922409057 5014.51465034485,709.017341136931 PathPoint;PointKind.SMOOTHPOINT 5014.35351753235,715.715525150298 5013.77035522461,827.950587272643 5014.36138534546,714.232757091521 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,941.654963493347 5015.42133712769,958.567771911621 5013.40056800842,933.751587867736 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,998.444602489471 5014.18892288208,1010.65324544907 5013.89938735962,986.23619556427 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,1086.56686306 5014.94612121582,1099.75080013275 5015.09057426453,1073.38316202164 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,1256.93672418594 5014.29907226562,1263.84781122208 5013.78892326355,1250.02516508102 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,1276.51908159256 5015.00308418274,1288.6167883873 5015.03329658508,1264.42137479782 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,1319.60102319717 5013.60292816162,1351.6065788269 5014.48601150513,1287.59570360184 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,1535.9898018837 5015.33007049561,1549.4756269455 5014.70631027222,1522.50374078751 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,1597.67526626587 5014.0564289093,1606.95377826691 5014.0177192688,1577.82524585724 PathPoint;PointKind.SMOOTHPOINT 5015.02826118469,1636.55579566956 5015.06099128723,1637.6656293869 5014.60465812683,1622.19522714615 PathPoint;PointKind.SMOOTHPOINT 5015.12361907959,1639.86641407013 5014.73369026184,1641.63006305695 5015.360912323,1638.79599809647 PathPoint;PointKind.SMOOTHPOINT 5015.21708869934,1643.26011657715 5015.57837867737,1656.91730260849 5015.18719100952,1642.14036941528 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,1672.08959341049 5013.48837280273,1679.5095705986 5015.71999931335,1668.68503332138 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,1689.7140455246 5014.63801765442,1697.01175689697 5015.39899253845,1682.41657018661 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,1705.3803563118 5015.48616790771,1711.6642999649 5014.55021286011,1699.09641265869 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,1725.94202041626 5015.23502731323,1737.02997207642 5014.80135345459,1714.8543047905 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,1775.87792873383 5014.16185760498,1796.98294401169 5015.87420845032,1754.77314949036 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,1848.33411455154 5015.21614456177,1863.35015058517 5014.81992149353,1833.31807851791 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,1880.64533472061 5015.75272941589,1904.73382472992 5012.33558082581,1856.5570807457 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,1951.14337921143 5015.36468887329,1968.2818365097 5014.67200660706,1934.00444984436 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,1999.12091016769 5015.06760025024,2003.76748323441 5014.88506698608,1986.58701181412 PathPoint;PointKind.SMOOTHPOINT 5014.43439865112,2012.65158176422 5013.827003479,2020.0585770607 5014.79317092896,2008.2875418663 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,2034.36957836151 5014.18892288208,2044.49734210968 5013.95320320129,2027.99688577652 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,2087.24293470383 5015.33007049561,2113.19774866104 5014.70631027222,2061.28812074661 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,2212.57224082947 5014.04793167114,2242.9368853569 5015.9887638092,2182.20736026764 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,2290.90308666229 5014.40953636169,2305.86176633835 5015.62715911865,2275.94417095184 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,2364.33810710907 5014.00544548035,2365.59215784073 5014.57696342468,2346.98509454727 PathPoint;PointKind.SMOOTHPOINT 5013.07011985779,2369.23393249512 5013.0238571167,2374.83243227005 5013.1333770752,2361.55148506165 PathPoint;PointKind.SMOOTHPOINT 5013.81504440308,2374.5836520195 5014.38845062256,2397.93477058411 5013.79395866394,2373.7403011322 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,2457.35595703125 5015.01063728333,2476.12777233124 5013.22307014465,2441.40664100647 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,2532.74959087372 5014.394115448,2555.55617809296 5013.69388008118,2509.94205951691 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,2600.3094792366 5015.69167518616,2621.65147304535 5014.34502029419,2578.96748542786 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,2672.76566505432 5013.77381706238,2705.05776643753 5014.3141784668,2640.47309160233 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,2734.45112943649 5014.39820671082,2750.15142917633 5013.69010353088,2718.75059366226 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,2794.17821645737 5014.82778930664,2821.16166830063 5015.20859146118,2767.19476461411 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,2863.69695425034 5014.99395751953,2880.19457817078 5015.04242324829,2847.11601018906 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,2910.69517850876 5013.49938774109,2921.03041648865 5014.56406021118,2900.82752466202 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,2952.79804944992 5014.66004753113,2965.06404876709 5015.37633323669,2940.53205013275 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,2984.13043498993 5014.45737266541,2991.55796527863 5013.46571350098,2973.74256134033 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,3027.21237659454 5015.12739562988,3033.8475394249 5014.7434463501,3010.5667591095 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,3044.83659267426 5015.534948349,3062.02367305756 5014.85831642151,3039.51283693314 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,3062.46128082275 5013.96044158936,3071.58707857132 5014.12786865234,3053.33548307419 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,3098.68901968002 5014.38278579712,3111.92677259445 5013.70520973206,3085.45197486877 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,3148.62516403198 5013.75871086121,3160.74505805969 5014.31103134155,3137.2841835022 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,3177.99917221069 5014.13573646545,3186.21175289154 5013.93715286255,3168.40673446655 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,3217.16435909271 5014.14517784119,3219.35216188431 5013.44273948669,3204.14375782013 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,3224.99763250351 5015.20292663574,3227.1960568428 5014.87436676025,3223.28425884247 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,3229.89345788956 5014.0164604187,3237.15788841248 5014.05044937134,3228.24900627136 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,3253.39257001877 5014.43597221375,3268.274538517 5013.72503662109,3241.25733375549 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,3289.62054491043 5014.58073997498,3299.26278591156 5013.50757026672,3279.9783039093 PathPoint;PointKind.SMOOTHPOINT 5013.07011985779,3306.26592636108 5014.32204627991,3315.1854300499 5011.81819343567,3297.34642267227 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,3333.68179321289 5013.9635887146,3345.04732131958 5014.12063026428,3322.89124488831 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,3351.306245327 5016.06051826477,3356.56107902527 5013.97554779053,3346.05117559433 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,3367.95139074326 5014.72141647339,3373.24871063232 5015.31496429443,3362.65383481979 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,3387.53422021866 5013.53809738159,3400.44270515442 5016.49859809875,3374.62526321411 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,3405.15843629837 5013.91103172302,3422.10617780685 5014.1775932312,3388.21116685867 PathPoint;PointKind.SMOOTHPOINT 5015.01819038391,3449.21968460083 5014.62259674072,3467.89566993713 5015.4137840271,3430.54322719574 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,3523.63353967667 5014.20749092102,3553.19141864777 5013.88081932068,3494.07613277435 PathPoint;PointKind.SMOOTHPOINT 5014.04415512085,3580.42341470718 5013.58750724792,3592.67808437347 5014.5011177063,3568.16921710968 PathPoint;PointKind.SMOOTHPOINT 5012.09608459473,3605.88114023209 5011.7322769165,3622.75901556015 5012.43880653381,3589.956843853 PathPoint;PointKind.SMOOTHPOINT 5013.3036365509,3648.94773960114 5013.14785385132,3671.31860733032 5013.45941925049,3626.57663583755 PathPoint;PointKind.SMOOTHPOINT 5014.98262786865,3725.31855583191 5015.43140792847,3741.47015333176 5014.53384780884,3709.16672229767 PathPoint;PointKind.SMOOTHPOINT 5014.79128265381,3753.75243902206 5013.95446205139,3760.38264513016 5015.90662384033,3744.91271495819 PathPoint;PointKind.SMOOTHPOINT 5010.04887962341,3779.10890579224 5003.45942878723,3781.93376541138 5015.02731704712,3776.97491884232 PathPoint;PointKind.SMOOTHPOINT 4943.59670066833,3781.10882520676 4925.44597053528,3783.21283578873 4947.76003265381,3780.62637090683 PathPoint;PointKind.SMOOTHPOINT 4791.9071521759,3781.09513521194 4777.62612724304,3782.91189193726 4806.18786239624,3779.27837848663 PathPoint;PointKind.SMOOTHPOINT 4642.080701828,3781.10882520676 4619.82737922668,3781.72770738602 4666.40577697754,3780.43211460114 PathPoint;PointKind.SMOOTHPOINT 4479.24718284607,3784.08380270004 4450.50291442871,3784.83368396759 4507.99208068848,3783.3339214325 PathPoint;PointKind.SMOOTHPOINT 4394.49793243408,3784.08380270004 4380.30062103271,3784.97483253479 4408.69524383545,3783.1927728653 PathPoint;PointKind.SMOOTHPOINT 4360.40323638916,3784.08380270004 4351.60733604431,3783.93746137619 4370.31982803345,3784.24808263779 PathPoint;PointKind.SMOOTHPOINT 4328.25661087036,3784.08380270004 4326.99555778503,3784.04886960983 4338.15778160095,3784.35571432114 PathPoint;PointKind.SMOOTHPOINT 4320.46401405334,3784.08380270004 4311.24010467529,3784.51196908951 4321.5063419342,3784.03541564941 PathPoint;PointKind.SMOOTHPOINT 4294.16254425049,3784.08380270004 4288.14870262146,3784.32030916214 4304.54018974304,3783.67546319962 PathPoint;PointKind.SMOOTHPOINT 4270.44706726074,3784.29127693176 4269.2864074707,3784.28490400314 4280.12951278687,3784.34603691101 PathPoint;PointKind.SMOOTHPOINT 4266.89270401001,3784.26838159561 4265.96902275085,3783.65705251694 4268.50277328491,3785.33502101898 PathPoint;PointKind.SMOOTHPOINT 4263.51741218567,3784.24265384674 4257.93409729004,3784.19733524323 4264.66139221191,3784.25185918808 PathPoint;PointKind.SMOOTHPOINT 4245.45668983459,3784.08380270004 4224.52484512329,3783.90795707703 4251.89602279663,3784.13785457611 PathPoint;PointKind.SMOOTHPOINT 4197.72424125671,3784.08380270004 4176.5975894928,3783.36838245392 4218.85057830811,3784.79922294617 PathPoint;PointKind.SMOOTHPOINT 4156.81035423279,3784.08380270004 4149.49517631531,3784.34934139252 4175.55840873718,3783.40284347534 PathPoint;PointKind.SMOOTHPOINT 4140.25018119812,3784.08380270004 4135.38976097107,3784.37955379486 4143.36017036438,3783.89426708221 PathPoint;PointKind.SMOOTHPOINT 4126.61211395264,3785.06310939789 4112.86075019836,3784.78364467621 4134.99888801575,3785.23305416107 PathPoint;PointKind.SMOOTHPOINT 4098.36257362366,3784.08380270004 4079.2604675293,3783.89615535736 4117.46467971802,3784.27097797394 PathPoint;PointKind.SMOOTHPOINT 4051.60416030884,3784.08380270004 4019.47264099121,3784.51645374298 4083.72340583801,3783.65091562271 PathPoint;PointKind.SMOOTHPOINT 3961.01006889343,3784.08380270004 3903.47023391724,3784.26389694214 4018.64935302734,3783.90300035477 PathPoint;PointKind.SMOOTHPOINT 3856.77822494507,3784.08380270004 3833.13670539856,3783.57491254807 3880.42037391663,3784.59269285202 PathPoint;PointKind.SMOOTHPOINT 3799.30542373657,3784.08380270004 3784.43431282043,3784.10669803619 3814.17559051514,3784.0606713295 PathPoint;PointKind.SMOOTHPOINT 3773.97767448425,3784.08380270004 3759.19059181213,3784.09914493561 3788.76475715637,3784.06822443008 PathPoint;PointKind.SMOOTHPOINT 3746.70153999329,3785.06310939789 3734.0611114502,3784.84855413437 3759.34322738647,3785.27695655823 PathPoint;PointKind.SMOOTHPOINT 3713.58213806152,3785.06310939789 3703.17868614197,3785.63643693924 3723.98464584351,3784.48883771896 PathPoint;PointKind.SMOOTHPOINT 3670.71986579895,3785.06310939789 3636.81745910645,3785.1615357399 3704.54170608521,3784.96444702148 PathPoint;PointKind.SMOOTHPOINT 3564.53963661194,3785.06310939789 3541.33493804932,3784.67931747437 3588.82946395874,3785.46436786652 PathPoint;PointKind.SMOOTHPOINT 3473.94617462158,3785.06310939789 3438.09695625305,3785.14123678207 3509.62544822693,3784.98474597931 PathPoint;PointKind.SMOOTHPOINT 3328.80044364929,3785.06310939789 3311.15608596802,3785.17758607864 3346.44543075562,3784.94816064835 PathPoint;PointKind.SMOOTHPOINT 3262.55975151062,3785.06310939789 3242.75143051148,3784.78340864182 3293.21432495117,3785.49528837204 PathPoint;PointKind.SMOOTHPOINT 3190.47421836853,3785.06310939789 3188.74141120911,3785.07561922073 3201.80701637268,3784.97955322266 PathPoint;PointKind.SMOOTHPOINT 3184.62969207764,3785.06310939789 3183.90711212158,3785.53399801254 3186.35557556152,3783.93675327301 PathPoint;PointKind.SMOOTHPOINT 3178.94409561157,3785.13793230057 3170.42325401306,3785.73486328125 3180.4087677002,3785.03549337387 PathPoint;PointKind.SMOOTHPOINT 3153.4571018219,3785.06310939789 3116.17090606689,3784.75744485855 3161.85992622376,3785.13179540634 PathPoint;PointKind.SMOOTHPOINT 3070.65655136108,3785.06310939789 3052.49040031433,3785.16224384308 3088.82238769531,3784.96350288391 PathPoint;PointKind.SMOOTHPOINT 3026.81992912293,3785.06310939789 2998.69249725342,3785.2389550209 3054.94861984253,3784.88702774048 PathPoint;PointKind.SMOOTHPOINT 2922.58902931213,3785.06310939789 2919.83529472351,3785.13628005981 2957.1173992157,3784.14493560791 PathPoint;PointKind.SMOOTHPOINT 2914.32530784607,3785.23801088333 2913.7597694397,3785.24721622467 2917.08313369751,3785.19387245178 PathPoint;PointKind.SMOOTHPOINT 2911.87338256836,3785.06310939789 2911.04411506653,3785.07491111755 2912.43986511231,3785.05508422852 PathPoint;PointKind.SMOOTHPOINT 2909.92468261719,3784.08380270004 2908.78605270386,3784.80748414993 2911.47999191284,3783.09576272964 PathPoint;PointKind.SMOOTHPOINT 2906.08896636963,3785.33289670944 2905.52059555054,3785.33714532852 2907.44097137451,3785.32298326492 PathPoint;PointKind.SMOOTHPOINT 2904.38196563721,3785.34399032593 2875.66885375977,3785.50779819489 2904.9515953064,3785.34092187881 PathPoint;PointKind.SMOOTHPOINT 2808.61557388306,3785.06310939789 2763.5814704895,3785.68222761154 2845.75511360169,3784.55209493637 PathPoint;PointKind.SMOOTHPOINT 2607.94511222839,3784.08380270004 2562.13083648682,3783.88104915619 2653.75938796997,3784.2863202095 PathPoint;PointKind.SMOOTHPOINT 2465.72211647034,3784.08380270004 2424.29084205627,3785.78183412552 2507.1533908844,3782.38577127457 PathPoint;PointKind.SMOOTHPOINT 2382.921251297,3783.1044960022 2337.77259254456,3783.80835056305 2428.06991004944,3782.40087747574 PathPoint;PointKind.SMOOTHPOINT 2281.61151313782,3784.08380270004 2234.54531097412,3784.37790155411 2328.67803001404,3783.78923177719 PathPoint;PointKind.SMOOTHPOINT 2193.93984222412,3784.08380270004 2163.68180656433,3783.64619493485 2254.53396224976,3784.95949029923 PathPoint;PointKind.SMOOTHPOINT 2120.8805885315,3784.08380270004 2100.82364463806,3783.81684780121 2140.88623428345,3784.3498134613 PathPoint;PointKind.SMOOTHPOINT 2063.40684318543,3784.08380270004 2025.06384277344,3783.83360624313 2084.35662651062,3784.22046661377 PathPoint;PointKind.SMOOTHPOINT 1982.55404853821,3784.08380270004 1928.09430503845,3783.76232385635 2037.01410675049,3784.40504550934 PathPoint;PointKind.SMOOTHPOINT 1850.07234954834,3783.1044960022 1808.90480422974,3783.34359884262 1899.77395439148,3782.81629800797 PathPoint;PointKind.SMOOTHPOINT 1741.24947929382,3782.04517364502 1739.55852890015,3782.04328536987 1779.6670665741,3782.08671569824 PathPoint;PointKind.SMOOTHPOINT 1737.10786247254,3781.00001335144 1735.73288345337,3781.81787252426 1740.63830757141,3778.90001535416 PathPoint;PointKind.SMOOTHPOINT 1731.27088928223,3782.06240415573 1728.39347267151,3782.07562208176 1732.90519142151,3782.05508708954 PathPoint;PointKind.SMOOTHPOINT 1722.46177101135,3782.12542533875 1676.53514289856,3782.57082223892 1725.4594078064,3782.09639310837 PathPoint;PointKind.SMOOTHPOINT 1621.90230751038,3783.63840579987 1580.18558883667,3784.37247276306 1663.61808204651,3782.90410280228 PathPoint;PointKind.SMOOTHPOINT 1478.92935180664,3782.15941429138 1445.69476509094,3782.81747817993 1512.16425323486,3781.50158643723 PathPoint;PointKind.SMOOTHPOINT 1360.08572006226,3782.15941429138 1311.35626220703,3781.88065767288 1408.81454849243,3782.43864297867 PathPoint;PointKind.SMOOTHPOINT 1238.31935310364,3782.15941429138 1115.5588092804,3781.81055545807 1312.99780273438,3782.37231731415 PathPoint;PointKind.SMOOTHPOINT 1130.86296463013,3781.90756559372 1122.96147727966,3781.95996522903 1129.28153419495,3781.91818714142 PathPoint;PointKind.SMOOTHPOINT 1102.91554832459,3782.15941429138 1044.53637504578,3782.7867937088 1113.93143081665,3782.04116106033 PathPoint;PointKind.SMOOTHPOINT 997.70966911316,3782.15941429138 939.246467590333,3782.52668380737 1056.17255592346,3781.79238080978 PathPoint;PointKind.SMOOTHPOINT 871.147083282472,3781.10882520676 820.058540344239,3781.74422979355 922.235626220704,3780.47436475754 PathPoint;PointKind.SMOOTHPOINT 810.645488739015,3781.10882520676 796.964620590211,3781.15107536316 838.827995300294,3781.0226726532 PathPoint;PointKind.SMOOTHPOINT 767.004932403565,3782.10913896561 758.436883926393,3783.17341804504 771.298555374146,3781.57593727112 PathPoint;PointKind.SMOOTHPOINT 733.28285598755,3783.10921669006 727.350839614869,3783.22369337082 738.291820526124,3783.01197052002 PathPoint;PointKind.SMOOTHPOINT 705.470766067506,3782.12542533875 684.805168151856,3780.93463182449 721.931804656983,3783.07428359985 PathPoint;PointKind.SMOOTHPOINT 659.686702728272,3782.12542533875 643.906072616578,3781.58632278442 671.879295349122,3782.54202604294 PathPoint;PointKind.SMOOTHPOINT 626.566041946412,3782.12542533875 601.51618385315,3785.0449347496 645.698675155641,3779.89560842514 PathPoint;PointKind.SMOOTHPOINT 582.730678558351,3782.12542533875 582.478593826295,3782.08270311356 586.653255462647,3782.79127836227 PathPoint;PointKind.SMOOTHPOINT 563.680500030518,3783.10921669006 558.779167175294,3783.57868909836 568.2422580719,3782.67231702805 PathPoint;PointKind.SMOOTHPOINT 543.843854904176,3785.10937213898 536.504129409791,3787.126994133 547.361082077027,3784.14233922958 PathPoint;PointKind.SMOOTHPOINT 522.334827423097,3785.06310939789 514.420122146607,3785.03997802734 528.278802871705,3785.08010387421 PathPoint;PointKind.SMOOTHPOINT 507.145856857301,3784.10905838013 497.526983261109,3783.35988521576 516.765674591065,3784.85893964768 PathPoint;PointKind.SMOOTHPOINT 490.188201904298,3785.06310939789 471.108755111695,3785.47971010208 509.267333984376,3784.64603662491 PathPoint;PointKind.SMOOTHPOINT 462.895072937013,3782.05721139908 452.221282958985,3782.29442596436 473.568548202516,3781.8202328682 PathPoint;PointKind.SMOOTHPOINT 446.644891738893,3783.10921669006 441.7800655365,3782.53022432327 451.11223602295,3783.6407661438 PathPoint;PointKind.SMOOTHPOINT 426.852306365968,3783.03628206253 426.160253524781,3784.24643039703 426.521543502809,3783.61480236054 PathPoint;PointKind.SMOOTHPOINT 401.020702362061,3783.10921669006 355.58187866211,3780.46822786331 410.11463546753,3783.63769769669 PathPoint;PointKind.SMOOTHPOINT 312.747930526734,3782.10913896561 299.716943740846,3781.17231845856 337.751525878907,3783.90654087067 PathPoint;PointKind.SMOOTHPOINT 272.082666397096,3779.10890579224 267.267250061036,3775.83676099777 277.322315216065,3782.66948461533 PathPoint;PointKind.SMOOTHPOINT 267.123741149903,3767.10797309876 266.598800659181,3764.28759813309 268.173936843873,3772.7517914772 PathPoint;PointKind.SMOOTHPOINT 266.13176727295,3698.14934492111 265.651830673219,3679.60742712021 266.448368072511,3710.36459684372 PathPoint;PointKind.CORNERPOINT 263.215955734254,3523.63353967667 263.215955734254,3523.63353967667 263.215955734254,3523.63353967667 PathPoint;PointKind.CORNERPOINT 263.215955734254,3084.98155832291 263.215955734254,3084.98155832291 263.215955734254,3084.98155832291 PathPoint;PointKind.CORNERPOINT 263.215955734254,2486.72972917557 263.215955734254,2486.72972917557 263.215955734254,2486.72972917557 PathPoint;PointKind.SMOOTHPOINT 264.156316757203,2475 264.274648666383,2466.73077106476 264.038299560548,2483.26922893524 PathPoint;PointKind.SMOOTHPOINT 263.215955734254,2458.3350276947 262.375988006593,2452.30883359909 265.331453323365,2473.51015090942 PathPoint;PointKind.SMOOTHPOINT 264.19030570984,2433.85684490204 263.756946563722,2426.4661359787 264.401792526246,2437.46628284454 PathPoint;PointKind.SMOOTHPOINT 263.215955734254,2375.10882854462 263.049787521363,2349.10609960556 263.389991760255,2402.23885774612 PathPoint;PointKind.SMOOTHPOINT 267.156156539918,2106.99995756149 267.266305923463,2059.11046743393 267.045692443849,2154.88968372345 PathPoint;PointKind.SMOOTHPOINT 265.164655685426,2015.76605558395 264.597543716432,2001.96252822876 265.731452941895,2029.56958293915 PathPoint;PointKind.SMOOTHPOINT 267.112726211549,1969.74666595459 267.055133819581,1942.61781692505 267.170003890992,1996.87551498413 PathPoint;PointKind.SMOOTHPOINT 268.155998229981,1917.99990177155 266.710208892823,1901.22068881989 269.60178756714,1934.77887868881 PathPoint;PointKind.SMOOTHPOINT 267.112726211549,1885.54092407227 267.193292617799,1873.55037689209 267.033103942872,1897.53170728683 PathPoint;PointKind.SMOOTHPOINT 268.08676147461,1861.06250524521 266.302970886231,1848.30909490585 269.154895782472,1868.69987010956 PathPoint;PointKind.SMOOTHPOINT 268.08676147461,1827.77245044708 266.929878234864,1809.92943048477 269.243330001832,1845.61476230621 PathPoint;PointKind.SMOOTHPOINT 268.08676147461,1767.06582069397 270.304855346681,1738.02060842514 265.868038177491,1796.1110329628 PathPoint;PointKind.SMOOTHPOINT 268.08676147461,1669.15238142014 267.594551086427,1662.98385858536 269.442543029786,1686.13765239716 PathPoint;PointKind.SMOOTHPOINT 267.112726211549,1630.96602916718 267.512411117555,1610.02175331116 266.713041305543,1651.91030502319 PathPoint;PointKind.SMOOTHPOINT 267.112726211549,1529.13583517075 265.948289871217,1508.50902557373 268.276847839356,1549.76288080215 PathPoint;PointKind.SMOOTHPOINT 268.08676147461,1423.38935852051 268.524841308595,1397.70622014999 267.649625778199,1449.07249689102 PathPoint;PointKind.SMOOTHPOINT 268.08676147461,1336.24640464783 267.193292617799,1313.38198900223 268.981489181519,1359.11058425903 PathPoint;PointKind.SMOOTHPOINT 268.155998229981,1270.00004768372 268.167642593385,1265.41932821274 268.125471115113,1282.1702170372 PathPoint;PointKind.SMOOTHPOINT 265.164655685426,1244.2076253891 265.232948303224,1242.37812280655 265.081256866456,1246.44357919693 PathPoint;PointKind.SMOOTHPOINT 266.138690948487,1230.49992799759 267.098249435426,1226.88317298889 265.281414031983,1233.72911453247 PathPoint;PointKind.SMOOTHPOINT 267.156156539918,1212.0000243187 267.94702911377,1190.39390802383 266.977085113526,1216.88570022583 PathPoint;PointKind.SMOOTHPOINT 267.112726211549,1189.37612771988 266.501239776612,1181.0200381279 268.283456802369,1205.38822889328 PathPoint;PointKind.SMOOTHPOINT 268.08676147461,1144.33628082275 268.76119041443,1124.47257041931 267.398799896241,1164.60502624512 PathPoint;PointKind.SMOOTHPOINT 267.620042800904,1110.83993196487 267.457021713258,1095.10847568512 267.761348724366,1124.4482588768 PathPoint;PointKind.SMOOTHPOINT 268.08676147461,1061.10937356949 267.219413757325,1041.87870740891 268.95442390442,1080.34003973007 PathPoint;PointKind.SMOOTHPOINT 269.061111450196,1007.25718259811 269.121536254884,985.348942279816 269.00005722046,1029.16542291641 PathPoint;PointKind.SMOOTHPOINT 270.035461425782,935.780303478241 270.918230056764,908.06608915329 269.152063369752,963.494281768799 PathPoint;PointKind.SMOOTHPOINT 270.035461425782,856.470623016357 270.929244995118,829.804165363311 269.141048431397,883.136372566223 PathPoint;PointKind.SMOOTHPOINT 267.04223060608,791.847474575042 268.522008895875,767.529559135437 265.561508178712,816.165153980255 PathPoint;PointKind.SMOOTHPOINT 267.04223060608,737.994811534881 266.478895187379,714.327406883239 267.605251312257,761.662216186523 PathPoint;PointKind.SMOOTHPOINT 266.628068923951,689.450798034668 266.255449295045,673.23004245758 267.001317977906,705.671553611755 PathPoint;PointKind.SMOOTHPOINT 266.628068923951,664.545865058898 267.260326385499,658.597798347473 265.995811462403,670.494403839111 PathPoint;PointKind.SMOOTHPOINT 265.636409759522,640.637233257293 265.754112243653,624.555265903472 265.520595550538,656.453897953033 PathPoint;PointKind.SMOOTHPOINT 265.636409759522,596.805174350738 265.046323776246,574.021010398864 266.226181030274,619.588866233825 PathPoint;PointKind.SMOOTHPOINT 266.628068923951,570.903940200805 266.100610733033,564.180972576141 267.103284835816,576.957278251647 PathPoint;PointKind.SMOOTHPOINT 266.068195343018,550.980277061462 264.77567100525,543.172023296356 267.419256210328,559.14659500122 PathPoint;PointKind.SMOOTHPOINT 265.093845367433,517.689514160156 265.384639739991,502.483942508697 264.793294906617,533.411529064178 PathPoint;PointKind.SMOOTHPOINT 265.093845367433,485.378057956695 263.969377517701,455.717504024505 265.489753723145,495.816679000854 PathPoint;PointKind.SMOOTHPOINT 265.140108108521,427.894713878631 264.848054885865,399.812757968902 265.483459472657,461.012227535247 PathPoint;PointKind.SMOOTHPOINT 265.140108108521,332.887330055236 264.850887298585,302.467925548553 265.417055130006,362.12750673294 PathPoint;PointKind.SMOOTHPOINT 265.140108108521,232.832822799682 264.908794403077,220.94447851181 265.472444534303,249.938235282897 PathPoint;PointKind.SMOOTHPOINT 267.123741149903,197.829866409301 267.102970123292,194.471569061279 267.177242279054,206.551573276519 PathPoint;PointKind.SMOOTHPOINT 269.155839920045,183.999903202056 269.979442596436,182.189519405365 267.089752197267,188.543329238891 PathPoint";
	
	mask645[2] = "PointKind.SMOOTHPOINT 272.918701171875,179.82846736908 275.28854959701,176.964058132018 271.667889794178,181.340551972251 PathPoint;PointKind.SMOOTHPOINT 303.442849551789,176.281883117858 305.133603847663,176.277011369874 287.133579336649,176.328876731588 PathPoint;PointKind.SMOOTHPOINT 308,179 310.917360671038,177.961532960407 306.322001707468,179.597302190499 PathPoint;PointKind.SMOOTHPOINT 315.026384844182,176.320457492651 326.37200009566,176.404794426917 312.850659680877,176.304284373256 PathPoint;PointKind.SMOOTHPOINT 351.776847839355,176.427447795868 212.227334976196,178.059153556824 339.036358777855,176.576106225535 PathPoint;PointKind.SMOOTHPOINT 942.050399780273,174.013051986694 977.48514175415,173.933036327362 772.805242538452,174.397079944611 PathPoint;PointKind.SMOOTHPOINT 1493.42516899109,174.99235868454 1505.1003742218,174.786064624786 1481.75090789795,175.19912481308 PathPoint;PointKind.SMOOTHPOINT 1535.31435012817,178.908877372742 1541.86540603638,178.940505981445 1524.25629615784,178.85529756546 PathPoint;PointKind.SMOOTHPOINT 1545.05627632141,176.950500011444 1546.93296408922,176.635185375444 1540.08539199829,177.785589694977 PathPoint;PointKind.SMOOTHPOINT 1554.60596929441,176.230064615138 1557.81854522689,176.094056700844 1550.69779311448,176.395521526381 PathPoint;PointKind.SMOOTHPOINT 1562,179 1563.31596107338,179.16063034361 1556.16696162114,178.287439763966 PathPoint;PointKind.SMOOTHPOINT 1566.99923063799,176.042010958115 1570.89994300617,176.23414301615 1565.70926919984,175.97847309054 PathPoint;PointKind.SMOOTHPOINT 1580.12563705444,177.92980670929 1584.10989761353,178.989129066467 1575.9168532913,176.810385168106 PathPoint;PointKind.SMOOTHPOINT 1605.45401573181,179.887948036194 1620.9303188324,179.842157363892 1594.56464767456,179.920284748077 PathPoint;PointKind.SMOOTHPOINT 1849.82640266418,177.878823280334 1861.04023933411,178.364582061768 1838.61225128174,177.393064498901 PathPoint;PointKind.CORNERPOINT 1876,178 1876,178 1876,178 PathPoint;PointKind.SMOOTHPOINT 1887.81849861145,178.857657909393 1889.32691574097,178.980631828308 1881.97176933289,178.381104469299 PathPoint;PointKind.SMOOTHPOINT 1895.62934875488,176.745386123657 1900.45640945435,176.551837921143 1889.49465751648,176.991806030273 PathPoint;PointKind.SMOOTHPOINT 1908.27638626099,177.878823280334 1919.90501403809,178.919026851654 1896.64681434631,176.838147640228 PathPoint;PointKind.SMOOTHPOINT 1962.82896995544,177.878823280334 1971.7797088623,177.802112102509 1953.87917518616,177.955062389374 PathPoint;PointKind.SMOOTHPOINT 2007.64057159424,177.878823280334 2021.55999183655,177.760334014893 1993.72052192688,177.997312545776 PathPoint;PointKind.SMOOTHPOINT 2057.32297897339,177.878823280334 1871.78074836731,177.719972133636 2043.05737495422,177.866313457489 PathPoint;PointKind.SMOOTHPOINT 2559.10408973694,176.865291595459 2580.01768112183,176.6521525383 2425.81295013428,178.222253322601 PathPoint;PointKind.SMOOTHPOINT 2609.7611618042,175.886220932007 2617.64911651611,175.492279529572 2601.87257766724,176.280162334442 PathPoint;PointKind.SMOOTHPOINT 2638.01164627075,176.865291595459 2647.73468971252,176.54381275177 2628.28923225403,177.186534404755 PathPoint;PointKind.SMOOTHPOINT 2695.48727989197,176.865291595459 2703.01803588867,176.773238182068 2687.95620918274,176.956872940063 PathPoint;PointKind.SMOOTHPOINT 2722,176 2731.04169082642,176.355703830719 2712.95830917358,175.644296169281 PathPoint;PointKind.SMOOTHPOINT 2755.88533401489,177.844598293304 2774.1811466217,178.349475860596 2737.58952140808,177.339720726013 PathPoint;PointKind.SMOOTHPOINT 2796.80016517639,177.844598293304 2804.36868667603,177.695424556732 2789.23101425171,177.993535995483 PathPoint;PointKind.SMOOTHPOINT 2818.23145866394,175.886220932007 2832.2739315033,175.570170879364 2807.72572517395,176.122491359711 PathPoint;PointKind.SMOOTHPOINT 2850.37902832031,176.865291595459 2855.42072296143,177.068045139313 2845.33670425415,176.662302017212 PathPoint;PointKind.SMOOTHPOINT 2863.18940162659,176.465213298798 2869.56799507141,175.953018665314 2856.16250038147,177.029099464417 PathPoint;PointKind.SMOOTHPOINT 2879.6032333374,177.844598293304 2882.21282958984,178.062222003937 2875.94470024109,177.539405822754 PathPoint;PointKind.SMOOTHPOINT 2890,177 2892.9274559021,176.461841583252 2882.95925140381,178.294884681702 PathPoint;PointKind.SMOOTHPOINT 2904.32704925537,175.828156471252 2912.25276947021,175.122177600861 2900.55459022522,176.16450548172 PathPoint;PointKind.SMOOTHPOINT 2915.64788818359,177.844598293304 2922.96149253845,178.009114265442 2908.33365440369,177.679846286774 PathPoint;PointKind.SMOOTHPOINT 2951.69159889221,176.865291595459 2961.78694725037,177.205417156219 2941.59562110901,176.524930000305 PathPoint;PointKind.SMOOTHPOINT 2980.91611862183,176.865291595459 2997.61004447937,176.693222522736 2964.22250747681,177.037360668182 PathPoint;PointKind.SMOOTHPOINT 3553,181 3587.60352342223,181.242647997413 3520.44069649827,180.771922495388 PathPoint;PointKind.SMOOTHPOINT 3657.01932907104,179.836728572845 3661.64340019226,180.10439157486 3639.02658462524,178.795108795166 PathPoint;PointKind.SMOOTHPOINT 3672.6060962677,181.795105934143 3681.72552108765,182.573311328888 3667.80893325806,181.386058330536 PathPoint;PointKind.SMOOTHPOINT 3715.46931266785,179.836728572845 3719.39944267273,179.825870990753 3713.29087257385,179.842865467072 PathPoint;PointKind.SMOOTHPOINT 3726.1846446991,181.795105934143 3729.75946426392,181.819889545441 3719.08284187317,181.745538711548 PathPoint;PointKind.SMOOTHPOINT 3740.83262443542,182.804388999939 3742.09493637085,182.780077457428 3733.01894187927,182.954034805298 PathPoint;PointKind.SMOOTHPOINT 3748,184 3749.8948841095,183.327538013458 3745.85649299622,184.761682987213 PathPoint;PointKind.SMOOTHPOINT 3751.54890060425,181.783304214478 3758.28123092651,181.861431598663 3750.70924758911,181.773862838745 PathPoint;PointKind.SMOOTHPOINT 3770.22205352783,182.82870054245 3788.5122013092,181.793689727783 3764.803647995,183.13530921936 PathPoint;PointKind.SMOOTHPOINT 3797.31659889221,180.867254734039 3804.56757545471,181.356790065765 3798.51817131042,180.948450565338 PathPoint;PointKind.SMOOTHPOINT 3807.05852508545,181.846325397491 3821.28730773926,182.806985378265 3801.94476127625,181.501007080078 PathPoint;PointKind.SMOOTHPOINT 3824.77432250977,179.82846736908 3826.24277114868,179.791646003723 3815.19164085388,180.067570209503 PathPoint;PointKind.SMOOTHPOINT 3832.38627433777,180.867254734039 3838.16282272339,181.106593608856 3828.49674224854,180.706279277802 PathPoint;PointKind.SMOOTHPOINT 3842.62796401978,179.82846736908 3850.01300811768,180.38031578064 3841.48838996887,179.743494987488 PathPoint;PointKind.SMOOTHPOINT 3862.58545875549,180.867254734039 3870.61849594116,180.41241645813 3854.55242156982,181.322329044342 PathPoint;PointKind.SMOOTHPOINT 3882.06868171692,180.867254734039 3893.49998474121,181.777403354645 3870.63769340515,179.956634044647 PathPoint;PointKind.SMOOTHPOINT 3906.42239570618,181.846325397491 3913.43576431274,181.876773834229 3899.40934181213,181.815640926361 PathPoint;PointKind.SMOOTHPOINT 3922.98351287842,178.908877372742 3934.01733398438,177.965919971466 3907.69855499268,180.214855670929 PathPoint;PointKind.SMOOTHPOINT 3937.59593009949,181.846325397491 3947.72904396057,181.505727767944 3931.0643863678,182.065601348877 PathPoint;PointKind.CORNERPOINT 3956.10480308533,180.867254734039 3956.10480308533,180.867254734039 3956.10480308533,180.867254734039 PathPoint;PointKind.SMOOTHPOINT 3966.82107925415,178.908877372742 3974.31721687317,178.262615203857 3959.32399749756,179.555375576019 PathPoint;PointKind.SMOOTHPOINT 3980.45883178711,179.887948036194 3988.22027206421,179.839088916779 3970.112657547,179.953093528748 PathPoint;PointKind.SMOOTHPOINT 3994.09721374512,178.908877372742 3995.74284553528,178.607697486877 3989.15622711182,179.813597202301 PathPoint;PointKind.SMOOTHPOINT 3999.94205474854,176.950500011444 4008.03960800171,176.548297405243 3996.59634590149,177.116904258728 PathPoint;PointKind.SMOOTHPOINT 4013.58075141907,178.908877372742 4016.29986763,179.332087039948 4009.42025184631,178.261671066284 PathPoint;PointKind.SMOOTHPOINT 4026.24446868896,178.908877372742 4038.56609344482,179.62028503418 4021.37366294861,178.627524375916 PathPoint;PointKind.SMOOTHPOINT 4059.36638832092,179.887948036194 4066.95127487183,179.967963695526 4041.26034736633,179.696996212006 PathPoint;PointKind.SMOOTHPOINT 4082.74606704712,178.908877372742 4084.61829185486,178.698570728302 4075.01672744751,179.777247905731 PathPoint;PointKind.SMOOTHPOINT 4102.22929000854,178.908877372742 4105.21339416504,179.362535476685 4095.69050788879,177.915408611298 PathPoint;PointKind.SMOOTHPOINT 4110.99655151367,178.908877372742 4126.17985725403,178.583858013153 4107.99073219299,178.973078727722 PathPoint;PointKind.SMOOTHPOINT 4154.07251358032,180.82878112793 4163.11200141907,180.672290325165 4139.69959259033,181.077325344086 PathPoint;PointKind.SMOOTHPOINT 4178.21442604065,180.695185661316 4178.72803688049,180.661668777466 4170.60121536255,181.191802024841 PathPoint;PointKind.SMOOTHPOINT 4184.05863761902,179.887948036194 4186.96846961975,179.704549312592 4182.91686058044,179.960174560547 PathPoint;PointKind.SMOOTHPOINT 4191.85154914856,179.887948036194 4204.47813034058,179.291253089905 4188.82338523865,180.03098487854 PathPoint;PointKind.SMOOTHPOINT 4216.20557785034,180.867254734039 4222.87968635559,180.915877819061 4206.2134552002,180.7945561409 PathPoint;PointKind.SMOOTHPOINT 4235.68943023682,178.908877372742 4240.02774238586,178.040742874146 4229.81122970581,180.085744857788 PathPoint;PointKind.SMOOTHPOINT 4255.17233848572,176.950500011444 4257.1147441864,177.305731773376 4245.63875198364,175.207858085632 PathPoint;PointKind.SMOOTHPOINT 4263,178 4268.76899528503,179.585443019867 4261.12022209167,177.483320713043 PathPoint;PointKind.SMOOTHPOINT 4274.65587615967,178.908877372742 4286.84752464294,178.905100822449 4268.37610244751,178.910765647888 PathPoint;PointKind.SMOOTHPOINT 4291.21636390686,177.92980670929 4301.72650337219,177.658367156982 4280.705909729,178.20148229599 PathPoint;PointKind.SMOOTHPOINT 4307.81084060669,180.82878112793 4309.88920211792,180.757026672363 4298.72760772705,181.142470836639 PathPoint;PointKind.SMOOTHPOINT 4315.57070732117,180.867254734039 4317.60154724121,180.710999965668 4313.07126045227,181.059858798981 PathPoint;PointKind.SMOOTHPOINT 4322.38958358765,180.867254734039 4323.06999206543,180.847663879395 4320.02326011658,180.934524536133 PathPoint;PointKind.SMOOTHPOINT 4324.33765411377,178.908877372742 4331.55352352358,178.250842850968 4323.58297348022,178.977563381195 PathPoint;PointKind.SMOOTHPOINT 4348.69199752808,178.908877372742 4352.0890045166,178.866627216339 4346.63999042156,178.934501149638 PathPoint;PointKind.SMOOTHPOINT 4358.43360900879,176.950500011444 4369.12030220032,176.901168823242 4354.94627952576,176.966786384583 PathPoint;PointKind.SMOOTHPOINT 4381.81360244751,176.950500011444 4383.14735412598,176.996762752533 4370.9981918335,176.576149463654 PathPoint;PointKind.SMOOTHPOINT 4386.68440818787,178.908877372742 4409.4780921936,179.785981178284 4385.30250549316,178.855533599854 PathPoint;PointKind.SMOOTHPOINT 4447.08183288574,178.908877372742 4447.3584651947,178.911945819855 4433.42645645142,178.748137950897 PathPoint;PointKind.SMOOTHPOINT 4463.64295005798,176.950500011444 4466.56096458435,178.174338340759 4469.86104011536,179.558207988739 PathPoint;PointKind.SMOOTHPOINT 4471.92649841309,179.378349781036 4473.00061225891,179.258680343628 4468.6279964447,179.745383262634 PathPoint;PointKind.SMOOTHPOINT 4478.25536727905,176.950500011444 4483.51389884949,176.754355430603 4475.71563720703,177.045149803162 PathPoint;PointKind.SMOOTHPOINT 4493.84181976318,178.908877372742 4500.90648651123,179.205572605133 4490.03914833069,178.74908208847 PathPoint;PointKind.SMOOTHPOINT 4512.35100746155,177.92980670929 4515.81253051758,177.736494541168 4501.35778427124,178.543968200684 PathPoint;PointKind.SMOOTHPOINT 4526.96342468262,177.92980670929 4541.92359924316,177.997784614563 4520.70693969727,177.901246547699 PathPoint;PointKind.SMOOTHPOINT 4566.33962631226,177.738854885101 4567.60760307312,177.732245922089 4552.65624046326,177.809901237488 PathPoint;PointKind.SMOOTHPOINT 4571.77471160889,176.950500011444 4575.3545665741,176.938934326172 4570.45040130615,176.954748630524 PathPoint;PointKind.SMOOTHPOINT 4579.56793785095,176.950500011444 4580.26534080505,176.952860355377 4575.42191505432,176.937282085419 PathPoint;PointKind.SMOOTHPOINT 4581.5163230896,177.92980670929 4582.31663703918,177.948925495148 4580.75629234314,177.911632061005 PathPoint;PointKind.SMOOTHPOINT 4583.46470832825,176.950500011444 4586.51647567749,176.978116035461 4582.59924888611,176.942710876465 PathPoint;PointKind.SMOOTHPOINT 4593.20631980896,176.950500011444 4596.96178436279,177.178745269775 4589.54558372498,176.728155612946 PathPoint;PointKind.SMOOTHPOINT 4604.89663124084,177.92980670929 4643.47094535828,178.472921848297 4601.35296821594,177.880239486694 PathPoint;PointKind.SMOOTHPOINT 4654.57840919495,178.908877372742 4670.04715919495,179.245462417603 4639.10965919495,178.572292327881 PathPoint;PointKind.SMOOTHPOINT 4684.7779083252,177.92980670929 4698.14186096191,178.258602619171 4671.41332626343,177.601010799408 PathPoint;PointKind.SMOOTHPOINT 4713.02807807922,177.92980670929 4731.65905952454,177.539877891541 4694.39678192139,178.319971561432 PathPoint;PointKind.SMOOTHPOINT 4743.22694778442,178.908877372742 4763.74935150146,179.253251552582 4722.70485877991,178.564739227295 PathPoint;PointKind.SMOOTHPOINT 4787.06451416016,178.908877372742 4821.35433197021,178.040742874146 4752.7746963501,179.777011871338 PathPoint;PointKind.SMOOTHPOINT 4853.30772399902,178.908877372742 4884.95427131653,178.735864162445 4828.81994247437,179.042708873749 PathPoint;PointKind.SMOOTHPOINT 4896.09981536865,179.866940975189 4903.9972114563,180.046091079712 4903.91223907471,180.044438838959 PathPoint;PointKind.SMOOTHPOINT 4908.76321792603,179.866940975189 4913.43386650085,178.379688262939 4905.29697418213,180.971345901489 PathPoint;PointKind.SMOOTHPOINT 4933.18868637085,178.908877372742 4943.60485300482,179.045383172672 4925.51977157593,178.808326721191 PathPoint;PointKind.SMOOTHPOINT 4982.89792043994,178.014273527026 4989.06929045274,178.129340372344 4965.65919681448,177.692852912029 PathPoint;PointKind.SMOOTHPOINT 4998.80560817307,179.148195230571 4999.66446921797,179.910225967391 4998.09277259554,178.515726656511 PathPoint;PointKind.SMOOTHPOINT 5006,182 5006.73592061421,182.833063167762 5004.91933216788,180.776660220808 PathPoint;PointKind.SMOOTHPOINT 5008.02860967017,185.784198078611 5011.94621671965,197.964411137348 5007.46289930253,184.025350720958 PathPoint;PointKind.SMOOTHPOINT 5011.81520462036,234.20654296875 5011.69939041138,236.885533332825 5012.03630600381,229.096460994479 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,305.217254161835 5013.72173309326,323.898432254791 5014.20733451843,295.715217590332 PathPoint;PointKind.SMOOTHPOINT 5015.99238395691,442.296116352081 5015.96087012094,451.17607368137 5016.05312347412,425.092277526855 PathPoint;PointKind.SMOOTHPOINT 5014.41614188667,703.772656215185 5014.40288496718,706.271662822633 5015.07579868823,579.423503595318 PathPoint;PointKind.SMOOTHPOINT 5013,711 5011.86561961679,712.484856027441 5014.51459706908,709.017456383728 PathPoint;PointKind.SMOOTHPOINT 5014.35343141078,715.715573127573 5013.77031828063,827.950509302353 5014.36113536081,714.232752222818 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,941.654963493347 5015.4211807251,958.567771911621 5013.4003058934,933.751637693872 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,998.444602489471 5014.18876647949,1010.65324544907 5013.89923095703,986.23619556427 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1086.56686306 5014.94596481323,1099.75080013275 5015.09041786194,1073.38316202164 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1256.93672418594 5014.29891586304,1263.84781122208 5013.78876686096,1250.02516508102 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1276.51908159256 5015.00292778015,1288.6167883873 5015.0331401825,1264.42137479782 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1319.60102319717 5013.60277175903,1351.6065788269 5014.48585510254,1287.59570360184 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1535.9898018837 5015.32991409302,1549.4756269455 5014.70615386963,1522.50374078751 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1597.67526626587 5014.05627250671,1606.95377826691 5014.01756286621,1577.82524585724 PathPoint;PointKind.SMOOTHPOINT 5015.0281047821,1636.55579566956 5015.06083488464,1637.6656293869 5014.60450172424,1622.19522714615 PathPoint;PointKind.SMOOTHPOINT 5015.123462677,1639.86641407013 5014.73353385925,1641.63006305695 5015.36075592041,1638.79599809647 PathPoint;PointKind.SMOOTHPOINT 5015.21693229675,1643.26011657715 5015.57822227478,1656.91730260849 5015.18703460693,1642.14036941528 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1672.08959341049 5013.48821640015,1679.5095705986 5015.71984291077,1668.68503332138 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1689.7140455246 5014.63786125183,1697.01175689697 5015.39883613586,1682.41657018661 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1705.3803563118 5015.48601150513,1711.6642999649 5014.55005645752,1699.09641265869 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1725.94202041626 5015.23487091064,1737.02997207642 5014.801197052,1714.8543047905 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1775.87792873383 5014.16170120239,1796.98294401169 5015.87405204773,1754.77314949036 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1848.33411455154 5015.21598815918,1863.35015058517 5014.81976509094,1833.31807851791 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,1880.64533472061 5015.75257301331,1904.73382472992 5012.33542442322,1856.5570807457 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1951.14337921143 5015.3645324707,1968.2818365097 5014.67185020447,1934.00444984436 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,1999.12091016769 5015.06744384766,2003.76748323441 5014.8849105835,1986.58701181412 PathPoint;PointKind.SMOOTHPOINT 5014.43424224854,2012.65158176422 5013.82684707642,2020.0585770607 5014.79301452637,2008.2875418663 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2034.36957836151 5014.18876647949,2044.49734210968 5013.95304679871,2027.99688577652 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2087.24293470383 5015.32991409302,2113.19774866104 5014.70615386963,2061.28812074661 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2212.57224082947 5014.04777526855,2242.9368853569 5015.98860740662,2182.20736026764 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2290.90308666229 5014.40937995911,2305.86176633835 5015.62700271606,2275.94417095184 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2364.33810710907 5014.00528907776,2365.59215784073 5014.57680702209,2346.98509454727 PathPoint;PointKind.SMOOTHPOINT 5013.0699634552,2369.23393249512 5013.02370071411,2374.83243227005 5013.13322067261,2361.55148506165 PathPoint;PointKind.SMOOTHPOINT 5013.81488800049,2374.5836520195 5014.38829421997,2397.93477058411 5013.79380226135,2373.7403011322 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2457.35595703125 5015.01048088074,2476.12777233124 5013.22291374207,2441.40664100647 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2532.74959087372 5014.39395904541,2555.55617809296 5013.69372367859,2509.94205951691 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2600.3094792366 5015.69151878357,2621.65147304535 5014.3448638916,2578.96748542786 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2672.76566505432 5013.77366065979,2705.05776643753 5014.31402206421,2640.47309160233 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2734.45112943649 5014.39805030823,2750.15142917633 5013.6899471283,2718.75059366226 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2794.17821645737 5014.82763290405,2821.16166830063 5015.20843505859,2767.19476461411 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2863.69695425034 5014.99380111694,2880.19457817078 5015.0422668457,2847.11601018906 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2910.69517850876 5013.4992313385,2921.03041648865 5014.56390380859,2900.82752466202 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,2952.79804944992 5014.65989112854,2965.06404876709 5015.37617683411,2940.53205013275 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,2984.13043498993 5014.45721626282,2991.55796527863 5013.46555709839,2973.74256134033 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3027.21237659454 5015.12723922729,3033.8475394249 5014.74328994751,3010.5667591095 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3044.83659267426 5015.53479194641,3062.02367305756 5014.85816001892,3039.51283693314 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3062.46128082275 5013.96028518677,3071.58707857132 5014.12771224976,3053.33548307419 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3098.68901968002 5014.38262939453,3111.92677259445 5013.70505332947,3085.45197486877 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3148.62516403198 5013.75855445862,3160.74505805969 5014.31087493896,3137.2841835022 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3177.99917221069 5014.13558006287,3186.21175289154 5013.93699645996,3168.40673446655 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3217.16435909271 5014.1450214386,3219.35216188431 5013.44258308411,3204.14375782013 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3224.99763250351 5015.20277023315,3227.1960568428 5014.87421035767,3223.28425884247 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3229.89345788956 5014.01630401611,3237.15788841248 5014.05029296875,3228.24900627136 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3253.39257001877 5014.43581581116,3268.274538517 5013.72488021851,3241.25733375549 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3289.62054491043 5014.58058357239,3299.26278591156 5013.50741386414,3279.9783039093 PathPoint;PointKind.SMOOTHPOINT 5013.0699634552,3306.26592636108 5014.32188987732,3315.1854300499 5011.81803703308,3297.34642267227 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3333.68179321289 5013.96343231201,3345.04732131958 5014.12047386169,3322.89124488831 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3351.306245327 5016.06067657471,3356.56107902527 5013.97539138794,3346.05117559433 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3367.95139074326 5014.7212600708,3373.24871063232 5015.31480789185,3362.65383481979 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3387.53422021866 5013.537940979,3400.44270515442 5016.49875640869,3374.62526321411 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3405.15843629837 5013.91087532043,3422.10617780685 5014.17743682861,3388.21116685867 PathPoint;PointKind.SMOOTHPOINT 5015.01803398132,3449.21968460083 5014.62244033813,3467.89566993713 5015.41362762451,3430.54322719574 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3523.63353967667 5014.20733451843,3553.19141864777 5013.88066291809,3494.07613277435 PathPoint;PointKind.SMOOTHPOINT 5014.04399871826,3580.42341470718 5013.58735084534,3592.67808437347 5014.50096130371,3568.16921710968 PathPoint;PointKind.SMOOTHPOINT 5012.09592819214,3605.88114023209 5011.73212051392,3622.75901556015 5012.43865013123,3589.956843853 PathPoint;PointKind.SMOOTHPOINT 5013.30348014832,3648.94773960114 5013.14769744873,3671.31860733032 5013.4592628479,3626.57663583755 PathPoint;PointKind.SMOOTHPOINT 5014.98247146606,3725.31855583191 5015.43125152588,3741.47015333176 5014.53369140625,3709.16672229767 PathPoint;PointKind.SMOOTHPOINT 5014.79112625122,3753.75243902206 5014.29962526725,3757.64664623519 5015.90646743774,3744.91271495819 PathPoint;PointKind.SMOOTHPOINT 5013.67994987287,3770.79698752999 5013.12704660906,3774.88566061436 5014.46690921047,3764.97748948614 PathPoint;PointKind.SMOOTHPOINT 5006,3779 4999.41023445129,3781.82485961914 5008.05438549992,3778.11939601248 PathPoint;PointKind.SMOOTHPOINT 4943.59434127808,3781.10882520676 4925.44298171997,3783.21283578873 4947.75767326355,3780.62637090683 PathPoint;PointKind.SMOOTHPOINT 4791.89975738525,3781.09513521194 4777.61841773987,3782.91189193726 4806.18109703064,3779.27837848663 PathPoint;PointKind.SMOOTHPOINT 4642.06827163696,3781.10882520676 4619.8143196106,3781.72770738602 4666.39429092407,3780.43211460114 PathPoint;PointKind.SMOOTHPOINT 4479.22940254211,3784.08380270004 4450.48418998718,3784.83368396759 4507.97524452209,3783.3339214325 PathPoint;PointKind.SMOOTHPOINT 4394.47763442993,3784.08380270004 4380.27969360352,3784.97483253479 4408.67526054382,3783.1927728653 PathPoint;PointKind.SMOOTHPOINT 4360.38167953491,3784.08380270004 4351.58546447754,3783.93746137619 4370.29858589172,3784.24808263779 PathPoint;PointKind.SMOOTHPOINT 4328.23410987854,3784.08380270004 4326.97305679321,3784.04886960983 4338.13559532166,3784.35571432114 PathPoint;PointKind.SMOOTHPOINT 4320.441198349,3784.08380270004 4311.21697425842,3784.51196908951 4321.48352622986,3784.03541564941 PathPoint;PointKind.SMOOTHPOINT 4294.13878440857,3784.08380270004 4288.12462806702,3784.32030916214 4304.51674461365,3783.67546319962 PathPoint;PointKind.SMOOTHPOINT 4270.42267799377,3784.29127693176 4269.26170349121,3784.28490400314 4280.10543823242,3784.34603691101 PathPoint;PointKind.SMOOTHPOINT 4266.86800003052,3784.26838159561 4265.94431877136,3783.65705251694 4268.47806930542,3785.33502101898 PathPoint;PointKind.SMOOTHPOINT 4263.49270820618,3784.24265384674 4257.90907859802,3784.19733524323 4264.63668823242,3784.25185918808 PathPoint;PointKind.SMOOTHPOINT 4245.43135643005,3784.08380270004 4224.4988822937,3783.90795707703 4251.87100410461,3784.13785457611 PathPoint;PointKind.SMOOTHPOINT 4197.69733428955,3784.08380270004 4176.57005310059,3783.36838245392 4218.82430076599,3784.79922294617 PathPoint;PointKind.SMOOTHPOINT 4156.78218841553,3784.08380270004 4149.46669578552,3784.34934139252 4175.53087234497,3783.40284347534 PathPoint;PointKind.SMOOTHPOINT 4140.22138595581,3784.08380270004 4135.36096572876,3784.37955379486 4143.33137512207,3783.89426708221 PathPoint;PointKind.SMOOTHPOINT 4126.5830039978,3785.06310939789 4112.83101081848,3784.78364467621 4134.96977806091,3785.23305416107 PathPoint;PointKind.SMOOTHPOINT 4098.33251953125,3784.08380270004 4079.22978401184,3783.89615535736 4117.43525505066,3784.27097797394 PathPoint;PointKind.SMOOTHPOINT 4051.57253265381,3784.08380270004 4019.43975448608,3784.51645374298 4083.69272232056,3783.65091562271 PathPoint;PointKind.SMOOTHPOINT 3960.97529411316,3784.08380270004 3903.43357086182,3784.26389694214 4018.61646652222,3783.90300035477 PathPoint;PointKind.SMOOTHPOINT 3856.73998832703,3784.08380270004 3833.09783935547,3783.57491254807 3880.38308143616,3784.59269285202 PathPoint;PointKind.SMOOTHPOINT 3799.26529884338,3784.08380270004 3784.39387321472,3784.10669803619 3814.136095047,3784.0606713295 PathPoint;PointKind.SMOOTHPOINT 3773.93692016602,3784.08380270004 3759.14920806885,3784.09914493561 3788.72431755066,3784.06822443008 PathPoint;PointKind.SMOOTHPOINT 3746.65984153748,3785.06310939789 3734.01909828186,3784.84855413437 3759.30184364319,3785.27695655823 PathPoint;PointKind.SMOOTHPOINT 3713.53918075562,3785.06310939789 3703.13541412354,3785.63643693924 3723.94231796265,3784.48883771896 PathPoint;PointKind.SMOOTHPOINT 3670.67564964294,3785.06310939789 3636.77198410034,3785.1615357399 3704.4987487793,3784.96444702148 PathPoint;PointKind.SMOOTHPOINT 3564.49195861816,3785.06310939789 3541.28631591797,3784.67931747437 3588.78241539001,3785.46436786652 PathPoint;PointKind.SMOOTHPOINT 3473.89534950256,3785.06310939789 3438.04518699646,3785.14123678207 3509.57588195801,3784.98474597931 PathPoint;PointKind.SMOOTHPOINT 3328.74489784241,3785.06310939789 3311.09991073608,3785.17758607864 3346.39051437378,3784.94816064835 PathPoint;PointKind.SMOOTHPOINT 3262.50200271606,3785.06310939789 3242.69305229187,3784.78340864182 3293.15783500671,3785.49528837204 PathPoint;PointKind.SMOOTHPOINT 3190.4142665863,3785.06310939789 3188.68145942688,3785.07561922073 3201.74737930298,3784.97955322266 PathPoint;PointKind.SMOOTHPOINT 3184.56942558289,3785.06310939789 3183.84684562683,3785.53399801254 3186.29530906677,3783.93675327301 PathPoint;PointKind.SMOOTHPOINT 3178.88382911682,3785.13793230057 3170.36267280579,3785.73486328125 3180.34850120544,3785.03549337387 PathPoint;PointKind.SMOOTHPOINT 3153.39589118958,3785.06310939789 3116.10843658447,3784.75744485855 3161.79903030396,3785.13179540634 PathPoint;PointKind.SMOOTHPOINT 3070.59250831604,3785.06310939789 3052.42572784424,3785.16224384308 3088.75897407532,3784.96350288391 PathPoint;PointKind.SMOOTHPOINT 3026.75462722778,3785.06310939789 2998.6262512207,3785.2389550209 3054.88426208496,3784.88702774048 PathPoint;PointKind.SMOOTHPOINT 2922.52026557922,3785.06310939789 2919.7665309906,3785.13628005981 2957.04957962036,3784.14493560791 PathPoint;PointKind.SMOOTHPOINT 2914.25622940063,3785.23801088333 2913.69069099426,3785.24721622467 2917.01405525208,3785.19387245178 PathPoint;PointKind.SMOOTHPOINT 2911.80430412292,3785.06310939789 2910.97503662109,3785.07491111755 2912.37078666687,3785.05508422852 PathPoint;PointKind.SMOOTHPOINT 2909.85560417175,3784.08380270004 2908.7166595459,3784.80748414993 2911.41091346741,3783.09576272964 PathPoint;PointKind.SMOOTHPOINT 2906.01957321167,3785.33289670944 2905.45120239258,3785.33714532852 2907.37157821655,3785.32298326492 PathPoint;PointKind.SMOOTHPOINT 2904.31257247925,3785.34399032593 2875.59851646423,3785.50779819489 2904.88220214844,3785.34092187881 PathPoint;PointKind.SMOOTHPOINT 2808.54303359985,3785.06310939789 2763.50735664368,3785.68222761154 2845.68383216858,3784.55209493637 PathPoint;PointKind.SMOOTHPOINT 2607.86596298218,3784.08380270004 2562.05011367798,3783.88104915619 2653.68181228638,3784.2863202095 PathPoint;PointKind.SMOOTHPOINT 2465.63824653625,3784.08380270004 2424.20571327209,3785.78183412552 2507.07077980042,3782.38577127457 PathPoint;PointKind.SMOOTHPOINT 2382.8345489502,3783.1044960022 2337.68463134766,3783.80835056305 2427.98478126526,3782.40087747574 PathPoint;PointKind.SMOOTHPOINT 2281.52166366577,3784.08380270004 2234.45388793945,3784.37790155411 2328.58975410461,3783.78923177719 PathPoint;PointKind.SMOOTHPOINT 2193.84716033936,3784.08380270004 2163.58818054199,3783.64619493484 2254.44316864014,3784.95949029922 PathPoint;PointKind.SMOOTHPOINT 2120.78538894653,3784.08380270004 2100.72781562805,3783.81684780121 2140.79166412354,3784.3498134613 PathPoint;PointKind.SMOOTHPOINT 2063.30975532532,3784.08380270004 2024.96549606323,3783.83360624313 2084.26016807556,3784.22046661377 PathPoint;PointKind.SMOOTHPOINT 1982.45444297791,3784.08380270004 1927.992811203,3783.76232385635 2036.91607475281,3784.40504550934 PathPoint;PointKind.SMOOTHPOINT 1849.9683380127,3783.1044960022 1808.79915370145,3783.34349731841 1899.67151641846,3782.81629800797 PathPoint;PointKind.SMOOTHPOINT 1741.14176972975,3782.04520184716 1739.4507990319,3782.04337978104 1779.5604571959,3782.08659900976 PathPoint;PointKind.SMOOTHPOINT 1737,3781 1735.62512742606,3781.8178009104 1740.53038845858,3778.90005637597 PathPoint;PointKind.SMOOTHPOINT 1731.16282305967,3782.0625198952 1728.28533607434,3782.07572276178 1732.79751287371,3782.05501939507 PathPoint;PointKind.SMOOTHPOINT 1722.35335350037,3782.12542533875 1676.42546653748,3782.57082223892 1725.35144115832,3782.09635795282 PathPoint;PointKind.SMOOTHPOINT 1621.79074287415,3783.63840579987 1580.07276535034,3784.37247276306 1663.50777626038,3782.90410280228 PathPoint;PointKind.SMOOTHPOINT 1478.81306648254,3782.15941429138 1445.57753562927,3782.81747817993 1512.04891204834,3781.50158643723 PathPoint;PointKind.SMOOTHPOINT 1359.96565818787,3782.15941429138 1311.23462677002,3781.88065767288 1408.69606018066,3782.43864297867 PathPoint;PointKind.SMOOTHPOINT 1238.19519996643,3782.15941429138 1115.43056488037,3781.81055545807 1312.87616729736,3782.37231731415 PathPoint;PointKind.SMOOTHPOINT 1130.73534965515,3781.90756559372 1122.83354759216,3781.95996522903 1129.15391921997,3781.91818714142 PathPoint;PointKind.SMOOTHPOINT 1102.78698921204,3782.15941429138 1044.40592765808,3782.7867937088 1113.80318641663,3782.04116106033 PathPoint;PointKind.SMOOTHPOINT 997.577648162842,3782.15941429138 939.112558364868,3782.52668380737 1056.04242324829,3781.79238080978 PathPoint;PointKind.SMOOTHPOINT 871.010971069336,3781.10882520676 819.920539855957,3781.74422979355 922.10108757019,3780.47436475754 PathPoint;PointKind.SMOOTHPOINT 810.507173538208,3781.10882520676 796.82599067688,3781.15107536316 838.690624237061,3781.0226726532 PathPoint;PointKind.SMOOTHPOINT 766.865358352661,3782.10913896561 758.296995162964,3783.17341804504 771.158981323242,3781.57593727112 PathPoint;PointKind.SMOOTHPOINT 733.142023086548,3783.10921669006 727.210006713867,3783.22369337082 738.151302337646,3783.01197052002 PathPoint;PointKind.SMOOTHPOINT 705.328989028931,3782.12542533875 684.662761688232,3780.93463182449 721.790657043457,3783.07428359985 PathPoint;PointKind.SMOOTHPOINT 659.543352127075,3782.12542533875 643.762407302856,3781.58632278442 671.736574172974,3782.54202604294 PathPoint;PointKind.SMOOTHPOINT 626.421747207642,3782.12542533875 601.370944976807,3785.0449347496 645.555009841919,3779.89560842514 PathPoint;PointKind.SMOOTHPOINT 582.584810256958,3782.12542533875 582.332725524902,3782.08270311356 586.507701873779,3782.79127836227 PathPoint;PointKind.SMOOTHPOINT 563.534002304077,3783.10921669006 558.632669448853,3783.57868909836 568.096075057983,3782.67231702805 PathPoint;PointKind.SMOOTHPOINT 543.696727752686,3785.10937213898 536.357002258301,3787.126994133 547.214269638062,3784.14233922958 PathPoint;PointKind.SMOOTHPOINT 522.187070846558,3785.06310939789 514.272050857544,3785.03997802734 528.13136100769,3785.08010387421 PathPoint;PointKind.SMOOTHPOINT 506.997785568237,3784.10905838013 497.378597259521,3783.35988521576 516.617918014526,3784.85893964767 PathPoint;PointKind.SMOOTHPOINT 490.039501190186,3785.06310939789 470.959424972534,3785.47971010208 509.119262695312,3784.64603662491 PathPoint;PointKind.SMOOTHPOINT 462.745428085327,3782.05721139908 452.071323394775,3782.29442596436 473.419218063354,3781.82023286819 PathPoint;PointKind.SMOOTHPOINT 446.494617462158,3783.10921669006 441.629791259766,3782.53022432327 450.96227645874,3783.6407661438 PathPoint;PointKind.SMOOTHPOINT 426.701402664185,3783.03628206253 426.009349822998,3784.24643039703 426.370639801025,3783.61480236053 PathPoint;PointKind.SMOOTHPOINT 400.868854522705,3783.10921669006 355.428771972656,3780.46822786331 409.963102340698,3783.63769769669 PathPoint;PointKind.SMOOTHPOINT 312.593250274658,3782.10913896561 299.561948776245,3781.17231845856 337.597789764404,3783.90654087067 PathPoint;PointKind.SMOOTHPOINT 271,3779 268.180398405863,3776.75432992744 272.85276598092,3780.47570587496 PathPoint;PointKind.SMOOTHPOINT 266.967487335205,3767.10797309875 266.442546844482,3764.28759813309 268.017997741699,3772.7517914772 PathPoint;PointKind.SMOOTHPOINT 265.975513458252,3698.14934492111 265.495576858521,3679.60742712021 266.292114257812,3710.36459684372 PathPoint;PointKind.CORNERPOINT 263.059701919556,3523.63353967667 263.059701919556,3523.63353967667 263.059701919556,3523.63353967667 PathPoint;PointKind.CORNERPOINT 263.059701919556,3084.98155832291 263.059701919556,3084.98155832291 263.059701919556,3084.98155832291 PathPoint;PointKind.CORNERPOINT 263.059701919556,2486.72972917557 263.059701919556,2486.72972917557 263.059701919556,2486.72972917557 PathPoint;PointKind.SMOOTHPOINT 264,2475 264.11833190918,2466.73077106476 263.881982803345,2483.26922893524 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2458.3350276947 262.219868025148,2452.30886733118 265.175208097899,2473.5100363702 PathPoint;PointKind.SMOOTHPOINT 264.034051895142,2433.85684490204 263.600692749023,2426.4661359787 264.245538711548,2437.46628284454 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2375.10882854462 262.893533706665,2349.10609960556 263.233737945557,2402.23885774612 PathPoint;PointKind.SMOOTHPOINT 267,2107 267.110149383545,2059.11050987244 266.889535903931,2154.88972616196 PathPoint;PointKind.SMOOTHPOINT 265.008401870728,2015.76605558395 264.441289901733,2001.96252822876 265.575199127197,2029.56958293915 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1969.74666595459 266.898880004883,1942.61781692505 267.013750076294,1996.87551498413 PathPoint;PointKind.SMOOTHPOINT 268,1918 266.553895950317,1901.22078704834 269.445789337158,1934.77897691727 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1885.54092407227 267.037038803101,1873.55037689209 266.876850128174,1897.53170728683 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1861.06250524521 266.146821860681,1848.30905517412 268.998899633295,1868.69983071365 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1827.77245044708 266.773624420166,1809.92943048477 269.087390899658,1845.61476230621 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1767.06582069397 268.320857064398,1733.99449541144 267.586354918299,1796.19363948637 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1669.15238142014 267.438297271729,1662.98385858536 269.286603927612,1686.13765239716 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1630.96602916718 267.356157302856,1610.02175331116 266.556787490845,1651.91030502319 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1529.13583517075 265.792036056519,1508.50902557373 268.120908737183,1549.76288080215 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1423.38935852051 268.368902206421,1397.70622014999 267.493371963501,1449.07249689102 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1336.24640464783 267.037038803101,1313.38198900223 268.825550079346,1359.11058425903 PathPoint;PointKind.SMOOTHPOINT 268,1270 268.011644363403,1265.41928052902 267.969472885132,1282.17016935349 PathPoint;PointKind.SMOOTHPOINT 267,1247 267.068292617798,1245.17049741745 266.91660118103,1249.23595380783 PathPoint;PointKind.SMOOTHPOINT 265.982437133789,1230.49992799759 266.941995620728,1226.88317298889 265.125160217285,1233.72911453247 PathPoint;PointKind.SMOOTHPOINT 267,1212 267.791187286377,1190.39388370514 266.820928573608,1216.88567590714 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1189.37612771988 266.344985961914,1181.0200381279 268.127517700195,1205.38822889328 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1144.33628082275 268.605251312256,1124.47257041931 267.242546081543,1164.60502624512 PathPoint;PointKind.SMOOTHPOINT 267.463788986206,1110.83993196487 267.30076789856,1095.10847568512 267.605409622192,1124.4482588768 PathPoint;PointKind.SMOOTHPOINT 267.930822372437,1061.10937356949 267.063159942627,1041.87870740891 268.798484802246,1080.34003973007 PathPoint;PointKind.SMOOTHPOINT 268.905172348022,1007.25718259811 268.96559715271,985.348942279816 268.844118118286,1029.16542291641 PathPoint;PointKind.SMOOTHPOINT 269.879522323608,935.780303478241 270.76229095459,908.06608915329 268.996124267578,963.494281768799 PathPoint;PointKind.SMOOTHPOINT 269.879522323608,856.470623016357 270.773305892944,829.804165363312 268.985109329224,883.136372566223 PathPoint;PointKind.SMOOTHPOINT 266.885976791382,791.847474575043 268.366069793701,767.529559135437 265.405254364014,816.165153980255 PathPoint;PointKind.SMOOTHPOINT 266.885976791382,737.994811534882 266.322641372681,714.32740688324 267.448997497559,761.662216186523 PathPoint;PointKind.SMOOTHPOINT 266.471815109253,689.450798034668 266.099195480347,673.230042457581 266.845064163208,705.671553611755 PathPoint;PointKind.SMOOTHPOINT 266.471815109253,664.545865058899 267.104072570801,658.597798347473 265.839557647705,670.494403839111 PathPoint;PointKind.SMOOTHPOINT 265.480155944824,640.637233257294 265.597858428955,624.555265903473 265.36434173584,656.453897953033 PathPoint;PointKind.SMOOTHPOINT 265.480155944824,596.805174350739 264.890069961548,574.021010398865 266.069927215576,619.588866233826 PathPoint;PointKind.SMOOTHPOINT 266.471815109253,570.903940200806 265.944356918335,564.180972576141 266.947031021118,576.957278251648 PathPoint;PointKind.SMOOTHPOINT 265.91194152832,550.980277061462 264.619417190552,543.172023296356 267.26300239563,559.146595001221 PathPoint;PointKind.SMOOTHPOINT 264.937591552734,517.689514160156 265.228385925293,502.483942508698 264.637041091919,533.411529064178 PathPoint;PointKind.SMOOTHPOINT 264.937591552734,485.378057956696 263.813123703003,455.717504024506 265.333499908447,495.816679000854 PathPoint;PointKind.SMOOTHPOINT 264.983854293823,427.894713878632 264.691801071167,399.812757968903 265.327205657959,461.012227535248 PathPoint;PointKind.SMOOTHPOINT 264.983854293823,332.887330055237 264.694633483887,302.467925548553 265.260801315308,362.127506732941 PathPoint;PointKind.SMOOTHPOINT 264.983854293823,232.832822799683 264.752540588379,220.94447851181 265.316190719604,249.938235282898 PathPoint;PointKind.SMOOTHPOINT 266.967487335205,197.829866409302 266.946784044412,194.471545103335 267.020988464355,206.55157327652 PathPoint;PointKind.SMOOTHPOINT 269,184 269.823561067731,182.189467838003 266.933347401425,188.543367995408 PathPoint";
	
	subshadow645[0] = "PointKind.SMOOTHPOINT 266.137735898718,178.007771301693 268.195033450932,176.084155945632 264.619587422232,179.427271227218 PathPoint;PointKind.CORNERPOINT 272.00993934606,173.990540272581 272.00993934606,173.990540272581 272.00993934606,173.990540272581 PathPoint;PointKind.SMOOTHPOINT 5002.06485463481,176.237061151198 5006.23812941466,176.240446257473 4799.11942949315,176.072444185329 PathPoint;PointKind.SMOOTHPOINT 5010.98336535678,178.007771301693 5014.48697280325,180.518206875556 5007.24641521426,175.330138970211 PathPoint;PointKind.CORNERPOINT 5015.99376200879,184.019428254233 5015.99376200879,184.019428254233 5015.99376200879,184.019428254233 PathPoint;PointKind.SMOOTHPOINT 5018.05647722773,313.397955382276 5018.23385045487,955.414966001514 5018.03366620374,230.831574481943 PathPoint;PointKind.CORNERPOINT 5019.01214358755,3772.51108850982 5019.01214358755,3772.51108850982 5019.01214358755,3772.51108850982 PathPoint;PointKind.SMOOTHPOINT 5016.99584133919,3779.99222869831 5015.22121540747,3782.93261645846 5018.68919011246,3777.18650952248 PathPoint;PointKind.CORNERPOINT 5012.07238238106,3784.00961816903 5012.07238238106,3784.00961816903 5012.07238238106,3784.00961816903 PathPoint;PointKind.CORNERPOINT 273.992952063378,3784.00961816903 273.992952063378,3784.00961816903 273.992952063378,3784.00961816903 PathPoint;PointKind.SMOOTHPOINT 267.139815229121,3781.99611434915 265.698714056038,3781.13944166275 269.447777468127,3783.36809866805 PathPoint;PointKind.SMOOTHPOINT 264.133577237912,3779.99222869831 263.279297480933,3778.76636574182 265.136247943762,3781.4310277168 PathPoint;PointKind.SMOOTHPOINT 262.129418577106,3772.97862892034 262.080476225192,3684.31064286561 262.130715904699,3775.32897418112 PathPoint;PointKind.SMOOTHPOINT 260.115998994473,190.11653594591 260.139471432846,185.077196188677 259.42220087004,339.069295621962 PathPoint";
	
} else if (mask_variant_645 == 2) {
	
	mask645[0] = "PointKind.SMOOTHPOINT 285.31479401472,178.265526771545 292.158538611428,171.421001434326 282.698929513493,180.881731987 PathPoint;PointKind.SMOOTHPOINT 306.104311710456,170.48441696167 311.975675041283,168.476236343384 300.232636818825,172.492361545563 PathPoint;PointKind.SMOOTHPOINT 351.646400514933,170.076549530029 357.367279977956,170.009279727936 333.98619952362,170.283787727356 PathPoint;PointKind.SMOOTHPOINT 498.342935200004,166.001415729523 666.22840853014,166.016993999481 417.902920861645,165.99409866333 PathPoint;PointKind.SMOOTHPOINT 944.726379034789,166.076474666595 980.091957333838,165.995986938477 920.816268337114,166.13099861145 PathPoint;PointKind.SMOOTHPOINT 1495.02594370716,167.059321880341 1506.67831773597,166.852083683014 1483.37419279995,167.266796112061 PathPoint;PointKind.SMOOTHPOINT 1536.83335316716,170.990710735321 1543.37176817702,171.022575378418 1525.7966232849,170.93713092804 PathPoint;PointKind.SMOOTHPOINT 1546.55623114355,169.025016307831 1549.96906817862,168.448384284973 1541.59493691802,169.863174438477 PathPoint;PointKind.SMOOTHPOINT 1565.02898270885,168.042405128479 1568.94935229186,167.982924461365 1559.63773457531,168.123600959778 PathPoint;PointKind.SMOOTHPOINT 1581.5572833032,170.007863521576 1585.53373383073,171.071434497833 1575.9675709382,168.512821674347 PathPoint;PointKind.SMOOTHPOINT 1606.83608060805,171.973793983459 1622.28233053389,171.927767276764 1595.96790512017,172.006130695343 PathPoint;PointKind.SMOOTHPOINT 1858.65198395154,172.956641197205 1869.84418267446,173.444288253784 1847.45978522863,172.468994140625 PathPoint;PointKind.CORNERPOINT 1890.73651543515,172.956641197205 1890.73651543515,172.956641197205 1890.73651543515,172.956641197205 PathPoint;PointKind.SMOOTHPOINT 1896.57017990883,173.93948841095 1898.07533014768,174.062934398651 1890.73464607033,173.461046695709 PathPoint;PointKind.SMOOTHPOINT 1904.36543119762,171.819191455841 1909.18309589301,171.624935150146 1898.24263829884,172.066555500031 PathPoint;PointKind.SMOOTHPOINT 1916.98800556669,172.956641197205 1928.59395703587,174.001093387604 1905.3811194151,171.912189006805 PathPoint;PointKind.SMOOTHPOINT 1971.43419055752,172.956641197205 1980.36726189854,172.879693984985 1962.5014307773,173.033352375031 PathPoint;PointKind.SMOOTHPOINT 2016.15843225436,172.956641197205 2030.05092845609,172.837679862976 2002.26562449182,173.075602531433 PathPoint;PointKind.SMOOTHPOINT 2065.74395715899,172.956641197205 1880.56374365936,172.79731798172 2051.50625158764,172.944131374359 PathPoint;PointKind.SMOOTHPOINT 2561.59671371893,173.93948841095 2582.46941814904,173.72564125061 2428.56523584946,175.301406860352 PathPoint;PointKind.SMOOTHPOINT 2612.15493145025,172.956641197205 2620.02744981816,172.561047554016 2604.28147839992,173.351998806 PathPoint;PointKind.SMOOTHPOINT 2640.35024943114,173.93948841095 2650.05412219856,173.616829395294 2630.64668822453,174.261911392212 PathPoint;PointKind.SMOOTHPOINT 2697.71357821961,173.93948841095 2705.22998258979,173.847198963165 2690.19748541022,174.031541824341 PathPoint;PointKind.SMOOTHPOINT 2716.18664134571,173.93948841095 2725.21037688037,174.296608448029 2707.16290581104,173.582368373871 PathPoint;PointKind.SMOOTHPOINT 2757.99405080571,174.922335624695 2776.25431790343,175.429337501526 2739.733783708,174.415569782257 PathPoint;PointKind.SMOOTHPOINT 2798.82907899984,174.922335624695 2806.38287066637,174.772689819336 2791.27497577249,175.071981430054 PathPoint;PointKind.SMOOTHPOINT 2820.21866280197,172.956641197205 2834.23391396005,172.639410972595 2809.73339554086,173.193855762482 PathPoint;PointKind.SMOOTHPOINT 2852.30350584639,173.93948841095 2857.33521281337,174.142950057983 2847.27086419699,173.735790729523 PathPoint;PointKind.SMOOTHPOINT 2865.08871495458,173.537757873535 2871.45514840123,173.023674964905 2858.07548128109,174.104004383087 PathPoint;PointKind.SMOOTHPOINT 2881.47089353235,174.922335624695 2884.07523028387,175.1409034729 2877.81940092226,174.615962982178 PathPoint;PointKind.SMOOTHPOINT 2898.97157539258,173.93948841095 2901.89339260226,173.399205684662 2891.94463304376,175.239093780518 PathPoint;PointKind.SMOOTHPOINT 2905.77762113213,170.990710735321 2913.6878383572,170.281899452209 2902.01240882897,171.328239917755 PathPoint;PointKind.SMOOTHPOINT 2917.44495007948,174.922335624695 2924.74450813085,175.087559700012 2910.14508046732,174.757111549377 PathPoint;PointKind.SMOOTHPOINT 2953.41838350501,173.93948841095 2963.4942598711,174.28103017807 2943.34250713892,173.597710609436 PathPoint;PointKind.SMOOTHPOINT 2982.58608275178,173.93948841095 2999.24773136977,173.766711235046 2965.9250572554,174.112265586853 PathPoint;PointKind.SMOOTHPOINT 3554.2761659087,174.922335624695 3586.75949522003,175.851603031158 3521.79252503656,173.993068218231 PathPoint;PointKind.SMOOTHPOINT 3655.39104356732,174.922335624695 3660.00588218001,175.190942764282 3637.43330200923,173.876703262329 PathPoint;PointKind.SMOOTHPOINT 3670.94758601739,176.888030052185 3675.73502931489,177.298965930939 3666.15983115908,176.477330207825 PathPoint;PointKind.SMOOTHPOINT 3696.22638332224,177.87087726593 3700.51408309188,176.619186878204 3693.45442685876,178.680239200592 PathPoint;PointKind.SMOOTHPOINT 3713.72706518247,174.922335624695 3717.64930413029,174.911478042603 3708.43208933702,174.93696975708 PathPoint;PointKind.SMOOTHPOINT 3724.42170130314,176.888030052185 3727.98938405725,176.913049697876 3717.33338147614,176.838226795197 PathPoint;PointKind.SMOOTHPOINT 3737.06109995556,175.90518283844 3738.32074028173,175.880871295929 3729.26210993714,176.055536746979 PathPoint;PointKind.SMOOTHPOINT 3743.86683413432,176.888030052185 3745.75769664717,176.212735652924 3741.72734610074,177.652545452118 PathPoint;PointKind.SMOOTHPOINT 3747.75604763704,176.888030052185 3754.47547947338,176.966393470764 3746.91826063801,176.878352642059 PathPoint;PointKind.SMOOTHPOINT 3766.22911076314,175.90518283844 3783.02379584397,174.949243545532 3760.82134990704,176.212971687317 PathPoint;PointKind.SMOOTHPOINT 3787.61900612608,172.956641197205 3789.02071817837,172.957113265991 3776.259499252,172.952628612518 PathPoint;PointKind.SMOOTHPOINT 3794.42474030483,172.956641197205 3801.66136307401,173.448064804077 3793.40593647932,172.887483119965 PathPoint;PointKind.SMOOTHPOINT 3804.14730672042,173.93948841095 3809.96975500519,174.334846019745 3799.04362920797,173.592753887177 PathPoint;PointKind.SMOOTHPOINT 3815.81432410697,170.007863521576 3819.68733644794,170.119979858398 3813.95212518798,169.954047679901 PathPoint;PointKind.SMOOTHPOINT 3823.5924395516,170.990710735321 3824.72309370536,171.93319606781 3821.96484591721,169.633749008179 PathPoint;PointKind.SMOOTHPOINT 3829.42610402528,172.956641197205 3835.19122512232,173.196924209595 3825.54405642103,172.794957637787 PathPoint;PointKind.SMOOTHPOINT 3838.17628917499,170.007863521576 3845.54688308942,170.561600208282 3837.03909224437,169.922419071198 PathPoint;PointKind.SMOOTHPOINT 3859.56618453793,172.956641197205 3867.5835786792,172.499914646149 3851.54879039667,173.41336774826 PathPoint;PointKind.SMOOTHPOINT 3879.01162892992,172.956641197205 3890.42036241085,173.87033033371 3867.60258388818,172.042716026306 PathPoint;PointKind.SMOOTHPOINT 3903.31773340809,173.93948841095 3910.31756996706,173.97017288208 3896.31851997073,173.908803939819 PathPoint;PointKind.SMOOTHPOINT 3919.84634556324,170.990710735321 3930.85877370287,170.044212818146 3904.59139397038,172.301881790161 PathPoint;PointKind.SMOOTHPOINT 3934.43019518662,173.93948841095 3944.54377040986,173.597474575043 3927.91172006815,174.159708499908 PathPoint;PointKind.CORNERPOINT 3952.90325831273,172.956641197205 3952.90325831273,172.956641197205 3952.90325831273,172.956641197205 PathPoint;PointKind.SMOOTHPOINT 3963.598517555,170.990710735321 3971.08002711526,170.342088222504 3956.11607331233,171.639805316925 PathPoint;PointKind.SMOOTHPOINT 3977.2096743517,171.973793983459 3984.95632215524,171.924698829651 3966.88361466088,172.039175510406 PathPoint;PointKind.SMOOTHPOINT 3990.82176583081,170.990710735321 3992.46400282295,170.68835067749 3985.89038144236,171.89897108078 PathPoint;PointKind.SMOOTHPOINT 3996.65511874369,169.025016307831 4004.73669441035,168.621161460876 3993.3158100581,169.192128658295 PathPoint;PointKind.SMOOTHPOINT 4010.26689866199,170.990710735321 4012.98090481614,171.41557264328 4006.11472784162,170.34114408493 PathPoint;PointKind.SMOOTHPOINT 4022.90629731442,170.990710735321 4035.20360220526,171.704950809479 4018.04470254582,170.708413600922 PathPoint;PointKind.SMOOTHPOINT 4055.96321006391,171.973793983459 4063.53351445301,172.054045677185 4037.89268349517,171.781898021698 PathPoint;PointKind.SMOOTHPOINT 4079.29724483701,170.990710735321 4081.54359822599,170.736973762512 4071.58331091778,171.86262178421 PathPoint;PointKind.SMOOTHPOINT 4086.10297901576,169.025016307831 4090.62902279963,168.900626182556 4083.98872740722,169.083316802979 PathPoint;PointKind.SMOOTHPOINT 4098.74268922899,170.990710735321 4101.72121050481,171.44625711441 4094.81453062591,170.390475273132 PathPoint;PointKind.SMOOTHPOINT 4107.4928743787,170.990710735321 4122.64656871061,170.664511203766 4104.49285540749,171.055384159088 PathPoint;PointKind.SMOOTHPOINT 4150.27235354378,173.93948841095 4159.29421971363,173.782525539398 4135.92747105623,174.188976764679 PathPoint;PointKind.SMOOTHPOINT 4174.57970426517,172.783864021301 4175.44210456762,172.727215766907 4166.98167096462,173.282368659973 PathPoint;PointKind.SMOOTHPOINT 4177.16597049012,172.614391326904 4177.60994463427,172.036815166473 4175.99543655359,174.136577129364 PathPoint;PointKind.SMOOTHPOINT 4180.41243405644,171.973793983459 4183.31649230035,171.789687156677 4179.68805518967,172.019820690155 PathPoint;PointKind.SMOOTHPOINT 4188.19054950107,171.973793983459 4200.79193773554,171.374738693237 4185.16809815204,172.117302894592 PathPoint;PointKind.SMOOTHPOINT 4212.49696554004,172.956641197205 4219.15782394544,173.00550031662 4202.52421579972,172.883706569672 PathPoint;PointKind.SMOOTHPOINT 4231.94240993203,170.990710735321 4233.93016785459,170.59063243866 4226.07603157405,172.172298908234 PathPoint;PointKind.SMOOTHPOINT 4235.86527200146,169.198737621307 4237.06353484945,169.10621213913 4233.30424220155,169.396770477295 PathPoint;PointKind.SMOOTHPOINT 4239.72052537666,169.025016307831 4243.84683665039,168.964119434357 4238.3428035062,169.045551300049 PathPoint;PointKind.SMOOTHPOINT 4251.38754276321,169.025016307831 4253.32607407891,169.38142824173 4247.72732645063,168.352082252502 PathPoint;PointKind.SMOOTHPOINT 4256.24882597101,170.990710735321 4262.00615804797,172.582290649414 4254.37229525508,170.472143173218 PathPoint;PointKind.SMOOTHPOINT 4270.83298715519,170.990710735321 4283.00099431282,170.986934185028 4264.56531848307,170.992835044861 PathPoint;PointKind.SMOOTHPOINT 4287.36128774954,170.007863521576 4297.85091686189,169.735479831696 4276.87134707638,170.280719280243 PathPoint;PointKind.SMOOTHPOINT 4302.9175186388,173.93948841095 4305.19471654727,173.860416889191 4293.85203395655,174.254358291626 PathPoint;PointKind.SMOOTHPOINT 4306.80673214152,171.973793983459 4307.71680124682,171.819663524628 4305.28257669369,172.231307506561 PathPoint;PointKind.SMOOTHPOINT 4311.66801534932,172.956641197205 4312.48804338257,172.893147945404 4310.46539065009,173.049874782562 PathPoint;PointKind.SMOOTHPOINT 4314.58453602535,170.990710735321 4315.37527734314,170.903850078583 4313.5940842329,171.099994659424 PathPoint;PointKind.SMOOTHPOINT 4318.47374952807,172.956641197205 4319.15295207841,172.93705034256 4317.50884572146,172.984257221222 PathPoint;PointKind.SMOOTHPOINT 4320.41820049903,170.990710735321 4321.50025116753,170.891576290131 4319.66484647759,171.059868812561 PathPoint;PointKind.SMOOTHPOINT 4327.22393467778,170.990710735321 4328.597294697,171.413920402527 4325.33338372573,170.408649921417 PathPoint;PointKind.SMOOTHPOINT 4329.16838564874,172.956641197205 4331.21035515101,172.986853599548 4328.00127888104,172.939410686493 PathPoint;PointKind.SMOOTHPOINT 4335.00236168322,170.990710735321 4337.4316012635,170.493386268616 4332.68528399198,171.465139865875 PathPoint;PointKind.SMOOTHPOINT 4344.724616538,170.990710735321 4348.11502119526,170.948460578918 4340.74442728084,171.040750026703 PathPoint;PointKind.SMOOTHPOINT 4354.4474945144,169.025016307831 4365.11315548039,168.975449085236 4350.9670487851,169.041302680969 PathPoint;PointKind.SMOOTHPOINT 4377.7818408483,169.025016307831 4379.11314015913,169.071515083313 4366.9878168315,168.64924955368 PathPoint;PointKind.SMOOTHPOINT 4382.64312405609,170.990710735321 4405.39267076293,171.871355056763 4381.26384438161,170.937366962433 PathPoint;PointKind.SMOOTHPOINT 4442.92297352059,170.990710735321 4444.85371581622,171.013606071472 4429.29405775812,170.82949924469 PathPoint;PointKind.SMOOTHPOINT 4448.75663799427,169.025016307831 4449.46948911132,167.758927822113 4447.86339317233,170.612347602844 PathPoint;PointKind.SMOOTHPOINT 4453.61792120206,170.990710735321 4455.36858135361,172.209592342377 4452.24487274364,170.035007476807 PathPoint;PointKind.SMOOTHPOINT 4459.45158567574,169.025016307831 4462.36374450053,170.253339290619 4457.78068508974,168.320217609406 PathPoint;PointKind.SMOOTHPOINT 4467.71885158094,171.462071418762 4468.79093230375,171.341929912567 4464.4269001374,171.83052110672 PathPoint;PointKind.SMOOTHPOINT 4474.03574685993,169.025016307831 4479.28398858494,168.82816362381 4471.50088816746,169.120138168335 PathPoint;PointKind.SMOOTHPOINT 4489.59166618839,170.990710735321 4496.64228715823,171.288586139679 4485.79623248735,170.830443382263 PathPoint;PointKind.SMOOTHPOINT 4508.06441775369,170.007863521576 4511.51962705796,169.813843250275 4497.09280407924,170.624385356903 PathPoint;PointKind.SMOOTHPOINT 4522.64857893788,170.007863521576 4537.57981885651,170.076077461243 4516.40427732597,169.979303359985 PathPoint;PointKind.SMOOTHPOINT 4561.94792393446,169.816203594208 4563.21348391588,169.809594631195 4548.29159082134,169.887485980988 PathPoint;PointKind.SMOOTHPOINT 4567.37250907392,169.025016307831 4570.94548836168,169.013450622559 4566.05086814798,169.02926492691 PathPoint;PointKind.SMOOTHPOINT 4575.15062451855,169.025016307831 4575.84696291305,169.027376651764 4571.01247393431,169.011798381805 PathPoint;PointKind.SMOOTHPOINT 4577.09507548951,170.007863521576 4577.89391738817,170.027218341827 4576.33642493442,169.989688873291 PathPoint;PointKind.SMOOTHPOINT 4579.03983802127,169.025016307831 4582.08534486971,169.052868366241 4578.1758799148,169.017227172852 PathPoint;PointKind.SMOOTHPOINT 4588.76240443686,169.025016307831 4592.51048089586,169.254205703735 4585.10904246194,168.801727771759 PathPoint;PointKind.SMOOTHPOINT 4600.42973338421,170.007863521576 4638.92899023892,170.553102970123 4596.89320671039,169.958060264587 PathPoint;PointKind.SMOOTHPOINT 4650.01494672804,170.990710735321 4665.45340763381,171.328711986542 4634.57617426147,170.652945518494 PathPoint;PointKind.SMOOTHPOINT 4680.1553388015,170.007863521576 4693.49325677405,170.338075637817 4666.81679770734,169.677887439728 PathPoint;PointKind.SMOOTHPOINT 4708.35065678239,170.007863521576 4726.94522862163,169.616518497467 4689.75577338235,170.399680614471 PathPoint;PointKind.SMOOTHPOINT 4738.49042573424,170.990710735321 4758.9727444783,171.336501121521 4718.00841855097,170.645392417908 PathPoint;PointKind.SMOOTHPOINT 4782.242597726,170.990710735321 4816.46537099998,170.119271755219 4748.01951289122,171.862385749817 PathPoint;PointKind.SMOOTHPOINT 4848.35642322498,170.990710735321 4869.96596895397,170.871985435486 4823.91665916236,171.125250339508 PathPoint;PointKind.SMOOTHPOINT 4888.90356923722,170.756328582764 4890.76234098737,170.815573215485 4874.71010529988,170.301490306854 PathPoint;PointKind.SMOOTHPOINT 4895.02480433198,172.956641197205 4901.58378235482,173.106287002563 4892.78156655103,172.905421733856 PathPoint;PointKind.SMOOTHPOINT 4903.77498948169,175.90518283844 4904.7402048491,175.59007692337 4901.59811415176,176.616118431091 PathPoint;PointKind.SMOOTHPOINT 4907.6638914236,172.956641197205 4912.32515259593,171.463487625122 4905.3614570901,173.6942486763 PathPoint;PointKind.SMOOTHPOINT 4928.08171708147,170.990710735321 4942.36958394209,171.179066181183 4920.42791439719,170.889924049377 PathPoint;PointKind.SMOOTHPOINT 4973.39044684456,175.962303161621 4992.1345678692,179.375360488892 4953.57642602274,172.354517459869 PathPoint;PointKind.SMOOTHPOINT 4999.13004257692,191.92719745636 5005.94045016772,199.551344394684 4993.64781868893,185.788887023926 PathPoint;PointKind.SMOOTHPOINT 5006.83494123287,219.151640415192 5009.77140180029,236.007328510284 5005.24037304358,210.000114917755 PathPoint;PointKind.SMOOTHPOINT 5011.69622444067,266.32995891571 5011.50461454688,270.782747745514 5012.13677141598,256.071196079254 PathPoint;PointKind.SMOOTHPOINT 5011.69622444067,278.124597549438 5010.69549114172,280.911927700043 5012.46328713743,275.986834049225 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,297.782013893127 5008.45754989443,316.534474372864 5008.90557432901,290.412784099579 PathPoint;PointKind.SMOOTHPOINT 5010.72384317479,435.384872436523 5010.66308881822,452.65432882309 5010.78490909216,418.115416049957 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,936.652529716492 5010.15399846627,953.630247592926 5007.40447438059,919.675047874451 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,993.659556388855 5008.92364485558,1005.91469812393 5008.63482799128,981.404414653778 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1082.11863803864 5009.67949136344,1095.35285043716 5009.82374401518,1068.88442564011 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,1253.13948202133 5009.03393737981,1260.07700490952 5008.52484702785,1246.20172309875 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1272.79689836502 5009.73650699037,1284.94086790085 5009.76672838825,1260.65292882919 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,1316.04359197617 5008.33884522852,1348.17141342163 5009.22025073995,1283.9157705307 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1533.25943517685 5010.06302271182,1546.79695177078 5009.4402126668,1519.72191858292 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,1595.18069791794 5008.79185463595,1604.49461507797 5008.75290953558,1575.25467443466 PathPoint;PointKind.SMOOTHPOINT 5009.7617434154,1634.20992898941 5009.79414573891,1635.32401132584 5009.33864384505,1619.79436445236 PathPoint;PointKind.SMOOTHPOINT 5009.85708102109,1637.53305721283 5009.46763001746,1639.30331516266 5010.0935556705,1636.45862865448 PathPoint;PointKind.SMOOTHPOINT 5009.94992614036,1640.93974161148 5010.31071355013,1654.64909124374 5009.92032786409,1639.81574583054 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1669.8794465065 5008.22481397465,1677.32774782181 5010.45216215465,1666.46190452576 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1687.57140445709 5009.37198085096,1694.89696788788 5010.13156608846,1680.24584102631 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1703.2974319458 5010.21880311327,1709.60545110703 5009.28443226535,1696.98941278458 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1723.93793153763 5009.96799666693,1735.06813335419 5009.53523871169,1712.80749368668 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1774.06455564499 5008.89685062653,1795.25029468536 5010.60607319129,1752.87905263901 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1846.79760980606 5009.94899145795,1861.87100219727 5009.55393235986,1831.72421741486 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,1879.23251199722 5010.48487603896,1903.41305541992 5007.07421992951,1855.05220460892 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1949.9998717308 5010.09729440014,1967.20394659042 5009.40625253928,1932.79556083679 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1998.16080141068 5009.80068851577,2002.82531309128 5009.61873700687,1985.57922410965 PathPoint;PointKind.SMOOTHPOINT 5009.16884320747,2011.74340057373 5008.56254588501,2019.17871999741 5009.52682657001,2007.36260223389 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2033.54448127747 5008.92364485558,2043.71095466614 5008.68872801018,2027.14724111557 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2086.61964702606 5010.06302271182,2112.67383146286 5009.4402126668,2060.56569862366 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2212.42810297012 5008.78313093347,2242.90887641907 5010.72010444515,2181.94732952118 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2291.05847644806 5009.14422990404,2306.0742764473 5010.35931703538,2276.04244041443 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2364.77414178848 5008.74075866427,2366.0331492424 5009.3112264944,2347.35503959656 PathPoint;PointKind.SMOOTHPOINT 5007.80732249875,2369.6886138916 5007.76121149992,2375.30882883072 5007.87025778094,2361.97689819336 PathPoint;PointKind.SMOOTHPOINT 5008.5507065745,2375.0591044426 5009.12304376944,2398.49944400787 5008.5298320007,2374.21244907379 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2458.14769554138 5009.74398444964,2476.99126529694 5007.95998729218,2442.13748264313 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2533.82929134369 5009.12865186389,2556.72321128845 5008.42982098297,2510.93489933014 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2601.64763736725 5010.42381012159,2623.07129907608 5009.07942525703,2580.22397565842 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2674.38069152832 5008.50958054851,2706.79647493362 5009.04889229835,2641.96490812302 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2736.3021903038 5009.13270215433,2752.06244277954 5008.42608225333,2720.54146575928 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2796.25752258301 5009.56172137994,2823.34412145615 5009.94151399868,2769.17092370987 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2866.04179906845 5009.72747172708,2882.6026802063 5009.77576365154,2849.39759778976 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2913.21988153458 5008.23571860275,2923.59453725815 5009.29845250148,2903.31446218491 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2955.48372793198 5009.39441322877,2967.79669809341 5010.10882214985,2943.17075777054 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2986.93601894379 5009.19189870688,2994.39163732529 5008.20207003604,2976.50825548172 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,3030.18247652054 5009.86081975073,3036.84289503098 5009.47728840235,3013.4731297493 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,3047.87419843674 5010.26740659853,3065.12689638138 5009.59194277782,3042.5299077034 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3065.56615638733 5008.69589390865,3074.7268872261 5008.86289049901,3056.40542554855 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3101.93244743347 5009.11743567499,3115.22047567368 5008.44103717187,3088.64465522766 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3152.05930757523 5008.49462562997,3164.22546434402 5009.04577669032,3140.67513275146 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3181.54566812515 5008.87067951908,3189.78964138031 5008.67283840924,3171.91664505005 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3220.86073684692 5008.88033790397,3223.05680084229 5008.17901453662,3207.79009628296 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,3228.72375059128 5009.93590590423,3230.93043613434 5009.60814393957,3227.00400400162 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3233.6382226944 5008.75166329237,3240.93050527573 5008.78562341989,3231.98763418198 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3257.22726392746 5009.17040101148,3272.16611671448 5008.46066550245,3245.0457649231 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3293.593791008 5009.31496522403,3303.27285337448 5008.24381918363,3283.91472864151 PathPoint;PointKind.SMOOTHPOINT 5007.80732249875,3310.30266571045 5009.05668131842,3319.2561583519 5006.55765211828,3301.349173069 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3337.82333183289 5008.69900951668,3349.23229026794 5008.85572460054,3326.99171352386 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,3355.51505374908 5010.79238655143,3360.79018640518 5008.71084882719,3350.23992109299 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,3372.22392845154 5009.45547914614,3377.54154729843 5010.04775623247,3366.90630960464 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,3391.88158082962 5008.27435214231,3404.83939695358 5011.22919479711,3378.92352867126 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3409.57330274582 5008.64666730179,3426.58571767807 5008.91242866667,3392.56112384796 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,3453.80284357071 5009.35671437162,3472.55034732819 5010.146521007,3435.05510377884 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3528.50135612488 5008.94265006456,3558.17229557037 5008.61613434311,3498.83088874817 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3585.50838279724 5008.32357874917,3597.80978727341 5009.23520565849,3573.20721435547 PathPoint;PointKind.SMOOTHPOINT 5006.83494123287,3611.06311845779 5006.47197289748,3628.00566720963 5007.17734655527,3595.07816123962 PathPoint;PointKind.SMOOTHPOINT 5008.04005841853,3654.29446983337 5007.88458957787,3676.75101804733 5008.19583881998,3631.83792161942 PathPoint;PointKind.SMOOTHPOINT 5011.69622444067,3731.95733833313 5012.14424887525,3748.17077684402 5011.24820000609,3715.74366378784 PathPoint;PointKind.SMOOTHPOINT 5009.03019865017,3764.05258703232 5007.09010953046,3770.46847391129 5011.71336028483,3755.1791100502 PathPoint;PointKind.SMOOTHPOINT 4998.24334053184,3778.40300607681 4997.53734375245,3778.89372158051 5003.10555842205,3775.02346563339 PathPoint;PointKind.SMOOTHPOINT 4996.06958080995,3779.80811882019 4994.7579098297,3779.79254055023 4997.40773445844,3779.82369709015 PathPoint;PointKind.SMOOTHPOINT 4992.56857206765,3781.70040655136 4988.88623493807,3783.49072742462 4993.77400081411,3781.11456918716 PathPoint;PointKind.SMOOTHPOINT 4979.33035355203,3785.00630426407 4974.22044482352,3786.40386390686 4983.58814348459,3783.84194660187 PathPoint;PointKind.SMOOTHPOINT 4963.08308080191,3787.98128175735 4944.96737791675,3790.0930814743 4968.22570341474,3787.38175439835 PathPoint;PointKind.SMOOTHPOINT 4789.04833190475,3789.94721221924 4774.79473673245,3791.77081394196 4803.30192707706,3788.12337446213 PathPoint;PointKind.SMOOTHPOINT 4637.37554807561,3789.94721221924 4615.21080099584,3791.51731300354 4659.53998359459,3788.37663936615 PathPoint;PointKind.SMOOTHPOINT 4475.007816565,3789.94721221924 4446.3186747115,3790.69968986511 4503.69726997931,3789.19449853897 PathPoint;PointKind.SMOOTHPOINT 4390.42092793992,3789.94721221924 4376.2511426236,3790.84154653549 4404.59102481704,3789.05264186859 PathPoint;PointKind.SMOOTHPOINT 4356.39194548535,3789.94721221924 4347.61278518097,3789.8003988266 4366.28929751138,3790.11220026016 PathPoint;PointKind.SMOOTHPOINT 4324.30710244094,3789.94721221924 4323.04808523639,3789.91227912903 4334.18918798762,3790.2203040123 PathPoint;PointKind.SMOOTHPOINT 4316.52929855711,3789.94721221924 4307.32298839194,3790.37703084946 4317.56928851722,3789.89858913422 PathPoint;PointKind.SMOOTHPOINT 4290.27811998637,3789.94721221924 4284.27527799672,3790.18466281891 4300.6356473183,3789.53722047806 PathPoint;PointKind.SMOOTHPOINT 4266.60822266774,3790.15563058853 4265.44921648092,3790.14902162552 4276.27221565239,3790.21039056778 PathPoint;PointKind.SMOOTHPOINT 4263.06016824421,3790.13249921799 4262.1385713892,3789.51880979538 4264.66719886562,3791.20315122604 PathPoint;PointKind.SMOOTHPOINT 4259.69157284315,3790.10677146912 4254.11868476151,3790.06121683121 4260.83344318582,3790.11597681046 PathPoint;PointKind.SMOOTHPOINT 4241.66528790842,3789.94721221924 4220.77388983014,3789.77065849304 4248.09247571164,3790.0015001297 PathPoint;PointKind.SMOOTHPOINT 4194.02452553555,3789.94721221924 4172.93840195544,3789.22895956039 4215.11002599405,3790.66522884369 PathPoint;PointKind.SMOOTHPOINT 4153.18918578062,3789.94721221924 4145.88838148605,3790.21369504929 4171.90152760336,3789.26365661621 PathPoint;PointKind.SMOOTHPOINT 4136.66088518628,3789.94721221924 4131.80957192418,3790.24414348602 4139.76465390486,3789.75696849823 PathPoint;PointKind.SMOOTHPOINT 4123.04910526797,3790.93005943298 4109.3239172174,3790.64965057373 4131.41949779893,3791.10071229935 PathPoint;PointKind.SMOOTHPOINT 4094.85347572628,3789.94721221924 4075.78813551384,3789.75885677338 4113.91912749951,3790.13509559631 PathPoint;PointKind.SMOOTHPOINT 4048.18478305848,3789.94721221924 4016.1145833718,3790.38151550293 4080.24252031304,3789.51267290115 PathPoint;PointKind.SMOOTHPOINT 3957.76422995972,3789.94721221924 3900.33485028104,3790.12801456451 4015.29299753453,3789.76570177078 PathPoint;PointKind.SMOOTHPOINT 3853.73252006426,3789.94721221924 3830.13615109511,3789.43643379211 3877.32920059421,3790.45775461197 PathPoint;PointKind.SMOOTHPOINT 3796.36919127579,3789.94721221924 3781.52705774679,3789.97010755539 3811.21163636559,3789.92408084869 PathPoint;PointKind.SMOOTHPOINT 3771.09039397093,3789.94721221924 3756.33175873712,3789.9625544548 3785.84902920475,3789.93163394928 PathPoint;PointKind.SMOOTHPOINT 3743.86683413432,3790.93005943298 3731.2504909813,3790.71479606628 3756.48411196974,3791.1448507309 PathPoint;PointKind.SMOOTHPOINT 3710.81023294563,3790.93005943298 3700.42715762787,3791.50574731827 3721.19361982419,3790.35389947891 PathPoint;PointKind.SMOOTHPOINT 3668.03075378055,3790.93005943298 3634.19306965897,3791.02895784378 3701.78774365418,3790.83116102219 PathPoint;PointKind.SMOOTHPOINT 3562.05396979253,3790.93005943298 3538.89378594745,3790.5448513031 3586.29713898851,3791.33297014236 PathPoint;PointKind.SMOOTHPOINT 3471.63403981537,3790.93005943298 3435.85346252685,3791.00865888596 3507.24512802711,3790.85145998001 PathPoint;PointKind.SMOOTHPOINT 3326.76667860418,3790.93005943298 3309.15601578053,3791.04500818253 3344.37796454944,3790.81463861465 PathPoint;PointKind.SMOOTHPOINT 3260.6528531052,3790.93005943298 3240.88245079579,3790.64941453934 3291.24905863332,3791.36389064789 PathPoint;PointKind.SMOOTHPOINT 3188.70567469335,3790.93005943298 3186.9762006764,3790.94256925583 3200.01688964298,3790.84626722336 PathPoint;PointKind.SMOOTHPOINT 3182.87232178048,3790.93005943298 3182.15105852174,3791.40283632278 3184.59494145977,3789.79969072342 PathPoint;PointKind.SMOOTHPOINT 3177.19786487709,3791.00535440445 3168.69350120088,3791.60440969467 3178.65970816434,3790.90244340897 PathPoint;PointKind.SMOOTHPOINT 3151.75986000195,3790.93005943298 3114.54485677683,3790.62321472168 3160.14645369466,3790.99898147583 PathPoint;PointKind.SMOOTHPOINT 3069.11742234782,3790.93005943298 3050.98645298331,3791.02966594696 3087.24870327313,3790.83021688461 PathPoint;PointKind.SMOOTHPOINT 3025.36556191686,3790.93005943298 2997.2917526491,3791.10661315918 3053.43999430622,3790.75326967239 PathPoint;PointKind.SMOOTHPOINT 2921.3341635822,3790.93005943298 2918.58588573974,3791.0034661293 2955.79621555281,3790.0085811615 PathPoint;PointKind.SMOOTHPOINT 2913.08652600759,3791.10566902161 2912.52197783271,3791.11487436295 2915.83854257968,3791.06129455566 PathPoint;PointKind.SMOOTHPOINT 2910.63890433993,3790.93005943298 2909.8113988474,3790.94186115265 2911.20438719721,3790.92203426361 PathPoint;PointKind.SMOOTHPOINT 2908.69414180817,3789.94721221924 2907.55756799916,3790.67349004745 2910.24633772826,3788.95539569855 PathPoint;PointKind.SMOOTHPOINT 2904.86568266202,3791.2010269165 2904.29833043992,3791.20527553558 2906.21505249942,3791.19111347198 PathPoint;PointKind.SMOOTHPOINT 2903.16206819171,3791.21212053299 2874.50377085769,3791.37663650513 2903.73066665702,3791.20905208588 PathPoint;PointKind.SMOOTHPOINT 2807.57926414955,3790.93005943298 2762.63132179622,3791.55177402496 2844.64752223649,3790.41715669632 PathPoint;PointKind.SMOOTHPOINT 2607.29333668165,3789.94721221924 2561.56680388185,3789.7437505722 2653.02018104225,3790.15043783188 PathPoint;PointKind.SMOOTHPOINT 2465.3431192681,3789.94721221924 2423.99152326275,3791.65161657333 2506.69471527345,3788.24257183075 PathPoint;PointKind.SMOOTHPOINT 2382.70099317478,3788.9641289711 2337.63870800678,3789.67081594467 2427.76296678197,3788.25767803192 PathPoint;PointKind.SMOOTHPOINT 2281.58580395535,3789.94721221924 2234.60960077508,3790.24249124527 2328.56169557482,3789.65146112442 PathPoint;PointKind.SMOOTHPOINT 2194.08208309343,3789.94721221924 2163.88187134582,3789.50795221329 2254.56008522858,3790.82620429993 PathPoint;PointKind.SMOOTHPOINT 2121.1625234157,3789.94721221924 2101.14411870716,3789.67931318283 2141.12983215256,3790.21416711807 PathPoint;PointKind.SMOOTHPOINT 2063.79919462723,3789.94721221924 2025.52986964507,3789.69607162476 2084.70866323209,3790.08434820175 PathPoint;PointKind.SMOOTHPOINT 1983.10120794406,3789.94721221924 1928.74599870769,3789.62455320358 2037.45704030205,3790.2696352005 PathPoint;PointKind.SMOOTHPOINT 1850.87386850691,3788.9641289711 1803.35586109038,3789.24146938324 1900.48026798534,3788.6747508049 PathPoint;PointKind.SMOOTHPOINT 1723.50781227755,3787.98128175735 1677.6691175887,3788.42833089828 1771.76297255376,3787.51062917709 PathPoint;PointKind.SMOOTHPOINT 1624.33707402908,3786.99843454361 1582.70039988907,3787.73556995392 1665.97312504748,3786.2612991333 PathPoint;PointKind.SMOOTHPOINT 1480.44240564457,3786.01535129547 1447.27146164122,3786.67601156235 1513.61334964793,3785.35516309738 PathPoint;PointKind.SMOOTHPOINT 1361.82653456492,3786.01535129547 1313.19033542675,3785.735414505 1410.46211058149,3786.29576015472 PathPoint;PointKind.SMOOTHPOINT 1240.29351968763,3786.01535129547 1188.09711525462,3785.8661775589 1314.82883368925,3786.22896242142 PathPoint;PointKind.SMOOTHPOINT 1145.70303680273,3785.69859313965 1145.10546318275,3785.70071744919 1171.29713364014,3785.6157450676 PathPoint;PointKind.SMOOTHPOINT 1143.89504946345,3785.70496606827 1142.49333741116,3785.71039485931 1144.50290458993,3785.70260572433 PathPoint;PointKind.SMOOTHPOINT 1139.17833046821,3786.01535129547 1137.21892457871,3786.79355669022 1140.870105628,3785.3438334465 PathPoint;PointKind.SMOOTHPOINT 1133.04338669812,3785.76255846024 1125.15715965487,3785.81519412994 1135.31466495133,3785.74745225906 PathPoint;PointKind.SMOOTHPOINT 1105.14934801364,3786.01535129547 1046.88186977513,3786.64509105682 1116.14401718751,3785.89662599564 PathPoint;PointKind.SMOOTHPOINT 1000.14494529149,3786.01535129547 941.793968757806,3786.38403701782 1058.49592182518,3785.64690160751 PathPoint;PointKind.SMOOTHPOINT 870.834126530374,3786.01535129547 819.843462404617,3786.6528801918 921.824479095328,3785.37829446793 PathPoint;PointKind.SMOOTHPOINT 809.581895799993,3786.01535129547 799.219071934424,3786.04745197296 837.709916647456,3785.92872667313 PathPoint;PointKind.SMOOTHPOINT 782.358647524179,3786.01535129547 774.196066048756,3786.48411560059 787.24516715701,3785.73517847061 PathPoint;PointKind.SMOOTHPOINT 763.885584398075,3786.99843454361 758.358807315265,3787.68883514404 771.359616499068,3786.06491851807 PathPoint;PointKind.SMOOTHPOINT 742.495689035134,3785.03274011612 730.914973990991,3785.14013576508 760.583663008841,3784.86444759369 PathPoint;PointKind.SMOOTHPOINT 725.967076879987,3789.94721221924 720.0464869423,3790.06216096878 731.88828993928,3789.83179140091 PathPoint;PointKind.SMOOTHPOINT 708.466395019764,3787.98128175735 692.036859199943,3787.02911901474 724.896242400388,3788.93368053436 PathPoint;PointKind.SMOOTHPOINT 681.24314674395,3790.93005943298 669.557124148424,3790.29654312134 692.929169339475,3791.56333971024 PathPoint;PointKind.SMOOTHPOINT 662.770083617846,3787.98128175735 647.02006190917,3787.44005489349 678.520105326521,3788.52250862122 PathPoint;PointKind.SMOOTHPOINT 629.713170868356,3787.98128175735 610.617609258039,3790.21959590912 648.809044039476,3785.74296760559 PathPoint;PointKind.SMOOTHPOINT 597.62895094555,3791.91267061234 588.818946121681,3791.53407144547 608.437618320082,3792.37742233276 PathPoint;PointKind.SMOOTHPOINT 585.961621998199,3787.98128175735 584.414722611753,3787.71739530563 592.777326122644,3789.14493131638 PathPoint;PointKind.SMOOTHPOINT 577.211125287685,3787.98128175735 573.812931610353,3787.73675012589 579.808919262344,3788.16822099686 PathPoint;PointKind.SMOOTHPOINT 564.571726635257,3787.98128175735 559.679910468777,3788.4526424408 567.848411599455,3787.6657037735 PathPoint;PointKind.SMOOTHPOINT 549.987877011871,3791.91267061234 546.132935197473,3792.97860193253 553.498544139054,3790.94209718704 PathPoint;PointKind.SMOOTHPOINT 542.209761567238,3792.89551782608 540.195520976429,3793.15798807144 545.063970082691,3792.52399969101 PathPoint;PointKind.SMOOTHPOINT 537.348478359443,3791.91267061234 533.801670179122,3791.42525959015 538.728381155529,3792.10267829895 PathPoint;PointKind.SMOOTHPOINT 525.681772533698,3790.93005943298 517.781836815127,3790.90692806244 531.369003430006,3790.94658184052 PathPoint;PointKind.SMOOTHPOINT 513.041750759664,3791.91267061234 503.441004618011,3791.16042900085 522.643120022922,3792.66514825821 PathPoint;PointKind.SMOOTHPOINT 493.596929489285,3790.93005943298 474.55402165466,3791.34831237793 512.639525763107,3790.51133441925 PathPoint;PointKind.SMOOTHPOINT 467.345750918549,3791.91267061234 456.692552384668,3792.15082931519 477.998637891627,3791.67474794388 PathPoint;PointKind.SMOOTHPOINT 452.76158973436,3790.93005943298 448.303154644726,3790.39638566971 457.220647945599,3791.46373319626 PathPoint;PointKind.SMOOTHPOINT 444.98378585053,3792.89551782608 439.332072885753,3793.2335190773 450.635187254503,3792.55775260925 PathPoint;PointKind.CORNERPOINT 440.122502642734,3791.91267061234 440.122502642734,3791.91267061234 440.122502642734,3791.91267061234 PathPoint;PointKind.SMOOTHPOINT 431.372317493024,3792.89551782608 430.681275632171,3794.11038684845 432.512006910067,3790.89016962051 PathPoint;PointKind.SMOOTHPOINT 408.037971159125,3794.86144828796 362.686557566028,3792.21054601669 417.114672030284,3795.39205360413 PathPoint;PointKind.SMOOTHPOINT 319.561869031324,3791.91267061234 306.556386435477,3790.97230958939 344.517577783563,3793.71715354919 PathPoint;PointKind.SMOOTHPOINT 287.789833033033,3786.00425767899 282.983696087352,3782.71960306168 293.01969267067,3789.57852649689 PathPoint;PointKind.SMOOTHPOINT 276.899848288941,3769.04164600372 274.343491901069,3762.26863908768 280.417058192985,3778.3612279892 PathPoint;PointKind.SMOOTHPOINT 272.939910483962,3746.09225797653 270.672059399585,3730.95844078064 274.150324203265,3754.1700630188 PathPoint;PointKind.SMOOTHPOINT 268.03189315573,3708.36829710007 266.982244810729,3696.57365846634 268.688351767461,3715.74342775345 PathPoint;PointKind.CORNERPOINT 267.05951188985,3528.50135612488 267.05951188985,3528.50135612488 267.05951188985,3528.50135612488 PathPoint;PointKind.CORNERPOINT 267.05951188985,3088.17235040665 267.05951188985,3088.17235040665 267.05951188985,3088.17235040665 PathPoint;PointKind.CORNERPOINT 267.05951188985,2487.63382005692 267.05951188985,2487.63382005692 267.05951188985,2487.63382005692 PathPoint;PointKind.SMOOTHPOINT 268.03189315573,2476.82226467133 268.149974700033,2468.52140712738 267.914434733034,2485.12312221527 PathPoint;PointKind.SMOOTHPOINT 267.05951188985,2459.13054275513 266.718041249862,2443.75361013412 267.401605651445,2474.50700330734 PathPoint;PointKind.SMOOTHPOINT 268.03189315573,2434.55865430832 267.599758322095,2427.13985729218 268.243131380103,2438.18201828003 PathPoint;PointKind.SMOOTHPOINT 267.05951188985,2375.58593320847 266.893761542702,2349.48406982422 267.233051257071,2402.82005357742 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,2107.26014661789 272.031087621875,2059.18749380112 271.810814134219,2155.33279943466 PathPoint;PointKind.SMOOTHPOINT 269.004585982414,2014.86967611313 268.438480003527,2001.01351308823 269.570380400497,2028.72583913803 PathPoint;PointKind.SMOOTHPOINT 270.949036953371,1968.67444086075 270.891709765636,1941.44173669815 271.005741019501,1995.90690898895 PathPoint;PointKind.SMOOTHPOINT 272.893487924329,1916.5818862915 271.450026724449,1899.73870801926 274.336637563405,1933.42506456375 PathPoint;PointKind.SMOOTHPOINT 270.949036953371,1884.14674806595 271.028796518916,1872.11041021347 270.869277387826,1896.18332195282 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1859.57485961914 268.438480003527,1847.1315984726 275.40373331337,1872.01835680008 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1826.15734624863 270.766462322866,1808.24634838104 273.075439433228,1844.06787204742 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1765.21869468689 274.135057723923,1736.0625462532 269.706844032171,1794.37484312057 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1666.93090486526 271.429463711457,1660.73877859116 273.274526786287,1683.98132133484 PathPoint;PointKind.SMOOTHPOINT 270.949036953371,1628.59868335724 271.347523220292,1607.57439184189 270.549927564844,1649.62297487259 PathPoint;PointKind.SMOOTHPOINT 270.949036953371,1526.37926864624 269.786603597716,1505.67362356186 272.11084718742,1547.08514976501 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1420.22846508026 272.35822646493,1394.44713640213 271.484609973572,1446.00979375839 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1332.75246667862 271.028796518916,1309.8007183075 272.814039919587,1355.70421504974 PathPoint;PointKind.SMOOTHPOINT 271.455011697296,1255.48448371887 271.466539447004,1250.8860616684 271.424478738611,1267.70115184784 PathPoint;PointKind.SMOOTHPOINT 269.004585982414,1240.36199617386 269.072506237448,1238.52541255951 268.921087687234,1242.60644721985 PathPoint;PointKind.SMOOTHPOINT 269.976655687491,1226.60166311264 270.934393595634,1222.97121810913 269.121109722702,1229.84335947037 PathPoint;PointKind.SMOOTHPOINT 271.455011697296,1216.48428487778 272.244818332671,1194.79579257965 271.276175796426,1221.38884353638 PathPoint;PointKind.SMOOTHPOINT 270.949036953371,1185.32089996338 270.338689340472,1176.93270969391 272.117389964281,1201.39389801025 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1140.10851192474 272.594389553536,1120.16903448105 271.234115088033,1160.45491266251 PathPoint;PointKind.SMOOTHPOINT 271.455011697296,1106.48446846008 271.292065397374,1090.69282341003 271.596148741014,1120.14472293854 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1056.56366634369 271.055279187163,1037.25935745239 272.786934129734,1075.86797523499 PathPoint;PointKind.SMOOTHPOINT 272.893487924329,1002.50565338135 272.953930720093,980.513620853424 272.832733567761,1024.49744987488 PathPoint;PointKind.SMOOTHPOINT 273.865869190209,930.755446434021 274.746963140837,902.935252666473 272.984463678778,958.575404167175 PathPoint;PointKind.SMOOTHPOINT 273.865869190209,851.142461776733 274.758179329741,824.374273300171 272.973247489873,877.910414218903 PathPoint;PointKind.SMOOTHPOINT 274.837938895286,786.272421360016 276.315360222683,761.861744403839 273.36051756789,810.683098316193 PathPoint;PointKind.SMOOTHPOINT 274.837938895286,732.214172363281 274.275883206838,708.455894470215 275.399994583735,755.971978187561 PathPoint;PointKind.SMOOTHPOINT 274.424809270628,683.484399795532 274.052805671955,667.201567173004 274.797124430105,699.766996383667 PathPoint;PointKind.SMOOTHPOINT 274.424809270628,658.484344959259 275.056031457323,652.513382911682 273.793587083934,664.455543041229 PathPoint;PointKind.SMOOTHPOINT 273.434980599785,634.484367847443 273.552439022482,618.340795516968 273.319391541906,650.361221313477 PathPoint;PointKind.SMOOTHPOINT 273.434980599785,590.484488487244 272.846130682286,567.613463878632 274.023518956481,613.355513095856 PathPoint;PointKind.SMOOTHPOINT 274.424809270628,564.484355926514 273.898271513711,557.735660552979 274.899004812656,570.5608253479 PathPoint;PointKind.SMOOTHPOINT 273.865869190209,544.484453678131 272.575695905361,536.646459579468 275.214615906004,552.6821641922 PathPoint;PointKind.SMOOTHPOINT 272.893487924329,511.066468238831 273.183551031837,495.802832126617 272.593454871127,526.848671913147 PathPoint;PointKind.SMOOTHPOINT 272.893487924329,478.631566047668 271.771245912249,448.857715606689 273.288547022418,489.109840869904 PathPoint;PointKind.SMOOTHPOINT 271.88590028772,424.573317050934 271.594590936999,396.383965492249 272.22861717092,457.817345142365 PathPoint;PointKind.SMOOTHPOINT 270.46487146565,330.48434305191 270.187582351061,301.132522106171 270.741537458634,359.836400032043 PathPoint;PointKind.SMOOTHPOINT 270.46487146565,272.48431968689 269.58035034619,253.87347984314 271.364659064452,291.410265445709 PathPoint;PointKind.SMOOTHPOINT 270.46487146565,225.484443187714 270.234004910694,213.550780296326 270.819116098558,243.806612968445 PathPoint;PointKind.SMOOTHPOINT 275.910019618097,189.931526660919 277.002040232295,185.331924438477 273.888924689624,198.443398952484 PathPoint";
	
	mask645[1] = "PointKind.SMOOTHPOINT 286.314754486084,178.26568365097 293.158493041992,171.421158313751 283.698863983154,180.881888866425 PathPoint;PointKind.SMOOTHPOINT 307.104349136353,170.484573841095 312.975625991821,168.476393222809 301.232757568359,172.492518424988 PathPoint;PointKind.SMOOTHPOINT 348.683853149414,169.500074386597 354.404697418213,169.433040618896 331.023445129395,169.707548618317 PathPoint;PointKind.SMOOTHPOINT 499.343032836914,166.001572608948 667.228631973267,166.017150878906 418.903141021729,165.994255542755 PathPoint;PointKind.SMOOTHPOINT 945.726556777954,166.076631546021 981.09206199646,165.996143817902 921.816272735596,166.131155490875 PathPoint;PointKind.SMOOTHPOINT 1496.02595329285,167.059478759766 1507.6784992218,166.852240562439 1484.37435150146,167.266952991486 PathPoint;PointKind.SMOOTHPOINT 1537.83330917358,170.990867614746 1544.37177658081,171.022732257843 1526.79665565491,170.937287807465 PathPoint;PointKind.SMOOTHPOINT 1547.55635261536,169.025173187256 1550.9690952301,168.448541164398 1542.59490966797,169.863331317902 PathPoint;PointKind.SMOOTHPOINT 1566.02903366089,168.042562007904 1569.94940757751,167.98308134079 1560.63769340515,168.123757839203 PathPoint;PointKind.SMOOTHPOINT 1582.55742073059,170.008020401001 1586.53381347656,171.071591377258 1576.96749687195,168.512978553772 PathPoint;PointKind.SMOOTHPOINT 1607.8360748291,171.973950862885 1623.28248023987,171.927924156189 1596.96810722351,172.006287574768 PathPoint;PointKind.SMOOTHPOINT 1859.65204238892,172.95679807663 1870.84416389465,173.444445133209 1848.45992088318,172.46915102005 PathPoint;PointKind.CORNERPOINT 1891.73666954041,172.95679807663 1891.73666954041,172.95679807663 1891.73666954041,172.95679807663 PathPoint;PointKind.SMOOTHPOINT 1897.57018089294,173.939645290375 1899.07545089722,174.063091278076 1891.73478126526,173.461203575134 PathPoint;PointKind.SMOOTHPOINT 1905.36561012268,171.819348335266 1910.18322944641,171.625092029572 1899.24256324768,172.066712379456 PathPoint;PointKind.SMOOTHPOINT 1917.98810005188,172.95679807663 1929.59406852722,174.001250267029 1906.38118743896,171.91234588623 PathPoint;PointKind.SMOOTHPOINT 1972.43431091309,172.95679807663 1981.36742591858,172.87985086441 1963.50151062012,173.033509254456 PathPoint;PointKind.SMOOTHPOINT 2017.15842247009,172.95679807663 2031.05109214783,172.837836742401 2003.26575279236,173.075759410858 PathPoint;PointKind.SMOOTHPOINT 2066.74389839172,172.95679807663 1881.56390190125,172.797474861145 2052.50630378723,172.944288253784 PathPoint;PointKind.SMOOTHPOINT 2562.59676933289,173.939645290375 2583.4694480896,173.725798130035 2429.56526756287,175.301563739777 PathPoint;PointKind.SMOOTHPOINT 2613.15502166748,172.95679807663 2621.0275554657,172.561204433441 2605.28154373169,173.352155685425 PathPoint;PointKind.SMOOTHPOINT 2641.35043144226,173.939645290375 2651.05427742004,173.616986274719 2631.646900177,174.262068271637 PathPoint;PointKind.SMOOTHPOINT 2698.71371269226,173.939645290375 2706.22999191284,173.84735584259 2691.19743347168,174.031698703766 PathPoint;PointKind.SMOOTHPOINT 2717.18670845032,173.939645290375 2726.21046066284,174.296765327454 2708.16295623779,173.582525253296 PathPoint;PointKind.SMOOTHPOINT 2758.99406433105,174.92249250412 2777.25431442261,175.429494380951 2740.7338142395,174.415726661682 PathPoint;PointKind.SMOOTHPOINT 2799.82927322388,174.92249250412 2807.38300323486,174.772846698761 2792.27491378784,175.072138309479 PathPoint;PointKind.SMOOTHPOINT 2821.21870994568,172.95679807663 2835.23411750793,172.63956785202 2810.73343276978,173.194012641907 PathPoint;PointKind.SMOOTHPOINT 2853.30365180969,173.939645290375 2858.33527565002,174.143106937408 2848.27108383179,173.735947608948 PathPoint;PointKind.SMOOTHPOINT 2866.08884811401,173.53791475296 2872.45516777039,173.02383184433 2859.07547950745,174.104161262512 PathPoint;PointKind.SMOOTHPOINT 2882.47089385986,174.92249250412 2885.07545471191,175.141060352325 2878.81959915161,174.616119861603 PathPoint;PointKind.SMOOTHPOINT 2899.97174263,173.939645290375 2902.89353370667,173.399362564087 2892.94484138489,175.239250659943 PathPoint;PointKind.SMOOTHPOINT 2907.79612541199,172.500071525574 2915.70611000061,171.791260242462 2904.03059005737,172.837600708008 PathPoint;PointKind.SMOOTHPOINT 2918.44505310059,174.92249250412 2925.74449539185,175.087716579437 2911.1452960968,174.757268428802 PathPoint;PointKind.SMOOTHPOINT 2954.41858291626,173.939645290375 2964.4944190979,174.281187057495 2944.34243202209,173.597867488861 PathPoint;PointKind.SMOOTHPOINT 2983.58613967896,173.939645290375 3000.24796485901,173.766868114471 2966.92525863647,174.112422466278 PathPoint;PointKind.SMOOTHPOINT 3555.27623176575,174.92249250412 3587.75959968567,175.851759910583 3522.7925491333,173.993225097656 PathPoint;PointKind.SMOOTHPOINT 3656.39116287231,174.92249250412 3661.00610733032,175.191099643707 3638.43335151672,173.876860141754 PathPoint;PointKind.SMOOTHPOINT 3671.94771766663,176.88818693161 3676.73512458801,177.299122810364 3667.15999603271,176.47748708725 PathPoint;PointKind.SMOOTHPOINT 3697.22637176514,177.871034145355 3701.51401519775,176.619343757629 3694.4543838501,178.680396080017 PathPoint;PointKind.SMOOTHPOINT 3713.64429473877,175.500068664551 3717.56655693054,175.489447116852 3708.3492565155,175.514938831329 PathPoint;PointKind.SMOOTHPOINT 3728.49400520325,176.500146389008 3732.06190109253,176.525166034698 3721.40573501587,176.450107097626 PathPoint;PointKind.SMOOTHPOINT 3738.06126594543,175.905339717865 3739.32074546814,175.881028175354 3730.26206016541,176.055693626404 PathPoint;PointKind.SMOOTHPOINT 3744.86692428589,176.88818693161 3746.75771713257,176.212892532349 3742.72750854492,177.652702331543 PathPoint;PointKind.SMOOTHPOINT 3748.7561416626,176.88818693161 3755.47556877136,176.966550350189 3747.91837692261,176.878509521484 PathPoint;PointKind.SMOOTHPOINT 3767.22913742065,175.905339717865 3784.02377128601,174.949400424957 3761.82143211365,176.213128566742 PathPoint;PointKind.SMOOTHPOINT 3788.6192035675,172.95679807663 3790.02093315125,172.957270145416 3777.25965499878,172.952785491943 PathPoint;PointKind.SMOOTHPOINT 3795.42486190796,172.95679807663 3802.66136169434,173.448221683502 3794.40613746643,172.88763999939 PathPoint;PointKind.SMOOTHPOINT 3805.14727592468,173.939645290375 3810.96977233887,174.33500289917 3800.04358291626,173.592910766602 PathPoint;PointKind.SMOOTHPOINT 3816.81429862976,170.008020401001 3820.68746566772,170.120136737823 3814.9521446228,169.954204559326 PathPoint;PointKind.SMOOTHPOINT 3824.59241867065,170.990867614746 3825.72318077087,171.933352947235 3822.96504020691,169.633905887604 PathPoint;PointKind.SMOOTHPOINT 3830.42624473572,172.95679807663 3836.19114875793,173.19708108902 3826.54426574707,172.795114517212 PathPoint;PointKind.SMOOTHPOINT 3839.17651176453,170.008020401001 3846.5470790863,170.561757087708 3838.03914070129,169.922575950623 PathPoint;PointKind.SMOOTHPOINT 3860.56626319885,172.95679807663 3868.5835647583,172.500071525574 3852.5489616394,173.413524627686 PathPoint;PointKind.SMOOTHPOINT 3880.01172065735,172.95679807663 3891.42036437988,173.870487213135 3868.60276222229,172.042872905731 PathPoint;PointKind.SMOOTHPOINT 3904.31791305542,173.939645290375 3911.31774902344,173.970329761505 3897.31870651245,173.908960819244 PathPoint;PointKind.SMOOTHPOINT 3920.84630012512,170.990867614746 3931.85872077942,170.044369697571 3905.59155464172,172.302038669586 PathPoint;PointKind.SMOOTHPOINT 3935.43039321899,173.939645290375 3945.54399490356,173.597631454468 3928.91175270081,174.159865379333 PathPoint;PointKind.CORNERPOINT 3953.90338897705,172.95679807663 3953.90338897705,172.95679807663 3953.90338897705,172.95679807663 PathPoint;PointKind.SMOOTHPOINT 3964.59857940674,170.990867614746 3972.08024024963,170.342245101929 3957.11628913879,171.63996219635 PathPoint;PointKind.SMOOTHPOINT 3978.20989608765,171.973950862885 3985.9565448761,171.924855709076 3967.88354873657,172.039332389832 PathPoint;PointKind.SMOOTHPOINT 3991.8218421936,170.990867614746 3993.464012146,170.688507556915 3986.89061164856,171.899127960205 PathPoint;PointKind.SMOOTHPOINT 3997.65535354614,169.025173187256 4005.73685646057,168.621318340302 3994.31593894958,169.19228553772 PathPoint;PointKind.SMOOTHPOINT 4011.26698493958,170.990867614746 4013.98106575012,171.415729522705 4007.11466789246,170.341300964355 PathPoint;PointKind.SMOOTHPOINT 4023.90646934509,170.990867614746 4036.20354652405,171.705107688904 4019.04479026794,170.708570480347 PathPoint;PointKind.SMOOTHPOINT 4056.9632434845,171.973950862885 4064.53365325928,172.05420255661 4038.89276504517,171.782054901123 PathPoint;PointKind.SMOOTHPOINT 4080.29728889465,170.990867614746 4082.54370689392,170.737130641937 4072.58337020874,171.862778663635 PathPoint;PointKind.SMOOTHPOINT 4087.10294723511,169.025173187256 4091.62914276123,168.900783061981 4084.98870849609,169.083473682404 PathPoint;PointKind.SMOOTHPOINT 4099.74274635315,170.990867614746 4102.7211856842,171.446413993835 4095.81450462341,170.390632152557 PathPoint;PointKind.SMOOTHPOINT 4108.49301338196,170.990867614746 4123.64673614502,170.664668083191 4105.49285888672,171.055541038513 PathPoint;PointKind.SMOOTHPOINT 4151.27251625061,173.939645290375 4160.29438018799,173.782682418823 4136.92760467529,174.189133644104 PathPoint;PointKind.SMOOTHPOINT 4175.57965278625,172.784020900726 4176.44227981567,172.727372646332 4167.98186302185,173.282525539398 PathPoint;PointKind.SMOOTHPOINT 4178.16596031189,172.614548206329 4178.61001968384,172.036972045898 4176.99554443359,174.136734008789 PathPoint;PointKind.SMOOTHPOINT 4181.41253471375,171.973950862885 4184.31670188904,171.789844036102 4180.68806648254,172.01997756958 PathPoint;PointKind.SMOOTHPOINT 4189.19065475464,171.973950862885 4201.7920589447,171.374895572662 4186.16815567017,172.117459774017 PathPoint;PointKind.SMOOTHPOINT 4213.49716186523,172.95679807663 4220.15805244446,173.005657196045 4203.52423667908,172.883863449097 PathPoint;PointKind.SMOOTHPOINT 4232.94261932373,170.990867614746 4234.93034362793,170.590789318085 4227.07606315613,172.172455787659 PathPoint;PointKind.SMOOTHPOINT 4236.86519622803,169.198894500732 4238.063621521,169.106369018555 4234.30438041687,169.39692735672 PathPoint;PointKind.SMOOTHPOINT 4240.72073936462,169.025173187256 4244.84693527222,168.964276313782 4239.34292793274,169.045708179474 PathPoint;PointKind.SMOOTHPOINT 4252.3877620697,169.025173187256 4254.32607650757,169.381585121155 4248.72734069824,168.352239131927 PathPoint;PointKind.SMOOTHPOINT 4257.2488117218,170.990867614746 4263.00616264343,172.582447528839 4255.37249565125,170.472300052643 PathPoint;PointKind.SMOOTHPOINT 4271.8332195282,170.990867614746 4284.00094985962,170.987091064453 4265.56540489197,170.992991924286 PathPoint;PointKind.SMOOTHPOINT 4288.36129188538,170.008020401001 4298.85097503662,169.735636711121 4277.87129402161,170.280876159668 PathPoint;PointKind.SMOOTHPOINT 4303.91753196716,173.939645290375 4306.19479179382,173.860573768616 4294.85223770142,174.254515171051 PathPoint;PointKind.SMOOTHPOINT 4307.80674934387,171.973950862885 4308.71689796448,171.819820404053 4306.28259658813,172.231464385986 PathPoint;PointKind.SMOOTHPOINT 4312.5856590271,172.500071525574 4313.40517044067,172.436578273773 4311.38251304626,172.593305110931 PathPoint;PointKind.SMOOTHPOINT 4315.58455467224,170.990867614746 4316.37542724609,170.904006958008 4314.59415435791,171.100151538849 PathPoint;PointKind.SMOOTHPOINT 4319.47377204895,172.95679807663 4320.15292167664,172.937207221985 4318.5088634491,172.984414100647 PathPoint;PointKind.SMOOTHPOINT 4321.4183807373,170.990867614746 4322.50036239624,170.891733169556 4320.66495895386,171.060025691986 PathPoint;PointKind.SMOOTHPOINT 4328.22403907776,170.990867614746 4329.5974445343,171.414077281952 4326.3335609436,170.408806800842 PathPoint;PointKind.SMOOTHPOINT 4330.16833305359,172.95679807663 4332.21050262451,172.987010478973 4329.00137901306,172.939567565918 PathPoint;PointKind.SMOOTHPOINT 4336.00247383118,170.990867614746 4338.43173980713,170.493543148041 4333.68524551392,171.4652967453 PathPoint;PointKind.SMOOTHPOINT 4345.72457313538,170.990867614746 4349.11497116089,170.948617458344 4341.74440383911,171.040906906128 PathPoint;PointKind.SMOOTHPOINT 4355.44761657715,169.025173187256 4366.11322402954,168.975605964661 4351.96721076965,169.041459560394 PathPoint;PointKind.SMOOTHPOINT 4378.78197669983,169.025173187256 4380.1132106781,169.071671962738 4367.98796653748,168.649406433105 PathPoint;PointKind.SMOOTHPOINT 4383.64334106445,170.990867614746 4406.39265060425,171.871511936188 4382.26395606995,170.937523841858 PathPoint;PointKind.SMOOTHPOINT 4443.9230632782,170.990867614746 4445.85382461548,171.013762950897 4430.29412269592,170.829656124115 PathPoint;PointKind.SMOOTHPOINT 4449.20331001282,170.500152111053 4449.91613388062,169.234063625336 4448.31015586853,172.087483406067 PathPoint;PointKind.SMOOTHPOINT 4454.61793899536,170.990867614746 4456.36868476868,172.209749221802 4453.24484825134,170.035164356232 PathPoint;PointKind.SMOOTHPOINT 4460.45176506042,169.025173187256 4463.36380004883,170.253496170044 4458.78064155579,168.320374488831 PathPoint;PointKind.SMOOTHPOINT 4469.0031337738,170.500152111053 4470.07504463196,170.380010604858 4465.71124076843,170.868601799011 PathPoint;PointKind.SMOOTHPOINT 4475.0358581543,169.025173187256 4480.28400421143,168.828320503235 4472.50084877014,169.12029504776 PathPoint;PointKind.SMOOTHPOINT 4490.59178352356,170.990867614746 4497.64228820801,171.288743019104 4486.79635047913,170.830600261688 PathPoint;PointKind.SMOOTHPOINT 4509.06446456909,170.008020401001 4512.51969337463,169.8140001297 4498.09295654297,170.624542236328 PathPoint;PointKind.SMOOTHPOINT 4523.64855766296,170.008020401001 4538.57977867126,170.076234340668 4517.40434646606,169.97946023941 PathPoint;PointKind.SMOOTHPOINT 4562.94796943665,169.816360473633 4564.21342849731,169.80975151062 4549.29164886475,169.887642860413 PathPoint;PointKind.SMOOTHPOINT 4568.37266921997,169.025173187256 4571.94560050964,169.013607501984 4567.05087661743,169.029421806335 PathPoint;PointKind.SMOOTHPOINT 4576.15078926086,169.025173187256 4576.84693336487,169.027533531189 4572.01263427734,169.01195526123 PathPoint;PointKind.SMOOTHPOINT 4578.09508323669,170.008020401001 4578.89413833618,170.027375221252 4577.33662605286,169.989845752716 PathPoint;PointKind.SMOOTHPOINT 4580.04000663757,169.025173187256 4583.08547973633,169.053025245667 4579.17580604553,169.017384052277 PathPoint;PointKind.SMOOTHPOINT 4589.7624206543,169.025173187256 4593.51064682007,169.25436258316 4586.1092376709,168.801884651184 PathPoint;PointKind.SMOOTHPOINT 4601.4297580719,170.008020401001 4639.92917060852,170.553259849548 4597.89333343506,169.958217144012 PathPoint;PointKind.SMOOTHPOINT 4651.01491928101,170.990867614746 4666.45345687866,171.328868865967 4635.57638168335,170.653102397919 PathPoint;PointKind.SMOOTHPOINT 4681.15556716919,170.008020401001 4694.49339866638,170.338232517242 4667.81679153442,169.678044319153 PathPoint;PointKind.SMOOTHPOINT 4709.35066223145,170.008020401001 4727.94545173645,169.616675376892 4690.75587272644,170.399837493896 PathPoint;PointKind.SMOOTHPOINT 4739.49036598206,170.990867614746 4759.9728012085,171.336658000946 4719.00856018066,170.645549297333 PathPoint;PointKind.SMOOTHPOINT 4783.24264526367,170.990867614746 4817.46542930603,170.119428634644 4749.01954650879,171.862542629242 PathPoint;PointKind.SMOOTHPOINT 4849.356508255,170.990867614746 4870.96592903137,170.872142314911 4824.91687774658,171.125407218933 PathPoint;PointKind.SMOOTHPOINT 4885.78700065613,170.500152111053 4887.64537811279,170.559632778168 4871.59315109253,170.045313835144 PathPoint;PointKind.SMOOTHPOINT 4896.02491378784,172.95679807663 4903.90688896179,173.136656284332 4893.78164291382,172.905578613281 PathPoint;PointKind.SMOOTHPOINT 4908.66408348083,172.95679807663 4913.32529067993,171.463644504547 4905.20413398743,174.065215587616 PathPoint;PointKind.SMOOTHPOINT 4929.08168792725,170.990867614746 4943.36963653564,171.179223060608 4921.4278793335,170.890080928802 PathPoint;PointKind.SMOOTHPOINT 4974.39053535461,175.962460041046 4993.13449859619,179.375517368317 4954.57654953003,172.354674339294 PathPoint;PointKind.SMOOTHPOINT 5000.13024330139,191.927354335785 5006.94062232971,199.551501274109 4994.6479511261,185.789043903351 PathPoint;PointKind.SMOOTHPOINT 5007.8350353241,219.151797294617 5010.7716178894,236.007485389709 5006.24038696289,210.00027179718 PathPoint;PointKind.SMOOTHPOINT 5012.69639968872,266.330115795135 5012.50473976135,270.782904624939 5013.1369972229,256.071352958679 PathPoint;PointKind.SMOOTHPOINT 5012.69639968872,278.124754428864 5011.69561386108,280.912084579468 5013.46335411072,275.98699092865 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,297.782170772552 5009.45769309998,316.534631252289 5009.90552902222,290.412940979004 PathPoint;PointKind.SMOOTHPOINT 5011.72393798828,435.385029315948 5011.66319847107,452.654485702515 5011.78499221802,418.115572929382 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,936.652686595917 5011.15399360657,953.630404472351 5008.40466499329,919.675204753876 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,993.65971326828 5009.92378234863,1005.91485500336 5009.63487625122,981.404571533203 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,1082.11879491806 5010.67972183228,1095.35300731659 5010.82386016846,1068.88458251953 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,1253.13963890076 5010.03393173218,1260.07716178894 5009.5250415802,1246.20187997818 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,1272.79705524445 5010.73668479919,1284.94102478027 5010.76689720154,1260.65308570862 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,1316.04374885559 5009.33904647827,1348.17157030106 5010.22024154663,1283.91592741013 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,1533.25959205627 5011.06304168701,1546.79710865021 5010.4402256012,1519.72207546234 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,1595.18085479736 5009.7919178009,1604.4947719574 5009.75289344788,1575.25483131409 PathPoint;PointKind.SMOOTHPOINT 5010.76186180115,1634.21008586884 5010.79427719116,1635.32416820526 5010.33857345581,1619.79452133179 PathPoint;PointKind.SMOOTHPOINT 5009.53511238098,1637.50016927719 5008.13369750977,1639.27042722702 5010.21520614624,1636.64029598236 PathPoint;PointKind.SMOOTHPOINT 5010.95005989075,1640.93989849091 5011.31072044373,1654.64924812317 5010.92047691345,1639.81590270996 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,1669.87960338593 5009.22480583191,1677.32790470123 5011.45234107971,1666.46206140518 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,1687.57156133652 5010.3719329834,1694.8971247673 5011.13164901733,1680.24599790573 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,1703.29758882523 5011.2188243866,1709.60560798645 5010.28444290161,1696.989569664 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,1723.93808841705 5010.96799850464,1735.06829023361 5010.53526878357,1712.8076505661 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,1774.06471252441 5009.89703178406,1795.25045156479 5011.60623550415,1752.87920951843 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,1846.79776668549 5010.94911575317,1861.87115907669 5010.55415153503,1831.72437429428 PathPoint;PointKind.SMOOTHPOINT 5010.52488327026,1889.50016498566 5012.23062515259,1913.68070840836 5008.81977081299,1865.31985759735 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,1950.00002861023 5011.09734535217,1967.20410346985 5010.40623664856,1932.79571771622 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,1998.1609582901 5010.80088615417,2002.8254699707 5010.61866760254,1985.57938098907 PathPoint;PointKind.SMOOTHPOINT 5010.16894340515,2011.74355745316 5009.56249237061,2019.17887687683 5010.52677154541,2007.36275911331 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,2033.54463815689 5009.92378234863,2043.71111154556 5009.6886920929,2027.147397995 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,2086.61980390549 5011.06304168701,2112.67398834229 5010.4402256012,2060.56585550308 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,2212.42825984955 5009.78310585022,2242.90903329849 5011.72016143799,2181.9474864006 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,2291.05863332748 5010.14439582825,2306.07443332672 5011.35950088501,2276.04259729385 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,2364.77429866791 5009.74093437195,2366.03330612183 5010.31119346619,2347.35519647598 PathPoint;PointKind.SMOOTHPOINT 5008.80749702454,2369.68877077103 5008.76123428345,2375.30898571014 5008.87043952942,2361.97705507278 PathPoint;PointKind.SMOOTHPOINT 5009.5508480072,2375.05926132202 5010.12299537659,2398.4996008873 5009.52976226807,2374.21260595322 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,2458.14785242081 5010.74392318726,2476.99142217636 5008.96013259888,2442.13763952255 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,2533.82944822311 5010.12866020203,2556.72336816788 5009.42999839783,2510.93505620956 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,2601.64779424667 5011.42401695251,2623.07145595551 5010.07956504822,2580.22413253784 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,2674.38084840775 5009.5096206665,2706.79663181305 5010.04903793335,2641.96506500244 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,2736.30234718323 5010.13275146484,2752.06259965897 5009.42622184753,2720.5416226387 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,2796.25767946243 5010.56170463562,2823.34427833557 5010.94156265259,2769.17108058929 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,2866.04195594788 5010.72755813599,2882.60283708572 5010.77570915222,2849.39775466919 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,2913.220038414 5009.23582077026,2923.59469413757 5010.29860496521,2903.31461906433 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,2955.4838848114 5010.39459228516,2967.79685497284 5011.10898971558,2943.17091464996 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,2986.93617582321 5010.19191741943,2994.39179420471 5009.20214653015,2976.50841236115 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,3030.18263339996 5010.86099624634,3036.8430519104 5010.47736167908,3013.47328662872 PathPoint;PointKind.SMOOTHPOINT 5011.51528358459,3045.50008535385 5012.03078269958,3062.75278329849 5011.35572433472,3040.15579462051 PathPoint;PointKind.SMOOTHPOINT 5010.52488327026,3070.50014019012 5010.44148445129,3079.6608710289 5010.60859680176,3061.33964538574 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,3101.9326043129 5010.11764526367,3115.2206325531 5009.44101333618,3088.64481210709 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,3152.05946445465 5009.49482917786,3164.22562122345 5010.04589080811,3140.67528963089 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,3181.54582500458 5009.87091064453,3189.78979825974 5009.67295646667,3171.91680192947 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,3220.86089372635 5009.88035202026,3223.05695772171 5009.17917251587,3207.79025316238 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,3228.7239074707 5010.93589782715,3230.93059301376 5010.60828208923,3227.00416088104 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,3233.63837957382 5009.75163459778,3240.93066215515 5009.78562355042,3231.9877910614 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,3257.22742080688 5010.17051696777,3272.1662735939 5009.46084022522,3245.04592180252 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,3293.59394788742 5010.31497001648,3303.27301025391 5009.2440032959,3283.91488552094 PathPoint;PointKind.SMOOTHPOINT 5008.80749702454,3310.30282258987 5010.05690574646,3319.25631523132 5007.55777359009,3301.34932994843 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,3337.82348871231 5009.6990776062,3349.23244714737 5009.85580444336,3326.99187040329 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,3355.51521062851 5011.7925453186,3360.79034328461 5009.71103668213,3350.24007797241 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,3372.22408533096 5010.45564651489,3377.54170417786 5011.04793548584,3366.90646648407 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,3391.88173770905 5009.27453041077,3404.83955383301 5012.22936630249,3378.92368555069 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,3409.57345962524 5009.64683532715,3426.5858745575 5009.91245269775,3392.56128072739 PathPoint;PointKind.SMOOTHPOINT 5010.75179100037,3453.80300045013 5010.35682678223,3472.55050420761 5011.14675521851,3435.05526065826 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,3528.5015130043 5009.9426651001,3558.1724524498 5009.61630821228,3498.83104562759 PathPoint;PointKind.SMOOTHPOINT 5009.77932929993,3585.50853967667 5009.32362556458,3597.80994415283 5010.2353477478,3573.20737123489 PathPoint;PointKind.SMOOTHPOINT 5007.8350353241,3611.06327533722 5007.47217178345,3628.00582408905 5008.17744255066,3595.07831811905 PathPoint;PointKind.SMOOTHPOINT 5010.52488327026,3657.50020980835 5010.3694152832,3679.95675802231 5010.68066596985,3635.04366159439 PathPoint;PointKind.SMOOTHPOINT 5012.69639968872,3731.95749521255 5013.14423561096,3748.17093372345 5012.24824905396,3715.74382066727 PathPoint;PointKind.SMOOTHPOINT 5010.03015518188,3764.05274391174 5007.97539710999,3770.43204545975 5010.56548118591,3762.39011764526 PathPoint;PointKind.SMOOTHPOINT 4999.24338340759,3778.40316295624 4998.53748321533,3778.89387845993 5004.10569190979,3775.02362251282 PathPoint;PointKind.SMOOTHPOINT 4997.06966400146,3779.80827569962 4995.75794219971,3779.79269742966 4998.40782165527,3779.82385396957 PathPoint;PointKind.SMOOTHPOINT 4993.56880187988,3781.70056343079 4989.88635063171,3783.49088430405 4994.77415084839,3781.11472606659 PathPoint;PointKind.SMOOTHPOINT 4980.33041954041,3785.00646114349 4975.22043228149,3786.40402078629 4984.5881652832,3783.84210348129 PathPoint;PointKind.SMOOTHPOINT 4964.083070755,3787.98143863678 4945.96758842468,3790.09323835373 4969.22578811646,3787.38191127777 PathPoint;PointKind.SMOOTHPOINT 4790.04830360413,3789.94736909866 4775.79465866089,3791.77097082138 4804.30194854736,3788.12353134155 PathPoint;PointKind.SMOOTHPOINT 4638.37574958801,3789.94736909866 4616.21086120605,3791.51746988297 4660.54000854492,3788.37679624557 PathPoint;PointKind.SMOOTHPOINT 4476.00800514221,3789.94736909866 4447.31881141663,3790.69984674454 4504.6971988678,3789.1946554184 PathPoint;PointKind.SMOOTHPOINT 4391.42114639282,3789.94736909866 4377.25121498108,3790.84170341492 4405.59107780457,3789.05279874802 PathPoint;PointKind.SMOOTHPOINT 4357.39191055298,3789.94736909866 4348.61300468445,3789.80055570602 4367.28930473328,3790.11235713959 PathPoint;PointKind.SMOOTHPOINT 4325.30728340149,3789.94736909866 4324.04811859131,3789.91243600845 4335.18925666809,3790.22046089172 PathPoint;PointKind.SMOOTHPOINT 4317.52947807312,3789.94736909866 4308.32319259644,3790.37718772888 4318.56928825378,3789.89874601364 PathPoint;PointKind.SMOOTHPOINT 4291.27804756165,3789.94736909866 4285.27522087097,3790.18481969833 4301.63586616516,3789.53737735748 PathPoint;PointKind.SMOOTHPOINT 4267.60820388794,3790.15578746796 4266.44943237305,3790.14917850494 4277.27239608765,3790.2105474472 PathPoint;PointKind.SMOOTHPOINT 4264.0601348877,3790.13265609741 4263.13865661621,3789.5189666748 4265.66737174988,3791.20330810547 PathPoint;PointKind.SMOOTHPOINT 4260.69176673889,3790.10692834854 4255.11883735657,3790.06137371063 4261.83354377747,3790.11613368988 PathPoint;PointKind.SMOOTHPOINT 4242.66534805298,3789.94736909866 4221.77410125732,3789.77081537247 4249.09240722656,3790.00165700912 PathPoint;PointKind.SMOOTHPOINT 4195.0244808197,3789.94736909866 4173.93842697144,3789.22911643982 4216.11021995544,3790.66538572311 PathPoint;PointKind.SMOOTHPOINT 4154.18927192688,3789.94736909866 4146.88857078552,3790.21385192871 4172.90176391602,3789.26381349564 PathPoint;PointKind.SMOOTHPOINT 4137.66088485718,3789.94736909866 4132.80959129333,3790.24430036545 4140.76457977295,3789.75712537766 PathPoint;PointKind.SMOOTHPOINT 4124.04925346375,3790.93021631241 4110.324010849,3790.64980745316 4132.41966247559,3791.10086917877 PathPoint;PointKind.SMOOTHPOINT 4095.85352897644,3789.94736909866 4076.78824424744,3789.7590136528 4114.91912841797,3790.13525247574 PathPoint;PointKind.SMOOTHPOINT 4049.18480873108,3789.94736909866 4017.11465835571,3790.38167238235 4081.24268531799,3789.51282978058 PathPoint;PointKind.SMOOTHPOINT 3958.76443862915,3789.94736909866 3901.33506774902,3790.12817144394 4016.29294395447,3789.76585865021 PathPoint;PointKind.SMOOTHPOINT 3854.73275184631,3789.94736909866 3831.1362361908,3789.43659067154 3878.32926750183,3790.45791149139 PathPoint;PointKind.SMOOTHPOINT 3797.36915588379,3789.94736909866 3782.5269985199,3789.97026443481 3812.21162796021,3789.92423772812 PathPoint;PointKind.SMOOTHPOINT 3772.09050178528,3789.94736909866 3757.33174324036,3789.96271133423 3786.8492603302,3789.9317908287 PathPoint;PointKind.SMOOTHPOINT 3744.86692428589,3790.93021631241 3732.25041389465,3790.71495294571 3757.48406410217,3791.14500761032 PathPoint;PointKind.SMOOTHPOINT 3711.81046485901,3790.93021631241 3701.42715454102,3791.50590419769 3722.193775177,3790.35405635834 PathPoint;PointKind.SMOOTHPOINT 3669.03096199036,3790.93021631241 3635.19307136536,3791.02911472321 3702.78797149658,3790.83131790161 PathPoint;PointKind.SMOOTHPOINT 3563.05403709412,3790.93021631241 3539.89371299744,3790.54500818253 3587.2972869873,3791.33312702179 PathPoint;PointKind.SMOOTHPOINT 3472.63398170471,3790.93021631241 3436.85368537903,3791.00881576538 3508.24527740479,3790.85161685944 PathPoint;PointKind.SMOOTHPOINT 3327.76677131653,3790.93021631241 3310.15608787537,3791.04516506195 3345.37808418274,3790.81479549408 PathPoint;PointKind.SMOOTHPOINT 3261.6529083252,3790.93021631241 3241.8826675415,3790.64957141876 3292.24925994873,3791.36404752731 PathPoint;PointKind.SMOOTHPOINT 3189.70584869385,3790.93021631241 3187.97618865967,3790.94272613525 3201.01693153381,3790.84642410278 PathPoint;PointKind.SMOOTHPOINT 3183.87233734131,3790.93021631241 3183.15101623535,3791.40299320221 3185.59507369995,3789.79984760284 PathPoint;PointKind.SMOOTHPOINT 3178.19807052612,3791.00551128387 3169.69359397888,3791.6045665741 3179.65991020203,3790.90260028839 PathPoint;PointKind.SMOOTHPOINT 3152.75985717773,3790.93021631241 3115.54478645325,3790.6233716011 3161.14663124084,3790.99913835526 PathPoint;PointKind.SMOOTHPOINT 3070.1176071167,3790.93021631241 3051.98638916016,3791.02982282639 3088.24882507324,3790.83037376404 PathPoint;PointKind.SMOOTHPOINT 3026.36564254761,3790.93021631241 2998.29171180725,3791.1067700386 3054.44020271301,3790.75342655182 PathPoint;PointKind.SMOOTHPOINT 2926.60586357117,3791.50023937225 2923.85779380798,3791.57364606857 2961.06782913208,3790.57876110077 PathPoint;PointKind.SMOOTHPOINT 2914.08659934998,3791.10582590103 2913.52200508118,3791.11503124237 2916.83876037598,3791.06145143509 PathPoint;PointKind.SMOOTHPOINT 2911.63908004761,3790.93021631241 2910.8113861084,3790.94201803207 2912.20461845398,3790.92219114304 PathPoint;PointKind.SMOOTHPOINT 2909.69415664673,3789.94736909866 2908.55772972107,3790.67364692688 2911.24631881714,3788.95555257797 PathPoint;PointKind.SMOOTHPOINT 2905.8162689209,3790.5001616478 2905.24852752686,3790.50441026688 2907.16512680054,3790.49024820328 PathPoint;PointKind.SMOOTHPOINT 2904.16213989258,3791.21227741241 2875.50378799438,3791.37679338455 2904.73082542419,3791.2092089653 PathPoint;PointKind.SMOOTHPOINT 2808.57922554016,3790.93021631241 2763.6313533783,3791.55193090439 2845.64764022827,3790.41731357574 PathPoint;PointKind.SMOOTHPOINT 2608.29334259033,3789.94736909866 2562.56687164307,3789.74390745163 2654.02012825012,3790.1505947113 PathPoint;PointKind.SMOOTHPOINT 2466.34320259094,3789.94736909866 2424.99155044556,3791.65177345276 2507.69485473633,3788.24272871017 PathPoint;PointKind.SMOOTHPOINT 2383.70095252991,3788.96428585052 2338.63883972168,3789.6709728241 2428.76306533813,3788.25783491135 PathPoint;PointKind.SMOOTHPOINT 2282.58602142334,3789.94736909866 2235.60982704163,3790.24264812469 2329.56190109253,3789.65161800385 PathPoint;PointKind.SMOOTHPOINT 2195.08209228516,3789.94736909866 2164.88196372986,3789.50810909271 2255.56008338928,3790.82636117935 PathPoint;PointKind.SMOOTHPOINT 2122.16257095337,3789.94736909866 2102.14433670044,3789.67947006226 2142.12982177734,3790.2143239975 PathPoint;PointKind.SMOOTHPOINT 2064.79928970337,3789.94736909866 2026.52993202209,3789.69622850418 2085.70878982544,3790.08450508118 PathPoint;PointKind.SMOOTHPOINT 1984.10133361816,3789.94736909866 1929.74607467651,3789.62471008301 2038.45722198486,3790.26979207993 PathPoint;PointKind.SMOOTHPOINT 1851.87392234802,3788.96428585052 1804.35579299927,3789.24162626266 1901.48048400879,3788.67490768433 PathPoint;PointKind.SMOOTHPOINT 1724.5078754425,3787.98143863678 1678.66905212402,3788.42848777771 1772.76306152344,3787.51078605652 PathPoint;PointKind.SMOOTHPOINT 1625.33723831177,3786.99859142303 1583.70045661926,3787.73572683334 1666.9730758667,3786.26145601273 PathPoint;PointKind.SMOOTHPOINT 1481.44248962402,3786.0155081749 1448.27147483826,3786.67616844177 1514.61350440979,3785.35531997681 PathPoint;PointKind.SMOOTHPOINT 1362.82670974731,3786.0155081749 1314.19040679932,3785.73557138443 1411.46206855774,3786.29591703415 PathPoint;PointKind.SMOOTHPOINT 1241.29354476929,3786.0155081749 1189.09721374512,3785.86633443832 1315.82880020142,3786.22911930084 PathPoint;PointKind.SMOOTHPOINT 1146.70323371887,3785.69875001907 1146.10559463501,3785.70087432861 1172.29722976685,3785.61590194702 PathPoint;PointKind.SMOOTHPOINT 1144.89521026611,3785.70512294769 1143.49348068237,3785.71055173874 1145.50292015076,3785.70276260376 PathPoint;PointKind.SMOOTHPOINT 1140.1782989502,3786.0155081749 1138.21889877319,3786.79371356964 1141.87019348145,3785.34399032593 PathPoint;PointKind.SMOOTHPOINT 1134.04360771179,3785.76271533966 1126.1572265625,3785.81535100937 1136.31488800049,3785.74760913849 PathPoint;PointKind.SMOOTHPOINT 1106.14937782288,3786.0155081749 1047.88192749023,3786.64524793625 1117.14417457581,3785.89678287506 PathPoint;PointKind.SMOOTHPOINT 1001.14491462708,3786.0155081749 942.794065475464,3786.38419389725 1059.49607849121,3785.64705848694 PathPoint;PointKind.SMOOTHPOINT 871.834259033203,3786.0155081749 820.843591690063,3786.65303707123 922.824611663818,3785.37845134735 PathPoint;PointKind.SMOOTHPOINT 812.986793518066,3787.50016450882 802.624254226685,3787.53202915192 841.114854812622,3787.41330385208 PathPoint;PointKind.SMOOTHPOINT 783.358812332153,3786.0155081749 775.196113586426,3786.48427248001 788.24535369873,3785.73533535004 PathPoint;PointKind.SMOOTHPOINT 764.885816574097,3786.99859142303 759.358835220337,3787.68899202347 772.359609603882,3786.06507539749 PathPoint;PointKind.SMOOTHPOINT 743.495750427246,3785.03289699554 731.914958953857,3785.1402926445 761.583852767944,3784.86460447311 PathPoint;PointKind.SMOOTHPOINT 726.96704864502,3789.94736909866 721.19270324707,3791.27364635468 735.015506744385,3788.09851169586 PathPoint;PointKind.SMOOTHPOINT 709.466514587402,3787.98143863678 693.036947250366,3787.02927589417 725.896396636963,3788.93383741379 PathPoint;PointKind.SMOOTHPOINT 682.243251800537,3790.93021631241 670.557346343994,3790.29670000076 693.92915725708,3791.56349658966 PathPoint;PointKind.SMOOTHPOINT 663.77025604248,3787.98143863678 648.020153045654,3787.44021177292 679.520044326782,3788.52266550064 PathPoint;PointKind.SMOOTHPOINT 630.713167190552,3787.98143863678 611.617670059204,3790.21975278854 649.808979034424,3785.74312448502 PathPoint;PointKind.SMOOTHPOINT 598.629169464111,3791.91282749176 589.819107055664,3791.53422832489 609.437656402588,3792.37757921219 PathPoint;PointKind.SMOOTHPOINT 586.961832046509,3787.98143863678 585.414705276489,3787.71755218506 593.777561187744,3789.1450881958 PathPoint;PointKind.SMOOTHPOINT 576.380567550659,3789.50008392334 572.981986999512,3789.25578832626 578.978204727173,3789.68702316284 PathPoint;PointKind.SMOOTHPOINT 565.571765899658,3787.98143863678 560.679874420166,3788.45279932022 568.848552703857,3787.66586065292 PathPoint;PointKind.SMOOTHPOINT 550.987987518311,3791.91282749176 547.133073806763,3792.97875881195 554.498605728149,3790.94225406647 PathPoint;PointKind.SMOOTHPOINT 543.209867477417,3792.89567470551 541.195707321167,3793.15814495087 546.063995361328,3792.52415657043 PathPoint;PointKind.SMOOTHPOINT 538.348503112793,3791.91282749176 534.801692962646,3791.42541646957 539.728517532349,3792.10283517838 PathPoint;PointKind.SMOOTHPOINT 526.681795120239,3790.93021631241 518.781881332397,3790.90708494186 532.368965148926,3790.94673871994 PathPoint;PointKind.SMOOTHPOINT 514.041681289673,3791.91282749176 504.441061019897,3791.16058588028 523.643245697021,3792.66530513763 PathPoint;PointKind.SMOOTHPOINT 494.596853256226,3790.93021631241 475.554227828979,3791.34846925735 513.639478683472,3790.51149129868 PathPoint;PointKind.SMOOTHPOINT 468.345737457275,3791.91282749176 457.692718505859,3792.15098619461 478.998756408691,3791.6749048233 PathPoint;PointKind.SMOOTHPOINT 455.602397918701,3792.50008106232 451.143550872803,3791.96640729904 460.0612449646,3793.03375482559 PathPoint;PointKind.SMOOTHPOINT 445.983839035034,3792.89567470551 440.332231521606,3793.23367595673 451.635131835938,3792.55790948868 PathPoint;PointKind.CORNERPOINT 441.12247467041,3791.91282749176 441.12247467041,3791.91282749176 441.12247467041,3791.91282749176 PathPoint;PointKind.SMOOTHPOINT 432.372522354126,3792.89567470551 431.681413650513,3794.11054372787 433.512096405029,3790.89032649994 PathPoint;PointKind.SMOOTHPOINT 409.038162231445,3794.86160516739 363.686513900757,3792.21070289612 418.114786148071,3795.39221048355 PathPoint;PointKind.SMOOTHPOINT 320.562086105347,3791.91282749176 307.556591033936,3790.97246646881 345.517530441284,3793.71731042862 PathPoint;PointKind.SMOOTHPOINT 292.254638671875,3784.50016736984 287.448663711548,3781.21574878693 297.484531402588,3788.07443618774 PathPoint;PointKind.SMOOTHPOINT 277.899971008301,3769.04180288315 275.343561172485,3762.2687959671 281.417198181152,3778.36138486862 PathPoint;PointKind.SMOOTHPOINT 273.939943313599,3746.09241485596 271.672124862671,3730.95859766006 275.150327682495,3754.17021989822 PathPoint;PointKind.SMOOTHPOINT 271.465044021606,3710.50008058548 270.415477752686,3698.70567798615 272.121849060059,3717.87521123886 PathPoint;PointKind.CORNERPOINT 268.059539794922,3528.5015130043 268.059539794922,3528.5015130043 268.059539794922,3528.5015130043 PathPoint;PointKind.CORNERPOINT 268.059539794922,3088.17250728607 268.059539794922,3088.17250728607 268.059539794922,3088.17250728607 PathPoint;PointKind.CORNERPOINT 268.059539794922,2487.63397693634 268.059539794922,2487.63397693634 268.059539794922,2487.63397693634 PathPoint;PointKind.SMOOTHPOINT 269.032001495361,2476.82242155075 269.150018692017,2468.52156400681 268.914613723755,2485.1232790947 PathPoint;PointKind.SMOOTHPOINT 268.059539794922,2459.13069963455 267.718076705933,2443.75376701355 268.40163230896,2474.50716018677 PathPoint;PointKind.SMOOTHPOINT 269.032001495361,2434.55881118774 268.599901199341,2427.1400141716 269.243173599243,2438.18217515945 PathPoint;PointKind.SMOOTHPOINT 268.059539794922,2375.58609008789 267.893686294556,2349.48422670364 268.233261108398,2402.82021045685 PathPoint;PointKind.SMOOTHPOINT 272.92121887207,2107.26030349731 273.031053543091,2059.18765068054 272.810754776001,2155.33295631409 PathPoint;PointKind.SMOOTHPOINT 271.465044021606,2020.50019741058 270.898876190186,2006.64403438568 272.030897140503,2034.35636043549 PathPoint;PointKind.SMOOTHPOINT 271.949071884155,1968.67459774017 271.891794204712,1941.44189357758 272.00572013855,1995.90706586838 PathPoint;PointKind.SMOOTHPOINT 272.455129623413,1920.50021409988 271.011543273926,1903.65679979324 273.898086547852,1937.34339237213 PathPoint;PointKind.SMOOTHPOINT 271.949071884155,1884.14690494537 272.029008865356,1872.1105670929 271.869449615479,1896.18347883224 PathPoint;PointKind.SMOOTHPOINT 272.92121887207,1859.57501649857 269.438610076904,1847.13175535202 276.403827667236,1872.0185136795 PathPoint;PointKind.SMOOTHPOINT 272.92121887207,1826.15750312805 271.766538619995,1808.24650526047 274.075584411621,1844.06802892685 PathPoint;PointKind.SMOOTHPOINT 272.455129623413,1751.50006055832 274.669132232666,1722.34414815903 270.240812301636,1780.6564450264 PathPoint;PointKind.SMOOTHPOINT 272.92121887207,1666.93106174469 272.429637908936,1660.73893547058 274.274482727051,1683.98147821426 PathPoint;PointKind.SMOOTHPOINT 271.949071884155,1628.59884023666 272.347497940063,1607.57454872131 271.550016403198,1649.62313175201 PathPoint;PointKind.SMOOTHPOINT 271.949071884155,1526.37942552567 270.786838531494,1505.67378044128 273.110990524292,1547.08530664444 PathPoint;PointKind.SMOOTHPOINT 272.92121887207,1420.22862195969 273.358354568481,1394.44729328156 272.484712600708,1446.00995063782 PathPoint;PointKind.SMOOTHPOINT 272.92121887207,1332.75262355804 272.029008865356,1309.80087518692 273.814058303833,1355.70437192917 PathPoint;PointKind.SMOOTHPOINT 272.455129623413,1255.4846405983 272.466773986816,1250.88621854782 272.424602508545,1267.70130872726 PathPoint;PointKind.SMOOTHPOINT 270.004777908325,1240.36215305328 270.072441101074,1238.52556943893 269.921064376831,1242.60660409927 PathPoint;PointKind.SMOOTHPOINT 270.976610183716,1226.60181999207 271.934595108032,1222.97137498856 270.121221542358,1229.84351634979 PathPoint;PointKind.SMOOTHPOINT 272.455129623413,1216.4844417572 273.244743347168,1194.79594945908 272.276372909546,1221.3890004158 PathPoint;PointKind.SMOOTHPOINT 271.949071884155,1185.3210568428 271.338844299316,1176.93286657333 273.117599487305,1201.39405488968 PathPoint;PointKind.SMOOTHPOINT 272.92121887207,1140.10866880417 273.594388961792,1120.16919136047 272.234201431274,1160.45506954193 PathPoint;PointKind.SMOOTHPOINT 272.455129623413,1106.48462533951 272.292108535767,1090.69298028946 272.596120834351,1120.14487981796 PathPoint;PointKind.SMOOTHPOINT 272.92121887207,1056.56382322311 272.055444717407,1037.25951433182 273.786993026733,1075.86813211441 PathPoint;PointKind.SMOOTHPOINT 273.89368057251,1002.50581026077 273.954105377197,980.513777732849 273.832941055298,1024.4976067543 PathPoint;PointKind.SMOOTHPOINT 274.865827560425,930.755603313446 275.747022628784,902.935409545898 273.984632492065,958.5755610466 PathPoint;PointKind.SMOOTHPOINT 274.865827560425,851.142618656158 275.758352279663,824.374430179596 273.973302841187,877.910571098328 PathPoint;PointKind.SMOOTHPOINT 275.83797454834,786.272578239441 277.315549850464,761.861901283264 274.36071395874,810.683255195618 PathPoint;PointKind.SMOOTHPOINT 275.83797454834,732.214329242706 275.275897979736,708.45605134964 276.400051116943,755.972135066986 PathPoint;PointKind.SMOOTHPOINT 275.424757003784,683.484556674957 275.052766799927,667.201724052429 275.797061920166,699.767153263092 PathPoint;PointKind.SMOOTHPOINT 275.424757003784,658.484501838684 276.056070327759,652.513539791107 274.793758392334,664.455699920654 PathPoint;PointKind.SMOOTHPOINT 274.434986114502,634.484524726868 274.552373886108,618.340952396393 274.319486618042,650.361378192902 PathPoint;PointKind.SMOOTHPOINT 274.434986114502,590.484645366669 273.846158981323,567.613620758057 275.023498535156,613.355669975281 PathPoint;PointKind.SMOOTHPOINT 275.424757003784,564.484512805939 274.898242950439,557.735817432404 275.899028778076,570.560982227325 PathPoint;PointKind.SMOOTHPOINT 274.865827560425,544.484610557556 273.575820922852,536.646616458893 276.214685440063,552.682321071625 PathPoint;PointKind.SMOOTHPOINT 273.89368057251,511.066625118256 274.183530807495,495.802989006042 273.593444824219,526.848828792572 PathPoint;PointKind.SMOOTHPOINT 273.89368057251,478.631722927094 272.771415710449,448.857872486115 274.288644790649,489.109997749329 PathPoint;PointKind.SMOOTHPOINT 272.885971069336,424.573473930359 272.594547271729,396.384122371674 273.228693008423,457.81750202179 PathPoint;PointKind.SMOOTHPOINT 271.465044021606,341.500225067139 272.85984992981,312.180740833282 269.99439239502,372.399251461029 PathPoint;PointKind.SMOOTHPOINT 271.465044021606,272.484476566315 270.580387115479,253.873636722565 272.364807128906,291.410422325134 PathPoint;PointKind.SMOOTHPOINT 271.465044021606,225.484600067139 271.234045028687,213.550937175751 271.819095611572,243.80676984787 PathPoint;PointKind.SMOOTHPOINT 274.434986114502,198.500204086304 275.527038574219,193.900601863861 272.413902282715,207.011840343475 PathPoint";
	
	mask645[2] = "PointKind.SMOOTHPOINT 285.31479401472,178.265526771545 292.158538611428,171.421001434326 282.698929513493,180.881731987 PathPoint;PointKind.SMOOTHPOINT 306.104311710456,170.48441696167 311.975675041283,168.476236343384 300.232636818825,172.492361545563 PathPoint;PointKind.SMOOTHPOINT 347.683658662729,169.499917507172 353.404538125751,169.432883739471 330.023457671416,169.707391738892 PathPoint;PointKind.SMOOTHPOINT 498.342935200004,166.001415729523 666.22840853014,166.016993999481 417.902920861645,165.99409866333 PathPoint;PointKind.SMOOTHPOINT 944.726379034789,166.076474666595 980.091957333838,165.995986938477 920.816268337114,166.13099861145 PathPoint;PointKind.SMOOTHPOINT 1495.02594370716,167.059321880341 1506.67831773597,166.852083683014 1483.37419279995,167.266796112061 PathPoint;PointKind.SMOOTHPOINT 1536.83335316716,170.990710735321 1543.37176817702,171.022575378418 1525.7966232849,170.93713092804 PathPoint;PointKind.SMOOTHPOINT 1546.55623114355,169.025016307831 1549.96906817862,168.448384284973 1541.59493691802,169.863174438477 PathPoint;PointKind.SMOOTHPOINT 1565.02898270885,168.042405128479 1568.94935229186,167.982924461365 1559.63773457531,168.123600959778 PathPoint;PointKind.SMOOTHPOINT 1581.5572833032,170.007863521576 1585.53373383073,171.071434497833 1575.9675709382,168.512821674347 PathPoint;PointKind.SMOOTHPOINT 1606.83608060805,171.973793983459 1622.28233053389,171.927767276764 1595.96790512017,172.006130695343 PathPoint;PointKind.SMOOTHPOINT 1858.65198395154,172.956641197205 1869.84418267446,173.444288253784 1847.45978522863,172.468994140625 PathPoint;PointKind.CORNERPOINT 1890.73651543515,172.956641197205 1890.73651543515,172.956641197205 1890.73651543515,172.956641197205 PathPoint;PointKind.SMOOTHPOINT 1896.57017990883,173.93948841095 1898.07533014768,174.062934398651 1890.73464607033,173.461046695709 PathPoint;PointKind.SMOOTHPOINT 1904.36543119762,171.819191455841 1909.18309589301,171.624935150146 1898.24263829884,172.066555500031 PathPoint;PointKind.SMOOTHPOINT 1916.98800556669,172.956641197205 1928.59395703587,174.001093387604 1905.3811194151,171.912189006805 PathPoint;PointKind.SMOOTHPOINT 1971.43419055752,172.956641197205 1980.36726189854,172.879693984985 1962.5014307773,173.033352375031 PathPoint;PointKind.SMOOTHPOINT 2016.15843225436,172.956641197205 2030.05092845609,172.837679862976 2002.26562449182,173.075602531433 PathPoint;PointKind.SMOOTHPOINT 2065.74395715899,172.956641197205 1880.56374365936,172.79731798172 2051.50625158764,172.944131374359 PathPoint;PointKind.SMOOTHPOINT 2561.59671371893,173.93948841095 2582.46941814904,173.72564125061 2428.56523584946,175.301406860352 PathPoint;PointKind.SMOOTHPOINT 2612.15493145025,172.956641197205 2620.02744981816,172.561047554016 2604.28147839992,173.351998806 PathPoint;PointKind.SMOOTHPOINT 2640.35024943114,173.93948841095 2650.05412219856,173.616829395294 2630.64668822453,174.261911392212 PathPoint;PointKind.SMOOTHPOINT 2697.71357821961,173.93948841095 2705.22998258979,173.847198963165 2690.19748541022,174.031541824341 PathPoint;PointKind.SMOOTHPOINT 2716.18664134571,173.93948841095 2725.21037688037,174.296608448029 2707.16290581104,173.582368373871 PathPoint;PointKind.SMOOTHPOINT 2757.99405080571,174.922335624695 2776.25431790343,175.429337501526 2739.733783708,174.415569782257 PathPoint;PointKind.SMOOTHPOINT 2798.82907899984,174.922335624695 2806.38287066637,174.772689819336 2791.27497577249,175.071981430054 PathPoint;PointKind.SMOOTHPOINT 2820.21866280197,172.956641197205 2834.23391396005,172.639410972595 2809.73339554086,173.193855762482 PathPoint;PointKind.SMOOTHPOINT 2852.30350584639,173.93948841095 2857.33521281337,174.142950057983 2847.27086419699,173.735790729523 PathPoint;PointKind.SMOOTHPOINT 2865.08871495458,173.537757873535 2871.45514840123,173.023674964905 2858.07548128109,174.104004383087 PathPoint;PointKind.SMOOTHPOINT 2881.47089353235,174.922335624695 2884.07523028387,175.1409034729 2877.81940092226,174.615962982178 PathPoint;PointKind.SMOOTHPOINT 2898.97157539258,173.93948841095 2901.89339260226,173.399205684662 2891.94463304376,175.239093780518 PathPoint;PointKind.SMOOTHPOINT 2906.79611339684,172.499914646149 2914.70601906111,171.791103363037 2903.03058953288,172.837443828583 PathPoint;PointKind.SMOOTHPOINT 2917.44495007948,174.922335624695 2924.74450813085,175.087559700012 2910.14508046732,174.757111549377 PathPoint;PointKind.SMOOTHPOINT 2953.41838350501,173.93948841095 2963.4942598711,174.28103017807 2943.34250713892,173.597710609436 PathPoint;PointKind.SMOOTHPOINT 2982.58608275178,173.93948841095 2999.24773136977,173.766711235046 2965.9250572554,174.112265586853 PathPoint;PointKind.SMOOTHPOINT 3554.2761659087,174.922335624695 3586.75949522003,175.851603031158 3521.79252503656,173.993068218231 PathPoint;PointKind.SMOOTHPOINT 3655.39104356732,174.922335624695 3660.00588218001,175.190942764282 3637.43330200923,173.876703262329 PathPoint;PointKind.SMOOTHPOINT 3670.94758601739,176.888030052185 3675.73502931489,177.298965930939 3666.15983115908,176.477330207825 PathPoint;PointKind.SMOOTHPOINT 3696.22638332224,177.87087726593 3700.51408309188,176.619186878204 3693.45442685876,178.680239200592 PathPoint;PointKind.SMOOTHPOINT 3712.64407983156,175.499911785126 3716.56663034018,175.489290237427 3707.34910398611,175.514781951904 PathPoint;PointKind.SMOOTHPOINT 3727.49400238063,176.499989509583 3731.06168513474,176.525009155273 3720.40568255363,176.449950218201 PathPoint;PointKind.SMOOTHPOINT 3737.06109995556,175.90518283844 3738.32074028173,175.880871295929 3729.26210993714,176.055536746979 PathPoint;PointKind.SMOOTHPOINT 3743.86683413432,176.888030052185 3745.75769664717,176.212735652924 3741.72734610074,177.652545452118 PathPoint;PointKind.SMOOTHPOINT 3747.75604763704,176.888030052185 3754.47547947338,176.966393470764 3746.91826063801,176.878352642059 PathPoint;PointKind.SMOOTHPOINT 3766.22911076314,175.90518283844 3783.02379584397,174.949243545532 3760.82134990704,176.212971687317 PathPoint;PointKind.SMOOTHPOINT 3787.61900612608,172.956641197205 3789.02071817837,172.957113265991 3776.259499252,172.952628612518 PathPoint;PointKind.SMOOTHPOINT 3794.42474030483,172.956641197205 3801.66136307401,173.448064804077 3793.40593647932,172.887483119965 PathPoint;PointKind.SMOOTHPOINT 3804.14730672042,173.93948841095 3809.96975500519,174.334846019745 3799.04362920797,173.592753887177 PathPoint;PointKind.SMOOTHPOINT 3815.81432410697,170.007863521576 3819.68733644794,170.119979858398 3813.95212518798,169.954047679901 PathPoint;PointKind.SMOOTHPOINT 3823.5924395516,170.990710735321 3824.72309370536,171.93319606781 3821.96484591721,169.633749008179 PathPoint;PointKind.SMOOTHPOINT 3829.42610402528,172.956641197205 3835.19122512232,173.196924209595 3825.54405642103,172.794957637787 PathPoint;PointKind.SMOOTHPOINT 3838.17628917499,170.007863521576 3845.54688308942,170.561600208282 3837.03909224437,169.922419071198 PathPoint;PointKind.SMOOTHPOINT 3859.56618453793,172.956641197205 3867.5835786792,172.499914646149 3851.54879039667,173.41336774826 PathPoint;PointKind.SMOOTHPOINT 3879.01162892992,172.956641197205 3890.42036241085,173.87033033371 3867.60258388818,172.042716026306 PathPoint;PointKind.SMOOTHPOINT 3903.31773340809,173.93948841095 3910.31756996706,173.97017288208 3896.31851997073,173.908803939819 PathPoint;PointKind.SMOOTHPOINT 3919.84634556324,170.990710735321 3930.85877370287,170.044212818146 3904.59139397038,172.301881790161 PathPoint;PointKind.SMOOTHPOINT 3934.43019518662,173.93948841095 3944.54377040986,173.597474575043 3927.91172006815,174.159708499908 PathPoint;PointKind.CORNERPOINT 3952.90325831273,172.956641197205 3952.90325831273,172.956641197205 3952.90325831273,172.956641197205 PathPoint;PointKind.SMOOTHPOINT 3963.598517555,170.990710735321 3971.08002711526,170.342088222504 3956.11607331233,171.639805316925 PathPoint;PointKind.SMOOTHPOINT 3977.2096743517,171.973793983459 3984.95632215524,171.924698829651 3966.88361466088,172.039175510406 PathPoint;PointKind.SMOOTHPOINT 3990.82176583081,170.990710735321 3992.46400282295,170.68835067749 3985.89038144236,171.89897108078 PathPoint;PointKind.SMOOTHPOINT 3996.65511874369,169.025016307831 4004.73669441035,168.621161460876 3993.3158100581,169.192128658295 PathPoint;PointKind.SMOOTHPOINT 4010.26689866199,170.990710735321 4012.98090481614,171.41557264328 4006.11472784162,170.34114408493 PathPoint;PointKind.SMOOTHPOINT 4022.90629731442,170.990710735321 4035.20360220526,171.704950809479 4018.04470254582,170.708413600922 PathPoint;PointKind.SMOOTHPOINT 4055.96321006391,171.973793983459 4063.53351445301,172.054045677185 4037.89268349517,171.781898021698 PathPoint;PointKind.SMOOTHPOINT 4079.29724483701,170.990710735321 4081.54359822599,170.736973762512 4071.58331091778,171.86262178421 PathPoint;PointKind.SMOOTHPOINT 4086.10297901576,169.025016307831 4090.62902279963,168.900626182556 4083.98872740722,169.083316802979 PathPoint;PointKind.SMOOTHPOINT 4098.74268922899,170.990710735321 4101.72121050481,171.44625711441 4094.81453062591,170.390475273132 PathPoint;PointKind.SMOOTHPOINT 4107.4928743787,170.990710735321 4122.64656871061,170.664511203766 4104.49285540749,171.055384159088 PathPoint;PointKind.SMOOTHPOINT 4150.27235354378,173.93948841095 4159.29421971363,173.782525539398 4135.92747105623,174.188976764679 PathPoint;PointKind.SMOOTHPOINT 4174.57970426517,172.783864021301 4175.44210456762,172.727215766907 4166.98167096462,173.282368659973 PathPoint;PointKind.SMOOTHPOINT 4177.16597049012,172.614391326904 4177.60994463427,172.036815166473 4175.99543655359,174.136577129364 PathPoint;PointKind.SMOOTHPOINT 4180.41243405644,171.973793983459 4183.31649230035,171.789687156677 4179.68805518967,172.019820690155 PathPoint;PointKind.SMOOTHPOINT 4188.19054950107,171.973793983459 4200.79193773554,171.374738693237 4185.16809815204,172.117302894592 PathPoint;PointKind.SMOOTHPOINT 4212.49696554004,172.956641197205 4219.15782394544,173.00550031662 4202.52421579972,172.883706569672 PathPoint;PointKind.SMOOTHPOINT 4231.94240993203,170.990710735321 4233.93016785459,170.59063243866 4226.07603157405,172.172298908234 PathPoint;PointKind.SMOOTHPOINT 4235.86527200146,169.198737621307 4237.06353484945,169.10621213913 4233.30424220155,169.396770477295 PathPoint;PointKind.SMOOTHPOINT 4239.72052537666,169.025016307831 4243.84683665039,168.964119434357 4238.3428035062,169.045551300049 PathPoint;PointKind.SMOOTHPOINT 4251.38754276321,169.025016307831 4253.32607407891,169.38142824173 4247.72732645063,168.352082252502 PathPoint;PointKind.SMOOTHPOINT 4256.24882597101,170.990710735321 4262.00615804797,172.582290649414 4254.37229525508,170.472143173218 PathPoint;PointKind.SMOOTHPOINT 4270.83298715519,170.990710735321 4283.00099431282,170.986934185028 4264.56531848307,170.992835044861 PathPoint;PointKind.SMOOTHPOINT 4287.36128774954,170.007863521576 4297.85091686189,169.735479831696 4276.87134707638,170.280719280243 PathPoint;PointKind.SMOOTHPOINT 4302.9175186388,173.93948841095 4305.19471654727,173.860416889191 4293.85203395655,174.254358291626 PathPoint;PointKind.SMOOTHPOINT 4306.80673214152,171.973793983459 4308.80570625299,171.635556697845 4305.28257669369,172.231307506561 PathPoint;PointKind.SMOOTHPOINT 4314.58453602535,170.990710735321 4315.37527734314,170.903850078583 4313.45699747962,171.115100860596 PathPoint;PointKind.SMOOTHPOINT 4318.47374952807,172.956641197205 4319.15295207841,172.93705034256 4317.50884572146,172.984257221222 PathPoint;PointKind.SMOOTHPOINT 4320.41820049903,170.990710735321 4321.50025116753,170.891576290131 4319.66484647759,171.059868812561 PathPoint;PointKind.SMOOTHPOINT 4327.22393467778,170.990710735321 4328.597294697,171.413920402527 4325.33338372573,170.408649921417 PathPoint;PointKind.SMOOTHPOINT 4329.16838564874,172.956641197205 4331.21035515101,172.986853599548 4328.00127888104,172.939410686493 PathPoint;PointKind.SMOOTHPOINT 4335.00236168322,170.990710735321 4337.4316012635,170.493386268616 4332.68528399198,171.465139865875 PathPoint;PointKind.SMOOTHPOINT 4344.724616538,170.990710735321 4348.11502119526,170.948460578918 4340.74442728084,171.040750026703 PathPoint;PointKind.SMOOTHPOINT 4354.4474945144,169.025016307831 4365.11315548039,168.975449085236 4350.9670487851,169.041302680969 PathPoint;PointKind.SMOOTHPOINT 4377.7818408483,169.025016307831 4379.11314015913,169.071515083313 4366.9878168315,168.64924955368 PathPoint;PointKind.SMOOTHPOINT 4382.64312405609,170.990710735321 4405.39267076293,171.871355056763 4381.26384438161,170.937366962433 PathPoint;PointKind.SMOOTHPOINT 4442.92297352059,170.990710735321 4444.65338221995,171.011245727539 4429.29405775812,170.82949924469 PathPoint;PointKind.SMOOTHPOINT 4453.61792120206,170.990710735321 4455.36858135361,172.209592342377 4451.70836504103,169.661601066589 PathPoint;PointKind.SMOOTHPOINT 4459.45158567574,169.025016307831 4462.36374450053,170.253339290619 4457.78068508974,168.320217609406 PathPoint;PointKind.SMOOTHPOINT 4468.00299503319,170.499995231628 4469.075075756,170.379853725433 4464.71104358965,170.868444919586 PathPoint;PointKind.SMOOTHPOINT 4474.03574685993,169.025016307831 4479.28398858494,168.82816362381 4471.50088816746,169.120138168335 PathPoint;PointKind.SMOOTHPOINT 4489.59166618839,170.990710735321 4496.64228715823,171.288586139679 4485.79623248735,170.830443382263 PathPoint;PointKind.SMOOTHPOINT 4508.06441775369,170.007863521576 4511.51962705796,169.813843250275 4497.09280407924,170.624385356903 PathPoint;PointKind.SMOOTHPOINT 4522.64857893788,170.007863521576 4537.57981885651,170.076077461243 4516.40427732597,169.979303359985 PathPoint;PointKind.SMOOTHPOINT 4561.94792393446,169.816203594208 4563.21348391588,169.809594631195 4548.29159082134,169.887485980988 PathPoint;PointKind.SMOOTHPOINT 4567.37250907392,169.025016307831 4570.94548836168,169.013450622559 4566.05086814798,169.02926492691 PathPoint;PointKind.SMOOTHPOINT 4575.15062451855,169.025016307831 4575.84696291305,169.027376651764 4571.01247393431,169.011798381805 PathPoint;PointKind.SMOOTHPOINT 4577.09507548951,170.007863521576 4577.89391738817,170.027218341827 4576.33642493442,169.989688873291 PathPoint;PointKind.SMOOTHPOINT 4579.03983802127,169.025016307831 4582.08534486971,169.052868366241 4578.1758799148,169.017227172852 PathPoint;PointKind.SMOOTHPOINT 4588.76240443686,169.025016307831 4592.51048089586,169.254205703735 4585.10904246194,168.801727771759 PathPoint;PointKind.SMOOTHPOINT 4600.42973338421,170.007863521576 4638.92899023892,170.553102970123 4596.89320671039,169.958060264587 PathPoint;PointKind.SMOOTHPOINT 4650.01494672804,170.990710735321 4665.45340763381,171.328711986542 4634.57617426147,170.652945518494 PathPoint;PointKind.SMOOTHPOINT 4680.1553388015,170.007863521576 4693.49325677405,170.338075637817 4666.81679770734,169.677887439728 PathPoint;PointKind.SMOOTHPOINT 4708.35065678239,170.007863521576 4726.94522862163,169.616518497467 4689.75577338235,170.399680614471 PathPoint;PointKind.SMOOTHPOINT 4738.49042573424,170.990710735321 4758.9727444783,171.336501121521 4718.00841855097,170.645392417908 PathPoint;PointKind.SMOOTHPOINT 4782.242597726,170.990710735321 4816.46537099998,170.119271755219 4748.01951289122,171.862385749817 PathPoint;PointKind.SMOOTHPOINT 4848.35642322498,170.990710735321 4869.96596895397,170.871985435486 4823.91665916236,171.125250339508 PathPoint;PointKind.SMOOTHPOINT 4884.78691634837,170.499995231628 4886.64537653773,170.559475898743 4870.59314085023,170.045156955719 PathPoint;PointKind.SMOOTHPOINT 4895.02480433198,172.956641197205 4902.90666952398,173.136499404907 4892.78156655103,172.905421733856 PathPoint;PointKind.SMOOTHPOINT 4907.6638914236,172.956641197205 4912.32515259593,171.463487625122 4904.20400870729,174.065058708191 PathPoint;PointKind.SMOOTHPOINT 4928.08171708147,170.990710735321 4942.36958394209,171.179066181183 4920.42791439719,170.889924049377 PathPoint;PointKind.SMOOTHPOINT 4973.39044684456,175.962303161621 4992.1345678692,179.375360488892 4953.57642602274,172.354517459869 PathPoint;PointKind.SMOOTHPOINT 4999.13004257692,191.92719745636 5003.31336947759,197.787223339081 4994.34384552263,185.221224308014 PathPoint;PointKind.SMOOTHPOINT 5006.83494123287,219.151640415192 5009.77140180029,236.007328510284 5005.24037304358,210.000114917755 PathPoint;PointKind.SMOOTHPOINT 5011.69622444067,266.32995891571 5011.50461454688,270.782747745514 5012.13677141598,256.071196079254 PathPoint;PointKind.SMOOTHPOINT 5011.69622444067,278.124597549438 5010.69549114172,280.911927700043 5012.46328713743,275.986834049225 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,297.782013893127 5008.45754989443,316.534474372864 5008.90557432901,290.412784099579 PathPoint;PointKind.SMOOTHPOINT 5010.72384317479,435.384872436523 5010.66308881822,452.65432882309 5010.78490909216,418.115416049957 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,936.652529716492 5010.15399846627,953.630247592926 5007.40447438059,919.675047874451 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,993.659556388855 5008.92364485558,1005.91469812393 5008.63482799128,981.404414653778 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1082.11863803864 5009.67949136344,1095.35285043716 5009.82374401518,1068.88442564011 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,1253.13948202133 5009.03393737981,1260.07700490952 5008.52484702785,1246.20172309875 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1272.79689836502 5009.73650699037,1284.94086790085 5009.76672838825,1260.65292882919 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,1316.04359197617 5008.33884522852,1348.17141342163 5009.22025073995,1283.9157705307 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1533.25943517685 5010.06302271182,1546.79695177078 5009.4402126668,1519.72191858292 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,1595.18069791794 5008.79185463595,1604.49461507797 5008.75290953558,1575.25467443466 PathPoint;PointKind.SMOOTHPOINT 5009.7617434154,1634.20992898941 5009.79414573891,1635.32401132584 5009.33864384505,1619.79436445236 PathPoint;PointKind.SMOOTHPOINT 5008.53512853435,1637.50001239777 5007.13372804286,1639.2702703476 5009.2152657671,1636.64013910294 PathPoint;PointKind.SMOOTHPOINT 5009.94992614036,1640.93974161148 5010.31071355013,1654.64909124374 5009.92032786409,1639.81574583054 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1669.8794465065 5008.22481397465,1677.32774782181 5010.45216215465,1666.46190452576 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1687.57140445709 5009.37198085096,1694.89696788788 5010.13156608846,1680.24584102631 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1703.2974319458 5010.21880311327,1709.60545110703 5009.28443226535,1696.98941278458 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1723.93793153763 5009.96799666693,1735.06813335419 5009.53523871169,1712.80749368668 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1774.06455564499 5008.89685062653,1795.25029468536 5010.60607319129,1752.87905263901 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1846.79760980606 5009.94899145795,1861.87100219727 5009.55393235986,1831.72421741486 PathPoint;PointKind.SMOOTHPOINT 5009.52495720519,1889.50000810623 5011.23044104032,1913.68055152893 5007.81978493087,1865.31970071793 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1949.9998717308 5010.09729440014,1967.20394659042 5009.40625253928,1932.79556083679 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,1998.16080141068 5009.80068851577,2002.82531309128 5009.61873700687,1985.57922410965 PathPoint;PointKind.SMOOTHPOINT 5009.16884320747,2011.74340057373 5008.56254588501,2019.17871999741 5009.52682657001,2007.36260223389 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2033.54448127747 5008.92364485558,2043.71095466614 5008.68872801018,2027.14724111557 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2086.61964702606 5010.06302271182,2112.67383146286 5009.4402126668,2060.56569862366 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2212.42810297012 5008.78313093347,2242.90887641907 5010.72010444515,2181.94732952118 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2291.05847644806 5009.14422990404,2306.0742764473 5010.35931703538,2276.04244041443 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2364.77414178848 5008.74075866427,2366.0331492424 5009.3112264944,2347.35503959656 PathPoint;PointKind.SMOOTHPOINT 5007.80732249875,2369.6886138916 5007.76121149992,2375.30882883072 5007.87025778094,2361.97689819336 PathPoint;PointKind.SMOOTHPOINT 5008.5507065745,2375.0591044426 5009.12304376944,2398.49944400787 5008.5298320007,2374.21244907379 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2458.14769554138 5009.74398444964,2476.99126529694 5007.95998729218,2442.13748264313 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2533.82929134369 5009.12865186389,2556.72321128845 5008.42982098297,2510.93489933014 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2601.64763736725 5010.42381012159,2623.07129907608 5009.07942525703,2580.22397565842 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2674.38069152832 5008.50958054851,2706.79647493362 5009.04889229835,2641.96490812302 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2736.3021903038 5009.13270215433,2752.06244277954 5008.42608225333,2720.54146575928 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2796.25752258301 5009.56172137994,2823.34412145615 5009.94151399868,2769.17092370987 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2866.04179906845 5009.72747172708,2882.6026802063 5009.77576365154,2849.39759778976 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2913.21988153458 5008.23571860275,2923.59453725815 5009.29845250148,2903.31446218491 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,2955.48372793198 5009.39441322877,2967.79669809341 5010.10882214985,2943.17075777054 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,2986.93601894379 5009.19189870688,2994.39163732529 5008.20207003604,2976.50825548172 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,3030.18247652054 5009.86081975073,3036.84289503098 5009.47728840235,3013.4731297493 PathPoint;PointKind.SMOOTHPOINT 5010.51509743684,3045.49992847443 5011.03073056565,3062.75262641907 5010.35557830575,3040.15563774109 PathPoint;PointKind.SMOOTHPOINT 5009.52495720519,3070.4999833107 5009.44145891001,3079.66071414948 5009.60845550037,3061.33948850632 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3101.93244743347 5009.11743567499,3115.22047567368 5008.44103717187,3088.64465522766 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3152.05930757523 5008.49462562997,3164.22546434402 5009.04577669032,3140.67513275146 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3181.54566812515 5008.87067951908,3189.78964138031 5008.67283840924,3171.91664505005 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3220.86073684692 5008.88033790397,3223.05680084229 5008.17901453662,3207.79009628296 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,3228.72375059128 5009.93590590423,3230.93043613434 5009.60814393957,3227.00400400162 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3233.6382226944 5008.75166329237,3240.93050527573 5008.78562341989,3231.98763418198 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3257.22726392746 5009.17040101148,3272.16611671448 5008.46066550245,3245.0457649231 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3293.593791008 5009.31496522403,3303.27285337448 5008.24381918363,3283.91472864151 PathPoint;PointKind.SMOOTHPOINT 5007.80732249875,3310.30266571045 5009.05668131842,3319.2561583519 5006.55765211828,3301.349173069 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3337.82333183289 5008.69900951668,3349.23229026794 5008.85572460054,3326.99171352386 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,3355.51505374908 5010.79238655143,3360.79018640518 5008.71084882719,3350.23992109299 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,3372.22392845154 5009.45547914614,3377.54154729843 5010.04775623247,3366.90630960464 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,3391.88158082962 5008.27435214231,3404.83939695358 5011.22919479711,3378.92352867126 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3409.57330274582 5008.64666730179,3426.58571767807 5008.91242866667,3392.56112384796 PathPoint;PointKind.SMOOTHPOINT 5009.75177346971,3453.80284357071 5009.35671437162,3472.55034732819 5010.146521007,3435.05510377884 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3528.50135612488 5008.94265006456,3558.17229557037 5008.61613434311,3498.83088874817 PathPoint;PointKind.SMOOTHPOINT 5008.77939220383,3585.50838279724 5008.32357874917,3597.80978727341 5009.23520565849,3573.20721435547 PathPoint;PointKind.SMOOTHPOINT 5006.83494123287,3611.06311845779 5006.47197289748,3628.00566720963 5007.17734655527,3595.07816123962 PathPoint;PointKind.SMOOTHPOINT 5008.53512853435,3659.49997234344 5008.3796596937,3681.9565205574 5008.69090893581,3637.04342412949 PathPoint;PointKind.SMOOTHPOINT 5011.69622444067,3731.95733833313 5012.14424887525,3748.17077684402 5011.24820000609,3715.74366378784 PathPoint;PointKind.SMOOTHPOINT 5009.03019865017,3764.05258703232 5006.97545515499,3770.43188858032 5009.56546010957,3762.38996076584 PathPoint;PointKind.SMOOTHPOINT 4998.24334053184,3779.40308380127 4997.94517684346,3779.6103219986 5003.10555842205,3776.02354335785 PathPoint;PointKind.SMOOTHPOINT 4992.56857206765,3782.70048427582 4988.88623493807,3784.49080514908 4994.24134201847,3781.88734579086 PathPoint;PointKind.SMOOTHPOINT 4978.83559499701,3785.50008821487 4973.63190646682,3786.48387956619 4984.43153857807,3784.44147396088 PathPoint;PointKind.SMOOTHPOINT 4963.08308080191,3787.98128175735 4944.96737791675,3790.0930814743 4968.22570341474,3787.38175439835 PathPoint;PointKind.SMOOTHPOINT 4789.04833190475,3789.94721221924 4774.79473673245,3791.77081394196 4803.30192707706,3788.12337446213 PathPoint;PointKind.SMOOTHPOINT 4637.37554807561,3789.94721221924 4615.21080099584,3791.51731300354 4659.53998359459,3788.37663936615 PathPoint;PointKind.SMOOTHPOINT 4475.007816565,3789.94721221924 4446.3186747115,3790.69968986511 4503.69726997931,3789.19449853897 PathPoint;PointKind.SMOOTHPOINT 4390.42092793992,3789.94721221924 4376.2511426236,3790.84154653549 4404.59102481704,3789.05264186859 PathPoint;PointKind.SMOOTHPOINT 4356.39194548535,3789.94721221924 4347.61278518097,3789.8003988266 4366.28929751138,3790.11220026016 PathPoint;PointKind.SMOOTHPOINT 4324.30710244094,3789.94721221924 4323.04808523639,3789.91227912903 4334.18918798762,3790.2203040123 PathPoint;PointKind.SMOOTHPOINT 4316.52929855711,3789.94721221924 4307.32298839194,3790.37703084946 4317.56928851722,3789.89858913422 PathPoint;PointKind.SMOOTHPOINT 4290.27811998637,3789.94721221924 4284.27527799672,3790.18466281891 4300.6356473183,3789.53722047806 PathPoint;PointKind.SMOOTHPOINT 4266.60822266774,3790.15563058853 4265.44921648092,3790.14902162552 4276.27221565239,3790.21039056778 PathPoint;PointKind.SMOOTHPOINT 4263.06016824421,3790.13249921799 4262.1385713892,3789.51880979538 4264.66719886562,3791.20315122604 PathPoint;PointKind.SMOOTHPOINT 4259.69157284315,3790.10677146912 4254.11868476151,3790.06121683121 4260.83344318582,3790.11597681046 PathPoint;PointKind.SMOOTHPOINT 4241.66528790842,3789.94721221924 4220.77388983014,3789.77065849304 4248.09247571164,3790.0015001297 PathPoint;PointKind.SMOOTHPOINT 4194.02452553555,3789.94721221924 4172.93840195544,3789.22895956039 4215.11002599405,3790.66522884369 PathPoint;PointKind.SMOOTHPOINT 4153.18918578062,3789.94721221924 4145.88838148605,3790.21369504929 4171.90152760336,3789.26365661621 PathPoint;PointKind.SMOOTHPOINT 4136.66088518628,3789.94721221924 4131.80957192418,3790.24414348602 4139.76465390486,3789.75696849823 PathPoint;PointKind.SMOOTHPOINT 4123.04910526797,3790.93005943298 4109.3239172174,3790.64965057373 4131.41949779893,3791.10071229935 PathPoint;PointKind.SMOOTHPOINT 4094.85347572628,3789.94721221924 4075.78813551384,3789.75885677338 4113.91912749951,3790.13509559631 PathPoint;PointKind.SMOOTHPOINT 4048.18478305848,3789.94721221924 4016.1145833718,3790.38151550293 4080.24252031304,3789.51267290115 PathPoint;PointKind.SMOOTHPOINT 3957.76422995972,3789.94721221924 3900.33485028104,3790.12801456451 4015.29299753453,3789.76570177078 PathPoint;PointKind.SMOOTHPOINT 3853.73252006426,3789.94721221924 3830.13615109511,3789.43643379211 3877.32920059421,3790.45775461197 PathPoint;PointKind.SMOOTHPOINT 3796.36919127579,3789.94721221924 3781.52705774679,3789.97010755539 3811.21163636559,3789.92408084869 PathPoint;PointKind.SMOOTHPOINT 3771.09039397093,3789.94721221924 3756.33175873712,3789.9625544548 3785.84902920475,3789.93163394928 PathPoint;PointKind.SMOOTHPOINT 3743.86683413432,3790.93005943298 3731.2504909813,3790.71479606628 3756.48411196974,3791.1448507309 PathPoint;PointKind.SMOOTHPOINT 3710.81023294563,3790.93005943298 3700.42715762787,3791.50574731827 3721.19361982419,3790.35389947891 PathPoint;PointKind.SMOOTHPOINT 3668.03075378055,3790.93005943298 3634.19306965897,3791.02895784378 3701.78774365418,3790.83116102219 PathPoint;PointKind.SMOOTHPOINT 3562.05396979253,3790.93005943298 3538.89378594745,3790.5448513031 3586.29713898851,3791.33297014236 PathPoint;PointKind.SMOOTHPOINT 3471.63403981537,3790.93005943298 3435.85346252685,3791.00865888596 3507.24512802711,3790.85145998001 PathPoint;PointKind.SMOOTHPOINT 3326.76667860418,3790.93005943298 3309.15601578053,3791.04500818253 3344.37796454944,3790.81463861465 PathPoint;PointKind.SMOOTHPOINT 3260.6528531052,3790.93005943298 3240.88245079579,3790.64941453934 3291.24905863332,3791.36389064789 PathPoint;PointKind.SMOOTHPOINT 3188.70567469335,3790.93005943298 3186.9762006764,3790.94256925583 3200.01688964298,3790.84626722336 PathPoint;PointKind.SMOOTHPOINT 3182.87232178048,3790.93005943298 3182.15105852174,3791.40283632278 3184.59494145977,3789.79969072342 PathPoint;PointKind.SMOOTHPOINT 3177.19786487709,3791.00535440445 3168.69350120088,3791.60440969467 3178.65970816434,3790.90244340897 PathPoint;PointKind.SMOOTHPOINT 3151.75986000195,3790.93005943298 3114.54485677683,3790.62321472168 3160.14645369466,3790.99898147583 PathPoint;PointKind.SMOOTHPOINT 3069.11742234782,3790.93005943298 3050.98645298331,3791.02966594696 3087.24870327313,3790.83021688461 PathPoint;PointKind.SMOOTHPOINT 3025.36556191686,3790.93005943298 2997.2917526491,3791.10661315918 3053.43999430622,3790.75326967239 PathPoint;PointKind.SMOOTHPOINT 2925.60566219009,3791.50008249283 2922.85769590843,3791.57348918915 2960.0677141607,3790.57860422134 PathPoint;PointKind.SMOOTHPOINT 2913.08652600759,3791.10566902161 2912.52197783271,3791.11487436295 2915.83854257968,3791.06129455566 PathPoint;PointKind.SMOOTHPOINT 2910.63890433993,3790.93005943298 2909.8113988474,3790.94186115265 2911.20438719721,3790.92203426361 PathPoint;PointKind.SMOOTHPOINT 2908.69414180817,3789.94721221924 2907.55756799916,3790.67349004745 2910.24633772826,3788.95539569855 PathPoint;PointKind.SMOOTHPOINT 2904.81614449436,3790.50000476837 2904.24848071145,3790.50425338745 2906.16520277095,3790.49009132385 PathPoint;PointKind.SMOOTHPOINT 2903.16206819171,3791.21212053299 2874.50377085769,3791.37663650513 2903.73066665702,3791.20905208588 PathPoint;PointKind.SMOOTHPOINT 2807.57926414955,3790.93005943298 2762.63132179622,3791.55177402496 2844.64752223649,3790.41715669632 PathPoint;PointKind.SMOOTHPOINT 2607.29333668165,3789.94721221924 2561.56680388185,3789.7437505722 2653.02018104225,3790.15043783188 PathPoint;PointKind.SMOOTHPOINT 2465.3431192681,3789.94721221924 2423.99152326275,3791.65161657333 2506.69471527345,3788.24257183075 PathPoint;PointKind.SMOOTHPOINT 2382.70099317478,3788.9641289711 2337.63870800678,3789.67081594467 2427.76296678197,3788.25767803192 PathPoint;PointKind.SMOOTHPOINT 2281.58580395535,3789.94721221924 2234.60960077508,3790.24249124527 2328.56169557482,3789.65146112442 PathPoint;PointKind.SMOOTHPOINT 2194.08208309343,3789.94721221924 2163.88187134582,3789.50795221329 2254.56008522858,3790.82620429993 PathPoint;PointKind.SMOOTHPOINT 2121.1625234157,3789.94721221924 2101.14411870716,3789.67931318283 2141.12983215256,3790.21416711807 PathPoint;PointKind.SMOOTHPOINT 2063.79919462723,3789.94721221924 2025.52986964507,3789.69607162476 2084.70866323209,3790.08434820175 PathPoint;PointKind.SMOOTHPOINT 1983.10120794406,3789.94721221924 1928.74599870769,3789.62455320358 2037.45704030205,3790.2696352005 PathPoint;PointKind.SMOOTHPOINT 1850.87386850691,3788.9641289711 1803.35586109038,3789.24146938324 1900.48026798534,3788.6747508049 PathPoint;PointKind.SMOOTHPOINT 1723.50781227755,3787.98128175735 1677.6691175887,3788.42833089828 1771.76297255376,3787.51062917709 PathPoint;PointKind.SMOOTHPOINT 1624.33707402908,3786.99843454361 1582.70039988907,3787.73556995392 1665.97312504748,3786.2612991333 PathPoint;PointKind.SMOOTHPOINT 1480.44240564457,3786.01535129547 1447.27146164122,3786.67601156235 1513.61334964793,3785.35516309738 PathPoint;PointKind.SMOOTHPOINT 1361.82653456492,3786.01535129547 1313.19033542675,3785.735414505 1410.46211058149,3786.29576015472 PathPoint;PointKind.SMOOTHPOINT 1240.29351968763,3786.01535129547 1188.09711525462,3785.8661775589 1314.82883368925,3786.22896242142 PathPoint;PointKind.SMOOTHPOINT 1145.70303680273,3785.69859313965 1145.10546318275,3785.70071744919 1171.29713364014,3785.6157450676 PathPoint;PointKind.SMOOTHPOINT 1143.89504946345,3785.70496606827 1142.49333741116,3785.71039485931 1144.50290458993,3785.70260572433 PathPoint;PointKind.SMOOTHPOINT 1139.17833046821,3786.01535129547 1137.21892457871,3786.79355669022 1140.870105628,3785.3438334465 PathPoint;PointKind.SMOOTHPOINT 1133.04338669812,3785.76255846024 1125.15715965487,3785.81519412994 1135.31466495133,3785.74745225906 PathPoint;PointKind.SMOOTHPOINT 1105.14934801364,3786.01535129547 1046.88186977513,3786.64509105682 1116.14401718751,3785.89662599564 PathPoint;PointKind.SMOOTHPOINT 1000.14494529149,3786.01535129547 941.793968757806,3786.38403701782 1058.49592182518,3785.64690160751 PathPoint;PointKind.SMOOTHPOINT 870.834126530374,3786.01535129547 819.843462404617,3786.6528801918 921.824479095328,3785.37829446793 PathPoint;PointKind.SMOOTHPOINT 814.956942771786,3786.49992990494 804.597546075049,3786.77184152603 843.729582920468,3785.74532794952 PathPoint;PointKind.SMOOTHPOINT 782.358647524179,3786.01535129547 774.196066048756,3786.48411560059 787.24516715701,3785.73517847061 PathPoint;PointKind.SMOOTHPOINT 763.885584398075,3786.99843454361 758.358807315265,3787.68883514404 771.359616499068,3786.06491851807 PathPoint;PointKind.SMOOTHPOINT 742.495689035134,3785.03274011612 730.914973990991,3785.14013576508 760.583663008841,3784.86444759369 PathPoint;PointKind.SMOOTHPOINT 725.967076879987,3789.94721221924 720.192608958865,3791.27348947525 734.015315540743,3788.09835481644 PathPoint;PointKind.SMOOTHPOINT 708.466395019764,3787.98128175735 692.036859199943,3787.02911901474 724.896242400388,3788.93368053436 PathPoint;PointKind.SMOOTHPOINT 681.24314674395,3790.93005943298 669.557124148424,3790.29654312134 692.929169339475,3791.56333971024 PathPoint;PointKind.SMOOTHPOINT 662.770083617846,3787.98128175735 647.02006190917,3787.44005489349 678.520105326521,3788.52250862122 PathPoint;PointKind.SMOOTHPOINT 629.713170868356,3787.98128175735 610.617609258039,3790.21959590912 648.809044039476,3785.74296760559 PathPoint;PointKind.SMOOTHPOINT 597.62895094555,3791.91267061234 588.818946121681,3791.53407144547 608.437618320082,3792.37742233276 PathPoint;PointKind.SMOOTHPOINT 585.961621998199,3787.98128175735 584.414722611753,3787.71739530563 592.777326122644,3789.14493131638 PathPoint;PointKind.SMOOTHPOINT 575.38039400979,3787.50000762939 571.981888771654,3787.25571203232 577.978187984448,3787.6869468689 PathPoint;PointKind.SMOOTHPOINT 564.571726635257,3787.98128175735 559.679910468777,3788.4526424408 567.848411599455,3787.6657037735 PathPoint;PointKind.SMOOTHPOINT 549.987877011871,3791.91267061234 546.132935197473,3792.97860193253 553.498544139054,3790.94209718704 PathPoint;PointKind.SMOOTHPOINT 542.209761567238,3792.89551782608 540.195520976429,3793.15798807144 545.063970082691,3792.52399969101 PathPoint;PointKind.SMOOTHPOINT 537.348478359443,3791.91267061234 533.801670179122,3791.42525959015 538.728381155529,3792.10267829895 PathPoint;PointKind.SMOOTHPOINT 525.681772533698,3790.93005943298 517.781836815127,3790.90692806244 531.369003430006,3790.94658184052 PathPoint;PointKind.SMOOTHPOINT 513.041750759664,3791.91267061234 503.441004618011,3791.16042900085 522.643120022922,3792.66514825821 PathPoint;PointKind.SMOOTHPOINT 493.596929489285,3790.93005943298 474.55402165466,3791.34831237793 512.639525763107,3790.51133441925 PathPoint;PointKind.SMOOTHPOINT 467.345750918549,3791.91267061234 456.692552384668,3792.15082931519 477.998637891627,3791.67474794388 PathPoint;PointKind.SMOOTHPOINT 454.602290957948,3792.49992418289 450.143544307512,3791.96625041962 459.061037608385,3793.03359794617 PathPoint;PointKind.SMOOTHPOINT 444.98378585053,3792.89551782608 439.332072885753,3793.2335190773 450.635187254503,3792.55775260925 PathPoint;PointKind.CORNERPOINT 440.122502642734,3791.91267061234 440.122502642734,3791.91267061234 440.122502642734,3791.91267061234 PathPoint;PointKind.SMOOTHPOINT 431.372317493024,3792.89551782608 430.681275632171,3794.11038684845 432.512006910067,3790.89016962051 PathPoint;PointKind.SMOOTHPOINT 408.037971159125,3794.86144828796 362.686557566028,3792.21054601669 417.114672030284,3795.39205360413 PathPoint;PointKind.SMOOTHPOINT 319.561869031324,3791.91267061234 306.556386435477,3790.97230958939 344.517577783563,3793.71715354919 PathPoint;PointKind.SMOOTHPOINT 291.254700722188,3784.50001049042 286.448563776508,3781.2155919075 296.484560359825,3788.07427930832 PathPoint;PointKind.SMOOTHPOINT 276.899848288941,3769.04164600372 275.769817256788,3766.04707765579 280.417058192985,3778.3612279892 PathPoint;PointKind.SMOOTHPOINT 275.414949502274,3759.49995565414 275.526176708913,3758.29145956039 275.099961530533,3762.91867780685 PathPoint;PointKind.SMOOTHPOINT 272.939910483962,3746.09225797653 270.672059399585,3730.95844078064 273.61537430467,3750.59862661362 PathPoint;PointKind.SMOOTHPOINT 270.46487146565,3710.49992370605 269.415534681451,3698.70552110672 271.121641638183,3717.87505435944 PathPoint;PointKind.CORNERPOINT 267.05951188985,3528.50135612488 267.05951188985,3528.50135612488 267.05951188985,3528.50135612488 PathPoint;PointKind.CORNERPOINT 267.05951188985,3088.17235040665 267.05951188985,3088.17235040665 267.05951188985,3088.17235040665 PathPoint;PointKind.CORNERPOINT 267.05951188985,2487.63382005692 267.05951188985,2487.63382005692 267.05951188985,2487.63382005692 PathPoint;PointKind.SMOOTHPOINT 268.03189315573,2476.82226467133 268.149974700033,2468.52140712738 267.914434733034,2485.12312221527 PathPoint;PointKind.SMOOTHPOINT 267.05951188985,2459.13054275513 266.718041249862,2443.75361013412 267.401605651445,2474.50700330734 PathPoint;PointKind.SMOOTHPOINT 268.03189315573,2434.55865430832 267.599758322095,2427.13985729218 268.243131380103,2438.18201828003 PathPoint;PointKind.SMOOTHPOINT 267.05951188985,2375.58593320847 266.893761542702,2349.48406982422 267.233051257071,2402.82005357742 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,2107.26014661789 272.031087621875,2059.18749380112 271.810814134219,2155.33279943466 PathPoint;PointKind.SMOOTHPOINT 270.46487146565,2020.50004053116 269.898765486764,2006.64387750626 271.030665883733,2034.35620355606 PathPoint;PointKind.SMOOTHPOINT 270.949036953371,1968.67444086075 270.891709765636,1941.44173669815 271.005741019501,1995.90690898895 PathPoint;PointKind.SMOOTHPOINT 271.455011697296,1920.50005722046 270.011550497417,1903.65664291382 272.898161336372,1937.34323549271 PathPoint;PointKind.SMOOTHPOINT 270.949036953371,1884.14674806595 271.028796518916,1872.11041021347 270.869277387826,1896.18332195282 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1859.57485961914 270.371091663974,1850.31570243835 274.055609719181,1872.32520151138 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1826.15734624863 270.766462322866,1808.24634838104 273.075439433228,1844.06787204742 PathPoint;PointKind.SMOOTHPOINT 272.444840368139,1752.49998140335 274.658791433613,1723.34406900406 270.230577741862,1781.65636587143 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1666.93090486526 271.429463711457,1660.73877859116 273.274526786287,1683.98132133484 PathPoint;PointKind.SMOOTHPOINT 270.949036953371,1628.59868335724 271.347523220292,1607.57439184189 270.549927564844,1649.62297487259 PathPoint;PointKind.SMOOTHPOINT 270.949036953371,1526.37926864624 269.786603597716,1505.67362356186 272.11084718742,1547.08514976501 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1420.22846508026 272.35822646493,1394.44713640213 271.484609973572,1446.00979375839 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1332.75246667862 271.028796518916,1309.8007183075 272.814039919587,1355.70421504974 PathPoint;PointKind.SMOOTHPOINT 271.455011697296,1255.48448371887 271.466539447004,1250.8860616684 271.424478738611,1267.70115184784 PathPoint;PointKind.SMOOTHPOINT 270.46487146565,1241.49991798401 270.532791720684,1239.66357040405 270.38137317047,1243.74436903 PathPoint;PointKind.SMOOTHPOINT 269.976655687491,1226.60166311264 270.934393595634,1222.97121810913 269.121109722702,1229.84335947037 PathPoint;PointKind.SMOOTHPOINT 271.455011697296,1216.48428487778 272.244818332671,1194.79579257965 271.276175796426,1221.38884353638 PathPoint;PointKind.SMOOTHPOINT 270.949036953371,1185.32089996338 270.338689340472,1176.93270969391 272.117389964281,1201.39389801025 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1140.10851192474 272.594389553536,1120.16903448105 271.234115088033,1160.45491266251 PathPoint;PointKind.SMOOTHPOINT 271.455011697296,1106.48446846008 271.292065397374,1090.69282341003 271.596148741014,1120.14472293854 PathPoint;PointKind.SMOOTHPOINT 271.921106658448,1056.56366634369 271.055279187163,1037.25935745239 272.786934129734,1075.86797523499 PathPoint;PointKind.SMOOTHPOINT 272.893487924329,1002.50565338135 272.953930720093,980.513620853424 272.832733567761,1024.49744987488 PathPoint;PointKind.SMOOTHPOINT 273.865869190209,930.755446434021 274.746963140837,902.935252666473 272.984463678778,958.575404167175 PathPoint;PointKind.SMOOTHPOINT 273.865869190209,851.142461776733 274.758179329741,824.374273300171 272.973247489873,877.910414218903 PathPoint;PointKind.SMOOTHPOINT 274.837938895286,786.272421360016 276.315360222683,761.861744403839 273.36051756789,810.683098316193 PathPoint;PointKind.SMOOTHPOINT 274.837938895286,732.214172363281 274.275883206838,708.455894470215 275.399994583735,755.971978187561 PathPoint;PointKind.SMOOTHPOINT 274.424809270628,683.484399795532 274.052805671955,667.201567173004 274.797124430105,699.766996383667 PathPoint;PointKind.SMOOTHPOINT 274.424809270628,658.484344959259 275.056031457323,652.513382911682 273.793587083934,664.455543041229 PathPoint;PointKind.SMOOTHPOINT 273.434980599785,634.484367847443 273.552439022482,618.340795516968 273.319391541906,650.361221313477 PathPoint;PointKind.SMOOTHPOINT 273.434980599785,590.484488487244 272.910935329292,570.122509479523 274.023518956481,613.355513095856 PathPoint;PointKind.SMOOTHPOINT 273.865869190209,544.484453678131 273.094133081402,536.577301502228 274.878441799664,554.864302158356 PathPoint;PointKind.SMOOTHPOINT 272.893487924329,511.066468238831 273.183551031837,495.802832126617 272.593454871127,526.848671913147 PathPoint;PointKind.SMOOTHPOINT 272.893487924329,478.631566047668 271.771245912249,448.857715606689 273.288547022418,489.109840869904 PathPoint;PointKind.SMOOTHPOINT 271.88590028772,424.573317050934 271.594590936999,396.383965492249 272.22861717092,457.817345142365 PathPoint;PointKind.SMOOTHPOINT 270.46487146565,341.500068187714 271.859729180275,312.180583953857 268.994304475918,372.399094581604 PathPoint;PointKind.SMOOTHPOINT 270.46487146565,272.48431968689 269.58035034619,253.87347984314 271.364659064452,291.410265445709 PathPoint;PointKind.SMOOTHPOINT 271.455011697296,225.500021457672 271.22414514234,213.566594600677 271.809256330204,243.822191238403 PathPoint;PointKind.SMOOTHPOINT 273.434980599785,198.500047206879 274.527001213983,193.900444984436 271.413885671312,207.01168346405 PathPoint";
	
	subshadow645[0] = "PointKind.SMOOTHPOINT 269,206 271.050666809082,197.1576795578 266.720222473145,215.831776618958 PathPoint;PointKind.SMOOTHPOINT 290.109558105469,174.999911785126 303.260135650635,167.676236629486 275.516023635864,183.127520084381 PathPoint;PointKind.SMOOTHPOINT 355.497694015503,167.312507629395 366.010036468506,166.592366695404 350.514850616455,167.653813362122 PathPoint;PointKind.SMOOTHPOINT 4955.10967254639,174.000070095062 4966.09408378601,176.199674606323 4944.12431716919,171.800229549408 PathPoint;PointKind.SMOOTHPOINT 5000.10947227478,190.999975204468 5003.61222267151,195.311851501465 4987.35920906067,175.305104255676 PathPoint;PointKind.SMOOTHPOINT 5012.10946083069,263.999984264374 5014.73101615906,309.979248046875 5010.00246047974,227.047383785248 PathPoint;PointKind.SMOOTHPOINT 5013.10930252075,375.999956130981 5013.87751579285,398.554458618164 5012.68349647522,363.495326042175 PathPoint;PointKind.SMOOTHPOINT 5016.10945701599,3536.00008964539 5016.13368988037,3503.46794128418 5016.58561706543,2909.04647827148 PathPoint;PointKind.SMOOTHPOINT 5016.10945701599,3740.99997282028 5016.03833198547,3745.53206920624 5016.58121109009,3710.97427368164 PathPoint;PointKind.SMOOTHPOINT 5001.10962867737,3776.99993848801 4987.12254524231,3786.76255702972 5011.92189216614,3769.45344686508 PathPoint;PointKind.SMOOTHPOINT 4937.41527557373,3789.56263303757 4921.0348033905,3790.97907543182 4955.71927070618,3787.98002243042 PathPoint;PointKind.SMOOTHPOINT 320.343675613403,3792.56239414215 310.987272262573,3791.3432765007 344.797468185425,3794.22124385834 PathPoint;PointKind.SMOOTHPOINT 291.109399795532,3788.00008535385 279.289112091064,3783.43305587769 299.43039894104,3791.21487379074 PathPoint;PointKind.SMOOTHPOINT 269.109420776367,3745.99988937378 266.988573074341,3739.01043891907 272.287073135376,3756.47273540497 PathPoint;PointKind.SMOOTHPOINT 264.109268188477,3554.00007247925 262.967805862427,3262.35833644867 264.031219482422,3534.02471780777 PathPoint;PointKind.SMOOTHPOINT 265.109424591064,1981.00007772446 265.753011703491,1355.58446645737 264.448843002319,2622.89702653885 PathPoint;PointKind.SMOOTHPOINT 265.109424591064,420.000071525574 265.263319015503,519.561738967896 265.56827545166,727.819368839264 PathPoint";
	
} else {

	mask645[0] = "PointKind.SMOOTHPOINT 273.775035858154,135.223467826843 280.011693954468,127.612538814545 261.703607559204,149.954846382141 PathPoint;PointKind.SMOOTHPOINT 292.283279418945,121.110735416412 298.165571212769,119.051099300385 286.400358200073,123.170135498047 PathPoint;PointKind.SMOOTHPOINT 347.807065963745,119.094529628754 365.500833511353,118.881862640381 330.113298416138,119.307196617126 PathPoint;PointKind.SMOOTHPOINT 942.011692047119,119.094529628754 977.44454574585,119.011917591095 906.578523635864,119.177141666412 PathPoint;PointKind.SMOOTHPOINT 1493.35530471802,120.102632522583 1505.02956581116,119.88996553421 1481.6813583374,120.315299510956 PathPoint;PointKind.SMOOTHPOINT 1535.24196815491,124.134808063507 1541.79270935059,124.167380809784 1524.18422889709,124.079812049866 PathPoint;PointKind.SMOOTHPOINT 1544.9832649231,122.118602275848 1548.40261650085,121.527336120605 1540.01238059998,122.978239536285 PathPoint;PointKind.SMOOTHPOINT 1563.49087905884,121.110735416412 1567.41880607605,121.049838542938 1558.08946800232,121.194055557251 PathPoint;PointKind.SMOOTHPOINT 1580.05073738098,123.126705169678 1584.03468322754,124.217420101166 1574.45042800903,121.593425750732 PathPoint;PointKind.SMOOTHPOINT 1605.37754249573,125.142910957336 1620.85290145874,125.095704078674 1594.488489151,125.176191806793 PathPoint;PointKind.SMOOTHPOINT 1857.67092895508,126.151013851166 1868.88445091248,126.651170730591 1846.45740699768,125.650856971741 PathPoint;PointKind.CORNERPOINT 1889.81629562378,126.151013851166 1889.81629562378,126.151013851166 1889.81629562378,126.151013851166 PathPoint;PointKind.SMOOTHPOINT 1895.6611366272,127.159116744995 1897.16892433167,127.28563117981 1889.81440734863,126.668401241302 PathPoint;PointKind.SMOOTHPOINT 1903.47104263306,124.984531879425 1908.29778862,124.785082817078 1897.33666610718,125.238032817841 PathPoint;PointKind.SMOOTHPOINT 1916.11745071411,126.151013851166 1927.74544906616,127.222137928009 1904.48882293701,125.079889774323 PathPoint;PointKind.SMOOTHPOINT 1970.66720199585,126.151013851166 1979.61699676514,126.0721783638 1961.71740722656,126.229613304138 PathPoint;PointKind.SMOOTHPOINT 2015.47597122192,126.151013851166 2029.39507675171,126.028984069824 2001.55686569214,126.273043632507 PathPoint;PointKind.SMOOTHPOINT 2065.15554618835,126.151013851166 1879.62433052063,125.987678050995 2050.89088630676,126.138267993927 PathPoint;PointKind.SMOOTHPOINT 2561.94909286499,127.159116744995 2582.86111068726,126.93984079361 2428.66519165039,128.555968284607 PathPoint;PointKind.SMOOTHPOINT 2612.60301780701,126.151013851166 2620.4906578064,125.745270729065 2604.71474838257,126.556520938873 PathPoint;PointKind.SMOOTHPOINT 2640.85192871094,127.159116744995 2650.57402801514,126.828196525574 2631.12982940674,127.489800930023 PathPoint;PointKind.SMOOTHPOINT 2698.32410049438,127.159116744995 2705.85454177856,127.064466953278 2690.79365921021,127.253530502319 PathPoint;PointKind.SMOOTHPOINT 2716.83202934265,127.159116744995 2725.87309074402,127.52520608902 2707.79128265381,126.792791366577 PathPoint;PointKind.SMOOTHPOINT 2758.71869277954,128.166983604431 2777.01356124878,128.686967372894 2740.4238243103,127.647235870361 PathPoint;PointKind.SMOOTHPOINT 2799.63132095337,128.166983604431 2807.19952774048,128.013561248779 2792.06279945374,128.320641994476 PathPoint;PointKind.SMOOTHPOINT 2821.06135559082,126.151013851166 2835.10319900513,125.825758457184 2810.55625152588,126.394365310669 PathPoint;PointKind.SMOOTHPOINT 2853.20703697205,127.159116744995 2858.24841690063,127.367771148682 2848.16502761841,126.950226306915 PathPoint;PointKind.SMOOTHPOINT 2866.01646614075,126.747000694275 2872.39505958557,126.219699859619 2858.99019432068,127.327881336212 PathPoint;PointKind.SMOOTHPOINT 2882.42998313904,128.166983604431 2885.03926467896,128.391216278076 2878.77145004272,127.852821826935 PathPoint;PointKind.SMOOTHPOINT 2899.96387672424,127.159116744995 2902.89101791382,126.604907989502 2892.92344284058,128.49200296402 PathPoint;PointKind.SMOOTHPOINT 2906.78275299072,124.134808063507 2914.70784378052,123.407822132111 2903.01029396057,124.4808344841 PathPoint;PointKind.SMOOTHPOINT 2918.47212028503,128.166983604431 2925.78540992737,128.336456298828 2911.15851593018,127.997746944427 PathPoint;PointKind.SMOOTHPOINT 2954.51394271851,127.159116744995 2964.60866165161,127.509391784668 2944.41890907288,126.808605670929 PathPoint;PointKind.SMOOTHPOINT 2983.7368888855,127.159116744995 3000.43018531799,126.981854915619 2967.04422187805,127.336142539978 PathPoint;PointKind.SMOOTHPOINT 3556.5111656189,128.166983604431 3589.0562171936,129.120090484619 3523.96611404419,127.214112758636 PathPoint;PointKind.SMOOTHPOINT 3657.81807136536,128.166983604431 3662.44151306152,128.442671775818 3639.82627105713,127.094679355621 PathPoint;PointKind.SMOOTHPOINT 3673.40389442444,130.18318939209 3678.20042800903,130.604510784149 3668.60704612732,129.761868000031 PathPoint;PointKind.SMOOTHPOINT 3698.73069953918,131.191292285919 3703.02652549744,129.907501220703 3695.95336151123,132.021189212799 PathPoint;PointKind.SMOOTHPOINT 3716.26459312439,128.166983604431 3720.19440841675,128.155889987946 3710.95948410034,128.182089805603 PathPoint;PointKind.SMOOTHPOINT 3726.97961044312,130.18318939209 3730.55411529541,130.208917140961 3719.87780761719,130.131969928741 PathPoint;PointKind.SMOOTHPOINT 3739.64301300049,129.17508649826 3740.90501022339,129.150302886963 3731.82901573181,129.329216957092 PathPoint;PointKind.SMOOTHPOINT 3746.46157455444,130.18318939209 3748.35582923889,129.490664482117 3744.31806755066,130.967295646667 PathPoint;PointKind.SMOOTHPOINT 3750.35803031921,130.18318939209 3757.09036064148,130.263441085815 3749.5186920166,130.173275947571 PathPoint;PointKind.SMOOTHPOINT 3768.86627388,129.17508649826 3785.69269371033,128.194599628448 3763.44818305969,129.49090051651 PathPoint;PointKind.SMOOTHPOINT 3790.29662322998,126.151013851166 3791.70118522644,126.151485919952 3778.91567420959,126.147001266479 PathPoint;PointKind.SMOOTHPOINT 3797.11518478394,126.151013851166 3804.36553192139,126.654947280884 3796.09457206726,126.079967498779 PathPoint;PointKind.SMOOTHPOINT 3806.85648155212,127.159116744995 3812.68967819214,127.564623832703 3801.74303245544,126.803412914276 PathPoint;PointKind.SMOOTHPOINT 3818.54553413391,123.126705169678 3822.42593955994,123.24165391922 3816.67960357666,123.071473121643 PathPoint;PointKind.SMOOTHPOINT 3826.33844566345,124.134808063507 3827.47109603882,125.101368904114 3824.70760536194,122.742913246155 PathPoint;PointKind.SMOOTHPOINT 3832.18297195435,126.151013851166 3837.95920562744,126.397433757782 3828.29375457764,125.985081672668 PathPoint;PointKind.SMOOTHPOINT 3840.94991874695,123.126705169678 3848.3343334198,123.694603919983 3839.81065940857,123.03913640976 PathPoint;PointKind.SMOOTHPOINT 3862.38026809692,126.151013851166 3870.41299057007,125.682485580444 3854.3478603363,126.619542121887 PathPoint;PointKind.SMOOTHPOINT 3881.86254692078,126.151013851166 3893.2929058075,127.088070392609 3870.43187332153,125.21372127533 PathPoint;PointKind.SMOOTHPOINT 3906.21500205994,127.159116744995 3913.22805595398,127.190509319305 3899.20226287842,127.127488136292 PathPoint;PointKind.SMOOTHPOINT 3922.77486038208,124.134808063507 3933.80805206299,123.163998603821 3907.49084663391,125.479496002197 PathPoint;PointKind.SMOOTHPOINT 3937.38633346558,127.159116744995 3947.51913261414,126.808369636536 3930.85541915894,127.385001659393 PathPoint;PointKind.CORNERPOINT 3955.89457702637,126.151013851166 3955.89457702637,126.151013851166 3955.89457702637,126.151013851166 PathPoint;PointKind.SMOOTHPOINT 3966.60990905762,124.134808063507 3974.10573196411,123.469427108765 3959.11345672607,124.800425052643 PathPoint;PointKind.SMOOTHPOINT 3980.24703216553,125.142910957336 3988.0081577301,125.092635631561 3969.90117263794,125.209944725037 PathPoint;PointKind.SMOOTHPOINT 3993.88478469849,124.134808063507 3995.53010177612,123.824658870697 3988.94411277771,125.06619977951 PathPoint;PointKind.SMOOTHPOINT 3999.72931098938,122.118602275848 4007.8262348175,121.704361915588 3996.38360214233,122.289963245392 PathPoint;PointKind.SMOOTHPOINT 4013.36674880981,124.134808063507 4016.08617973328,124.570527553558 4009.20687866211,123.468482971191 PathPoint;PointKind.SMOOTHPOINT 4026.03015136719,124.134808063507 4038.35083198547,124.86722278595 4021.15934562683,123.845193862915 PathPoint;PointKind.SMOOTHPOINT 4059.14986801147,125.142910957336 4066.73443984985,125.225286960602 4041.04508590698,124.946058273315 PathPoint;PointKind.SMOOTHPOINT 4082.52828788757,124.134808063507 4084.77879714966,123.874462127686 4074.79957771301,125.028906345367 PathPoint;PointKind.SMOOTHPOINT 4089.34684944153,122.118602275848 4093.88154220581,121.991143703461 4087.2285194397,122.178318977356 PathPoint;PointKind.SMOOTHPOINT 4102.01056671143,124.134808063507 4104.99467086792,124.601920127869 4098.0747718811,123.51899433136 PathPoint;PointKind.SMOOTHPOINT 4110.7771987915,124.134808063507 4125.95956039429,123.800111293793 4107.77169418335,124.201133728027 PathPoint;PointKind.SMOOTHPOINT 4153.63789749146,127.159116744995 4162.67675590515,126.998141288757 4139.26592063904,127.414978027344 PathPoint;PointKind.SMOOTHPOINT 4177.99129676819,125.97375202179 4178.85549736023,125.915687561035 4170.37903022766,126.4850025177 PathPoint;PointKind.SMOOTHPOINT 4180.58263969421,125.800030708313 4181.02732849121,125.207584381104 4179.40970611572,127.361162185669 PathPoint;PointKind.SMOOTHPOINT 4183.83519363403,125.142910957336 4186.74471092224,124.954083442688 4183.10946655273,125.190117835999 PathPoint;PointKind.SMOOTHPOINT 4191.62810516357,125.142910957336 4204.25342750549,124.528513431549 4188.59994125366,125.290196418762 PathPoint;PointKind.SMOOTHPOINT 4215.98056030273,126.151013851166 4222.65403938293,126.201053142548 4205.98875236511,126.076190948486 PathPoint;PointKind.SMOOTHPOINT 4235.46283912659,124.134808063507 4237.45433998108,123.72434425354 4229.58526802063,125.346608638763 PathPoint;PointKind.SMOOTHPOINT 4239.39328384399,122.296808242798 4240.59359741211,122.201922416687 4236.82711791992,122.499797821045 PathPoint;PointKind.SMOOTHPOINT 4243.25575065613,122.118602275848 4247.38981437683,122.056289196014 4241.87542152405,122.139609336853 PathPoint;PointKind.SMOOTHPOINT 4254.94480323792,122.118602275848 4256.8872089386,122.484219551086 4251.27777290344,121.428437709808 PathPoint;PointKind.SMOOTHPOINT 4259.81529426575,124.134808063507 4265.58366012573,125.76698589325 4257.9352016449,123.602786540985 PathPoint;PointKind.SMOOTHPOINT 4274.42708206177,124.134808063507 4286.61841583252,124.130795478821 4268.14762306213,124.136932373047 PathPoint;PointKind.SMOOTHPOINT 4290.98694038391,123.126705169678 4301.49645042419,122.847240447998 4280.4771156311,123.406405925751 PathPoint;PointKind.SMOOTHPOINT 4306.57244873047,127.159116744995 4308.85411453247,127.077920913696 4297.48984527588,127.482011795044 PathPoint;PointKind.SMOOTHPOINT 4310.46921920776,125.142910957336 4311.38094139099,124.985003948212 4308.94223403931,125.407033443451 PathPoint;PointKind.SMOOTHPOINT 4315.3397102356,126.151013851166 4316.16110992432,126.085868358612 4314.13467597961,126.246607780457 PathPoint;PointKind.SMOOTHPOINT 4318.26181602478,124.134808063507 4319.05394744873,124.045587062836 4317.2695274353,124.246688365936 PathPoint;PointKind.SMOOTHPOINT 4322.15827178955,126.151013851166 4322.83868026733,126.130950927734 4321.19147491455,126.179337978363 PathPoint;PointKind.SMOOTHPOINT 4324.10634231567,124.134808063507 4325.19052696228,124.03307723999 4323.35166168213,124.2056183815 PathPoint;PointKind.SMOOTHPOINT 4330.92521858215,124.134808063507 4332.30114173889,124.568639278412 4329.03096389771,123.537641048431 PathPoint;PointKind.SMOOTHPOINT 4332.87328910828,126.151013851166 4334.91923522949,126.181934356689 4331.70381736755,126.133311271667 PathPoint;PointKind.SMOOTHPOINT 4338.71813011169,124.134808063507 4341.15211677551,123.624737739563 4336.39681053162,124.62127494812 PathPoint;PointKind.SMOOTHPOINT 4348.45911216736,124.134808063507 4351.85580444336,124.091377735138 4344.47138977051,124.186027526855 PathPoint;PointKind.SMOOTHPOINT 4358.20040893555,122.118602275848 4368.8861579895,122.067854881287 4354.71339416504,122.135360717773 PathPoint;PointKind.SMOOTHPOINT 4381.57882881165,122.118602275848 4382.91258049011,122.166281223297 4370.76436233521,121.733158111572 PathPoint;PointKind.SMOOTHPOINT 4386.44931983948,124.134808063507 4409.24205970764,125.037875652313 4385.06741714478,124.080048084259 PathPoint;PointKind.SMOOTHPOINT 4446.84359741211,124.134808063507 4448.77813529968,124.158175468445 4433.18885040283,123.969347953796 PathPoint;PointKind.SMOOTHPOINT 4452.68843841553,122.118602275848 4453.40252113342,120.820177078247 4451.79339599609,123.746531486511 PathPoint;PointKind.SMOOTHPOINT 4457.55892944336,124.134808063507 4459.31282234192,125.38484621048 4456.18332099915,123.154557228088 PathPoint;PointKind.SMOOTHPOINT 4463.40345573425,122.118602275848 4466.3211555481,123.378317832947 4461.72949981689,121.395864963531 PathPoint;PointKind.SMOOTHPOINT 4471.68637466431,124.618206501007 4472.76048851013,124.494996547699 4468.38818740845,124.996097564697 PathPoint;PointKind.SMOOTHPOINT 4478.01524353027,122.118602275848 4483.27346038818,121.916792869568 4475.47582817078,122.216084480286 PathPoint;PointKind.SMOOTHPOINT 4493.60075187683,124.134808063507 4500.66478919983,124.440236568451 4489.79808044434,123.97029209137 PathPoint;PointKind.SMOOTHPOINT 4512.1086807251,123.126705169678 4515.57020378113,122.927728176117 4501.11608695984,123.759041309357 PathPoint;PointKind.SMOOTHPOINT 4526.72046852112,123.126705169678 4541.68001365662,123.196571350098 4520.46429824829,123.097436904907 PathPoint;PointKind.SMOOTHPOINT 4566.09415245056,122.93008852005 4567.36212921143,122.923243522644 4552.41202545166,123.003259181976 PathPoint;PointKind.SMOOTHPOINT 4571.52923774719,122.118602275848 4575.10877799988,122.106800556183 4570.20492744446,122.123086929321 PathPoint;PointKind.SMOOTHPOINT 4579.32214927673,122.118602275848 4580.01955223083,122.120962619781 4575.1761264801,122.10514831543 PathPoint;PointKind.SMOOTHPOINT 4581.27021980286,123.126705169678 4582.07053375244,123.146532058716 4580.5101890564,123.108058452606 PathPoint;PointKind.SMOOTHPOINT 4583.2186050415,122.118602275848 4586.27005767822,122.147162437439 4582.35314559937,122.110577106476 PathPoint;PointKind.SMOOTHPOINT 4592.95958709717,122.118602275848 4596.71473693848,122.353692531586 4589.29948043823,121.889648914337 PathPoint;PointKind.SMOOTHPOINT 4604.64895439148,123.126705169678 4643.22138023376,123.68587064743 4601.10592079163,123.075485706329 PathPoint;PointKind.SMOOTHPOINT 4654.32821464539,124.134808063507 4669.79602050781,124.481306552887 4638.86040878296,123.788309574127 PathPoint;PointKind.SMOOTHPOINT 4684.52582550049,123.126705169678 4697.88914871216,123.465414524078 4671.16218757629,122.78823184967 PathPoint;PointKind.SMOOTHPOINT 4712.77473640442,123.126705169678 4731.40445899963,122.725210666656 4694.14469909668,123.528435707092 PathPoint;PointKind.SMOOTHPOINT 4742.97171783447,124.134808063507 4763.49286270142,124.48933172226 4722.45088768005,123.780520439148 PathPoint;PointKind.SMOOTHPOINT 4786.80676651001,124.134808063507 4821.0943813324,123.24094581604 4752.5188369751,125.028670310974 PathPoint;PointKind.SMOOTHPOINT 4853.04588508606,124.134808063507 4874.69653320312,124.013014316559 4828.55999183655,124.2726521492 PathPoint;PointKind.SMOOTHPOINT 4893.67023658752,123.894289016724 4895.53239059448,123.955185890198 4879.44963645935,123.427885055542 PathPoint;PointKind.SMOOTHPOINT 4899.80303955078,126.151013851166 4906.37423706055,126.304436206818 4897.55536270142,126.098378181458 PathPoint;PointKind.SMOOTHPOINT 4908.56967163086,129.17508649826 4909.53678321838,128.851955413818 4906.38871383667,129.904196739197 PathPoint;PointKind.SMOOTHPOINT 4912.46612739563,126.151013851166 4917.13614654541,124.619622707367 4910.15928459167,126.907504081726 PathPoint;PointKind.SMOOTHPOINT 4932.92244148254,124.134808063507 4947.23745536804,124.327884197235 4925.25415611267,124.031424999237 PathPoint;PointKind.SMOOTHPOINT 4978.70524597168,132.199395179749 4996.93748664856,138.014810562134 4958.17182731628,125.649912834167 PathPoint;PointKind.SMOOTHPOINT 5000.13559532166,147.320466518402 5006.95887756348,155.140049934387 4994.64291763306,141.024957180023 PathPoint;PointKind.SMOOTHPOINT 5011.82527732849,173.529961585999 5014.76721000671,190.81759262085 5010.22748184204,164.143817901611 PathPoint;PointKind.SMOOTHPOINT 5016.69576835632,221.917248249054 5016.50379371643,226.484041690826 5017.13699531555,211.39554309845 PathPoint;PointKind.SMOOTHPOINT 5016.69576835632,234.014010906219 5015.69309425354,236.872859477997 5017.46429634094,231.821487426758 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,254.175360679626 5013.45076751709,273.408387184143 5013.89986228943,246.617303371429 PathPoint;PointKind.SMOOTHPOINT 5015.72141838074,395.304573059082 5015.66067886353,413.016593933105 5015.78247261047,377.592552185059 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,909.418166160583 5015.15052986145,926.830895423889 5012.39585113525,892.005436897278 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,967.886009693146 5013.91780090332,980.455313205719 5013.62858009338,955.316706180573 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,1058.61196565628 5014.67499923706,1072.185359478 5014.81976699829,1045.03857183456 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,1234.01549625397 5014.02826499939,1241.13098907471 5013.51811599731,1226.90000343323 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,1254.17684602737 5014.7322769165,1266.63190889359 5014.76248931885,1241.72154712677 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,1298.53172111511 5013.33180618286,1331.48283052444 5014.21488952637,1265.58061170578 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,1521.31419944763 5015.05926322937,1535.19868659973 5014.43550300598,1507.42971229553 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,1584.82232141495 5013.78562164307,1594.37486934662 5013.74659729004,1564.38551950455 PathPoint;PointKind.SMOOTHPOINT 5014.75745391846,1624.85163021088 5014.78986930847,1625.99427270889 5014.33353614807,1610.0666718483 PathPoint;PointKind.SMOOTHPOINT 5014.85312652588,1628.25996685028 5014.46288299561,1630.07554340363 5015.08979034424,1627.15792226791 PathPoint;PointKind.SMOOTHPOINT 5014.94596672058,1631.75398397446 5015.30757141113,1645.81455278397 5014.91638374329,1630.60119199753 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,1661.43530893326 5013.2175655365,1669.07456207275 5015.44919204712,1657.9301981926 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,1679.5806889534 5014.36689567566,1687.09389972687 5015.12787055969,1672.06724214554 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,1695.70962715149 5015.21536064148,1702.17932987213 5014.27940559387,1689.23992443085 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,1716.87907981873 5014.964220047,1728.2946472168 5014.53054618835,1705.46351242065 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,1768.29043912888 5013.89105033875,1790.01905727386 5015.60340118408,1746.56182098389 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,1842.88722085953 5014.94502258301,1858.34700155258 5014.54942893982,1827.42767620087 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,1876.15343618393 5015.48192214966,1900.95356988907 5012.06477355957,1851.35353851318 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,1948.73424816132 5015.09356689453,1966.37923526764 5014.40119934082,1931.0890250206 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,1998.12940168381 5014.79647827148,2002.91358280182 5014.61425971985,1985.22540140152 PathPoint;PointKind.SMOOTHPOINT 5014.16359138489,2012.060151577 5013.55588150024,2019.68595075607 5014.5220489502,2007.56700086594 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,2034.4199256897 5013.91780090332,2044.84698104858 5013.68239593506,2027.85864162445 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,2088.85535764694 5015.05926322937,2115.57704734802 5014.43550300598,2062.13366794586 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,2217.88780736923 5013.77712440491,2249.14961862564 5015.71764183044,2186.62599611282 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,2298.53320646286 5014.13872909546,2313.93374252319 5015.35635185242,2283.13243436813 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,2374.13809108734 5013.73463821411,2375.42919921875 5014.30615615845,2356.27241182327 PathPoint;PointKind.SMOOTHPOINT 5012.79931259155,2379.17836952209 5012.75304985046,2384.94256544113 5012.86256980896,2371.26909303665 PathPoint;PointKind.SMOOTHPOINT 5013.54423713684,2384.68646812439 5014.11764335632,2408.72751522064 5013.52315139771,2383.8180975914 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,2469.90432548523 5014.73983001709,2489.2308216095 5012.95226287842,2453.4838848114 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,2547.52541589737 5014.12330818176,2571.0061173439 5013.42307281494,2524.04447841644 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,2617.08191919327 5015.42086791992,2639.05459690094 5014.07389831543,2595.1092414856 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,2691.67870092392 5013.50300979614,2724.92532539368 5014.04337120056,2658.43231248856 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,2755.18705892563 5014.12739944458,2771.35140228271 5013.41929626465,2739.02247953415 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,2816.67897510529 5014.55698204041,2844.45975112915 5014.93746948242,2788.89819908142 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,2888.25168418884 5014.7231502533,2905.23695516586 5014.77161598206,2871.18073272705 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,2936.6387348175 5013.22858047485,2947.27916526794 5014.29325294495,2926.47934246063 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,2979.98574304581 5014.38955497742,2992.61405515671 5015.10521125793,2967.35719490051 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3012.24385547638 5014.18656539917,3019.89066171646 5013.19490623474,3001.54890108109 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,3056.59873056412 5014.85690307617,3063.42980194092 5014.47263908386,3039.46121740341 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,3074.74387454987 5015.26414108276,3092.43866491318 5014.58750915527,3069.26244783401 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3092.88901853561 5013.68963432312,3102.28460359573 5013.85706138611,3083.49366950989 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3130.18740940094 5014.11197853088,3143.81603527069 5013.43440246582,3116.55901956558 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3181.59876871109 5013.48790359497,3194.07672691345 5014.04022407532,3169.9228553772 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3211.8409113884 5013.86461448669,3220.29613542557 5013.66666030884,3201.96499633789 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3252.16337490082 5013.87437057495,3254.41585111618 5013.17161750793,3238.75780153275 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,3260.22796201706 5014.93211936951,3262.49129581451 5014.60355949402,3258.46407699585 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3265.26824045181 5013.74565315247,3272.74746227264 5013.7796421051,3263.57540178299 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3289.46200180054 5014.16516494751,3304.7837023735 5013.45391464233,3276.96822929382 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3326.76039266586 5014.30993270874,3336.68752717972 5013.23676300049,3316.83325815201 PathPoint;PointKind.SMOOTHPOINT 5012.79931259155,3343.89743375778 5014.05123901367,3353.08035182953 5011.54738616943,3334.71451568604 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3372.12337064743 5013.69278144836,3383.8247756958 5013.84982299805,3361.01417589188 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,3390.26851463318 5015.79002571106,3395.67889499664 5013.70474052429,3384.85813426971 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,3407.4055557251 5014.45060920715,3412.85936641693 5015.0441570282,3401.95174503326 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,3427.5669054985 5013.26729011536,3440.85682201385 5016.22779083252,3414.27698898315 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3445.71204948425 5013.64022445679,3463.16041994095 5013.90647125244,3428.26391506195 PathPoint;PointKind.SMOOTHPOINT 5014.74738311768,3491.07502746582 5014.35178947449,3510.30309724808 5015.14297676086,3471.84695768356 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3567.68801498413 5013.93699836731,3598.11922121048 5013.60969734192,3537.25704479218 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3626.15585851669 5013.31669998169,3638.77260494232 5014.22999572754,3613.53934812546 PathPoint;PointKind.SMOOTHPOINT 5011.82527732849,3652.36558961868 5011.46146965027,3669.74220561981 5012.1683139801,3635.97087669373 PathPoint;PointKind.SMOOTHPOINT 5010.85092735291,3693.69639205933 5010.69514465332,3716.72839212418 5011.00702476501,3670.66439199448 PathPoint;PointKind.SMOOTHPOINT 5016.69576835632,3776.35776090622 5017.14454841614,3792.98685598373 5016.24667358398,3759.7286658287 PathPoint;PointKind.SMOOTHPOINT 5013.77334785461,3807.60777044296 5011.07091140747,3813.89643478394 5017.56846618652,3798.77701568604 PathPoint;PointKind.SMOOTHPOINT 5002.22528648376,3821.94709587097 5001.51812744141,3822.45032119751 5007.09672164917,3818.48093080521 PathPoint;PointKind.SMOOTHPOINT 5000.04747581482,3823.38808584213 4998.73323631287,3823.37227153778 5001.38815116882,3823.40413618088 PathPoint;PointKind.SMOOTHPOINT 4996.54000473022,3825.32899665833 4992.85062980652,3827.16510820389 4997.7475566864,3824.72805309296 PathPoint;PointKind.SMOOTHPOINT 4984.55040168762,3829.78532600403 4979.43065834045,3831.21852684021 4988.81601524353,3828.59099197388 PathPoint;PointKind.SMOOTHPOINT 4967.99022865295,3833.81750154495 4949.84012794495,3835.98335313797 4973.14270210266,3833.20263195038 PathPoint;PointKind.SMOOTHPOINT 4793.62532806396,3835.83370733261 4779.34493255615,3837.7040438652 4807.9060382843,3833.96313476562 PathPoint;PointKind.SMOOTHPOINT 4641.66512680054,3835.83370733261 4619.45806694031,3837.44416999817 4663.87155723572,3834.22300863266 PathPoint;PointKind.SMOOTHPOINT 4478.98927879333,3835.83370733261 4450.24563980103,3836.60553979874 4507.73323249817,3835.06187486649 PathPoint;PointKind.SMOOTHPOINT 4394.24191665649,3835.83370733261 4380.04523468018,3836.75117301941 4408.43891334534,3834.91624164581 PathPoint;PointKind.SMOOTHPOINT 4360.14847946167,3835.83370733261 4351.35257911682,3835.68335342407 4370.06444168091,3836.00294399261 PathPoint;PointKind.SMOOTHPOINT 4328.00279808044,3835.83370733261 4326.74143028259,3835.79806613922 4337.90365409851,3836.11388015747 PathPoint;PointKind.SMOOTHPOINT 4320.21020126343,3835.83370733261 4310.98629188538,3836.27461957932 4321.25221443176,3835.78390407562 PathPoint;PointKind.SMOOTHPOINT 4293.90936088562,3835.83370733261 4287.89488983154,3836.07729482651 4304.28637695312,3835.41333007812 PathPoint;PointKind.SMOOTHPOINT 4270.19451332092,3836.04755449295 4269.03322410583,3836.04070949554 4279.87664413452,3836.10373067856 PathPoint;PointKind.SMOOTHPOINT 4266.63952064514,3836.02395105362 4265.71615409851,3835.39444732666 4268.24958992004,3837.1219830513 PathPoint;PointKind.SMOOTHPOINT 4263.26454353333,3835.99751520157 4257.6812286377,3835.95078039169 4264.40883827209,3836.0069565773 PathPoint;PointKind.SMOOTHPOINT 4245.20413589478,3835.83370733261 4224.27323532104,3835.65266895294 4251.64346885681,3835.88941144943 PathPoint;PointKind.SMOOTHPOINT 4197.47294616699,3835.83370733261 4176.34692382812,3835.09728002548 4218.59865379333,3836.57013463974 PathPoint;PointKind.SMOOTHPOINT 4156.56031799316,3835.83370733261 4149.24545478821,3836.10703516006 4175.30805778503,3835.13268518448 PathPoint;PointKind.SMOOTHPOINT 4140.00045967102,3835.83370733261 4135.14003944397,3836.13842773438 4143.11013412476,3835.63874292374 PathPoint;PointKind.SMOOTHPOINT 4126.36302185059,3836.84181022644 4112.61165809631,3836.55432033539 4134.74916648865,3837.01694774628 PathPoint;PointKind.SMOOTHPOINT 4098.11379623413,3835.83370733261 4079.01231956482,3835.64063119888 4117.21558761597,3836.02654743195 PathPoint;PointKind.SMOOTHPOINT 4051.35664176941,3835.83370733261 4019.22575187683,3836.27934026718 4083.47525787354,3835.38807439804 PathPoint;PointKind.SMOOTHPOINT 3960.76475334167,3835.83370733261 3903.22617721558,3836.01923036575 4018.40246391296,3835.64771223068 PathPoint;PointKind.SMOOTHPOINT 3856.53574180603,3835.83370733261 3832.89453697205,3835.30994701385 3880.17694664001,3836.35746765137 PathPoint;PointKind.SMOOTHPOINT 3799.06357002258,3835.83370733261 3784.19308853149,3835.85731077194 3813.93405151367,3835.81010389328 PathPoint;PointKind.SMOOTHPOINT 3773.73676490784,3835.83370733261 3758.94999694824,3835.84952163696 3788.52321815491,3835.81789302826 PathPoint;PointKind.SMOOTHPOINT 3746.46157455444,3836.84181022644 3733.82114601135,3836.6211180687 3759.10263252258,3837.06226634979 PathPoint;PointKind.SMOOTHPOINT 3713.34217262268,3836.84181022644 3702.93935012817,3837.4323682785 3723.74530982971,3836.25101613998 PathPoint;PointKind.SMOOTHPOINT 3670.48147392273,3836.84181022644 3636.57969665527,3836.94330501556 3704.30268478394,3836.74031543732 PathPoint;PointKind.SMOOTHPOINT 3564.30376243591,3836.84181022644 3541.09969329834,3836.44668865204 3588.59296035767,3837.25510644913 PathPoint;PointKind.SMOOTHPOINT 3473.71250343323,3836.84181022644 3437.86391448975,3836.92253398895 3509.39114761353,3836.76132249832 PathPoint;PointKind.SMOOTHPOINT 3328.57023429871,3836.84181022644 3310.92619132996,3836.9598274231 3346.2149066925,3836.72355699539 PathPoint;PointKind.SMOOTHPOINT 3262.33111572266,3836.84181022644 3242.52310943604,3836.55408430099 3292.98537445068,3837.28673505783 PathPoint;PointKind.SMOOTHPOINT 3190.24747085571,3836.84181022644 3188.51466369629,3836.85479211807 3201.57995414734,3836.75589370728 PathPoint;PointKind.SMOOTHPOINT 3184.40294456482,3836.84181022644 3183.68036460876,3837.32686090469 3186.12882804871,3835.6824092865 PathPoint;PointKind.SMOOTHPOINT 3178.71766281128,3836.91899347305 3170.19713592529,3837.53339099884 3180.1823348999,3836.81348609924 PathPoint;PointKind.SMOOTHPOINT 3153.23161315918,3836.84181022644 3115.94604682922,3836.52717638016 3161.63412284851,3836.91262054443 PathPoint;PointKind.SMOOTHPOINT 3070.43232154846,3836.84181022644 3052.26679992676,3836.94401311874 3088.59784317017,3836.73937129974 PathPoint;PointKind.SMOOTHPOINT 3026.59758758545,3836.84181022644 2998.47047042847,3837.02284860611 3054.72501945496,3836.66053581238 PathPoint;PointKind.SMOOTHPOINT 2922.3685760498,3836.84181022644 2919.61515617371,3836.91710519791 2956.8960018158,3835.89672851562 PathPoint;PointKind.SMOOTHPOINT 2914.10548400879,3837.02190446854 2913.53994560242,3837.03134584427 2916.86268043518,3836.97634983063 PathPoint;PointKind.SMOOTHPOINT 2911.65324401855,3836.84181022644 2910.82397651672,3836.8538479805 2912.2197265625,3836.83354902267 PathPoint;PointKind.SMOOTHPOINT 2909.70485877991,3835.83370733261 2908.56591415405,3836.5786318779 2911.25985336304,3834.81663513184 PathPoint;PointKind.SMOOTHPOINT 2905.86914253235,3837.11985874176 2905.30045700073,3837.12410736084 2907.22083282471,3837.10970926285 PathPoint;PointKind.SMOOTHPOINT 2904.16214179993,3837.13118839264 2875.44965934753,3837.29995298386 2904.73177146912,3837.12788391113 PathPoint;PointKind.SMOOTHPOINT 2808.39795303345,3836.84181022644 2763.36479377747,3837.47957515717 2845.5365486145,3836.31568956375 PathPoint;PointKind.SMOOTHPOINT 2607.73221206665,3835.83370733261 2561.91888046265,3835.62505292892 2653.54585838318,3836.0423617363 PathPoint;PointKind.SMOOTHPOINT 2465.51267814636,3835.83370733261 2424.0826625824,3837.58201408386 2506.94269371033,3834.08540058136 PathPoint;PointKind.SMOOTHPOINT 2382.71401596069,3834.82560443878 2337.56630134583,3835.55023002625 2427.86141586304,3834.10097885132 PathPoint;PointKind.SMOOTHPOINT 2281.40679550171,3835.83370733261 2234.34153747559,3836.13677549362 2328.47205352783,3835.53040313721 PathPoint;PointKind.SMOOTHPOINT 2193.73732757568,3835.83370733261 2163.47960662842,3835.38335371017 2254.3298740387,3836.73535871506 PathPoint;PointKind.SMOOTHPOINT 2120.67933273315,3835.83370733261 2100.62301826477,3835.5589632988 2140.68466377258,3836.10750722885 PathPoint;PointKind.SMOOTHPOINT 2063.20716094971,3835.83370733261 2024.86541938782,3835.57619380951 2084.15631484985,3835.97438383102 PathPoint;PointKind.SMOOTHPOINT 1982.35625457764,3835.83370733261 1927.89776992798,3835.50278711319 2036.81505393982,3836.16439151764 PathPoint;PointKind.SMOOTHPOINT 1849.87801742554,3834.82560443878 1802.2698802948,3835.11002588272 1899.5786781311,3834.528673172 PathPoint;PointKind.SMOOTHPOINT 1722.27027130127,3833.81750154495 1676.34490203857,3834.27611637115 1770.61703872681,3833.33481121063 PathPoint;PointKind.SMOOTHPOINT 1622.91143608093,3832.80939865112 1581.19597625732,3833.5654168129 1664.62658119202,3832.05338048935 PathPoint;PointKind.SMOOTHPOINT 1478.74383163452,3831.80129575729 1445.5101890564,3832.47871446609 1511.97778892517,3831.12411308289 PathPoint;PointKind.SMOOTHPOINT 1359.90303230286,3831.80129575729 1311.17483329773,3831.51404190063 1408.63091659546,3832.08878564835 PathPoint;PointKind.SMOOTHPOINT 1238.13949775696,3831.80129575729 1185.84434700012,3831.64810943604 1312.81637382507,3832.02033567429 PathPoint;PointKind.SMOOTHPOINT 1143.36980056763,3831.47627639771 1142.77090263367,3831.47840070724 1169.01226234436,3831.39130401611 PathPoint;PointKind.SMOOTHPOINT 1141.5583152771,3831.48288536072 1140.15406799316,3831.48831415176 1142.16728401184,3831.48052501678 PathPoint;PointKind.SMOOTHPOINT 1136.8325920105,3831.80129575729 1134.8694152832,3832.59932804108 1138.52763366699,3831.11254739761 PathPoint;PointKind.SMOOTHPOINT 1130.68594169617,3831.54189395905 1122.78476905823,3831.59594583511 1132.96162796021,3831.52631568909 PathPoint;PointKind.SMOOTHPOINT 1102.73915481567,3831.80129575729 1044.36124038696,3832.44708585739 1113.75472259521,3831.67950201035 PathPoint;PointKind.SMOOTHPOINT 997.535478591919,3831.80129575729 939.073850631714,3832.17942285538 1055.99710655212,3831.4234046936 PathPoint;PointKind.SMOOTHPOINT 867.979347229004,3831.80129575729 816.892063140869,3832.45511102676 919.066631317139,3831.14771652222 PathPoint;PointKind.SMOOTHPOINT 806.611034393311,3831.80129575729 796.228668212891,3831.83410453796 834.792282104492,3831.71231079102 PathPoint;PointKind.SMOOTHPOINT 779.336158752441,3831.80129575729 771.158039093018,3832.28186178207 784.231826782227,3831.51380586624 PathPoint;PointKind.SMOOTHPOINT 760.82791519165,3832.80939865112 755.290863037109,3833.51750183105 768.316184997559,3831.85204315186 PathPoint;PointKind.SMOOTHPOINT 739.397565841675,3830.79342889786 727.794744491577,3830.90365695953 757.519971847534,3830.62088775635 PathPoint;PointKind.SMOOTHPOINT 722.837707519531,3835.83370733261 716.905691146851,3835.95172452927 728.770038604736,3835.71545410156 PathPoint;PointKind.SMOOTHPOINT 705.303813934326,3833.81750154495 688.843090057373,3832.84102725983 721.764852523804,3834.79421186447 PathPoint;PointKind.SMOOTHPOINT 678.028938293457,3836.84181022644 666.320688247681,3836.19200754166 689.737188339233,3837.49137687683 PathPoint;PointKind.SMOOTHPOINT 659.520694732666,3833.81750154495 643.741008758545,3833.26234865189 675.300695419312,3834.37265443802 PathPoint;PointKind.SMOOTHPOINT 626.401292800903,3833.81750154495 607.269289016724,3836.11317205429 645.533296585083,3831.52183103561 PathPoint;PointKind.SMOOTHPOINT 594.255926132202,3837.84967708588 585.429498672485,3837.46140050888 605.08518409729,3838.32623052597 PathPoint;PointKind.SMOOTHPOINT 582.566558837891,3833.81750154495 581.016914367676,3833.54677009583 589.395191192627,3835.01089143753 PathPoint;PointKind.SMOOTHPOINT 573.799612045288,3833.81750154495 570.394737243652,3833.56683301926 576.402284622192,3834.00916147232 PathPoint;PointKind.SMOOTHPOINT 561.136209487915,3833.81750154495 556.235191345215,3834.30089998245 564.418975830078,3833.49389839172 PathPoint;PointKind.SMOOTHPOINT 546.524736404419,3837.84967708588 542.662269592285,3838.94298839569 550.041963577271,3836.85432004929 PathPoint;PointKind.SMOOTHPOINT 538.731824874878,3838.85777997971 536.713573455811,3839.12685918808 541.591302871704,3838.47658443451 PathPoint;PointKind.SMOOTHPOINT 533.861333847046,3837.84967708588 530.307600021362,3837.34975624084 535.243865966797,3838.04440546036 PathPoint;PointKind.SMOOTHPOINT 522.172281265259,3836.84181022644 514.25757598877,3836.81820678711 527.8704662323,3836.85880470276 PathPoint;PointKind.SMOOTHPOINT 509.508563995361,3837.84967708588 499.889375686646,3837.07808065414 519.128067016602,3838.621509552 PathPoint;PointKind.SMOOTHPOINT 490.026599884033,3836.84181022644 470.947782516479,3837.27092075348 509.105417251587,3836.41246366501 PathPoint;PointKind.SMOOTHPOINT 463.725759506226,3837.84967708588 453.052284240723,3838.09397268295 474.398920059204,3837.60561752319 PathPoint;PointKind.SMOOTHPOINT 449.113971710205,3836.84181022644 444.646942138672,3836.29444646835 453.581315994263,3837.38917398453 PathPoint;PointKind.SMOOTHPOINT 441.321374893188,3838.85777997971 435.659067153931,3839.20427846909 446.983367919922,3838.51128149033 PathPoint;PointKind.CORNERPOINT 436.450883865356,3837.84967708588 436.450883865356,3837.84967708588 436.450883865356,3837.84967708588 PathPoint;PointKind.SMOOTHPOINT 427.683937072754,3838.85777997971 426.991884231567,3840.10380554199 428.826028823853,3836.8009762764 PathPoint;PointKind.SMOOTHPOINT 404.305517196655,3840.87398576736 358.867952346802,3838.15510559082 413.399450302124,3841.41828107834 PathPoint;PointKind.SMOOTHPOINT 315.661699295044,3837.84967708588 302.631341934204,3836.88524055481 340.664665222168,3839.70042276382 PathPoint;PointKind.SMOOTHPOINT 288.386823654175,3830.79342889786 283.57172203064,3827.42474603653 293.626787185669,3834.45927906036 PathPoint;PointKind.SMOOTHPOINT 275.723421096802,3814.66425466537 268.364183425903,3794.70377016068 279.247257232666,3824.22270345688 PathPoint;PointKind.SMOOTHPOINT 264.033739089966,3752.16423559189 262.982284545898,3740.06747293472 265.042707443237,3763.76579809189 PathPoint;PointKind.CORNERPOINT 263.059703826904,3567.68801498413 263.059703826904,3567.68801498413 263.059703826904,3567.68801498413 PathPoint;PointKind.CORNERPOINT 263.059703826904,3116.07467699051 263.059703826904,3116.07467699051 263.059703826904,3116.07467699051 PathPoint;PointKind.CORNERPOINT 263.059703826904,2500.14623212814 263.059703826904,2500.14623212814 263.059703826904,2500.14623212814 PathPoint;PointKind.SMOOTHPOINT 264.033739089966,2489.05757236481 264.152070999146,2480.54404783249 263.916036605835,2497.57109689713 PathPoint;PointKind.SMOOTHPOINT 263.059703826904,2470.91242837906 262.717611312866,2455.14155435562 263.402425765991,2486.6830663681 PathPoint;PointKind.SMOOTHPOINT 264.033739089966,2445.7108001709 263.601009368896,2438.10199546814 264.245540618896,2449.42716169357 PathPoint;PointKind.SMOOTHPOINT 263.059703826904,2385.22675085068 262.893535614014,2358.45596599579 263.233425140381,2413.15882492065 PathPoint;PointKind.SMOOTHPOINT 267.930509567261,2110.02481031418 268.040658950806,2060.72005796432 267.820045471191,2159.32932662964 PathPoint;PointKind.SMOOTHPOINT 265.008403778076,2015.26644277573 264.441291809082,2001.05528402328 265.575201034546,2029.47783756256 PathPoint;PointKind.SMOOTHPOINT 266.956474304199,1967.88749504089 266.899196624756,1939.95683717728 267.013437271118,1995.81791687012 PathPoint;PointKind.SMOOTHPOINT 268.904544830322,1914.45992994308 267.45844078064,1897.18504476547 270.350648880005,1931.7348151207 PathPoint;PointKind.SMOOTHPOINT 266.956474304199,1881.19371461868 267.0364112854,1868.84887981415 266.876537322998,1893.53854942322 PathPoint;PointKind.SMOOTHPOINT 267.930509567261,1855.99208641052 264.441291809082,1843.22994279861 271.419727325439,1868.75446605682 PathPoint;PointKind.SMOOTHPOINT 267.930509567261,1821.71800422668 266.773626327515,1803.3481554985 269.087078094482,1840.08761692047 PathPoint;PointKind.SMOOTHPOINT 267.930509567261,1759.2177491188 270.148603439331,1729.31455183029 265.712100982666,1789.12118244171 PathPoint;PointKind.SMOOTHPOINT 267.930509567261,1658.41123628616 267.437984466553,1652.06049489975 269.286291122437,1675.89855241776 PathPoint;PointKind.SMOOTHPOINT 266.956474304199,1619.09663963318 267.355844497681,1597.5334815979 266.556789398193,1640.65979766846 PathPoint;PointKind.SMOOTHPOINT 266.956474304199,1514.25771522522 265.792037963867,1493.02146482468 268.120595932007,1535.49420166016 PathPoint;PointKind.SMOOTHPOINT 267.930509567261,1405.38661527634 268.368274688721,1378.94462633133 267.493059158325,1431.82860422134 PathPoint;PointKind.SMOOTHPOINT 267.930509567261,1315.66876220703 267.0364112854,1292.12881612778 268.824922561646,1339.20870828629 PathPoint;PointKind.SMOOTHPOINT 267.930509567261,1234.01549625397 267.938692092896,1230.71597146988 267.899982452393,1246.54538202286 PathPoint;PointKind.SMOOTHPOINT 267.989046096802,1226.17443370819 268.029644012451,1223.65972328186 267.955057144165,1228.31998634338 PathPoint;PointKind.SMOOTHPOINT 265.008403778076,1220.91063070297 265.07638168335,1219.02707624435 264.903604507446,1223.78930616379 PathPoint;PointKind.SMOOTHPOINT 265.982439041138,1206.79766225815 266.941997528076,1203.07421970367 265.125162124634,1210.12244272232 PathPoint;PointKind.SMOOTHPOINT 268.904544830322,1199.74117803574 269.696046829224,1177.49682474136 268.725473403931,1204.77130699158 PathPoint;PointKind.SMOOTHPOINT 266.956474304199,1164.45899295807 266.344987869263,1155.85577535629 268.12720489502,1180.94387102127 PathPoint;PointKind.SMOOTHPOINT 267.930509567261,1118.08791208267 268.530981063843,1097.51397418976 267.321226119995,1138.95830917358 PathPoint;PointKind.SMOOTHPOINT 268.904544830322,1083.81359386444 267.260801315308,1067.70589876175 270.33459854126,1097.82412338257 PathPoint;PointKind.SMOOTHPOINT 267.930509567261,1032.40223455429 267.062847137451,1012.60319757462 268.797857284546,1052.20127153397 PathPoint;PointKind.SMOOTHPOINT 268.904544830322,976.958699703217 268.965284347534,954.403253078461 268.84380531311,999.514146327972 PathPoint;PointKind.SMOOTHPOINT 269.878894805908,903.369784832001 270.76166343689,874.836767196655 268.995811462402,931.902802467346 PathPoint;PointKind.SMOOTHPOINT 269.878894805908,821.716518878937 270.772993087769,794.262414455414 268.984481811523,849.17062330246 PathPoint;PointKind.SMOOTHPOINT 270.85293006897,755.184088230133 272.333023071289,730.147920131683 269.372522354126,780.220492362976 PathPoint;PointKind.SMOOTHPOINT 270.85293006897,699.740553379059 270.289594650269,675.373542785645 271.415950775146,724.10732793808 PathPoint;PointKind.SMOOTHPOINT 271.826965332031,649.337296962738 271.454030990601,632.637155532837 272.199899673462,666.037202358246 PathPoint;PointKind.SMOOTHPOINT 271.826965332031,625.143535614014 272.459222793579,619.019623279572 271.194393157959,631.267683982849 PathPoint;PointKind.SMOOTHPOINT 271.826965332031,600.950010299683 270.909893035889,584.419341564178 272.744037628174,617.480679035187 PathPoint;PointKind.SMOOTHPOINT 272.801000595093,553.570826530457 272.211229324341,530.113728523254 273.390771865845,577.028160572052 PathPoint;PointKind.SMOOTHPOINT 272.801000595093,524.337022781372 270.080310821533,517.989349842072 275.521690368652,530.684695720673 PathPoint;PointKind.SMOOTHPOINT 269.878894805908,507.199981689453 266.400691986084,499.887400150299 273.356468200684,514.512327194214 PathPoint;PointKind.SMOOTHPOINT 268.904544830322,472.925663471222 269.195339202881,457.2706823349 268.603994369507,489.112194061279 PathPoint;PointKind.SMOOTHPOINT 268.904544830322,439.65944814682 267.780391693115,409.122498512268 269.300453186035,450.406330108643 PathPoint;PointKind.SMOOTHPOINT 269.878894805908,384.215913295746 269.587156295776,355.304060459137 270.222246170044,418.311789512634 PathPoint;PointKind.SMOOTHPOINT 269.878894805908,283.409164428711 269.601003646851,253.30510187149 270.156156539917,313.513463020325 PathPoint;PointKind.SMOOTHPOINT 270.85293006897,231.997805118561 269.133026123047,212.970600605011 272.572834014893,251.025245666504 PathPoint;PointKind.SMOOTHPOINT 264.803211212158,176.097071647644 263.057186126709,157.326908588409 266.551753997803,194.896266937256 PathPoint";
	
	mask645[1] = "PointKind.SMOOTHPOINT 273.775033950806,136.565251350403 277.335062026978,132.475011348724 261.271505355835,150.930068492889 PathPoint;PointKind.SMOOTHPOINT 296.000032424927,122.343471050262 301.88232421875,120.284070968628 290.117111206055,124.402635097504 PathPoint;PointKind.SMOOTHPOINT 347.807064056396,120.43820142746 356.429243087769,120.334582328796 330.113296508789,120.650868415833 PathPoint;PointKind.SMOOTHPOINT 627.450227737427,120.386745929718 629.18586730957,120.386981964111 489.334859848022,120.351576805115 PathPoint;PointKind.SMOOTHPOINT 632.999868392944,119.343709945679 634.757537841797,121.079978942871 631.764307022095,118.12317609787 PathPoint;PointKind.SMOOTHPOINT 638.684520721436,120.389578342438 780.456533432007,120.426399707794 636.675710678101,120.389106273651 PathPoint;PointKind.SMOOTHPOINT 942.011690139771,120.43820142746 977.444543838501,120.355589389801 924.312887191772,120.479507446289 PathPoint;PointKind.SMOOTHPOINT 1493.35530281067,121.446068286896 1505.02956390381,121.233401298523 1481.68135643005,121.658735275269 PathPoint;PointKind.SMOOTHPOINT 1535.24196624756,125.477771759033 1541.79270744324,125.51034450531 1524.18422698975,125.422775745392 PathPoint;PointKind.SMOOTHPOINT 1544.98326301575,123.461802005768 1548.40261459351,122.870771884918 1540.01237869263,124.321439266205 PathPoint;PointKind.SMOOTHPOINT 1563.49087715149,122.454171180725 1567.4188041687,122.393274307251 1558.08946609497,122.537491321564 PathPoint;PointKind.SMOOTHPOINT 1580.05073547363,124.469904899597 1584.03468132019,125.560383796692 1574.45042610168,122.936625480652 PathPoint;PointKind.SMOOTHPOINT 1605.37754058838,126.485874652863 1620.85289955139,126.4386677742 1594.48848724365,126.519155502319 PathPoint;PointKind.SMOOTHPOINT 1857.67092704773,127.493741512299 1868.88444900513,127.993898391724 1846.45740509033,126.993584632874 PathPoint;PointKind.CORNERPOINT 1882.99993515015,127.342915534973 1882.99993515015,127.342915534973 1882.99993515015,127.342915534973 PathPoint;PointKind.SMOOTHPOINT 1895.66113471985,128.501844406128 1897.16892242432,128.628358840942 1889.81440544128,128.011128902435 PathPoint;PointKind.SMOOTHPOINT 1906.99991226196,125.342996120453 1911.8266582489,125.143547058105 1900.86553573608,125.596497058868 PathPoint;PointKind.SMOOTHPOINT 1916.11744880676,127.493741512299 1927.74544715881,128.564865589142 1904.48882102966,126.422853469849 PathPoint;PointKind.SMOOTHPOINT 1970.6672000885,127.493741512299 1979.61699485779,127.414906024933 1961.71740531921,127.572340965271 PathPoint;PointKind.SMOOTHPOINT 2015.47596931458,127.493741512299 2029.39507484436,127.371711730957 2001.55686378479,127.61577129364 PathPoint;PointKind.SMOOTHPOINT 2065.15554428101,127.493741512299 1879.62432861328,127.330405712128 2050.89088439941,127.48099565506 PathPoint;PointKind.SMOOTHPOINT 2561.94909095764,128.501844406128 2582.86110877991,128.282568454742 2428.66518974304,129.898459911346 PathPoint;PointKind.SMOOTHPOINT 2612.60301589966,127.493741512299 2620.49065589905,127.087998390198 2604.71474647522,127.899248600006 PathPoint;PointKind.SMOOTHPOINT 2640.85192680359,128.501844406128 2650.57402610779,128.170924186707 2631.12982749939,128.832528591156 PathPoint;PointKind.SMOOTHPOINT 2698.32409858704,128.501844406128 2705.85453987122,128.40719461441 2690.79365730286,128.596258163452 PathPoint;PointKind.SMOOTHPOINT 2716.8320274353,128.501844406128 2725.87308883667,128.867933750153 2707.79128074646,128.13551902771 PathPoint;PointKind.SMOOTHPOINT 2758.71869087219,129.509475231171 2777.01355934143,130.029458999634 2740.42382240295,128.989727497101 PathPoint;PointKind.SMOOTHPOINT 2799.63131904602,129.509475231171 2807.19952583313,129.356052875519 2792.06279754639,129.663133621216 PathPoint;PointKind.SMOOTHPOINT 2814.00014877319,127.342915534973 2828.0419921875,127.017660140991 2803.49504470825,127.586266994476 PathPoint;PointKind.SMOOTHPOINT 2853.2070350647,128.501844406128 2858.24841499329,128.710498809814 2848.16502571106,128.292953968048 PathPoint;PointKind.SMOOTHPOINT 2866.0164642334,128.089728355408 2872.39505767822,127.562427520752 2858.99019241333,128.670608997345 PathPoint;PointKind.SMOOTHPOINT 2882.42998123169,129.509475231171 2885.03926277161,129.733707904816 2878.77144813538,129.195313453674 PathPoint;PointKind.SMOOTHPOINT 2899.96387481689,128.501844406128 2902.89101600647,127.947635650635 2892.92344093323,129.834494590759 PathPoint;PointKind.SMOOTHPOINT 2906.78275108337,125.477771759033 2915.67652702332,126.836621761322 2903.03798675537,124.905624389648 PathPoint;PointKind.SMOOTHPOINT 2918.47211837769,129.509475231171 2925.78540802002,129.678947925568 2911.15851402283,129.340238571167 PathPoint;PointKind.SMOOTHPOINT 2954.51394081116,128.501844406128 2964.60865974426,128.852119445801 2944.41890716553,128.151333332062 PathPoint;PointKind.SMOOTHPOINT 2983.73688697815,128.501844406128 3000.43018341064,128.324582576752 2967.0442199707,128.678870201111 PathPoint;PointKind.SMOOTHPOINT 3556.51116371155,129.509475231171 3589.05621528625,130.462582111359 3523.96611213684,128.556840419769 PathPoint;PointKind.SMOOTHPOINT 3657.81806945801,129.509475231171 3662.44151115417,129.785163402557 3639.82626914978,128.437407016754 PathPoint;PointKind.SMOOTHPOINT 3673.40389251709,131.525444984436 3678.20042610168,131.946766376495 3668.60704421997,131.104123592377 PathPoint;PointKind.SMOOTHPOINT 3698.73069763184,132.533547878265 3703.02652359009,131.249756813049 3695.95335960388,133.363208770752 PathPoint;PointKind.SMOOTHPOINT 3716.26459121704,129.509475231171 3720.1944065094,129.498381614685 3710.95948219299,129.524581432343 PathPoint;PointKind.SMOOTHPOINT 3726.97960853577,131.525444984436 3730.55411338806,131.551172733307 3719.87780570984,131.474225521088 PathPoint;PointKind.SMOOTHPOINT 3739.64301109314,130.517578125 3740.90500831604,130.492794513702 3731.82901382446,130.671708583832 PathPoint;PointKind.SMOOTHPOINT 3746.46157264709,131.525444984436 3748.35582733154,130.833156108856 3744.31806564331,132.309551239014 PathPoint;PointKind.SMOOTHPOINT 3750.35802841187,131.525444984436 3757.09035873413,131.605696678162 3749.51869010925,131.515531539917 PathPoint;PointKind.SMOOTHPOINT 3768.86627197266,130.517578125 3785.69269180298,129.537091255188 3763.44818115234,130.83339214325 PathPoint;PointKind.SMOOTHPOINT 3790.29662132263,127.493741512299 3791.70118331909,127.494213581085 3778.91567230225,127.489728927612 PathPoint;PointKind.SMOOTHPOINT 3797.11518287659,127.493741512299 3804.36553001404,127.997674942017 3796.09457015991,127.422695159912 PathPoint;PointKind.SMOOTHPOINT 3806.85647964478,128.501844406128 3812.68967628479,128.907351493835 3801.7430305481,128.146140575409 PathPoint;PointKind.SMOOTHPOINT 3818.54553222656,124.469904899597 3822.42593765259,124.584853649139 3816.67960166931,124.414672851562 PathPoint;PointKind.SMOOTHPOINT 3826.3384437561,125.477771759033 3827.47109413147,126.44433259964 3824.70760345459,124.086112976074 PathPoint;PointKind.SMOOTHPOINT 3832.182970047,127.493741512299 3837.95920372009,127.740161418915 3828.29375267029,127.327809333801 PathPoint;PointKind.SMOOTHPOINT 3840.9499168396,124.469904899597 3848.33433151245,125.037567615509 3839.81065750122,124.382336139679 PathPoint;PointKind.SMOOTHPOINT 3862.38026618958,127.493741512299 3870.41298866272,127.025213241577 3854.34785842896,127.96226978302 PathPoint;PointKind.SMOOTHPOINT 3881.86254501343,127.493741512299 3893.29290390015,128.430798053741 3870.43187141418,126.556684970856 PathPoint;PointKind.SMOOTHPOINT 3906.21500015259,128.501844406128 3913.22805404663,128.533236980438 3899.20226097107,128.470215797424 PathPoint;PointKind.SMOOTHPOINT 3920.00003814697,125.342996120453 3931.03322982788,124.37242269516 3904.7160243988,126.687684059143 PathPoint;PointKind.SMOOTHPOINT 3937.38633155823,128.501844406128 3947.51913070679,128.151097297668 3930.85541725159,128.727729320526 PathPoint;PointKind.CORNERPOINT 3955.89457511902,127.493741512299 3955.89457511902,127.493741512299 3955.89457511902,127.493741512299 PathPoint;PointKind.SMOOTHPOINT 3966.60990715027,125.477771759033 3974.10573005676,124.812626838684 3959.11345481873,126.143388748169 PathPoint;PointKind.SMOOTHPOINT 3980.24703025818,126.485874652863 3988.00815582275,126.435599327087 3969.90117073059,126.552908420563 PathPoint;PointKind.SMOOTHPOINT 3993.88478279114,125.477771759033 3995.53009986877,125.167622566223 3988.94411087036,126.409163475037 PathPoint;PointKind.SMOOTHPOINT 3999.72930908203,123.461802005768 4007.82623291016,123.047561645508 3996.38360023499,123.633162975311 PathPoint;PointKind.SMOOTHPOINT 4013.36674690247,125.477771759033 4016.08617782593,125.913491249084 4009.20687675476,124.811682701111 PathPoint;PointKind.SMOOTHPOINT 4026.03014945984,125.477771759033 4038.35083007812,126.210186481476 4021.15934371948,125.188157558441 PathPoint;PointKind.SMOOTHPOINT 4059.14986610413,126.485874652863 4066.67590141296,126.584300994873 4041.04571342468,126.249132156372 PathPoint;PointKind.SMOOTHPOINT 4080.48422813416,126.035521030426 4082.73316383362,125.762193202972 4072.45276451111,127.011995315552 PathPoint;PointKind.SMOOTHPOINT 4089.34684753418,123.461802005768 4093.88154029846,123.33434343338 4087.22851753235,123.521518707275 PathPoint;PointKind.SMOOTHPOINT 4102.01056480408,125.477771759033 4104.99466896057,125.944883823395 4098.07476997375,124.862194061279 PathPoint;PointKind.SMOOTHPOINT 4110.77719688416,125.477771759033 4125.95955848694,125.143074989319 4107.771692276,125.544097423553 PathPoint;PointKind.SMOOTHPOINT 4153.63789558411,128.501844406128 4162.6767539978,128.34086894989 4139.26591873169,128.757705688477 PathPoint;PointKind.SMOOTHPOINT 4177.99129486084,127.316479682922 4178.85549545288,127.258415222168 4170.37902832031,127.827730178833 PathPoint;PointKind.SMOOTHPOINT 4180.58263778687,127.142758369446 4181.02732658386,126.55054807663 4179.40970420837,128.703889846802 PathPoint;PointKind.SMOOTHPOINT 4183.83519172668,126.485874652863 4186.74470901489,126.297047138214 4183.10946464539,126.533081531525 PathPoint;PointKind.SMOOTHPOINT 4191.62810325623,126.485874652863 4204.25342559814,125.871477127075 4188.59993934631,126.633160114288 PathPoint;PointKind.SMOOTHPOINT 4215.98055839539,127.493741512299 4222.65403747559,127.54378080368 4205.98875045776,127.418918609619 PathPoint;PointKind.SMOOTHPOINT 4235.46283721924,125.477771759033 4237.45433807373,125.067307949066 4229.58526611328,126.68957233429 PathPoint;PointKind.SMOOTHPOINT 4239.39328193665,123.640007972717 4240.59359550476,123.545122146606 4236.82711601257,123.842997550964 PathPoint;PointKind.SMOOTHPOINT 4243.25574874878,123.461802005768 4247.38981246948,123.399488925934 4241.8754196167,123.482809066772 PathPoint;PointKind.SMOOTHPOINT 4254.00003433228,122.343471050262 4255.94244003296,122.7090883255 4250.3330039978,121.653306484222 PathPoint;PointKind.SMOOTHPOINT 4259.8152923584,125.477771759033 4265.58365821838,127.109713554382 4257.93519973755,124.945750236511 PathPoint;PointKind.SMOOTHPOINT 4274.42708015442,125.477771759033 4286.61841392517,125.473759174347 4268.14762115479,125.479896068573 PathPoint;PointKind.SMOOTHPOINT 4290.98693847656,124.469904899597 4301.49644851685,124.190440177917 4280.47711372375,124.74960565567 PathPoint;PointKind.SMOOTHPOINT 4306.57244682312,128.501844406128 4308.85411262512,128.420648574829 4297.48984336853,128.824739456177 PathPoint;PointKind.SMOOTHPOINT 4310.46921730042,126.485874652863 4311.38093948364,126.327967643738 4308.94223213196,126.749997138977 PathPoint;PointKind.SMOOTHPOINT 4315.33970832825,127.493741512299 4316.16110801697,127.428596019745 4314.13467407227,127.589335441589 PathPoint;PointKind.SMOOTHPOINT 4318.26181411743,125.477771759033 4319.05394554138,125.388550758362 4317.26952552795,125.589652061462 PathPoint;PointKind.SMOOTHPOINT 4322.1582698822,127.493741512299 4322.83867835999,127.473678588867 4321.1914730072,127.522065639496 PathPoint;PointKind.SMOOTHPOINT 4324.10634040833,125.477771759033 4325.19052505493,125.376040935516 4323.35165977478,125.548582077026 PathPoint;PointKind.SMOOTHPOINT 4330.9252166748,125.477771759033 4332.30113983154,125.911602973938 4329.03096199036,124.880840778351 PathPoint;PointKind.SMOOTHPOINT 4332.87328720093,127.493741512299 4334.91923332214,127.524662017822 4331.70381546021,127.4760389328 PathPoint;PointKind.SMOOTHPOINT 4338.71812820435,125.477771759033 4341.15211486816,124.967701435089 4336.39680862427,125.964238643646 PathPoint;PointKind.SMOOTHPOINT 4348.45911026001,125.477771759033 4351.85580253601,125.434341430664 4344.47138786316,125.528991222382 PathPoint;PointKind.SMOOTHPOINT 4358.2004070282,123.461802005768 4368.88615608215,123.411054611206 4354.71339225769,123.478560447693 PathPoint;PointKind.SMOOTHPOINT 4379.00007247925,122.343471050262 4380.33382415771,122.391149997711 4368.18560600281,121.958026885986 PathPoint;PointKind.SMOOTHPOINT 4386.44931793213,125.477771759033 4409.24205780029,126.380839347839 4385.06741523743,125.423011779785 PathPoint;PointKind.SMOOTHPOINT 4444.84359741211,125.477771759033 4446.77813529968,125.501139163971 4431.18885040283,125.312311649323 PathPoint;PointKind.SMOOTHPOINT 4450.68843841553,123.461802005768 4451.40252113342,122.16361284256 4449.79339599609,125.089495182037 PathPoint;PointKind.SMOOTHPOINT 4455.55892944336,125.477771759033 4457.31282234192,126.727809906006 4454.18332099915,124.497756958008 PathPoint;PointKind.SMOOTHPOINT 4463.4034538269,123.461802005768 4466.32115364075,124.721517562866 4461.72949790955,122.739300727844 PathPoint;PointKind.SMOOTHPOINT 4471.68637275696,125.961170196533 4472.76048660278,125.837960243225 4468.3881855011,126.339061260223 PathPoint;PointKind.SMOOTHPOINT 4478.01524162292,123.461802005768 4483.27345848083,123.259992599487 4475.47582626343,123.559284210205 PathPoint;PointKind.SMOOTHPOINT 4493.60074996948,125.477771759033 4500.66478729248,125.783200263977 4489.79807853699,125.313255786896 PathPoint;PointKind.SMOOTHPOINT 4512.10867881775,124.469904899597 4515.57020187378,124.270927906036 4501.11608505249,125.102005004883 PathPoint;PointKind.SMOOTHPOINT 4526.72046661377,124.469904899597 4541.68001174927,124.539771080017 4520.46429634094,124.440636634827 PathPoint;PointKind.SMOOTHPOINT 4566.09415054321,124.273288249969 4567.36212730408,124.266443252563 4552.41202354431,124.346458911896 PathPoint;PointKind.SMOOTHPOINT 4571.52923583984,123.461802005768 4575.10877609253,123.450000286102 4570.20492553711,123.466286659241 PathPoint;PointKind.SMOOTHPOINT 4579.32214736938,123.461802005768 4580.01955032349,123.464162349701 4575.17612457275,123.448348045349 PathPoint;PointKind.SMOOTHPOINT 4581.27021789551,124.469904899597 4582.07053184509,124.489731788635 4580.51018714905,124.451258182526 PathPoint;PointKind.SMOOTHPOINT 4583.21860313416,123.461802005768 4586.27005577087,123.490362167358 4582.35314369202,123.453776836395 PathPoint;PointKind.SMOOTHPOINT 4592.95958518982,123.461802005768 4596.71473503113,123.696892261505 4589.29947853088,123.232848644257 PathPoint;PointKind.SMOOTHPOINT 4604.64895248413,124.469904899597 4643.22137832642,125.028834342957 4601.10591888428,124.418685436249 PathPoint;PointKind.SMOOTHPOINT 4654.32821273804,125.477771759033 4669.79601860046,125.824270248413 4638.86040687561,125.131273269653 PathPoint;PointKind.SMOOTHPOINT 4684.52582359314,124.469904899597 4697.88914680481,124.808614253998 4671.16218566895,124.13143157959 PathPoint;PointKind.SMOOTHPOINT 4712.77473449707,124.469904899597 4731.40445709229,124.068410396576 4694.14469718933,124.871635437012 PathPoint;PointKind.SMOOTHPOINT 4742.97171592712,125.477771759033 4763.49286079407,125.832295417786 4722.45088577271,125.123484134674 PathPoint;PointKind.SMOOTHPOINT 4786.80676460266,125.477771759033 4821.09437942505,124.584145545959 4752.51883506775,126.3716340065 PathPoint;PointKind.SMOOTHPOINT 4853.04588317871,125.477771759033 4874.69653129578,125.355978012085 4828.5599899292,125.615615844727 PathPoint;PointKind.SMOOTHPOINT 4888.99990081787,125.342996120453 4890.86205482483,125.403892993927 4874.7793006897,124.876828193665 PathPoint;PointKind.SMOOTHPOINT 4899.80303764343,127.493741512299 4906.3742351532,127.64716386795 4897.55536079407,127.44110584259 PathPoint;PointKind.SMOOTHPOINT 4908.56966972351,130.517578125 4909.53678131104,130.194447040558 4906.38871192932,131.246452331543 PathPoint;PointKind.SMOOTHPOINT 4912.46612548828,127.493741512299 4917.13614463806,125.962586402893 4910.15928268433,128.250231742859 PathPoint;PointKind.SMOOTHPOINT 4932.9224395752,125.477771759033 4947.23745346069,125.670847892761 4925.25415420532,125.374388694763 PathPoint;PointKind.SMOOTHPOINT 4978.70524406433,133.541414737701 4996.93748474121,139.356122016907 4958.17182540894,126.9926404953 PathPoint;PointKind.SMOOTHPOINT 5001.99995040894,150.340218544006 5008.82323265076,158.158857822418 4996.50727272034,144.045417308807 PathPoint;PointKind.SMOOTHPOINT 5011.82527542114,174.867260456085 5014.76720809937,192.152767181396 5010.22747993469,165.482060909271 PathPoint;PointKind.SMOOTHPOINT 5016.69576644897,223.248882293701 5016.50379180908,227.814967632294 5017.1369934082,212.728357315063 PathPoint;PointKind.SMOOTHPOINT 5016.69576644897,235.344228744507 5015.69309234619,238.202605247498 5017.46429443359,233.151941299438 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,255.502982139587 5013.45076560974,274.733884334564 5013.89986038208,247.945868968964 PathPoint;PointKind.SMOOTHPOINT 5015.72141647339,396.615672111511 5015.66067695618,414.325568675995 5015.78247070312,378.905775547028 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,910.668840408325 5015.1505279541,928.079681396484 5012.39584922791,893.258235454559 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,969.129838943481 5012.89372444153,981.667749881744 5014.65202331543,956.599481105804 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1059.84517335892 5014.67499732971,1073.41691493988 5014.81976509094,1046.27343177795 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,1235.22816896439 5014.02826309204,1242.34271764755 5013.51811408997,1228.11338424683 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1255.38715839386 5014.73227500916,1267.84056901932 5014.7624874115,1242.93327569962 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,1299.73684072495 5013.33180427551,1332.68393754959 5014.21488761902,1266.78950786591 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1522.49311923981 5015.05926132202,1536.37595415115 5014.43550109863,1508.61028432846 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,1585.99368810654 5013.78561973572,1595.54505586624 5013.74659538269,1565.55924654007 PathPoint;PointKind.SMOOTHPOINT 5014.75745201111,1626.0182762146 5014.78986740112,1627.16091871262 5014.33353424072,1611.23520612717 PathPoint;PointKind.SMOOTHPOINT 5014.85312461853,1629.42614078522 5014.46288108826,1631.24171733856 5015.08978843689,1628.32433223724 PathPoint;PointKind.SMOOTHPOINT 5014.94596481323,1632.919921875 5015.30756950378,1646.97883844376 5014.91638183594,1631.76712989807 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1662.5977063179 5013.21756362915,1670.23601531982 5015.44919013977,1659.09306764603 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1680.7409620285 5014.36689376831,1688.2532286644 5015.12786865234,1673.22845935822 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1696.86801195145 5015.21535873413,1703.33700656891 5014.27940368652,1690.39901733398 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1718.03486824036 5014.96421813965,1729.44925546646 5014.53054428101,1706.62071704865 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1769.44032669067 5013.8910484314,1791.16634845734 5015.60339927673,1747.71430492401 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1844.02837514877 5014.94502067566,1859.48626756668 5014.54942703247,1828.57048273087 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,1877.29057788849 5015.48192024231,1902.08787918091 5012.06477165222,1852.49351263046 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1949.86289262772 5015.09356498718,1967.5057554245 5014.40119743347,1932.21979379654 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1999.25214529037 5014.79647636414,2004.0358543396 5014.6142578125,1986.34979724884 PathPoint;PointKind.SMOOTHPOINT 5014.16358947754,2013.18124294281 5013.5558795929,2020.80633401871 5014.52204704285,2008.68880033493 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2035.53842067719 5013.91779899597,2045.96429586411 5013.68239402771,2028.97808074951 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2089.96747970581 5015.05926132202,2116.68610095978 5014.43550109863,2063.24885845184 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2218.98482322693 5014.26461219788,2250.25418758392 5015.2317237854,2187.62057304382 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2299.62078094482 5014.13872718811,2315.01942873001 5015.35634994507,2284.22166109085 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2375.21669626236 5013.73463630676,2376.50780439377 5014.3061542511,2357.35314130783 PathPoint;PointKind.SMOOTHPOINT 5012.7993106842,2380.25650262833 5012.75304794312,2386.01999044418 5012.86256790161,2372.34817028046 PathPoint;PointKind.SMOOTHPOINT 5013.54423522949,2385.76389312744 5014.11764144897,2409.80210781097 5013.52314949036,2384.89552259445 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2470.97160100937 5014.73982810974,2490.2959728241 5012.95226097107,2454.55328464508 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2548.58372211456 5014.12330627441,2572.06159114838 5013.42307090759,2525.10561704636 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2618.1319642067 5015.42086601257,2640.10204553604 5014.07389640808,2596.16188287735 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2692.72001266479 5013.50300788879,2725.96286058426 5014.04336929321,2659.47763681412 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2756.22081756592 5014.12739753723,2772.38327264786 5013.4192943573,2740.05836248398 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2817.70565271378 5014.55698013306,2845.48312425613 5014.93746757507,2789.92818117142 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2889.26986455917 5014.72314834595,2906.25324726105 5014.77161407471,2872.20103740692 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2937.6512503624 5013.2285785675,2948.29050064087 5014.2932510376,2927.49303817749 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2980.99330186844 5014.38955307007,2993.61996173859 5015.10520935059,2968.3661699295 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3013.24740171432 5014.18656349182,3020.89349985123 5013.19490432739,3002.55386352539 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3057.59708404541 5014.85690116882,3064.42744731903 5014.47263717651,3040.46169519424 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3075.74010372162 5015.26413917542,3093.43300580978 5014.58750724792,3070.25938510895 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3093.88312339783 5013.68963241577,3103.27776432037 5013.85705947876,3084.48895454407 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3131.17726564407 5014.11197662354,3144.80423927307 5013.43440055847,3117.55052804947 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3182.58248806 5013.48790168762,3195.059030056 5014.04022216797,3170.90799093246 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3212.82109022141 5013.86461257935,3221.275370121 5013.66665840149,3202.94635534286 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3253.13883304596 5013.8743686676,3255.39107322693 5013.17161560059,3239.73491191864 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3261.20247602463 5014.93211746216,3263.46557378769 5014.60355758667,3259.43882703781 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3266.24228239059 5013.74565124512,3273.72056007385 5013.77964019775,3264.54944372177 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3290.43297529221 5014.16516304016,3305.75302362442 5013.45391273499,3277.94085502625 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3327.72711753845 5014.30993080139,3337.65307188034 5013.23676109314,3317.80116319656 PathPoint;PointKind.SMOOTHPOINT 5012.7993106842,3344.86203432083 5014.05123710632,3354.044008255 5011.54738426208,3335.68029642105 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3373.08466672897 5013.69277954102,3384.78489160538 5013.8498210907,3361.97688817978 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3391.22768640518 5015.79002380371,3396.63759469986 5013.70473861694,3385.8180141449 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3408.36283922195 5014.4506072998,3413.81594181061 5015.04415512085,3402.90950059891 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3428.52182865143 5013.26728820801,3441.81009292603 5016.22778892517,3415.23332834244 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3446.66484832764 5013.64022254944,3464.11109447479 5013.90646934509,3429.21860218048 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3492.02239751816 5014.35178756714,3511.24834299088 5015.14297485352,3472.79668807983 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3568.62641572952 5013.93699645996,3599.05408143997 5013.60969543457,3538.19898605347 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3627.08741426468 5013.31669807434,3639.70274448395 5014.22999382019,3614.4723200798 PathPoint;PointKind.SMOOTHPOINT 5011.82527542114,3653.29407691956 5011.46146774292,3670.66856861115 5012.16831207275,3636.90125226974 PathPoint;PointKind.SMOOTHPOINT 5010.85092544556,3694.61992263794 5010.69514274597,3717.64932632446 5011.00702285767,3671.59075498581 PathPoint;PointKind.SMOOTHPOINT 5016.69576644897,3777.27161407471 5017.14454650879,3793.89882087708 5016.24667167664,3760.64440727234 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3808.51808309555 5011.07090950012,3814.80580329895 5017.56846427917,3799.6882724762 PathPoint;PointKind.SMOOTHPOINT 5002.22528457642,3822.85552024841 5001.51812553406,3823.35874557495 5007.09671974182,3819.38982725143 PathPoint;PointKind.SMOOTHPOINT 5000.04747390747,3824.29651021957 4998.73323440552,3824.28069591522 5001.38814926147,3824.31256055832 PathPoint;PointKind.SMOOTHPOINT 4996.54000282288,3826.23718500137 4992.85062789917,3828.07306051254 4997.74755477905,3825.636241436 PathPoint;PointKind.SMOOTHPOINT 4984.55039978027,3830.69304227829 4979.43065643311,3832.12600708008 4988.81601333618,3829.49870824814 PathPoint;PointKind.SMOOTHPOINT 4967.99022674561,3834.72474575043 4949.8401260376,3836.89012527466 4973.14270019531,3834.10987615585 PathPoint;PointKind.SMOOTHPOINT 4793.62532615662,3836.74071550369 4779.3449306488,3838.61081600189 4807.90603637695,3834.87014293671 PathPoint;PointKind.SMOOTHPOINT 4641.66512489319,3836.74071550369 4619.45806503296,3838.35094213486 4663.87155532837,3835.13001680374 PathPoint;PointKind.SMOOTHPOINT 4478.98927688599,3836.74071550369 4450.24563789368,3837.51231193542 4507.73323059082,3835.96888303757 PathPoint;PointKind.SMOOTHPOINT 4394.24191474915,3836.74071550369 4380.04523277283,3837.6579451561 4408.43891143799,3835.82324981689 PathPoint;PointKind.SMOOTHPOINT 4360.14847755432,3836.74071550369 4351.35257720947,3836.59036159515 4370.06443977356,3836.9097161293 PathPoint;PointKind.SMOOTHPOINT 4328.0027961731,3836.74071550369 4326.74142837524,3836.7050743103 4337.90365219116,3837.02065229416 PathPoint;PointKind.SMOOTHPOINT 4320.21019935608,3836.74071550369 4310.98628997803,3837.181391716 4321.25221252441,3836.6909122467 PathPoint;PointKind.SMOOTHPOINT 4293.90935897827,3836.74071550369 4287.89488792419,3836.9840669632 4304.28637504578,3836.32033824921 PathPoint;PointKind.SMOOTHPOINT 4270.19451141357,3836.95432662964 4269.03322219849,3836.94748163223 4279.87664222717,3837.01050281525 PathPoint;PointKind.SMOOTHPOINT 4266.63951873779,3836.93072319031 4265.71615219116,3836.30145549774 4268.2495880127,3838.02875518799 PathPoint;PointKind.SMOOTHPOINT 4263.26454162598,3836.90428733826 4257.68122673035,3836.85755252838 4264.40883636475,3836.91372871399 PathPoint;PointKind.SMOOTHPOINT 4245.20413398743,3836.74071550369 4224.2732334137,3836.55967712402 4251.64346694946,3836.79618358612 PathPoint;PointKind.SMOOTHPOINT 4197.47294425964,3836.74071550369 4176.34692192078,3836.00428819656 4218.59865188599,3837.47690677643 PathPoint;PointKind.SMOOTHPOINT 4156.56031608582,3836.74071550369 4149.24545288086,3837.01380729675 4175.30805587769,3836.03969335556 PathPoint;PointKind.SMOOTHPOINT 4140.00045776367,3836.74071550369 4135.14003753662,3837.04519987106 4143.11013221741,3836.54575109482 PathPoint;PointKind.SMOOTHPOINT 4126.36301994324,3837.74858236313 4112.79544830322,3835.48996925354 4134.82091903687,3839.15629148483 PathPoint;PointKind.SMOOTHPOINT 4098.11379432678,3836.74071550369 4079.01231765747,3836.54763936996 4117.21558570862,3836.93331956863 PathPoint;PointKind.SMOOTHPOINT 4051.35663986206,3836.74071550369 4019.22574996948,3837.18611240387 4083.47525596619,3836.29508256912 PathPoint;PointKind.SMOOTHPOINT 3960.76475143433,3836.74071550369 3903.22617530823,3836.92600250244 4018.40246200562,3836.55472040176 PathPoint;PointKind.SMOOTHPOINT 3856.53573989868,3836.74071550369 3832.8945350647,3836.21695518494 3880.17694473267,3837.26423978806 PathPoint;PointKind.SMOOTHPOINT 3799.06356811523,3836.74071550369 3784.19308662415,3836.76408290863 3813.93404960632,3836.71711206436 PathPoint;PointKind.SMOOTHPOINT 3773.73676300049,3836.74071550369 3758.94999504089,3836.75652980804 3788.52321624756,3836.72490119934 PathPoint;PointKind.SMOOTHPOINT 3746.46157264709,3837.74858236313 3733.821144104,3837.52789020538 3759.10263061523,3837.96903848648 PathPoint;PointKind.SMOOTHPOINT 3713.34217071533,3837.74858236313 3702.93934822083,3838.33914041519 3723.74530792236,3837.15778827667 PathPoint;PointKind.SMOOTHPOINT 3670.48147201538,3837.74858236313 3636.57969474792,3837.85007715225 3704.30268287659,3837.64708757401 PathPoint;PointKind.SMOOTHPOINT 3564.0000629425,3836.90688371658 3540.79599380493,3836.51199817657 3588.28926086426,3837.32017993927 PathPoint;PointKind.SMOOTHPOINT 3473.71250152588,3837.74858236313 3437.8639125824,3837.82930612564 3509.39114570618,3837.66809463501 PathPoint;PointKind.SMOOTHPOINT 3328.57023239136,3837.74858236313 3310.92618942261,3837.86659955978 3346.21490478516,3837.63032913208 PathPoint;PointKind.SMOOTHPOINT 3262.33111381531,3837.74858236313 3242.52310752869,3837.46085643768 3292.98537254333,3838.19350719452 PathPoint;PointKind.SMOOTHPOINT 3190.24746894836,3837.74858236313 3188.51466178894,3837.76156425476 3201.57995223999,3837.66266584396 PathPoint;PointKind.SMOOTHPOINT 3184.40294265747,3837.74858236313 3183.68036270142,3838.23363304138 3186.12882614136,3836.58941745758 PathPoint;PointKind.SMOOTHPOINT 3178.71766090393,3837.82576560974 3170.19713401794,3838.44016313553 3180.18233299255,3837.72025823593 PathPoint;PointKind.SMOOTHPOINT 3153.23161125183,3837.74858236313 3115.94604492188,3837.43394851685 3161.63412094116,3837.81939268112 PathPoint;PointKind.SMOOTHPOINT 3073.99990081787,3836.90688371658 3055.83437919617,3837.00908660889 3092.16542243958,3836.80444478989 PathPoint;PointKind.SMOOTHPOINT 3026.5975856781,3837.74858236313 2998.47046852112,3837.9296207428 3054.72501754761,3837.56730794907 PathPoint;PointKind.SMOOTHPOINT 2922.36857414246,3837.74858236313 2919.61515426636,3837.82387733459 2956.89599990845,3836.80350065231 PathPoint;PointKind.SMOOTHPOINT 2914.10548210144,3837.92867660522 2913.53994369507,3837.93811798096 2916.86267852783,3837.88312196732 PathPoint;PointKind.SMOOTHPOINT 2911.65324211121,3837.74858236313 2910.82397460938,3837.76062011719 2912.21972465515,3837.74032115936 PathPoint;PointKind.SMOOTHPOINT 2909.70485687256,3836.74071550369 2908.5659122467,3837.48540401459 2911.25985145569,3835.72364330292 PathPoint;PointKind.SMOOTHPOINT 2905.869140625,3838.02663087845 2905.30045509338,3838.03087949753 2907.22083091736,3838.01648139954 PathPoint;PointKind.SMOOTHPOINT 2904.16213989258,3838.03796052933 2875.44965744019,3838.20672512054 2904.73176956177,3838.03465604782 PathPoint;PointKind.SMOOTHPOINT 2808.3979511261,3837.74858236313 2763.36479187012,3838.38634729385 2845.53654670715,3837.22246170044 PathPoint;PointKind.SMOOTHPOINT 2607.7322101593,3836.74071550369 2561.9188785553,3836.53206110001 2653.54585647583,3836.94913387299 PathPoint;PointKind.SMOOTHPOINT 2465.51267623901,3836.74071550369 2424.08266067505,3838.48878622055 2506.94269180298,3834.99240875244 PathPoint;PointKind.SMOOTHPOINT 2371.99994087219,3835.90704202652 2326.85222625732,3836.63166761398 2417.14734077454,3835.18241643906 PathPoint;PointKind.SMOOTHPOINT 2281.40679359436,3836.74071550369 2234.34153556824,3837.04354763031 2328.47205162048,3836.43741130829 PathPoint;PointKind.SMOOTHPOINT 2193.73732566833,3836.74071550369 2163.47960472107,3836.29036188126 2254.32987213135,3837.64213085175 PathPoint;PointKind.SMOOTHPOINT 2120.67933082581,3836.74071550369 2100.62301635742,3836.46597146988 2140.68466186523,3837.01427936554 PathPoint;PointKind.SMOOTHPOINT 2063.20715904236,3836.74071550369 2024.86541748047,3836.48320198059 2084.1563129425,3836.88115596771 PathPoint;PointKind.SMOOTHPOINT 1982.35625267029,3836.74071550369 1927.89776802063,3836.40979528427 2036.81505203247,3837.07116365433 PathPoint;PointKind.SMOOTHPOINT 1849.87801551819,3835.73261260986 1802.26987838745,3836.0170340538 1899.57867622375,3835.43568134308 PathPoint;PointKind.SMOOTHPOINT 1722.27026939392,3834.72474575043 1676.34490013123,3835.18312454224 1770.61703681946,3834.24205541611 PathPoint;PointKind.SMOOTHPOINT 1622.91143417358,3833.7166428566 1581.19597434998,3834.47266101837 1664.62657928467,3832.96062469482 PathPoint;PointKind.SMOOTHPOINT 1469.99985694885,3832.90728092194 1436.76621437073,3833.58469963074 1503.2338142395,3832.23033428192 PathPoint;PointKind.SMOOTHPOINT 1359.90303039551,3832.70877599716 1311.17483139038,3832.4215221405 1408.63091468811,3832.99602985382 PathPoint;PointKind.SMOOTHPOINT 1238.13949584961,3832.70877599716 1185.84434509277,3832.5555896759 1312.81637191772,3832.92757987976 PathPoint;PointKind.SMOOTHPOINT 1143.36979866028,3832.38375663757 1142.77090072632,3832.38588094711 1169.01226043701,3832.29878425598 PathPoint;PointKind.SMOOTHPOINT 1141.55831336975,3832.39036560059 1140.15406608582,3832.39579439163 1142.16728210449,3832.38800525665 PathPoint;PointKind.SMOOTHPOINT 1136.83259010315,3832.70877599716 1134.86941337585,3833.50657224655 1138.52763175964,3832.02002763748 PathPoint;PointKind.SMOOTHPOINT 1130.68593978882,3832.44937419891 1122.78476715088,3832.50342607498 1132.96162605286,3832.43379592896 PathPoint;PointKind.SMOOTHPOINT 1102.73915290833,3832.70877599716 1044.36123847961,3833.35433006287 1113.75472068787,3832.58698225021 PathPoint;PointKind.SMOOTHPOINT 997.53547668457,3832.70877599716 939.073848724365,3833.08666706085 1055.99710464478,3832.33088493347 PathPoint;PointKind.SMOOTHPOINT 867.979345321655,3832.70877599716 816.892061233521,3833.36235523224 919.06662940979,3832.05519676208 PathPoint;PointKind.SMOOTHPOINT 806.611032485962,3832.70877599716 796.228666305542,3832.74158477783 834.792280197144,3832.61979103088 PathPoint;PointKind.SMOOTHPOINT 779.336156845093,3832.70877599716 771.158037185669,3833.18910598755 784.231824874878,3832.42128610611 PathPoint;PointKind.SMOOTHPOINT 760.827913284302,3833.7166428566 755.290861129761,3834.42474603653 768.31618309021,3832.75928735733 PathPoint;PointKind.SMOOTHPOINT 739.397563934326,3831.70090913773 727.794742584229,3831.8111371994 757.519969940186,3831.52836799622 PathPoint;PointKind.SMOOTHPOINT 722.837705612183,3836.74071550369 716.905689239502,3836.85849666595 728.770036697388,3836.62246227264 PathPoint;PointKind.SMOOTHPOINT 705.303812026978,3834.72474575043 688.843088150024,3833.7482714653 721.764850616455,3835.70122003555 PathPoint;PointKind.SMOOTHPOINT 678.028936386108,3837.74858236313 666.320686340332,3837.09877967834 689.737186431885,3838.39814901352 PathPoint;PointKind.SMOOTHPOINT 659.520692825317,3834.72474575043 643.741006851196,3834.16959285736 675.300693511963,3835.2796626091 PathPoint;PointKind.SMOOTHPOINT 626.401290893555,3834.72474575043 607.269287109375,3837.01994419098 645.533294677734,3832.42931127548 PathPoint;PointKind.SMOOTHPOINT 594.255924224854,3838.75644922256 585.429496765137,3838.36817264557 605.085182189941,3839.23276662827 PathPoint;PointKind.SMOOTHPOINT 582.566556930542,3834.72474575043 581.016912460327,3834.4540143013 589.395189285278,3835.91789960861 PathPoint;PointKind.SMOOTHPOINT 573.799610137939,3834.72474575043 570.394735336304,3834.47407722473 576.402282714844,3834.9161696434 PathPoint;PointKind.SMOOTHPOINT 561.136207580566,3834.72474575043 556.235189437866,3835.20790815353 564.418973922729,3834.4011425972 PathPoint;PointKind.SMOOTHPOINT 548.999948501587,3836.90688371658 545.137481689453,3838.0001950264 552.517175674438,3835.91176271439 PathPoint;PointKind.SMOOTHPOINT 538.731822967529,3839.764316082 536.713571548462,3840.03339529037 541.591300964355,3839.3831205368 PathPoint;PointKind.SMOOTHPOINT 533.861331939697,3838.75644922256 530.307598114014,3838.25652837753 535.243864059448,3838.95094156265 PathPoint;PointKind.SMOOTHPOINT 522.17227935791,3837.74858236313 514.257574081421,3837.7249789238 527.870464324951,3837.76557683945 PathPoint;PointKind.SMOOTHPOINT 509.508562088013,3838.75644922256 499.889373779297,3837.98485279083 519.128065109253,3839.5280456543 PathPoint;PointKind.SMOOTHPOINT 490.026597976685,3837.74858236313 470.947780609131,3838.17769289017 509.105415344238,3837.3192358017 PathPoint;PointKind.SMOOTHPOINT 463.725757598877,3838.75644922256 453.052282333374,3839.00050878525 474.398918151855,3838.51238965988 PathPoint;PointKind.SMOOTHPOINT 449.113969802856,3837.74858236313 444.646940231323,3837.20121860504 453.581314086914,3838.29594612122 PathPoint;PointKind.SMOOTHPOINT 441.32137298584,3839.764316082 435.659065246582,3840.11081457138 446.983366012573,3839.41781759262 PathPoint;PointKind.CORNERPOINT 436.450881958008,3838.75644922256 436.450881958008,3838.75644922256 436.450881958008,3838.75644922256 PathPoint;PointKind.SMOOTHPOINT 427.683935165405,3839.764316082 426.991882324219,3841.01010560989 428.826026916504,3837.70774841309 PathPoint;PointKind.SMOOTHPOINT 399.999933242798,3841.90632820129 354.562368392944,3839.18768405914 409.093866348267,3842.45062351227 PathPoint;PointKind.SMOOTHPOINT 315.661697387695,3838.75644922256 302.631340026855,3837.7920126915 340.664663314819,3840.60695886612 PathPoint;PointKind.SMOOTHPOINT 288.386821746826,3831.70090913773 283.571720123291,3828.33269834518 293.62678527832,3835.36628723145 PathPoint;PointKind.SMOOTHPOINT 275.723419189453,3815.57362318039 268.364181518555,3795.61549901962 279.247255325317,3825.13089179993 PathPoint;PointKind.SMOOTHPOINT 264.033737182617,3753.0809211731 262.98228263855,3740.98557472229 265.042705535889,3764.68106746674 PathPoint;PointKind.CORNERPOINT 263.059701919556,3568.62641572952 263.059701919556,3568.62641572952 263.059701919556,3568.62641572952 PathPoint;PointKind.CORNERPOINT 263.059701919556,3117.0661854744 263.059701919556,3117.0661854744 263.059701919556,3117.0661854744 PathPoint;PointKind.CORNERPOINT 263.059701919556,2501.20996713638 263.059701919556,2501.20996713638 263.059701919556,2501.20996713638 PathPoint;PointKind.SMOOTHPOINT 264.033737182617,2490.12272357941 264.152069091797,2481.61014318466 263.916034698486,2498.63530397415 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2471.9797039032 262.717609405518,2456.21071815491 263.402423858643,2487.7484536171 PathPoint;PointKind.SMOOTHPOINT 264.033737182617,2446.78114414215 263.601007461548,2439.17304754257 264.245538711548,2450.49703359604 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2386.30417585373 262.893533706665,2359.53645944595 263.233423233032,2414.2329454422 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,2111.13457202911 268.040657043457,2061.8354845047 267.820043563843,2160.43318748474 PathPoint;PointKind.SMOOTHPOINT 265.008401870728,2016.38729810715 264.441289901733,2002.17779159546 265.575199127197,2030.59704065323 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1969.01377916336 266.899194717407,1941.08642578125 267.01343536377,1996.94089651108 PathPoint;PointKind.SMOOTHPOINT 268.904542922974,1915.59258699417 267.458438873291,1898.3198261261 270.350646972656,1932.86534786224 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1882.33038425446 267.036409378052,1869.98696565628 266.876535415649,1894.67356681824 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1857.13158845901 264.441289901733,1844.37086105347 271.419725418091,1869.89255189896 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1822.86151885986 266.773624420166,1804.49379444122 269.087076187134,1841.22900724411 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1760.36858081818 270.148601531982,1730.46892404556 265.712099075317,1790.26847362518 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1659.5738697052 267.437982559204,1653.22407245636 269.286289215088,1677.05929756165 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1620.26399374008 267.355842590332,1598.70343208313 266.556787490845,1641.82455539703 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1515.43734312057 265.792036056519,1494.20368909836 268.120594024658,1536.67146921158 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1406.57898902893 268.368272781372,1380.14030456543 267.493057250977,1433.01790952682 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1316.87175750732 267.036409378052,1293.33464384079 268.824920654297,1340.40887117386 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1235.22816896439 267.938690185547,1231.92888021469 267.899980545044,1247.75640249252 PathPoint;PointKind.SMOOTHPOINT 267.989044189453,1227.38805055618 268.029642105103,1224.87357616425 267.955055236816,1229.53336715698 PathPoint;PointKind.SMOOTHPOINT 265.008401870728,1222.12471961975 265.076379776001,1220.24140119553 264.903602600098,1225.00315904617 PathPoint;PointKind.SMOOTHPOINT 265.982437133789,1208.01340341568 266.941995620728,1204.29043292999 265.125160217285,1211.33794784546 PathPoint;PointKind.SMOOTHPOINT 268.904542922974,1200.95786333084 269.696044921875,1178.71610641479 268.725471496582,1205.9872841835 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1165.67969083786 266.344985961914,1157.07765340805 268.127202987671,1182.16268062592 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1119.31403875351 268.530979156494,1098.74269723892 267.321224212646,1140.18207550049 PathPoint;PointKind.SMOOTHPOINT 268.904542922974,1085.04373311996 267.260799407959,1068.93792629242 270.334596633911,1099.05284643173 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1033.63851070404 267.062845230103,1013.8418340683 268.797855377197,1053.43518733978 PathPoint;PointKind.SMOOTHPOINT 268.904542922974,978.201584815979 268.965282440186,955.64873456955 268.843803405762,1000.75419902802 PathPoint;PointKind.SMOOTHPOINT 269.87889289856,904.621167182922 270.761661529541,876.091690063477 268.995809555054,933.150880336761 PathPoint;PointKind.SMOOTHPOINT 269.87889289856,822.977578639984 270.77299118042,795.526778697968 268.984479904175,850.428378582001 PathPoint;PointKind.SMOOTHPOINT 270.852928161621,756.45293712616 272.33302116394,731.419837474823 269.372520446777,781.486508846283 PathPoint;PointKind.SMOOTHPOINT 270.852928161621,701.016011238098 270.28959274292,676.651833057404 271.415948867798,725.379953384399 PathPoint;PointKind.SMOOTHPOINT 271.826963424683,650.61865568161 271.454029083252,633.920402526855 272.199897766113,667.316436767578 PathPoint;PointKind.SMOOTHPOINT 271.826963424683,626.427726745605 272.45922088623,620.304522514343 271.19439125061,632.551167011261 PathPoint;PointKind.SMOOTHPOINT 271.826963424683,602.237033843994 268.990774154663,585.927529335022 274.717597961426,618.859519958496 PathPoint;PointKind.SMOOTHPOINT 272.800998687744,554.863278865814 272.211227416992,531.409013271332 273.390769958496,578.318016529083 PathPoint;PointKind.SMOOTHPOINT 272.800998687744,525.633015632629 270.080308914185,519.286050796509 275.521688461304,531.97998046875 PathPoint;PointKind.SMOOTHPOINT 269.87889289856,508.49809885025 266.400690078735,501.186225414276 273.356466293335,515.809500217438 PathPoint;PointKind.SMOOTHPOINT 268.904542922974,474.227793216705 269.195337295532,458.574464321136 268.603992462158,490.412435531616 PathPoint;PointKind.SMOOTHPOINT 268.904542922974,440.965354442596 267.076377868652,410.465934276581 269.550333023071,451.736075878143 PathPoint;PointKind.SMOOTHPOINT 269.87889289856,385.528428554535 269.587154388428,356.619880199432 270.222244262695,419.620292186737 PathPoint;PointKind.SMOOTHPOINT 269.87889289856,284.733481407166 269.601001739502,254.632959365845 270.156154632568,314.83423948288 PathPoint;PointKind.SMOOTHPOINT 270.852928161621,233.328258991241 269.133024215698,214.303178787231 272.572832107544,252.353339195251 PathPoint;PointKind.SMOOTHPOINT 264.80320930481,177.433898448944 263.05718421936,158.666095733643 266.551752090454,196.230969429016 PathPoint";
	
	mask645[2] = "PointKind.SMOOTHPOINT 273.775033950806,135.223395824432 280.51744531525,128.056664796051 260.805168151855,149.00946187973 PathPoint;PointKind.SMOOTHPOINT 292.283277511597,121.110663414001 298.16556930542,119.051027297974 286.400356292725,123.170063495636 PathPoint;PointKind.SMOOTHPOINT 347.807064056396,119.094457626343 365.500831604004,118.88179063797 330.113296508789,119.307124614716 PathPoint;PointKind.SMOOTHPOINT 942.011690139771,119.094457626343 977.444543838501,119.011845588684 906.578521728516,119.177069664001 PathPoint;PointKind.SMOOTHPOINT 1493.35530281067,120.102560520172 1505.02956390381,119.889893531799 1481.68135643005,120.315227508545 PathPoint;PointKind.SMOOTHPOINT 1535.24196624756,124.134736061096 1541.79270744324,124.167308807373 1524.18422698975,124.079740047455 PathPoint;PointKind.SMOOTHPOINT 1544.98326301575,122.118530273438 1548.40261459351,121.527264118195 1540.01237869263,122.978167533875 PathPoint;PointKind.SMOOTHPOINT 1563.49087715149,121.110663414001 1567.4188041687,121.049766540527 1558.08946609497,121.19398355484 PathPoint;PointKind.SMOOTHPOINT 1580.05073547363,123.126633167267 1584.03468132019,124.217348098755 1574.45042610168,121.593353748322 PathPoint;PointKind.SMOOTHPOINT 1605.37754058838,125.142838954926 1620.85289955139,125.095632076263 1594.48848724365,125.176119804382 PathPoint;PointKind.SMOOTHPOINT 1857.67092704773,126.150941848755 1868.88444900513,126.65109872818 1846.45740509033,125.65078496933 PathPoint;PointKind.CORNERPOINT 1889.81629371643,126.150941848755 1889.81629371643,126.150941848755 1889.81629371643,126.150941848755 PathPoint;PointKind.SMOOTHPOINT 1895.66113471985,127.159044742584 1897.16892242432,127.285559177399 1889.81440544128,126.668329238892 PathPoint;PointKind.SMOOTHPOINT 1903.47104072571,124.984459877014 1908.29778671265,124.785010814667 1897.33666419983,125.23796081543 PathPoint;PointKind.SMOOTHPOINT 1916.11744880676,126.150941848755 1927.74544715881,127.222065925598 1904.48882102966,125.079817771912 PathPoint;PointKind.SMOOTHPOINT 1970.6672000885,126.150941848755 1979.61699485779,126.072106361389 1961.71740531921,126.229541301727 PathPoint;PointKind.SMOOTHPOINT 2015.47596931458,126.150941848755 2029.39507484436,126.028912067413 2001.55686378479,126.272971630096 PathPoint;PointKind.SMOOTHPOINT 2065.15554428101,126.150941848755 1879.62432861328,125.987606048584 2050.89088439941,126.138195991516 PathPoint;PointKind.SMOOTHPOINT 2557,127 2577.91201782227,126.780724048615 2423.7160987854,128.396851539612 PathPoint;PointKind.SMOOTHPOINT 2612.60301589966,126.150941848755 2620.49065589905,125.745198726654 2604.71474647522,126.556448936462 PathPoint;PointKind.SMOOTHPOINT 2640.85192680359,127.159044742584 2650.57402610779,126.828124523163 2631.12982749939,127.489728927612 PathPoint;PointKind.SMOOTHPOINT 2698.32409858704,127.159044742584 2705.85453987122,127.064394950867 2690.79365730286,127.253458499908 PathPoint;PointKind.SMOOTHPOINT 2716.8320274353,127.159044742584 2725.87308883667,127.525134086609 2707.79128074646,126.792719364166 PathPoint;PointKind.SMOOTHPOINT 2758.71869087219,128.16691160202 2777.01355934143,128.686895370483 2740.42382240295,127.64716386795 PathPoint;PointKind.SMOOTHPOINT 2796,127 2803.56820678711,126.846577644348 2788.43147850037,127.153658390045 PathPoint;PointKind.SMOOTHPOINT 2821.06135368347,126.150941848755 2835.10319709778,125.825686454773 2810.55624961853,126.394293308258 PathPoint;PointKind.SMOOTHPOINT 2853.2070350647,127.159044742584 2858.24841499329,127.367699146271 2848.16502571106,126.950154304504 PathPoint;PointKind.SMOOTHPOINT 2866.0164642334,126.746928691864 2872.39505767822,126.219627857208 2858.99019241333,127.327809333801 PathPoint;PointKind.SMOOTHPOINT 2882.42998123169,128.16691160202 2885.03926277161,128.391144275665 2878.77144813538,127.852749824524 PathPoint;PointKind.SMOOTHPOINT 2899.96387481689,127.159044742584 2902.89101600647,126.604835987091 2892.92344093323,128.491930961609 PathPoint;PointKind.SMOOTHPOINT 2907,125 2914.92509078979,124.273014068604 2903.22754096985,125.346026420593 PathPoint;PointKind.SMOOTHPOINT 2918.47211837769,128.16691160202 2925.78540802002,128.336384296417 2911.15851402283,127.997674942017 PathPoint;PointKind.SMOOTHPOINT 2954.51394081116,127.159044742584 2964.60865974426,127.509319782257 2944.41890716553,126.808533668518 PathPoint;PointKind.SMOOTHPOINT 2983.73688697815,127.159044742584 3000.43018341064,126.981782913208 2967.0442199707,127.336070537567 PathPoint;PointKind.SMOOTHPOINT 3556.51116371155,128.16691160202 3589.05621528625,129.120018482208 3523.96611213684,127.214040756226 PathPoint;PointKind.SMOOTHPOINT 3657.81806945801,128.16691160202 3662.44151115417,128.442599773407 3639.82626914978,127.09460735321 PathPoint;PointKind.SMOOTHPOINT 3673.40389251709,130.183117389679 3678.20042610168,130.604438781738 3668.60704421997,129.76179599762 PathPoint;PointKind.SMOOTHPOINT 3696,131 3700.29582595825,129.716208934784 3693.22266197205,131.82989692688 PathPoint;PointKind.SMOOTHPOINT 3716.26459121704,128.16691160202 3720.1944065094,128.155817985535 3710.95948219299,128.182017803192 PathPoint;PointKind.SMOOTHPOINT 3726.97960853577,130.183117389679 3730.55411338806,130.20884513855 3719.87780570984,130.131897926331 PathPoint;PointKind.SMOOTHPOINT 3739.64301109314,129.17501449585 3740.90500831604,129.150230884552 3731.82901382446,129.329144954681 PathPoint;PointKind.SMOOTHPOINT 3746.46157264709,130.183117389679 3748.35582733154,129.490592479706 3744.31806564331,130.967223644257 PathPoint;PointKind.SMOOTHPOINT 3750.35802841187,130.183117389679 3757.09035873413,130.263369083405 3749.51869010925,130.17320394516 PathPoint;PointKind.SMOOTHPOINT 3768.86627197266,129.17501449585 3785.69269180298,128.194527626038 3763.44818115234,129.490828514099 PathPoint;PointKind.SMOOTHPOINT 3790.29662132263,126.150941848755 3791.70118331909,126.151413917542 3778.91567230225,126.146929264069 PathPoint;PointKind.SMOOTHPOINT 3797.11518287659,126.150941848755 3804.36553001404,126.654875278473 3796.09457015991,126.079895496368 PathPoint;PointKind.SMOOTHPOINT 3806.85647964478,127.159044742584 3812.68967628479,127.564551830292 3801.7430305481,126.803340911865 PathPoint;PointKind.SMOOTHPOINT 3818.54553222656,123.126633167267 3822.42593765259,123.241581916809 3816.67960166931,123.071401119232 PathPoint;PointKind.SMOOTHPOINT 3826.3384437561,124.134736061096 3827.47109413147,125.101296901703 3824.70760345459,122.742841243744 PathPoint;PointKind.SMOOTHPOINT 3832.182970047,126.150941848755 3837.95920372009,126.397361755371 3828.29375267029,125.985009670258 PathPoint;PointKind.SMOOTHPOINT 3840.9499168396,123.126633167267 3848.33433151245,123.694531917572 3839.81065750122,123.039064407349 PathPoint;PointKind.SMOOTHPOINT 3862.38026618958,126.150941848755 3870.41298866272,125.682413578033 3854.34785842896,126.619470119476 PathPoint;PointKind.SMOOTHPOINT 3882,128 3893.43035888672,128.937056541443 3870.56932640076,127.062707424164 PathPoint;PointKind.SMOOTHPOINT 3906.21500015259,127.159044742584 3913.22805404663,127.190437316895 3899.20226097107,127.127416133881 PathPoint;PointKind.SMOOTHPOINT 3922.77485847473,124.134736061096 3933.80805015564,123.16392660141 3907.49084472656,125.479423999786 PathPoint;PointKind.SMOOTHPOINT 3937.38633155823,127.159044742584 3947.51913070679,126.808297634125 3930.85541725159,127.384929656982 PathPoint;PointKind.CORNERPOINT 3955,127 3955,127 3955,127 PathPoint;PointKind.SMOOTHPOINT 3966.60990715027,124.134736061096 3974.10573005676,123.469355106354 3959.11345481873,124.800353050232 PathPoint;PointKind.SMOOTHPOINT 3980.24703025818,125.142838954926 3988.00815582275,125.09256362915 3969.90117073059,125.209872722626 PathPoint;PointKind.SMOOTHPOINT 3993.88478279114,124.134736061096 3995.53009986877,123.824586868286 3988.94411087036,125.0661277771 PathPoint;PointKind.SMOOTHPOINT 3999.72930908203,122.118530273438 4007.82623291016,121.704289913177 3996.38360023499,122.289891242981 PathPoint;PointKind.SMOOTHPOINT 4013.36674690247,124.134736061096 4016.08617782593,124.570455551147 4009.20687675476,123.468410968781 PathPoint;PointKind.SMOOTHPOINT 4026.03014945984,124.134736061096 4038.35083007812,124.867150783539 4021.15934371948,123.845121860504 PathPoint;PointKind.SMOOTHPOINT 4059.14986610413,125.142838954926 4066.7344379425,125.225214958191 4041.04508399963,124.945986270905 PathPoint;PointKind.SMOOTHPOINT 4082.52828598022,124.134736061096 4084.77879524231,123.874390125275 4074.79957580566,125.028834342957 PathPoint;PointKind.SMOOTHPOINT 4089.34684753418,122.118530273438 4093.88154029846,121.99107170105 4087.22851753235,122.178246974945 PathPoint;PointKind.SMOOTHPOINT 4102.01056480408,124.134736061096 4104.99466896057,124.601848125458 4098.07476997375,123.518922328949 PathPoint;PointKind.SMOOTHPOINT 4110.77719688416,124.134736061096 4125.95955848694,123.800039291382 4107.771692276,124.201061725616 PathPoint;PointKind.SMOOTHPOINT 4153.63789558411,127.159044742584 4162.6767539978,126.998069286346 4139.26591873169,127.414906024933 PathPoint;PointKind.SMOOTHPOINT 4177.99129486084,125.973680019379 4178.85549545288,125.915615558624 4170.37902832031,126.484930515289 PathPoint;PointKind.SMOOTHPOINT 4180.58263778687,125.799958705902 4181.02732658386,125.207512378693 4179.40970420837,127.361090183258 PathPoint;PointKind.SMOOTHPOINT 4183.83519172668,125.142838954926 4186.74470901489,124.954011440277 4183.10946464539,125.190045833588 PathPoint;PointKind.SMOOTHPOINT 4191.62810325623,125.142838954926 4204.25342559814,124.528441429138 4188.59993934631,125.290124416351 PathPoint;PointKind.SMOOTHPOINT 4215.98055839539,126.150941848755 4222.65403747559,126.200981140137 4205.98875045776,126.076118946075 PathPoint;PointKind.SMOOTHPOINT 4235.46283721924,124.134736061096 4237.45433807373,123.724272251129 4229.58526611328,125.346536636353 PathPoint;PointKind.SMOOTHPOINT 4239.39328193665,122.296736240387 4240.59359550476,122.201850414276 4236.82711601257,122.499725818634 PathPoint;PointKind.SMOOTHPOINT 4243.25574874878,122.118530273438 4247.38981246948,122.056217193604 4241.8754196167,122.139537334442 PathPoint;PointKind.SMOOTHPOINT 4254.94480133057,122.118530273438 4256.88720703125,122.484147548676 4251.27777099609,121.428365707397 PathPoint;PointKind.SMOOTHPOINT 4259.8152923584,124.134736061096 4265.58365821838,125.766913890839 4257.93519973755,123.602714538574 PathPoint;PointKind.SMOOTHPOINT 4274.42708015442,124.134736061096 4286.61841392517,124.13072347641 4268.14762115479,124.136860370636 PathPoint;PointKind.SMOOTHPOINT 4290.98693847656,123.126633167267 4301.49644851685,122.847168445587 4280.47711372375,123.40633392334 PathPoint;PointKind.SMOOTHPOINT 4306.57244682312,127.159044742584 4308.85411262512,127.077848911285 4297.48984336853,127.481939792633 PathPoint;PointKind.SMOOTHPOINT 4310.46921730042,125.142838954926 4311.38093948364,124.984931945801 4308.94223213196,125.40696144104 PathPoint;PointKind.SMOOTHPOINT 4315.33970832825,126.150941848755 4316.16110801697,126.085796356201 4314.13467407227,126.246535778046 PathPoint;PointKind.SMOOTHPOINT 4318.26181411743,124.134736061096 4319.05394554138,124.045515060425 4317.26952552795,124.246616363525 PathPoint;PointKind.SMOOTHPOINT 4322.1582698822,126.150941848755 4322.83867835999,126.130878925323 4321.1914730072,126.179265975952 PathPoint;PointKind.SMOOTHPOINT 4324.10634040833,124.134736061096 4325.19052505493,124.033005237579 4323.35165977478,124.205546379089 PathPoint;PointKind.SMOOTHPOINT 4330.9252166748,124.134736061096 4332.30113983154,124.568567276001 4329.03096199036,123.537569046021 PathPoint;PointKind.SMOOTHPOINT 4332.87328720093,126.150941848755 4334.91923332214,126.181862354279 4331.70381546021,126.133239269257 PathPoint;PointKind.SMOOTHPOINT 4338.71812820435,124.134736061096 4341.15211486816,123.624665737152 4336.39680862427,124.621202945709 PathPoint;PointKind.SMOOTHPOINT 4348.45911026001,124.134736061096 4351.85580253601,124.091305732727 4344.47138786316,124.185955524445 PathPoint;PointKind.SMOOTHPOINT 4358.2004070282,122.118530273438 4368.88615608215,122.067782878876 4354.71339225769,122.135288715363 PathPoint;PointKind.SMOOTHPOINT 4378,122 4379.33375167847,122.047678947449 4367.18553352356,121.614555835724 PathPoint;PointKind.SMOOTHPOINT 4386.44931793213,124.134736061096 4409.24205780029,125.037803649902 4385.06741523743,124.079976081848 PathPoint;PointKind.SMOOTHPOINT 4446.84359550476,124.134736061096 4448.77813339233,124.158103466034 4433.18884849548,123.969275951385 PathPoint;PointKind.SMOOTHPOINT 4452.68843650818,122.118530273438 4453.40251922607,120.820105075836 4451.79339408875,123.7464594841 PathPoint;PointKind.SMOOTHPOINT 4457.55892753601,124.134736061096 4459.31282043457,125.384774208069 4456.1833190918,123.154485225677 PathPoint;PointKind.SMOOTHPOINT 4463.4034538269,122.118530273438 4466.32115364075,123.378245830536 4461.72949790955,121.395792961121 PathPoint;PointKind.SMOOTHPOINT 4471.68637275696,124.618134498596 4472.76048660278,124.494924545288 4468.3881855011,124.996025562286 PathPoint;PointKind.SMOOTHPOINT 4480,122 4485.25821685791,121.798190593719 4477.4605846405,122.097482204437 PathPoint;PointKind.SMOOTHPOINT 4493.60074996948,124.134736061096 4500.66478729248,124.44016456604 4489.79807853699,123.970220088959 PathPoint;PointKind.SMOOTHPOINT 4512.10867881775,123.126633167267 4515.57020187378,122.927656173706 4501.11608505249,123.758969306946 PathPoint;PointKind.SMOOTHPOINT 4526.72046661377,123.126633167267 4541.68001174927,123.196499347687 4520.46429634094,123.097364902496 PathPoint;PointKind.SMOOTHPOINT 4566.09415054321,122.930016517639 4567.36212730408,122.923171520233 4552.41202354431,123.003187179565 PathPoint;PointKind.SMOOTHPOINT 4571.52923583984,122.118530273438 4575.10877609253,122.106728553772 4570.20492553711,122.12301492691 PathPoint;PointKind.SMOOTHPOINT 4579.32214736938,122.118530273438 4580.01955032349,122.120890617371 4575.17612457275,122.105076313019 PathPoint;PointKind.SMOOTHPOINT 4581.27021789551,123.126633167267 4582.07053184509,123.146460056305 4580.51018714905,123.107986450195 PathPoint;PointKind.SMOOTHPOINT 4583.21860313416,122.118530273438 4586.27005577087,122.147090435028 4582.35314369202,122.110505104065 PathPoint;PointKind.SMOOTHPOINT 4592.95958518982,122.118530273438 4596.71473503113,122.353620529175 4589.29947853088,121.889576911926 PathPoint;PointKind.SMOOTHPOINT 4604.64895248413,123.126633167267 4643.22137832642,123.68579864502 4601.10591888428,123.075413703918 PathPoint;PointKind.SMOOTHPOINT 4654.32821273804,124.134736061096 4669.79601860046,124.481234550476 4638.86040687561,123.788237571716 PathPoint;PointKind.SMOOTHPOINT 4684.52582359314,123.126633167267 4697.88914680481,123.465342521667 4671.16218566895,122.78815984726 PathPoint;PointKind.SMOOTHPOINT 4712.77473449707,123.126633167267 4731.40445709229,122.725138664246 4694.14469718933,123.528363704681 PathPoint;PointKind.SMOOTHPOINT 4740,124 4760.52114486694,124.354523658752 4719.47916984558,123.645712375641 PathPoint;PointKind.SMOOTHPOINT 4786.80676460266,124.134736061096 4821.09437942505,123.240873813629 4752.51883506775,125.028598308563 PathPoint;PointKind.SMOOTHPOINT 4853.04588317871,124.134736061096 4874.69653129578,124.012942314148 4828.5599899292,124.27258014679 PathPoint;PointKind.SMOOTHPOINT 4893.67023468018,123.894217014313 4895.53238868713,123.955113887787 4879.449634552,123.427813053131 PathPoint;PointKind.SMOOTHPOINT 4899.80303764343,126.150941848755 4906.3742351532,126.304364204407 4897.55536079407,126.098306179047 PathPoint;PointKind.SMOOTHPOINT 4907,129 4907.96711158752,128.676868915558 4904.81904220581,129.729110240936 PathPoint;PointKind.SMOOTHPOINT 4912.46612548828,126.150941848755 4917.13614463806,124.619550704956 4910.15928268433,126.907432079315 PathPoint;PointKind.SMOOTHPOINT 4932.9224395752,124.134736061096 4947.23745346069,124.327812194824 4925.25415420532,124.031352996826 PathPoint;PointKind.SMOOTHPOINT 4978.70524406433,132.199323177338 4996.93748474121,138.014738559723 4958.17182540894,125.649840831757 PathPoint;PointKind.SMOOTHPOINT 5000.13559341431,147.320394515991 5006.95887565613,155.139977931976 4994.64291572571,141.024885177612 PathPoint;PointKind.SMOOTHPOINT 5011.82527542114,173.529889583588 5014.76720809937,190.817520618439 5010.22747993469,164.1437458992 PathPoint;PointKind.SMOOTHPOINT 5016.69576644897,221.917176246643 5016.50379180908,226.483969688416 5017.1369934082,211.395471096039 PathPoint;PointKind.SMOOTHPOINT 5016.69576644897,234.013938903809 5015.69309234619,236.872787475586 5017.46429443359,231.821415424347 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,254.175288677216 5013.45076560974,273.408315181732 5013.89986038208,246.617231369019 PathPoint;PointKind.SMOOTHPOINT 5015.72141647339,395.304501056671 5015.66067695618,413.016521930695 5015.78247070312,377.592480182648 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,909.418094158173 5015.1505279541,926.830823421478 5012.39584922791,892.005364894867 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,967.885937690735 5013.91779899597,980.455241203308 5013.62857818604,955.316634178162 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1058.61189365387 5014.67499732971,1072.18528747559 5014.81976509094,1045.03849983215 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,1234.01542425156 5014.02826309204,1241.1309170723 5013.51811408997,1226.89993143082 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1254.17677402496 5014.73227500916,1266.63183689117 5014.7624874115,1241.72147512436 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,1298.5316491127 5013.33180427551,1331.48275852203 5014.21488761902,1265.58053970337 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1521.31412744522 5015.05926132202,1535.19861459732 5014.43550109863,1507.42964029312 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,1584.82224941254 5013.78561973572,1594.37479734421 5013.74659538269,1564.38544750214 PathPoint;PointKind.SMOOTHPOINT 5014.75745201111,1624.85155820847 5014.78986740112,1625.99420070648 5014.33353424072,1610.06659984589 PathPoint;PointKind.SMOOTHPOINT 5014.85312461853,1628.25989484787 5014.46288108826,1630.07547140121 5015.08978843689,1627.1578502655 PathPoint;PointKind.SMOOTHPOINT 5014.94596481323,1631.75391197205 5015.30756950378,1645.81448078156 5014.91638183594,1630.60111999512 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1661.43523693085 5013.21756362915,1669.07449007034 5015.44919013977,1657.93012619019 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1679.58061695099 5014.36689376831,1687.09382772446 5015.12786865234,1672.06717014313 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1695.70955514908 5015.2042851992,1702.14937433829 5014.2883117112,1689.2392142422 PathPoint;PointKind.SMOOTHPOINT 5013.93830473198,1714.69559822696 5013.77484695167,1726.1120547187 5014.08760288353,1704.26809916109 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1768.29036712646 5013.8910484314,1790.01898527145 5015.60339927673,1746.56174898148 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1842.88714885712 5014.94502067566,1858.34692955017 5014.54942703247,1827.42760419846 PathPoint;PointKind.SMOOTHPOINT 5014,1874 5015.70857429504,1898.80013370514 5012.29142570496,1849.20010232925 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1948.73417615891 5015.09356498718,1966.37916326523 5014.40119743347,1931.08895301819 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,1998.1293296814 5014.79647636414,2002.91351079941 5014.6142578125,1985.22532939911 PathPoint;PointKind.SMOOTHPOINT 5014.16358947754,2012.06007957458 5013.5558795929,2019.68587875366 5014.52204704285,2007.56692886353 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2034.41985368729 5013.91779899597,2044.84690904617 5013.68239402771,2027.85856962204 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2088.85528564453 5015.05926132202,2115.57697534561 5014.43550109863,2062.13359594345 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2217.88773536682 5013.77712249756,2249.14954662323 5015.7176399231,2186.62592411041 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2298.53313446045 5014.13872718811,2313.93367052078 5015.35634994507,2283.13236236572 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2378.13801908493 5013.73463630676,2379.42912721634 5014.3061542511,2360.27233982086 PathPoint;PointKind.SMOOTHPOINT 5012.7993106842,2383.17829751968 5012.75304794312,2388.94249343872 5012.86256790161,2375.26902103424 PathPoint;PointKind.SMOOTHPOINT 5013.54423522949,2388.68639612198 5014.11764144897,2412.72744321823 5013.52314949036,2387.81802558899 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2469.90425348282 5014.73982810974,2489.23074960709 5012.95226097107,2453.48381280899 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2547.52534389496 5014.12330627441,2571.00604534149 5013.42307090759,2524.04440641403 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2617.08184719086 5015.42086601257,2639.05452489853 5014.07389640808,2595.10916948318 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2691.67862892151 5013.50300788879,2724.92525339127 5014.04336929321,2658.43224048615 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2755.18698692322 5014.12739753723,2771.3513302803 5013.4192943573,2739.02240753174 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2816.67890310287 5014.55698013306,2844.45967912674 5014.93746757507,2788.89812707901 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2888.25161218643 5014.72314834595,2905.23688316345 5014.77161407471,2871.18066072464 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,2936.63866281509 5013.2285785675,2947.27909326553 5014.2932510376,2926.47927045822 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,2979.9856710434 5014.38955307007,2992.6139831543 5015.10520935059,2967.3571228981 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3012.24378347397 5014.18656349182,3019.89058971405 5013.19490432739,3001.54882907867 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3056.59865856171 5014.85690116882,3063.42972993851 5014.47263717651,3039.461145401 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3074.74380254745 5015.26413917542,3092.43859291077 5014.58750724792,3069.2623758316 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3092.8889465332 5013.68963241577,3102.28453159332 5013.85705947876,3083.49359750748 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3130.18733739853 5014.11197662354,3143.81596326828 5013.43440055847,3116.55894756317 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3181.59869670868 5013.48790168762,3194.07665491104 5014.04022216797,3169.92278337479 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3211.84083938599 5013.86461257935,3220.29606342316 5013.66665840149,3201.96492433548 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3248.16330289841 5013.8743686676,3250.41577911377 5013.17161560059,3234.75772953033 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3256.22789001465 5014.93211746216,3258.4912238121 5014.60355758667,3254.46400499344 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3261.2681684494 5013.74565124512,3268.74739027023 5013.77964019775,3259.57532978058 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3289.46192979813 5014.16516304016,3304.78363037109 5013.45391273499,3276.96815729141 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3326.76032066345 5014.30993080139,3336.68745517731 5013.23676109314,3316.8331861496 PathPoint;PointKind.SMOOTHPOINT 5012.7993106842,3343.89736175537 5014.05123710632,3353.08027982712 5011.54738426208,3334.71444368362 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3372.12329864502 5013.69277954102,3383.82470369339 5013.8498210907,3361.01410388947 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3390.26844263077 5015.79002380371,3395.67882299423 5013.70473861694,3384.8580622673 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3407.40548372269 5014.4506072998,3412.85929441452 5015.04415512085,3401.95167303085 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3427.56683349609 5013.26728820801,3440.85675001144 5016.22778892517,3414.27691698074 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3445.71197748184 5013.64022254944,3463.16034793854 5013.90646934509,3428.26384305954 PathPoint;PointKind.SMOOTHPOINT 5014.74738121033,3491.07495546341 5014.35178756714,3510.30302524567 5015.14297485352,3471.84688568115 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3567.68794298172 5013.93699645996,3598.11914920807 5013.60969543457,3537.25697278976 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3626.15578651428 5013.31669807434,3638.77253293991 5014.22999382019,3613.53927612305 PathPoint;PointKind.SMOOTHPOINT 5011.82527542114,3652.36551761627 5011.46146774292,3669.7421336174 5012.16831207275,3635.97080469131 PathPoint;PointKind.SMOOTHPOINT 5010.85092544556,3693.69632005692 5010.69514274597,3716.72832012177 5011.00702285767,3670.66431999207 PathPoint;PointKind.SMOOTHPOINT 5016.69576644897,3776.35768890381 5017.14454650879,3792.98678398132 5016.24667167664,3759.72859382629 PathPoint;PointKind.SMOOTHPOINT 5013.77334594727,3807.60769844055 5011.07090950012,3813.89636278152 5017.56846427917,3798.77694368362 PathPoint;PointKind.SMOOTHPOINT 5002.22528457642,3821.94702386856 5001.51812553406,3822.4502491951 5007.09671974182,3818.4808588028 PathPoint;PointKind.SMOOTHPOINT 5000.04747390747,3823.38801383972 4998.73323440552,3823.37219953537 5001.38814926147,3823.40406417847 PathPoint;PointKind.SMOOTHPOINT 4996.54000282288,3825.32892465591 4992.85062789917,3827.16503620148 4997.74755477905,3824.72798109055 PathPoint;PointKind.SMOOTHPOINT 4984.55039978027,3829.78525400162 4979.43065643311,3831.2184548378 4988.81601333618,3828.59091997147 PathPoint;PointKind.SMOOTHPOINT 4967.99022674561,3833.81742954254 4949.8401260376,3835.98328113556 4973.14270019531,3833.20255994797 PathPoint;PointKind.SMOOTHPOINT 4793.62532615662,3835.8336353302 4779.3449306488,3837.70397186279 4807.90603637695,3833.96306276321 PathPoint;PointKind.SMOOTHPOINT 4641.66512489319,3835.8336353302 4619.45806503296,3837.44409799576 4663.87155532837,3834.22293663025 PathPoint;PointKind.SMOOTHPOINT 4478.98927688599,3835.8336353302 4450.24563789368,3836.60546779633 4507.73323059082,3835.06180286407 PathPoint;PointKind.SMOOTHPOINT 4394.24191474915,3835.8336353302 4380.04523277283,3836.751101017 4408.43891143799,3834.9161696434 PathPoint;PointKind.SMOOTHPOINT 4360.14847755432,3835.8336353302 4351.35257720947,3835.68328142166 4370.06443977356,3836.0028719902 PathPoint;PointKind.SMOOTHPOINT 4328.0027961731,3835.8336353302 4326.74142837524,3835.79799413681 4337.90365219116,3836.11380815506 PathPoint;PointKind.SMOOTHPOINT 4320.21019935608,3835.8336353302 4310.98628997803,3836.2745475769 4321.25221252441,3835.78383207321 PathPoint;PointKind.SMOOTHPOINT 4293.90935897827,3835.8336353302 4287.89488792419,3836.0772228241 4304.28637504578,3835.41325807571 PathPoint;PointKind.SMOOTHPOINT 4270.19451141357,3836.04748249054 4269.03322219849,3836.04063749313 4279.87664222717,3836.10365867615 PathPoint;PointKind.SMOOTHPOINT 4266.63951873779,3836.02387905121 4265.71615219116,3835.39437532425 4268.2495880127,3837.12191104889 PathPoint;PointKind.SMOOTHPOINT 4263.26454162598,3835.99744319916 4257.68122673035,3835.95070838928 4264.40883636475,3836.00688457489 PathPoint;PointKind.SMOOTHPOINT 4245.20413398743,3835.8336353302 4224.2732334137,3835.65259695053 4251.64346694946,3835.88933944702 PathPoint;PointKind.SMOOTHPOINT 4197.47294425964,3835.8336353302 4176.34692192078,3835.09720802307 4218.59865188599,3836.57006263733 PathPoint;PointKind.SMOOTHPOINT 4156.56031608582,3835.8336353302 4149.24545288086,3836.10696315765 4175.30805587769,3835.13261318207 PathPoint;PointKind.SMOOTHPOINT 4140.00045776367,3835.8336353302 4135.14003753662,3836.13835573196 4143.11013221741,3835.63867092133 PathPoint;PointKind.SMOOTHPOINT 4126.36301994324,3836.84173822403 4112.61165618896,3836.55424833298 4134.7491645813,3837.01687574387 PathPoint;PointKind.SMOOTHPOINT 4098.11379432678,3835.8336353302 4079.01231765747,3835.64055919647 4117.21558570862,3836.02647542953 PathPoint;PointKind.SMOOTHPOINT 4051.35663986206,3835.8336353302 4019.22574996948,3836.27926826477 4083.47525596619,3835.38800239563 PathPoint;PointKind.SMOOTHPOINT 3960.76475143433,3835.8336353302 3903.22617530823,3836.01915836334 4018.40246200562,3835.64764022827 PathPoint;PointKind.SMOOTHPOINT 3856.53573989868,3835.8336353302 3832.8945350647,3835.30987501144 3880.17694473267,3836.35739564896 PathPoint;PointKind.SMOOTHPOINT 3799.06356811523,3835.8336353302 3784.19308662415,3835.85723876953 3813.93404960632,3835.81003189087 PathPoint;PointKind.SMOOTHPOINT 3773.73676300049,3835.8336353302 3758.94999504089,3835.84944963455 3788.52321624756,3835.81782102585 PathPoint;PointKind.SMOOTHPOINT 3746.46157264709,3836.84173822403 3733.821144104,3836.62104606628 3759.10263061523,3837.06219434738 PathPoint;PointKind.SMOOTHPOINT 3713.34217071533,3836.84173822403 3702.93934822083,3837.43229627609 3723.74530792236,3836.25094413757 PathPoint;PointKind.SMOOTHPOINT 3670.48147201538,3836.84173822403 3636.57969474792,3836.94323301315 3704.30268287659,3836.74024343491 PathPoint;PointKind.SMOOTHPOINT 3564.30376052856,3836.84173822403 3541.09969139099,3836.44661664963 3588.59295845032,3837.25503444672 PathPoint;PointKind.SMOOTHPOINT 3473.71250152588,3836.84173822403 3437.8639125824,3836.92246198654 3509.39114570618,3836.76125049591 PathPoint;PointKind.SMOOTHPOINT 3328.57023239136,3836.84173822403 3310.92618942261,3836.95975542068 3346.21490478516,3836.72348499298 PathPoint;PointKind.SMOOTHPOINT 3262.33111381531,3836.84173822403 3242.52310752869,3836.55401229858 3292.98537254333,3837.28666305542 PathPoint;PointKind.SMOOTHPOINT 3190.24746894836,3836.84173822403 3188.51466178894,3836.85472011566 3201.57995223999,3836.75582170486 PathPoint;PointKind.SMOOTHPOINT 3184.40294265747,3836.84173822403 3183.68036270142,3837.32678890228 3186.12882614136,3835.68233728409 PathPoint;PointKind.SMOOTHPOINT 3178.71766090393,3836.91892147064 3170.19713401794,3837.53331899643 3180.18233299255,3836.81341409683 PathPoint;PointKind.SMOOTHPOINT 3153.23161125183,3836.84173822403 3115.94604492188,3836.52710437775 3161.63412094116,3836.91254854202 PathPoint;PointKind.SMOOTHPOINT 3070.43231964111,3836.84173822403 3052.26679801941,3836.94394111633 3088.59784126282,3836.73929929733 PathPoint;PointKind.SMOOTHPOINT 3026.5975856781,3836.84173822403 2998.47046852112,3837.0227766037 3054.72501754761,3836.66046380997 PathPoint;PointKind.SMOOTHPOINT 2922.36857414246,3836.84173822403 2919.61515426636,3836.9170331955 2956.89599990845,3835.89665651321 PathPoint;PointKind.SMOOTHPOINT 2914.10548210144,3837.02183246613 2913.53994369507,3837.03127384186 2916.86267852783,3836.97627782822 PathPoint;PointKind.SMOOTHPOINT 2911.65324211121,3836.84173822403 2910.82397460938,3836.85377597809 2912.21972465515,3836.83347702026 PathPoint;PointKind.SMOOTHPOINT 2909.70485687256,3835.8336353302 2908.5659122467,3836.57855987549 2911.25985145569,3834.81656312943 PathPoint;PointKind.SMOOTHPOINT 2905.869140625,3837.11978673935 2905.30045509338,3837.12403535843 2907.22083091736,3837.10963726044 PathPoint;PointKind.SMOOTHPOINT 2904.16213989258,3837.13111639023 2875.44965744019,3837.29988098145 2904.73176956177,3837.12781190872 PathPoint;PointKind.SMOOTHPOINT 2808.3979511261,3836.84173822403 2763.36479187012,3837.47950315475 2845.53654670715,3836.31561756134 PathPoint;PointKind.SMOOTHPOINT 2607.7322101593,3835.8336353302 2561.9188785553,3835.62498092651 2653.54585647583,3836.04228973389 PathPoint;PointKind.SMOOTHPOINT 2465.51267623901,3835.8336353302 2424.08266067505,3837.58194208145 2506.94269180298,3834.08532857895 PathPoint;PointKind.SMOOTHPOINT 2382.71401405334,3834.82553243637 2337.56629943848,3835.55015802383 2427.86141395569,3834.10090684891 PathPoint;PointKind.SMOOTHPOINT 2281.40679359436,3835.8336353302 2234.34153556824,3836.13670349121 2328.47205162048,3835.5303311348 PathPoint;PointKind.SMOOTHPOINT 2193.73732566833,3835.8336353302 2163.47960472107,3835.38328170776 2254.32987213135,3836.73528671265 PathPoint;PointKind.SMOOTHPOINT 2120.67933082581,3835.8336353302 2100.62301635742,3835.55889129639 2140.68466186523,3836.10743522644 PathPoint;PointKind.SMOOTHPOINT 2063.20715904236,3835.8336353302 2024.86541748047,3835.5761218071 2084.1563129425,3835.97431182861 PathPoint;PointKind.SMOOTHPOINT 1982.35625267029,3835.8336353302 1927.89776802063,3835.50271511078 2036.81505203247,3836.16431951523 PathPoint;PointKind.SMOOTHPOINT 1849.87801551819,3834.82553243637 1802.26987838745,3835.10995388031 1899.57867622375,3834.52860116959 PathPoint;PointKind.SMOOTHPOINT 1722.27026939392,3833.81742954254 1676.34490013123,3834.27604436874 1770.61703681946,3833.33473920822 PathPoint;PointKind.SMOOTHPOINT 1622.91143417358,3832.80932664871 1581.19597434998,3833.56534481049 1664.62657928467,3832.05330848694 PathPoint;PointKind.SMOOTHPOINT 1478.74382972717,3831.80122375488 1445.51018714905,3832.47864246368 1511.97778701782,3831.12404108047 PathPoint;PointKind.SMOOTHPOINT 1359.90303039551,3831.80122375488 1311.17483139038,3831.51396989822 1408.63091468811,3832.08871364594 PathPoint;PointKind.SMOOTHPOINT 1238.13949584961,3831.80122375488 1185.84434509277,3831.64803743362 1312.81637191772,3832.02026367188 PathPoint;PointKind.SMOOTHPOINT 1143.36979866028,3831.47620439529 1142.77090072632,3831.47832870483 1169.01226043701,3831.3912320137 PathPoint;PointKind.SMOOTHPOINT 1141.55831336975,3831.48281335831 1140.15406608582,3831.48824214935 1142.16728210449,3831.48045301437 PathPoint;PointKind.SMOOTHPOINT 1136.83259010315,3831.80122375488 1134.86941337585,3832.59925603867 1138.52763175964,3831.1124753952 PathPoint;PointKind.SMOOTHPOINT 1130.68593978882,3831.54182195663 1122.78476715088,3831.5958738327 1132.96162605286,3831.52624368668 PathPoint;PointKind.SMOOTHPOINT 1102.73915290833,3831.80122375488 1044.36123847961,3832.44701385498 1113.75472068787,3831.67943000793 PathPoint;PointKind.SMOOTHPOINT 997.53547668457,3831.80122375488 939.073848724365,3832.17935085297 1055.99710464478,3831.42333269119 PathPoint;PointKind.SMOOTHPOINT 867.979345321655,3831.80122375488 816.892061233521,3832.45503902435 919.06662940979,3831.14764451981 PathPoint;PointKind.SMOOTHPOINT 806.611032485962,3831.80122375488 796.228666305542,3831.83403253555 834.792280197144,3831.7122387886 PathPoint;PointKind.SMOOTHPOINT 779.336156845093,3831.80122375488 771.158037185669,3832.28178977966 784.231824874878,3831.51373386383 PathPoint;PointKind.SMOOTHPOINT 760.827913284302,3832.80932664871 755.290861129761,3833.51742982864 768.31618309021,3831.85197114944 PathPoint;PointKind.SMOOTHPOINT 739.397563934326,3830.79335689545 727.794742584229,3830.90358495712 757.519969940186,3830.62081575394 PathPoint;PointKind.SMOOTHPOINT 723,3834 717.067983627319,3834.11801719666 728.932331085205,3833.88174676895 PathPoint;PointKind.SMOOTHPOINT 705.303812026978,3833.81742954254 688.843088150024,3832.84095525742 721.764850616455,3834.79413986206 PathPoint;PointKind.SMOOTHPOINT 678.028936386108,3836.84173822403 666.320686340332,3836.19193553925 689.737186431885,3837.49130487442 PathPoint;PointKind.SMOOTHPOINT 659.520692825317,3833.81742954254 643.741006851196,3833.26227664948 675.300693511963,3834.37258243561 PathPoint;PointKind.SMOOTHPOINT 626.401290893555,3833.81742954254 607.269287109375,3836.11310005188 645.533294677734,3831.5217590332 PathPoint;PointKind.SMOOTHPOINT 597,3837 588.173572540283,3836.611723423 607.829257965088,3837.47655344009 PathPoint;PointKind.SMOOTHPOINT 582.566556930542,3833.81742954254 581.016912460327,3833.54669809341 589.395189285278,3835.01081943512 PathPoint;PointKind.SMOOTHPOINT 573.799610137939,3833.81742954254 570.394735336304,3833.56676101685 576.402282714844,3834.00908946991 PathPoint;PointKind.SMOOTHPOINT 561.136207580566,3833.81742954254 556.235189437866,3834.30082798004 564.418973922729,3833.49382638931 PathPoint;PointKind.SMOOTHPOINT 546.52473449707,3837.84960508347 542.662267684937,3838.94291639328 550.041961669922,3836.85424804688 PathPoint;PointKind.SMOOTHPOINT 538.731822967529,3838.85770797729 536.713571548462,3839.12678718567 541.591300964355,3838.4765124321 PathPoint;PointKind.SMOOTHPOINT 533.861331939697,3837.84960508347 530.307598114014,3837.34968423843 535.243864059448,3838.04433345795 PathPoint;PointKind.SMOOTHPOINT 522.17227935791,3836.84173822403 514.257574081421,3836.8181347847 527.870464324951,3836.85873270035 PathPoint;PointKind.SMOOTHPOINT 509.508562088013,3837.84960508347 499.889373779297,3837.07800865173 519.128065109253,3838.62143754959 PathPoint;PointKind.SMOOTHPOINT 490.026597976685,3836.84173822403 470.947780609131,3837.27084875107 509.105415344238,3836.4123916626 PathPoint;PointKind.SMOOTHPOINT 463.725757598877,3837.84960508347 453.052282333374,3838.09390068054 474.398918151855,3837.60554552078 PathPoint;PointKind.SMOOTHPOINT 449.113969802856,3836.84173822403 444.646940231323,3836.29437446594 453.581314086914,3837.38910198212 PathPoint;PointKind.SMOOTHPOINT 441.32137298584,3838.85770797729 435.659065246582,3839.20420646667 446.983366012573,3838.51120948792 PathPoint;PointKind.CORNERPOINT 436.450881958008,3837.84960508347 436.450881958008,3837.84960508347 436.450881958008,3837.84960508347 PathPoint;PointKind.SMOOTHPOINT 427.683935165405,3838.85770797729 426.991882324219,3840.10373353958 428.826026916504,3836.80090427399 PathPoint;PointKind.SMOOTHPOINT 404.305515289307,3840.87391376495 358.867950439453,3838.15503358841 413.399448394775,3841.41820907593 PathPoint;PointKind.SMOOTHPOINT 315.661697387695,3837.84960508347 306.952303584577,3837.20498288972 340.664663314819,3839.70035076141 PathPoint;PointKind.SMOOTHPOINT 294,3834 292.649876937068,3833.34884051339 299.008670252777,3836.41566360872 PathPoint;PointKind.SMOOTHPOINT 290.469094929839,3829.56565585213 289.595362581487,3828.02173159953 291.508602588431,3831.40251251412 PathPoint;PointKind.SMOOTHPOINT 289,3828 286.471939307067,3828.92021655836 289.910022330321,3827.66874181687 PathPoint;PointKind.SMOOTHPOINT 283,3826 279.879472502159,3823.8838358752 284.601027586723,3827.08572577687 PathPoint;PointKind.SMOOTHPOINT 275.723419189453,3814.66418266296 268.364181518555,3794.70369815826 278.052361108568,3820.98146621814 PathPoint;PointKind.SMOOTHPOINT 264.033737182617,3752.16416358948 262.98228263855,3740.06740093231 265.042705535889,3763.76572608948 PathPoint;PointKind.CORNERPOINT 263.059701919556,3567.68794298172 263.059701919556,3567.68794298172 263.059701919556,3567.68794298172 PathPoint;PointKind.CORNERPOINT 263.059701919556,3116.0746049881 263.059701919556,3116.0746049881 263.059701919556,3116.0746049881 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2761.78749994296 263.059701919556,2760.08915127093 263.059701919556,2929.54711843781 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2756.69843745691 264.619076919556,2754.47027805372 262.088231912857,2758.08655130402 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2749.74062499062 263.059701919556,2617.48975238912 263.059701919556,2752.05551161566 PathPoint;PointKind.CORNERPOINT 263.059701919556,2500.14616012573 263.059701919556,2500.14616012573 263.059701919556,2500.14616012573 PathPoint;PointKind.SMOOTHPOINT 264.033737182617,2489.0575003624 264.152069091797,2480.54397583008 263.916034698486,2497.57102489471 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2470.91235637665 262.717609405518,2455.14148235321 263.402423858643,2486.68299436569 PathPoint;PointKind.SMOOTHPOINT 264.033737182617,2445.71072816849 263.601007461548,2438.10192346573 264.245538711548,2449.42708969116 PathPoint;PointKind.SMOOTHPOINT 263.059701919556,2385.22667884827 262.893533706665,2358.45589399338 263.233423233032,2413.15875291824 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,2110.02473831177 268.040657043457,2060.71998596191 267.820043563843,2159.32925462723 PathPoint;PointKind.SMOOTHPOINT 265.008401870728,2015.26637077332 264.441289901733,2001.05521202087 265.575199127197,2029.47776556015 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1967.88742303848 266.899194717407,1939.95676517487 267.01343536377,1995.81784486771 PathPoint;PointKind.SMOOTHPOINT 268.904542922974,1914.45985794067 267.458438873291,1897.18497276306 270.350646972656,1931.73474311829 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1881.19364261627 267.036409378052,1868.84880781174 266.876535415649,1893.53847742081 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1855.99201440811 266.400474005954,1850.39577176115 271.419725418091,1868.75439405441 PathPoint;PointKind.SMOOTHPOINT 268,1843 268.54200575965,1837.88856726584 267.576718159811,1846.99179642503 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1821.71793222427 266.773624420166,1803.34808349609 268.579917020696,1832.03240832884 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1759.21767711639 270.148601531982,1729.31447982788 265.712099075317,1789.1211104393 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1658.41116428375 267.437982559204,1652.06042289734 269.286289215088,1675.89848041534 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1619.09656763077 267.355842590332,1597.53340959549 266.556787490845,1640.65972566605 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1514.25764322281 265.792036056519,1493.02139282227 268.120594024658,1535.49412965775 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1405.38654327393 268.368272781372,1378.94455432892 267.493057250977,1431.82853221893 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1315.66869020462 267.036409378052,1292.12874412537 268.824920654297,1339.20863628387 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1234.01542425156 267.938690185547,1230.71589946747 267.899980545044,1246.54531002045 PathPoint;PointKind.SMOOTHPOINT 267.989044189453,1226.17436170578 268.029642105103,1223.65965127945 267.955055236816,1228.31991434097 PathPoint;PointKind.SMOOTHPOINT 265.008401870728,1220.91055870056 265.044002496356,1219.92412469878 264.903602600098,1223.78923416138 PathPoint;PointKind.SMOOTHPOINT 265,1215 264.374674118357,1212.74164092043 265.808894326191,1217.92131494888 PathPoint;PointKind.SMOOTHPOINT 265.982437133789,1206.79759025574 266.941995620728,1203.07414770126 265.574123662709,1208.38115400949 PathPoint;PointKind.SMOOTHPOINT 268.904542922974,1199.74110603333 269.696044921875,1177.49675273895 268.725471496582,1204.77123498917 PathPoint;PointKind.SMOOTHPOINT 266.956472396851,1164.45892095566 266.344985961914,1155.85570335388 268.127202987671,1180.94379901886 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1118.08784008026 268.530979156494,1097.51390218735 267.321224212646,1138.95823717117 PathPoint;PointKind.SMOOTHPOINT 268.904542922974,1083.81352186203 267.260799407959,1067.70582675934 270.334596633911,1097.82405138016 PathPoint;PointKind.SMOOTHPOINT 267.930507659912,1032.40216255188 267.062845230103,1012.6031255722 268.797855377197,1052.20119953156 PathPoint;PointKind.SMOOTHPOINT 268.904542922974,976.958627700806 268.965282440186,954.40318107605 268.843803405762,999.514074325562 PathPoint;PointKind.SMOOTHPOINT 269.87889289856,903.36971282959 270.761661529541,874.836695194244 268.995809555054,931.902730464935 PathPoint;PointKind.SMOOTHPOINT 269.87889289856,821.716446876526 270.77299118042,794.262342453003 268.984479904175,849.170551300049 PathPoint;PointKind.SMOOTHPOINT 270.852928161621,755.184016227722 272.33302116394,730.147848129272 269.372520446777,780.220420360565 PathPoint;PointKind.SMOOTHPOINT 270.852928161621,699.740481376648 270.28959274292,675.373470783234 271.415948867798,724.107255935669 PathPoint;PointKind.SMOOTHPOINT 271.826963424683,649.337224960327 271.454029083252,632.637083530426 272.199897766113,666.037130355835 PathPoint;PointKind.SMOOTHPOINT 271.826963424683,625.143463611603 272.45922088623,619.019551277161 271.19439125061,631.267611980438 PathPoint;PointKind.SMOOTHPOINT 271.826963424683,600.949938297272 270.90989112854,584.419269561768 272.744035720825,617.480607032776 PathPoint;PointKind.SMOOTHPOINT 272.800998687744,553.570754528046 272.211227416992,530.113656520844 273.390769958496,577.028088569641 PathPoint;PointKind.SMOOTHPOINT 272.800998687744,524.336950778961 270.080308914185,517.989277839661 275.521688461304,530.684623718262 PathPoint;PointKind.SMOOTHPOINT 269.87889289856,507.199909687042 266.400690078735,499.887328147888 273.356466293335,514.512255191803 PathPoint;PointKind.SMOOTHPOINT 268,475 268.290794372559,459.345018863678 267.699449539185,491.186530590057 PathPoint;PointKind.SMOOTHPOINT 268.904542922974,439.659376144409 267.780389785767,409.122426509857 269.300451278687,450.406258106232 PathPoint;PointKind.SMOOTHPOINT 269.87889289856,384.215841293335 269.587154388428,355.303988456726 270.222244262695,418.311717510223 PathPoint;PointKind.SMOOTHPOINT 269.87889289856,283.4090924263 269.601001739502,253.30502986908 270.156154632568,313.513391017914 PathPoint;PointKind.SMOOTHPOINT 270.852928161621,231.99773311615 269.133024215698,212.9705286026 272.572832107544,251.025173664093 PathPoint;PointKind.SMOOTHPOINT 264.80320930481,176.096999645233 263.05718421936,157.326836585999 266.551752090454,194.896194934845 PathPoint";
	
	subshadow645[0] = "PointKind.SMOOTHPOINT 265.109375,162.890625 269.301604338475,150.362919662999 263.203267145312,168.586677294878 PathPoint;PointKind.SMOOTHPOINT 282.04994152889,130.6587430432 290.198577183496,122.939743055788 260.897968329498,150.695481434803 PathPoint;PointKind.SMOOTHPOINT 315.109375,120.890625 339.401864595078,121.738918681791 297.88159000085,120.288944352648 PathPoint;PointKind.SMOOTHPOINT 4918.109375,123.890625 4923.53218650818,123.890625 4912.68656349182,123.890625 PathPoint;PointKind.SMOOTHPOINT 4974.39086341858,131.214654922485 4979.61918258667,132.822285175323 4962.16963195801,127.456987380981 PathPoint;PointKind.SMOOTHPOINT 5000.4443397522,144.254374980927 5011.14141845703,155.85617351532 4992.44592094421,135.579638957977 PathPoint;PointKind.SMOOTHPOINT 5013.109375,192.890625 5016.14225959778,213.81719827652 5012.29741668701,187.288348674774 PathPoint;PointKind.CORNERPOINT 5019.109375,434.890625 5019.109375,434.890625 5019.109375,434.890625 PathPoint;PointKind.CORNERPOINT 5016.109375,3539.890625 5016.109375,3539.890625 5016.109375,3539.890625 PathPoint;PointKind.CORNERPOINT 5018.109375,3783.890625 5018.109375,3783.890625 5018.109375,3783.890625 PathPoint;PointKind.SMOOTHPOINT 5001.10932731628,3825.89051771164 4994.9054227795,3833.0204376327 5016.26416517764,3808.47432702575 PathPoint;PointKind.CORNERPOINT 4953.109375,3834.890625 4953.109375,3834.890625 4953.109375,3834.890625 PathPoint;PointKind.CORNERPOINT 361.109375,3838.890625 361.109375,3838.890625 361.109375,3838.890625 PathPoint;PointKind.SMOOTHPOINT 280.764186859131,3821.45110225677 268.756330490112,3801.8847951889 293.951271057129,3842.93872928619 PathPoint;PointKind.CORNERPOINT 271.109375,3768.890625 271.109375,3768.890625 271.109375,3768.890625 PathPoint;PointKind.CORNERPOINT 266.109375,3537.890625 266.109375,3537.890625 266.109375,3537.890625 PathPoint;PointKind.CORNERPOINT 268.109375,403.890625 268.109375,403.890625 268.109375,403.890625 PathPoint";
}



// Square

var negativeSquare = [];
var maskSquare = [];
var shadowSquare = [];
var subshadowSquare = [];

// Negative shapes

if (fancy == true && mask_variant_square == 3) {
	
	negativeSquare[0] = "PointKind.CORNERPOINT 121.019946535061,186.656970764108 121.019946535061,186.656970764108 121.019946535061,186.656970764108 PathPoint;PointKind.SMOOTHPOINT 447.657824388238,186.875961018811 499.38580728597,186.084849940257 381.311347769971,187.890950512782 PathPoint;PointKind.SMOOTHPOINT 785.260127493317,186.875961018811 812.144754748943,187.206128020252 729.360856951121,186.189464982351 PathPoint;PointKind.SMOOTHPOINT 1075.34513325652,186.889723810108 1077.4097142761,186.890196397371 949.631377984598,186.859478225265 PathPoint;PointKind.SMOOTHPOINT 1081.53371916034,186.891141571898 1084.34559648569,188.279366657472 1079.70292916379,185.987318431077 PathPoint;PointKind.SMOOTHPOINT 1088.97082771237,186.893504508214 1206.08220299918,186.931075195636 1086.49539335085,186.892559333687 PathPoint;PointKind.SMOOTHPOINT 1320.73205840016,186.875961018811 1342.12025332561,186.364385306425 1310.58302309671,187.118634578451 PathPoint;PointKind.SMOOTHPOINT 1684.89776037501,186.858847154192 1689.51095824022,186.971559216459 1662.49262361513,186.311354809805 PathPoint;PointKind.SMOOTHPOINT 1775.63642771693,187.340413575367 1779.11382360575,187.353882312367 1723.76846489995,187.139327694886 PathPoint;PointKind.SMOOTHPOINT 1786.30265198521,187.381292373631 1789.07007954673,186.293632787436 1782.94387065956,188.701228599677 PathPoint;PointKind.SMOOTHPOINT 1793.51014435391,187.408229847632 2001.87295552896,188.188235125501 1791.07621281055,187.399250689632 PathPoint;PointKind.SMOOTHPOINT 2468.17143349182,186.92477021324 2475.44817908373,187.041735560876 2435.58189808046,186.40067093838 PathPoint;PointKind.SMOOTHPOINT 2577.92305755039,187.389559786572 2579.32457579456,187.39381307194 2515.86922260909,187.20028858767 PathPoint;PointKind.SMOOTHPOINT 2582.16101100048,187.402319642677 2586.15829722098,188.520461107347 2580.79485610433,187.020232840401 PathPoint;PointKind.SMOOTHPOINT 2592.5192794464,187.433510402047 2781.78465479563,187.995180364329 2589.00578347315,187.422877188626 PathPoint;PointKind.SMOOTHPOINT 3398.99346131982,186.597736962958 3400.94728629803,186.603644303748 3141.35477162203,185.803790360826 PathPoint;PointKind.SMOOTHPOINT 3404.83651784401,186.615695278959 3406.42246577127,185.241884104912 3403.3301374498,187.920508712583 PathPoint;PointKind.SMOOTHPOINT 3411.23728383596,186.635780237644 3582.59782099486,187.170396018234 3409.11130811496,186.628927722328 PathPoint;PointKind.CORNERPOINT 3840,186.875961018811 3840,186.875961018811 3840,186.875961018811 PathPoint;PointKind.CORNERPOINT 3839.21910343409,3774.18660762539 3839.21910343409,3774.18660762539 3839.21910343409,3774.18660762539 PathPoint;PointKind.SMOOTHPOINT 3766.58611745312,3774.01107200822 3760.47313300508,3773.87370444785 3772.69910190116,3774.14843956859 PathPoint;PointKind.SMOOTHPOINT 3295.16303104164,3774.0549419497 3254.83457072603,3774.65441889304 3335.49173693606,3773.45546500637 PathPoint;PointKind.SMOOTHPOINT 2697.27551270416,3774.09881189119 2679.96368037464,3774.36275187768 2737.91782273346,3773.4794862828 PathPoint;PointKind.SMOOTHPOINT 2094.17795361162,3774.87708530382 2088.81377575856,3774.87212313756 2402.51049385631,3775.1679627643 PathPoint;PointKind.SMOOTHPOINT 2078.05128459844,3774.8619625114 2076.74013935477,3775.17835968409 2086.40759462024,3772.84496007217 PathPoint;PointKind.SMOOTHPOINT 2073.9918669401,3774.85794551966 1725.64790861797,3774.52666184817 2075.34574289597,3774.85936328145 PathPoint;PointKind.SMOOTHPOINT 1206.01375882632,3774.05242052958 1204.86788811889,3774.05194794232 1338.94286498872,3774.085501638 PathPoint;PointKind.SMOOTHPOINT 1202.63410330218,3774.05147535505 1199.99928829575,3775.53114607605 1203.58842254116,3773.51556139861 PathPoint;PointKind.SMOOTHPOINT 1194.92906827312,3774.05053018053 1177.30093044185,3774.04911241874 1197.38141822691,3774.05053018053 PathPoint;PointKind.SMOOTHPOINT 1161.18654036896,3774.07699506726 1098.2392897325,3774.34873274359 1165.71206660053,3774.05738269584 PathPoint;PointKind.SMOOTHPOINT 411.178799095209,3773.18550931818 386.966939061737,3772.60351810358 451.737366751769,3774.16069313574 PathPoint;PointKind.SMOOTHPOINT 305.850020122635,3773.52021232559 303.354693877844,3773.49469261338 343.469500632492,3773.90348059602 PathPoint;PointKind.SMOOTHPOINT 298.44434565773,3773.44577983164 295.511152402364,3774.27918747025 302.708084882417,3772.23430238249 PathPoint;PointKind.SMOOTHPOINT 289.427674227387,3773.35811489432 270.817466752096,3773.1799494961 292.374128738262,3773.38623383648 PathPoint;PointKind.SMOOTHPOINT 237.675220321983,3773.96720206673 205.984012181896,3773.71554934909 247.619197322677,3774.04612413968 PathPoint;PointKind.SMOOTHPOINT 151.971409654671,3773.96720206673 128.857603515496,3774.33999501987 167.490928124202,3773.81257951918 PathPoint;PointKind.CORNERPOINT 120,3773.59220550548 120,3773.59220550548 120,3773.59220550548 PathPoint";
			
	negativeSquare[1] = "PointKind.CORNERPOINT 121.02002620697,186.656942367554 121.02002620697,186.656942367554 121.02002620697,186.656942367554 PathPoint;PointKind.SMOOTHPOINT 220.116774420646,187.03650969818 222.527350117228,187.044038972693 164.328376882669,186.862258310723 PathPoint;PointKind.SMOOTHPOINT 227.415916748975,187.058904455722 230.206187060023,185.072883952966 225.416063900411,188.482332409644 PathPoint;PointKind.SMOOTHPOINT 234.820624949073,187.080780867944 313.613972320443,187.308954958248 232.333327702369,187.073578016364 PathPoint;PointKind.SMOOTHPOINT 447.657873630524,186.875982284546 499.385755062103,186.084794998169 410.709998411331,187.441199808747 PathPoint;PointKind.SMOOTHPOINT 785.260226726532,186.875982284546 812.144780158997,187.206194400787 729.360909461975,186.189358234406 PathPoint;PointKind.SMOOTHPOINT 1075.34507989883,186.889672279358 1077.40967273712,186.890144348145 949.63127374649,186.859459877014 PathPoint;PointKind.SMOOTHPOINT 1081.53366565704,186.891088485718 1084.34554338455,188.27944278717 1079.70298290253,185.987312793732 PathPoint;PointKind.SMOOTHPOINT 1088.97087335587,186.893448829651 1206.08217000961,186.930978298187 1086.49534463882,186.892504692078 PathPoint;PointKind.SMOOTHPOINT 1320.73210000992,186.875982284546 1342.12035655975,186.364495754242 1310.58309316635,187.118625640869 PathPoint;PointKind.SMOOTHPOINT 1684.8977637291,186.858751773834 1689.51105594635,186.971576213837 1662.49267101288,186.311388015747 PathPoint;PointKind.SMOOTHPOINT 1775.63646554947,187.340497970581 1779.11372423172,187.353951931 1723.76837968826,187.13939666748 PathPoint;PointKind.SMOOTHPOINT 1786.30262374878,187.381331920624 1789.07012701035,186.293685436249 1782.94385433197,188.701236248016 PathPoint;PointKind.SMOOTHPOINT 1793.51016998291,187.408239841461 1922.08102466543,187.889598611605 1791.07618331909,187.399270534515 PathPoint;PointKind.SMOOTHPOINT 2289.44173474471,187.065675691303 2291.65910669314,187.060927912854 2136.45315821429,187.393250804308 PathPoint;PointKind.SMOOTHPOINT 2296.05471837139,187.051542207623 2299.11340983662,184.538920388671 2294.36160142978,188.442386174032 PathPoint;PointKind.SMOOTHPOINT 2303.97496093145,187.034700344957 2391.60395350514,186.848985556147 2301.35507882034,187.040252740787 PathPoint;PointKind.SMOOTHPOINT 2468.17152500153,186.924841403961 2475.4482293129,187.04167842865 2456.33666064874,186.734468021034 PathPoint;PointKind.SMOOTHPOINT 2577.92303323746,187.38959312439 2579.32460546494,187.393841743469 2515.86911916733,187.200293540955 PathPoint;PointKind.SMOOTHPOINT 2582.16103076935,187.402338981628 2586.15827322006,188.52043390274 2580.79486370087,187.020199298859 PathPoint;PointKind.SMOOTHPOINT 2592.51916408539,187.433495521545 2781.78475856781,187.995257377625 2589.00579214096,187.422873973846 PathPoint;PointKind.SMOOTHPOINT 3378.99345397949,186.597697734833 3380.94734668732,186.603598594666 3121.35483264923,185.803678035736 PathPoint;PointKind.SMOOTHPOINT 3384.83648538589,186.615636348724 3388.47390864334,187.23666325287 3382.8720135871,186.280220499012 PathPoint;PointKind.SMOOTHPOINT 3391.23726606369,186.635699272156 3562.59776353836,187.170317173004 3389.11130428314,186.62885427475 PathPoint;PointKind.CORNERPOINT 3840.00011444092,186.875982284546 3840.00011444092,186.875982284546 3840.00011444092,186.875982284546 PathPoint;PointKind.CORNERPOINT 3839.21907663345,3774.18664455414 3839.21907663345,3774.18664455414 3839.21907663345,3774.18664455414 PathPoint;PointKind.SMOOTHPOINT 3766.58610105515,3774.01103496552 3760.4730463028,3773.87366294861 3772.6991558075,3774.14840698242 PathPoint;PointKind.SMOOTHPOINT 3295.16310453415,3774.05493736267 3267.6800751595,3774.46350170293 3335.4917049408,3773.45541000366 PathPoint;PointKind.SMOOTHPOINT 2850.28264107485,3773.93781448267 2847.93023890407,3773.93627743262 3018.86406558394,3774.04796490287 PathPoint;PointKind.SMOOTHPOINT 2843.27312304688,3773.93338479314 2841.53421173626,3775.04717785852 2846.56245275386,3771.82653058209 PathPoint;PointKind.SMOOTHPOINT 2837.11768223427,3773.92975747944 2764.727617543,3773.88862858551 2839.15608762823,3773.93091561294 PathPoint;PointKind.SMOOTHPOINT 2697.27547645569,3774.09883975983 2679.96376991272,3774.36272621155 2709.49052179056,3773.91269276376 PathPoint;PointKind.SMOOTHPOINT 2094.17786121368,3774.87704515457 2088.81374359131,3774.87208843231 2402.51053333282,3775.16807556152 PathPoint;PointKind.SMOOTHPOINT 2078.05128335953,3774.8619389534 2076.74011230469,3775.17846107483 2086.4076089859,3772.84502506256 PathPoint;PointKind.SMOOTHPOINT 2073.99196386337,3774.85792636871 1725.64792156219,3774.5267701149 2075.3458571434,3774.85934257507 PathPoint;PointKind.SMOOTHPOINT 1206.01372003555,3774.05234098434 1204.86777305603,3774.05186891556 1338.94286155701,3774.08538579941 PathPoint;PointKind.SMOOTHPOINT 1202.63417959213,3774.05139684677 1199.99932765961,3775.53109645844 1203.58846664429,3773.51559877396 PathPoint;PointKind.SMOOTHPOINT 1194.9290728569,3774.0504527092 1177.3008441925,3774.04903650284 1197.3814702034,3774.0504527092 PathPoint;PointKind.SMOOTHPOINT 1161.1865401268,3774.07688856125 1098.23923587799,3774.34880018234 1165.71202754974,3774.0572977066 PathPoint;PointKind.SMOOTHPOINT 411.178758144379,3773.18562269211 386.966822147369,3772.6035618782 451.73725605011,3774.16068077087 PathPoint;PointKind.SMOOTHPOINT 305.8500623703,3773.52031946182 303.354706764221,3773.49459171295 343.469460010529,3773.90340328217 PathPoint;PointKind.SMOOTHPOINT 298.444247245789,3773.44573259354 295.511047840118,3774.27917003632 302.70797252655,3772.23440408707 PathPoint;PointKind.SMOOTHPOINT 289.427733421326,3773.35816383362 270.817365646362,3773.17995786667 292.374150753021,3773.38625192642 PathPoint;PointKind.SMOOTHPOINT 237.675304412842,3773.96713256836 230.653564342542,3773.91138371969 247.619197368622,3774.04620409012 PathPoint;PointKind.SMOOTHPOINT 215.932249451274,3773.84806378578 213.764355877494,3773.84079824914 223.297924747046,3773.87274930741 PathPoint;PointKind.SMOOTHPOINT 209.434217967417,3773.82981149716 207.559580171274,3774.64007105274 212.849742867476,3772.35354675242 PathPoint;PointKind.SMOOTHPOINT 203.334235945461,3773.81879011473 181.950825237601,3773.79010638858 205.356323424362,3773.82150254467 PathPoint;PointKind.SMOOTHPOINT 151.971452236176,3773.96713256836 128.857548236847,3774.34006690979 162.084015794047,3773.86639297306 PathPoint;PointKind.CORNERPOINT 119.999885559082,3773.59230995178 119.999885559082,3773.59230995178 119.999885559082,3773.59230995178 PathPoint";
			
	negativeSquare[2] = "PointKind.CORNERPOINT 121.02002620697,186.656942367554 121.02002620697,186.656942367554 121.02002620697,186.656942367554 PathPoint;PointKind.SMOOTHPOINT 447.657873630524,186.875982284546 499.385755062103,186.084794998169 381.311438083649,187.890930175781 PathPoint;PointKind.SMOOTHPOINT 785.260226726532,186.875982284546 812.144780158997,187.206194400787 729.360909461975,186.189358234406 PathPoint;PointKind.SMOOTHPOINT 1075.34507989883,186.889672279358 1077.40967273712,186.890144348145 949.63127374649,186.859459877014 PathPoint;PointKind.SMOOTHPOINT 1081.53366565704,186.891088485718 1084.34554338455,188.27944278717 1079.70298290253,185.987312793732 PathPoint;PointKind.SMOOTHPOINT 1088.97087335587,186.893448829651 1206.08217000961,186.930978298187 1086.49534463882,186.892504692078 PathPoint;PointKind.SMOOTHPOINT 1320.73210000992,186.875982284546 1342.12035655975,186.364495754242 1310.58309316635,187.118625640869 PathPoint;PointKind.SMOOTHPOINT 1684.8977637291,186.858751773834 1689.51105594635,186.971576213837 1662.49267101288,186.311388015747 PathPoint;PointKind.SMOOTHPOINT 1775.63646554947,187.340497970581 1779.11372423172,187.353951931 1723.76837968826,187.13939666748 PathPoint;PointKind.SMOOTHPOINT 1786.30262374878,187.381331920624 1789.07012701035,186.293685436249 1782.94385433197,188.701236248016 PathPoint;PointKind.SMOOTHPOINT 1793.51016998291,187.408239841461 1894.96193691024,187.788066963849 1791.07618331909,187.399270534515 PathPoint;PointKind.SMOOTHPOINT 2185.82168701252,187.284726605926 2186.99027969358,187.282368433428 2049.83666169125,187.559138855896 PathPoint;PointKind.SMOOTHPOINT 2189.32323421265,187.277642369032 2190.99818728399,186.283563084924 2188.32073920438,187.872619946132 PathPoint;PointKind.SMOOTHPOINT 2192.48408226383,187.271216789588 2332.89915252959,186.985141400824 2191.43166856959,187.273360930214 PathPoint;PointKind.SMOOTHPOINT 2468.17152500153,186.924841403961 2475.4482293129,187.04167842865 2451.7094539188,186.660035651348 PathPoint;PointKind.SMOOTHPOINT 2577.92303323746,187.38959312439 2579.32460546494,187.393841743469 2515.86911916733,187.200293540955 PathPoint;PointKind.SMOOTHPOINT 2582.16103076935,187.402338981628 2586.15827322006,188.52043390274 2580.79486370087,187.020199298859 PathPoint;PointKind.SMOOTHPOINT 2592.51916408539,187.433495521545 2781.78475856781,187.995257377625 2589.00579214096,187.422873973846 PathPoint;PointKind.SMOOTHPOINT 3398.99345397949,186.597697734833 3400.94734668732,186.603598594666 3141.35483264923,185.803678035736 PathPoint;PointKind.SMOOTHPOINT 3404.83648538589,186.615636348724 3406.42240047455,185.241916179657 3403.33011388779,187.920434474945 PathPoint;PointKind.SMOOTHPOINT 3411.23726606369,186.635699272156 3582.59776353836,187.170317173004 3409.11130428314,186.62885427475 PathPoint;PointKind.CORNERPOINT 3840.00011444092,186.875982284546 3840.00011444092,186.875982284546 3840.00011444092,186.875982284546 PathPoint;PointKind.CORNERPOINT 3839.21907663345,3774.18664455414 3839.21907663345,3774.18664455414 3839.21907663345,3774.18664455414 PathPoint;PointKind.SMOOTHPOINT 3766.58610105515,3774.01103496552 3765.54529403588,3773.98764604373 3772.6991558075,3774.14840698242 PathPoint;PointKind.SMOOTHPOINT 3731.00256878749,3773.92285096688 3728.87894719866,3773.91954379564 3752.36217652703,3773.9561148406 PathPoint;PointKind.SMOOTHPOINT 3724.39313268966,3773.91288437104 3722.07454313076,3775.20267648992 3727.35833872686,3772.26339045222 PathPoint;PointKind.SMOOTHPOINT 3716.12756919196,3773.9012142877 3601.09991664765,3773.74416949661 3718.98271339774,3773.90511235495 PathPoint;PointKind.SMOOTHPOINT 3295.16310453415,3774.05493736267 3254.8345041275,3774.65446472168 3327.14877329875,3773.57943651892 PathPoint;PointKind.SMOOTHPOINT 2697.27547645569,3774.09883975983 2683.33115239102,3774.31139640119 2737.91776657104,3773.47948551178 PathPoint;PointKind.SMOOTHPOINT 2268.91127708209,3774.93448039997 2267.0148161424,3774.93496514954 2500.60532088425,3774.87525767346 PathPoint;PointKind.SMOOTHPOINT 2263,3776 2261.47585328571,3777.09652544549 2266.32738993132,3773.60615714185 PathPoint;PointKind.SMOOTHPOINT 2257.56998357852,3774.9369655148 2205.0348259038,3774.94655659792 2259.45378282781,3774.93662159892 PathPoint;PointKind.SMOOTHPOINT 2094.17786121368,3774.87704515457 2088.81374359131,3774.87208843231 2150.11449471054,3774.92984287172 PathPoint;PointKind.SMOOTHPOINT 2078.05128335953,3774.8619389534 2076.74011230469,3775.17846107483 2086.4076089859,3772.84502506256 PathPoint;PointKind.SMOOTHPOINT 2073.99196386337,3774.85792636871 1725.64792156219,3774.5267701149 2075.3458571434,3774.85934257507 PathPoint;PointKind.SMOOTHPOINT 1206.01372003555,3774.05234098434 1204.86777305603,3774.05186891556 1338.94286155701,3774.08538579941 PathPoint;PointKind.SMOOTHPOINT 1202.63417959213,3774.05139684677 1199.99932765961,3775.53109645844 1203.58846664429,3773.51559877396 PathPoint;PointKind.SMOOTHPOINT 1194.9290728569,3774.0504527092 1177.3008441925,3774.04903650284 1197.3814702034,3774.0504527092 PathPoint;PointKind.SMOOTHPOINT 1161.1865401268,3774.07688856125 1098.23923587799,3774.34880018234 1165.71202754974,3774.0572977066 PathPoint;PointKind.SMOOTHPOINT 411.178758144379,3773.18562269211 386.966822147369,3772.6035618782 451.73725605011,3774.16068077087 PathPoint;PointKind.SMOOTHPOINT 305.8500623703,3773.52031946182 303.354706764221,3773.49459171295 343.469460010529,3773.90340328217 PathPoint;PointKind.SMOOTHPOINT 298.444247245789,3773.44573259354 295.511047840118,3774.27917003632 302.70797252655,3772.23440408707 PathPoint;PointKind.SMOOTHPOINT 289.427733421326,3773.35816383362 270.817365646362,3773.17995786667 292.374150753021,3773.38625192642 PathPoint;PointKind.SMOOTHPOINT 237.675304412842,3773.96713256836 205.983910560608,3773.71551990509 247.619197368622,3774.04620409012 PathPoint;PointKind.SMOOTHPOINT 151.971452236176,3773.96713256836 128.857548236847,3774.34006690979 167.490949630737,3773.81253004074 PathPoint;PointKind.CORNERPOINT 119.999885559082,3773.59230995178 119.999885559082,3773.59230995178 119.999885559082,3773.59230995178 PathPoint";	

} else if (negative_variant_square == 2) {
	
	negativeSquare[0] = "PointKind.SMOOTHPOINT 204.076701240582,189.191715717316 205.563794016242,189.939000606537 202.589373611357,188.444430828094 PathPoint;PointKind.SMOOTHPOINT 218.419678182321,206.564083099365 232.494922059586,208.360540866852 204.344669158622,204.767861366272 PathPoint;PointKind.SMOOTHPOINT 251.204061634346,209.629933834076 253.859316043949,209.659202098846 238.944470670635,209.494922161102 PathPoint;PointKind.SMOOTHPOINT 259.459634162771,209.873049259186 263.473046740669,208.648266792297 256.730400880089,210.706014633179 PathPoint;PointKind.SMOOTHPOINT 267.315955630139,210.279264450073 276.28360416864,210.790042877197 264.612321386077,210.125370025635 PathPoint;PointKind.SMOOTHPOINT 297.307225629712,211.673755645752 304.625732432477,211.822929382324 286.207576425159,211.447398662567 PathPoint;PointKind.SMOOTHPOINT 328.657123504711,212.352590560913 330.234634903022,212.383511066437 315.968689930711,212.10428237915 PathPoint;PointKind.SMOOTHPOINT 333.446727116019,212.443227767944 337.044683736851,210.573363304138 332.015294635342,213.187208175659 PathPoint;PointKind.SMOOTHPOINT 341.363875656806,212.578475475311 356.809724941328,212.821826934814 338.698522543894,212.536461353302 PathPoint;PointKind.SMOOTHPOINT 385.415124051898,212.695548534393 412.192657863517,212.156682014465 372.898133580588,212.947633266449 PathPoint;PointKind.SMOOTHPOINT 522.699715078904,210.651726722717 572.168565518993,209.861483573914 473.231099492381,211.442205905914 PathPoint;PointKind.SMOOTHPOINT 847.470020989698,208.607904911041 873.168167815068,207.7272605896 796.796841466606,210.344409942627 PathPoint;PointKind.SMOOTHPOINT 1118.9816444767,207.638747692108 1120.95605840042,207.639219760895 998.758225556544,207.608535289764 PathPoint;PointKind.SMOOTHPOINT 1124.89995432298,207.640163898468 1127.58902764599,209.026865959167 1123.14912099345,206.737332344055 PathPoint;PointKind.SMOOTHPOINT 1132.01225969538,207.642524242401 1244.00899307565,207.680053710938 1129.64493575687,207.641580104828 PathPoint;PointKind.SMOOTHPOINT 1357.67717928036,207.5861120224 1378.13128084551,207.075097560883 1347.97138598603,207.82851934433 PathPoint;PointKind.SMOOTHPOINT 1701.91308809983,208.607904911041 1706.32481232453,208.72049331665 1680.48645792066,208.061013221741 PathPoint;PointKind.SMOOTHPOINT 1788.68889709948,209.088943004608 1792.01442358453,209.102396965027 1739.08618012715,208.888077735901 PathPoint;PointKind.SMOOTHPOINT 1798.88929200239,209.129776954651 1801.53585683007,208.043310642242 1795.67719978939,210.448265075684 PathPoint;PointKind.SMOOTHPOINT 1805.78200929121,209.156684875488 2005.04492591553,209.935834407806 1803.45437560524,209.147715568542 PathPoint;PointKind.SMOOTHPOINT 2453.90481013891,211.673755645752 2460.86375613316,211.790592670441 2422.738567752,211.150231361389 PathPoint;PointKind.SMOOTHPOINT 2558.86321701985,212.138035297394 2560.20352631718,212.142283916473 2499.5194787184,211.948971748352 PathPoint;PointKind.SMOOTHPOINT 2562.91608499672,212.150781154633 2566.73879647957,213.267695903778 2561.6095946128,211.769113540649 PathPoint;PointKind.SMOOTHPOINT 2572.82197352871,212.18193769455 2753.82150264526,212.742991447449 2569.46192356956,212.171316146851 PathPoint;PointKind.SMOOTHPOINT 3347.97636330187,214.347081184387 3349.84485826763,214.35298204422 3101.58960908728,213.554005622864 PathPoint;PointKind.SMOOTHPOINT 3353.56423418173,214.365019798279 3355.08091850662,212.992715835571 3352.12364241201,215.66840171814 PathPoint;PointKind.SMOOTHPOINT 3359.68545750845,214.38508272171 3509.40131745542,214.872965812683 3357.65233019341,214.378237724304 PathPoint;PointKind.SMOOTHPOINT 3625.94669468897,215.761399269104 3642.54896292917,216.743538379669 3619.03753765057,215.35258769989 PathPoint;PointKind.SMOOTHPOINT 3713.23025709685,215.545191764832 3714.78827564924,215.504121780396 3685.78339062405,216.267929077148 PathPoint;PointKind.SMOOTHPOINT 3717.74437747603,215.419857501984 3720.67135746072,213.392322063446 3716.55390475338,216.244325637817 PathPoint;PointKind.SMOOTHPOINT 3722.09269123809,215.285081863403 3727.59883307721,215.103807449341 3720.71339624892,215.330400466919 PathPoint;PointKind.SMOOTHPOINT 3734.54486212537,214.739370346069 3749.41226707849,213.729615211487 3731.93845725735,214.916396141052 PathPoint;PointKind.SMOOTHPOINT 3770.25505129426,211.673755645752 3772.49461489323,211.440553665161 3763.41447149693,212.38587141037 PathPoint;PointKind.SMOOTHPOINT 3770.25505129426,227.002537250519 3767.80999082562,234.283490180969 3772.70034661646,219.721348285675 PathPoint;PointKind.SMOOTHPOINT 3757.96093685644,246.418726444244 3755.45575387508,258.218793869019 3760.4661198378,234.618895053864 PathPoint;PointKind.SMOOTHPOINT 3752.98603378209,345.544438362122 3753.75846715845,367.411844730377 3752.21360040572,323.677031993866 PathPoint;PointKind.SMOOTHPOINT 3755.03513113958,591.825792789459 3755.0776396349,596.799037456512 3754.84701343375,569.806616306305 PathPoint;PointKind.SMOOTHPOINT 3755.38741148757,649.349026679993 3755.39797989801,651.191039085388 3755.20939248505,618.375885486603 PathPoint;PointKind.SMOOTHPOINT 3755.41958642602,654.97349023819 3755.83433782239,658.184266090393 3755.17510386452,653.082146644592 PathPoint;PointKind.SMOOTHPOINT 3755.46937538187,663.73603105545 3756.09408586565,773.9244389534 3755.45246592517,660.747599601746 PathPoint;PointKind.SMOOTHPOINT 3757.08422849707,1008.76662254333 3757.03068188418,1040.47147035599 3757.14341159553,973.643996715546 PathPoint;PointKind.SMOOTHPOINT 3755.90479389199,1569.8276925087 3755.90244535634,1571.71573162079 3756.18826214534,1354.7363948822 PathPoint;PointKind.SMOOTHPOINT 3755.89751343147,1575.46891450882 3754.96256138789,1578.64192485809 3756.42687336772,1573.67245674133 PathPoint;PointKind.SMOOTHPOINT 3755.88788443529,1583.15584659576 3755.76458631349,1683.26110124588 3755.89093753164,1580.60903549194 PathPoint;PointKind.SMOOTHPOINT 3756.05956239154,1770.09248971939 3756.56332328917,1789.27948951721 3755.77374560254,1759.20280694962 PathPoint;PointKind.SMOOTHPOINT 3756.25402114363,2320.31202793121 3756.25261202224,2322.18519687653 3756.42851734267,2070.16584634781 PathPoint;PointKind.SMOOTHPOINT 3756.25002863302,2325.92586994171 3754.27937236635,2328.38865280151 3757.41912968123,2324.46481704712 PathPoint;PointKind.SMOOTHPOINT 3756.24486185459,2333.24671268463 3756.10935134739,2525.04377603531 3756.24650582954,2330.80989360809 PathPoint;PointKind.SMOOTHPOINT 3756.05956239154,2711.27514839172 3756.23805110119,2738.37944984436 3755.95646167636,2695.60435295105 PathPoint;PointKind.SMOOTHPOINT 3755.5877415788,3156.96520328522 3755.58046111827,3158.67503643036 3756.15867059611,3025.11308670044 PathPoint;PointKind.SMOOTHPOINT 3755.56519563653,3162.01563119888 3754.35546492152,3164.70406293869 3756.24556641528,3160.50406694412 PathPoint;PointKind.SMOOTHPOINT 3755.53724806225,3167.9568529129 3755.39774504445,3196.47264003754 3755.54664220487,3166.01759433746 PathPoint;PointKind.SMOOTHPOINT 3755.03513113958,3221.21022462845 3753.97053992795,3249.66818332672 3755.23146872019,3215.96247196198 PathPoint;PointKind.SMOOTHPOINT 3752.98603378209,3646.32657766342 3752.82985616115,3650.81642389297 3753.71854205235,3625.28552770615 PathPoint;PointKind.SMOOTHPOINT 3752.52243284413,3660.44875144958 3752.45949208862,3662.49493360519 3752.67226941881,3655.5859708786 PathPoint;PointKind.SMOOTHPOINT 3752.33830764891,3666.6229391098 3753.01562533132,3669.03686285019 3751.78006072413,3664.63316917419 PathPoint;PointKind.SMOOTHPOINT 3752.19880463111,3671.60633325577 3751.64431536337,3692.07122325897 3752.24389651565,3669.94842767715 PathPoint;PointKind.SMOOTHPOINT 3751.96160253013,3716.83854818344 3753.066588555,3726.07646226883 3751.34558162827,3711.68780565262 PathPoint;PointKind.SMOOTHPOINT 3769.20126334663,3740.34261703491 3770.8379578434,3750.62946796417 3767.56433399629,3730.05553007126 PathPoint;PointKind.SMOOTHPOINT 3770.22569459859,3767.93432950974 3769.11953430589,3769.19239282608 3771.33185489129,3766.676030159 PathPoint;PointKind.SMOOTHPOINT 3754.85805155132,3766.9123005867 3749.15251903523,3765.94479560852 3764.20498859783,3768.49727153778 PathPoint;PointKind.SMOOTHPOINT 3720.49991435803,3763.52662324905 3718.48745415673,3763.39940071106 3734.54086961476,3764.41505670547 PathPoint;PointKind.SMOOTHPOINT 3714.12293549867,3763.18791389465 3712.59709188473,3763.63991975784 3717.65301943912,3762.14204549789 PathPoint;PointKind.SMOOTHPOINT 3709.17104807372,3763.00711154938 3705.02776147419,3762.88342952728 3710.8828957114,3763.05809497833 PathPoint;PointKind.SMOOTHPOINT 3695.61342145444,3762.82465696335 3665.88260405881,3762.87257194519 3700.52068670198,3762.81686782837 PathPoint;PointKind.SMOOTHPOINT 3243.80354159696,3764.86847877502 3205.23635880585,3765.46729803085 3282.37095924163,3764.2696595192 PathPoint;PointKind.SMOOTHPOINT 2670.07694861331,3766.9123005867 2653.52118137905,3767.17595100403 2708.94427426091,3766.29365444183 PathPoint;PointKind.SMOOTHPOINT 2101.12187551644,3766.68972015381 2095.99196908897,3766.68476343155 2395.98851180752,3766.98027849197 PathPoint;PointKind.SMOOTHPOINT 2085.69951158845,3766.67461395264 2084.44562840316,3766.99066400528 2093.69087385588,3764.65982437134 PathPoint;PointKind.SMOOTHPOINT 2081.81738215357,3766.67060136795 1748.68675902421,3766.33968114853 2083.11212985922,3766.67201757431 PathPoint;PointKind.SMOOTHPOINT 1246.86974435491,3765.86596012115 1245.77391761909,3765.86548805237 1373.99339587798,3765.89900493622 PathPoint;PointKind.SMOOTHPOINT 1243.63768958886,3765.86501598358 1241.11794568645,3767.34306335449 1244.55033054373,3765.32968997955 PathPoint;PointKind.SMOOTHPOINT 1236.26915897668,3765.86407184601 1219.41090035028,3765.86265563965 1238.61440668005,3765.86407184601 PathPoint;PointKind.SMOOTHPOINT 1204.00027910055,3765.89050769806 1143.80214352844,3766.16194725037 1208.32816060243,3765.87091684341 PathPoint;PointKind.SMOOTHPOINT 478.645883294594,3762.82465696335 455.491435435297,3762.24330425262 517.433123876414,3763.79877090454 PathPoint;PointKind.SMOOTHPOINT 378.21592286032,3761.33433580399 375.829575783018,3761.30884408951 414.192435972289,3761.71718358994 PathPoint;PointKind.SMOOTHPOINT 371.133678744275,3761.25998497009 368.328587759992,3762.0924782753 375.211206345508,3760.04983663559 PathPoint;PointKind.SMOOTHPOINT 362.510795239676,3761.17241621017 344.713357205521,3760.99444627762 365.328568316487,3761.20050430298 PathPoint;PointKind.SMOOTHPOINT 319.846357147849,3760.78083515167 289.539209102908,3760.5294585228 329.356047715128,3760.85967063904 PathPoint;PointKind.SMOOTHPOINT 237.885515944569,3760.78083515167 230.592138473294,3760.83866357803 249.435379433857,3759.93866443634 PathPoint;PointKind.SMOOTHPOINT 219.089950257768,3763.80065917969 218.042503356403,3764.08319234848 224.362882506523,3762.3783159256 PathPoint;PointKind.SMOOTHPOINT 215.297534884845,3765.13448953629 207.733840959877,3768.04432153702 216.488007607494,3764.67658281326 PathPoint;PointKind.SMOOTHPOINT 202.027603883091,3770.99994421005 200.546852153695,3770.62016487122 203.162416310758,3771.2912106514 PathPoint;PointKind.SMOOTHPOINT 201.317406701538,3761.90011024475 201.48321331866,3759.99389648438 200.912284301346,3766.5594291687 PathPoint;PointKind.SMOOTHPOINT 203.052035135054,3756.69319152832 205.542892048927,3751.80232286453 202.296511215392,3758.17713975906 PathPoint;PointKind.SMOOTHPOINT 210.223758459489,3741.36440992355 210.355041602507,3739.58471059799 209.862788529579,3746.25173807144 PathPoint;PointKind.SMOOTHPOINT 210.969418529407,3728.94050359726 211.087080165636,3726.84569835663 210.618312449241,3735.18125295639 PathPoint;PointKind.SMOOTHPOINT 211.3508207195,3722.06458568573 212.581688255386,3719.8569560051 210.140855150928,3724.23444986343 PathPoint;PointKind.SMOOTHPOINT 211.702396506797,3715.59582710266 213.804570770052,3676.60483360291 211.580272652826,3717.86128520966 PathPoint;PointKind.SMOOTHPOINT 217.395246930358,3591.14315271378 217.418732286891,3587.8360748291 217.282986926131,3606.91284656525 PathPoint;PointKind.SMOOTHPOINT 217.291911361614,3568.51902008057 216.842401637575,3510.02592086792 217.379981448612,3580.00350952148 PathPoint;PointKind.SMOOTHPOINT 213.777327756474,3224.25152778625 213.743508843066,3220.86915493011 215.108477764755,3356.79734945297 PathPoint;PointKind.SMOOTHPOINT 213.676340723382,3214.14665937424 212.374312557201,3210.54737091064 215.380907900536,3218.85908603668 PathPoint;PointKind.SMOOTHPOINT 213.563141304894,3202.73061990738 212.558672605984,3100.92969417572 213.600483021781,3206.51401519775 PathPoint;PointKind.SMOOTHPOINT 212.272620963414,3002.52081871033 212.888407011705,2982.94979095459 211.858104420609,3015.69319009781 PathPoint;PointKind.SMOOTHPOINT 210.600698431841,2167.23286628723 210.604925796017,2167.85906553268 213.128427355471,2545.13219118118 PathPoint;PointKind.SMOOTHPOINT 209.861614261752,2165.00706195831 209.054422557718,2164.07283782959 210.668805965786,2165.94128608704 PathPoint;PointKind.SMOOTHPOINT 192.000061204262,2141.0000038147 192.276014143523,2138.47372770309 191.756518057017,2143.2300567627 PathPoint;PointKind.SMOOTHPOINT 209.90999409621,2117.00002670288 210.713193289633,2114.57028865814 209.419150144673,2118.48515510559 PathPoint;PointKind.SMOOTHPOINT 210.551614036687,2107.003262043 209.591532661625,2104.47084903717 212.072290872189,2111.01490259171 PathPoint;PointKind.SMOOTHPOINT 210.547386672511,2098.89453649521 210.499006838054,2007.88699150085 210.548795793903,2101.59288167953 PathPoint;PointKind.SMOOTHPOINT 210.951099951311,1848.71790647507 210.969888236537,1848.04945707321 208.886032551378,1922.00682163239 PathPoint;PointKind.SMOOTHPOINT 210.904833798941,1847.00004816055 210.787407016277,1846.46070957184 211.022260581605,1847.53938674927 PathPoint;PointKind.SMOOTHPOINT 209.836015223131,1845.05394458771 205.211748521814,1839.5040678978 210.582849560876,1845.9504032135 PathPoint;PointKind.SMOOTHPOINT 192.000061204262,1816.99984073639 191.819458812525,1815.32234430313 192.44910122117,1821.17174863815 PathPoint;PointKind.SMOOTHPOINT 210.154006950586,1796.1355805397 210.836491411431,1795.47185182571 205.551581630845,1800.61291694641 PathPoint;PointKind.SMOOTHPOINT 210.904833798941,1795.00001907349 211.152369456797,1794.46186065674 210.657298141085,1795.53817749023 PathPoint;PointKind.SMOOTHPOINT 211.328979337924,1793.29797506332 216.882796450812,1692.93733119965 211.298213520866,1793.85336399078 PathPoint;PointKind.SMOOTHPOINT 212.272620963414,1617.82741069794 212.263696527932,1610.99350690842 212.282954520289,1625.67555427551 PathPoint;PointKind.SMOOTHPOINT 212.323349333525,1511.26873970032 212.324523601352,1509.57306861877 212.280840838201,1571.35719537735 PathPoint;PointKind.SMOOTHPOINT 213.311378282862,1504.16882514954 213.367977992106,1502.7903842926 213.216497442469,1506.48030996323 PathPoint;PointKind.SMOOTHPOINT 212.272620963414,1501.32909536362 211.535180768283,1498.44428300858 212.505125993089,1502.23829984665 PathPoint;PointKind.SMOOTHPOINT 212.419169588179,1487.29189395905 212.787185125049,1367.08004951477 212.388403771121,1497.31816291809 PathPoint;PointKind.SMOOTHPOINT 214.321718320905,582.62847661972 215.206176847932,569.225263595581 213.281082172935,598.399114608765 PathPoint;PointKind.SMOOTHPOINT 215.137599606856,481.169800758362 215.343096476518,479.91197347641 214.513358830213,484.992613792419 PathPoint;PointKind.SMOOTHPOINT 215.421772420903,467.920010089874 214.553753643449,454.129228591919 215.901108547739,475.538256168365 PathPoint;PointKind.SMOOTHPOINT 215.346149572868,427.297546863556 215.922480222184,401.039192676544 215.203593458713,433.792033195496 PathPoint;PointKind.SMOOTHPOINT 214.321718320905,255.616042613983 214.274512754274,250.9508228302 214.428576693129,266.180233955383 PathPoint;PointKind.SMOOTHPOINT 212.272620963414,244.374904632568 211.455800263202,242.141547203064 213.254543720052,247.058851718903 PathPoint;PointKind.SMOOTHPOINT 208.840940666835,239.574437141418 208.051832687331,239.07900094986 210.891916852848,240.862712860107 PathPoint;PointKind.SMOOTHPOINT 206.125563744507,238.24343919754 203.251190958452,237.135965824127 207.151873824993,238.639032840729 PathPoint;PointKind.SMOOTHPOINT 201.550146584779,218.919775485992 201.460197669258,216.833231449127 201.970064759586,228.666579723358 PathPoint;PointKind.SMOOTHPOINT 201.391855281747,212.544486522675 200.272308335826,205.448820590973 201.806841531682,215.175325870514 PathPoint;PointKind.SMOOTHPOINT 202.027603883091,193.279359340668 202.285707951387,190.066459178925 201.633049893339,198.19194316864 PathPoint";
	
	negativeSquare[1] = "PointKind.SMOOTHPOINT 204.060966051705,189.097968281393 205.548058827365,189.845272729462 202.57363842248,188.350663833325 PathPoint;PointKind.SMOOTHPOINT 218.403942993444,206.470790354138 232.479186870709,208.267295140699 204.328933969745,204.674521608148 PathPoint;PointKind.SMOOTHPOINT 251.188326445469,209.536721332017 253.843580855072,209.565990362832 238.928735481758,209.401706125354 PathPoint;PointKind.SMOOTHPOINT 259.443898973894,209.779843120239 263.457311551792,208.555028596857 256.714665691212,210.612830295613 PathPoint;PointKind.SMOOTHPOINT 267.300220441262,210.186068943084 276.267868979763,210.696860738921 264.596586197201,210.032170490733 PathPoint;PointKind.SMOOTHPOINT 297.291490440835,211.580596637079 304.6099972436,211.729774278008 286.191841236282,211.354233729405 PathPoint;PointKind.SMOOTHPOINT 328.641388315834,212.259449319532 330.218899714145,212.290370634345 315.952954741834,212.011134638746 PathPoint;PointKind.SMOOTHPOINT 333.430991927142,212.350088898831 337.028948547974,210.480175494661 331.999559446465,213.094088778904 PathPoint;PointKind.SMOOTHPOINT 348.199053822126,212.90690860603 363.644903106647,213.150266434823 345.533700709213,212.864893384376 PathPoint;PointKind.SMOOTHPOINT 385.399388863021,212.602416269325 412.17692267464,212.063535645528 372.882398391711,212.854507599248 PathPoint;PointKind.SMOOTHPOINT 522.683979890027,210.558540964263 572.152830330115,209.768277132256 473.215364303504,211.349040836841 PathPoint;PointKind.SMOOTHPOINT 847.454285800821,208.5146656592 873.152432626191,207.633998288466 796.781106277729,210.251216140704 PathPoint;PointKind.SMOOTHPOINT 1118.96590928782,207.545483074308 1120.94032321154,207.54595515545 998.742490367667,207.515269881208 PathPoint;PointKind.SMOOTHPOINT 1124.8842191341,207.546899317734 1127.57329245711,208.933637672884 1123.13338580458,206.644044133317 PathPoint;PointKind.SMOOTHPOINT 1131.99652450651,207.549259723445 1243.99325788677,207.586790174248 1129.62920056799,207.548315561161 PathPoint;PointKind.SMOOTHPOINT 1357.66144409148,207.492846026955 1378.11554565663,206.981818190546 1347.95565079715,207.735259693463 PathPoint;PointKind.SMOOTHPOINT 1701.89735291096,208.5146656592 1706.30907713565,208.62725701161 1680.47072273178,207.967759655986 PathPoint;PointKind.SMOOTHPOINT 1785.96999737367,208.90672904778 1789.29552385872,208.920183360332 1736.36728040134,208.705858521783 PathPoint;PointKind.SMOOTHPOINT 1795.92003837594,208.90672904778 1798.56660320363,207.820234299056 1792.70794616294,210.225251677885 PathPoint;PointKind.SMOOTHPOINT 1805.76627410233,209.063459986983 2005.02919072665,209.842629912149 1803.43864041636,209.054490445282 PathPoint;PointKind.SMOOTHPOINT 2453.88907495004,211.580596637079 2460.84802094428,211.697436719769 2422.72283256312,211.057058650403 PathPoint;PointKind.SMOOTHPOINT 2558.84748183097,212.044888440412 2560.1877911283,212.049137170692 2499.50374352952,211.85581994297 PathPoint;PointKind.SMOOTHPOINT 2562.90034980785,212.057634631251 2566.7230612907,213.174578613645 2561.59385942392,211.675957027799 PathPoint;PointKind.SMOOTHPOINT 2572.80623833983,212.088791986635 2753.80576745638,212.649860424114 2569.44618838068,212.078170160936 PathPoint;PointKind.SMOOTHPOINT 3347.960628113,214.253992145237 3349.82912307875,214.259893159514 3101.5738738984,213.460895826377 PathPoint;PointKind.SMOOTHPOINT 3353.54849899286,214.27193122864 3355.06518331775,212.899591348326 3352.10790722313,215.575347262195 PathPoint;PointKind.SMOOTHPOINT 3359.66972231958,214.291994677182 3509.38558226655,214.779890537624 3357.63659500453,214.285149500621 PathPoint;PointKind.SMOOTHPOINT 3625.93095950009,215.668347247204 3642.53322774029,216.650512063507 3619.0218024617,215.259524978077 PathPoint;PointKind.SMOOTHPOINT 3713.21452190798,215.452134084086 3714.77254046037,215.411063024717 3685.76765543517,216.174890312762 PathPoint;PointKind.SMOOTHPOINT 3717.25963971719,215.906984264575 3720.18661970188,213.879395758918 3716.06916699454,216.73147397939 PathPoint;PointKind.SMOOTHPOINT 3722.07695604921,215.192017374746 3719.19436338837,215.286905684324 3720.69766106004,215.237337164395 PathPoint;PointKind.SMOOTHPOINT 3770.23955095894,211.580596637079 3772.44294710886,211.115360671462 3747.96932677311,216.282524813178 PathPoint;PointKind.SMOOTHPOINT 3770.23955095894,226.909779445333 3767.79449049031,234.190922941725 3772.68484628114,219.628399908369 PathPoint;PointKind.SMOOTHPOINT 3757.05956887271,252.907996066823 3755.50812622015,264.872656574769 3759.15446267544,236.750074813475 PathPoint;PointKind.SMOOTHPOINT 3752.97029859321,345.454783179521 3753.74273196958,367.32276188809 3752.19786521685,323.586804470951 PathPoint;PointKind.SMOOTHPOINT 3755.0193959507,591.742583581534 3755.06190444603,596.715958414386 3754.83127824487,569.722830785754 PathPoint;PointKind.SMOOTHPOINT 3755.3716762987,649.267323039997 3755.38224470914,651.109383656778 3755.19365729618,618.293371179944 PathPoint;PointKind.SMOOTHPOINT 3755.40385123715,654.891933808484 3755.81860263352,658.102793697012 3755.15936867564,653.000540712345 PathPoint;PointKind.SMOOTHPOINT 3755.45364019299,663.654703969604 3756.07835067677,773.84599585237 3755.43673073629,660.666194299042 PathPoint;PointKind.SMOOTHPOINT 3757.06849330819,1008.69432601711 3757.0149466953,1040.40000364754 3757.12767640666,973.570780917308 PathPoint;PointKind.SMOOTHPOINT 3755.88905870311,1569.77008075411 3755.88671016746,1571.65816928225 3756.17252695647,1354.67315349698 PathPoint;PointKind.SMOOTHPOINT 3755.88177824259,1575.41145040315 3754.94682619902,1578.5845438003 3756.41113817884,1573.61494561658 PathPoint;PointKind.SMOOTHPOINT 3755.87214924641,1583.09858368181 3755.74885112461,1683.20645840821 3755.87520234276,1580.55170591976 PathPoint;PointKind.SMOOTHPOINT 3756.04382720267,1770.04011953826 3756.54758810029,1789.22762152154 3755.75801041366,1759.15015175049 PathPoint;PointKind.SMOOTHPOINT 3756.23828595476,2320.27405876399 3756.23687683337,2322.14727673616 3756.4127821538,2070.12133005096 PathPoint;PointKind.SMOOTHPOINT 3756.23429344415,2325.88804770678 3754.26363717748,2328.35089502553 3757.40339449235,2324.42695657174 PathPoint;PointKind.SMOOTHPOINT 3756.22912666571,2333.20908205969 3756.09361615852,2525.01116535601 3756.23077064067,2330.77219920376 PathPoint;PointKind.SMOOTHPOINT 3756.04382720267,2711.24741198605 3756.22231591232,2738.35242284538 3755.94072648749,2695.57620639029 PathPoint;PointKind.SMOOTHPOINT 3755.57200638992,3156.94913202088 3755.5647259294,3158.65900991785 3756.14293540723,3025.09356444239 PathPoint;PointKind.SMOOTHPOINT 3755.54946044765,3161.99969212047 3754.33972973264,3164.68819422518 3756.22983122641,3160.48808830322 PathPoint;PointKind.SMOOTHPOINT 3755.52151287337,3167.94106933536 3755.38200985557,3196.4576028098 3755.53090701599,3166.00176000329 PathPoint;PointKind.SMOOTHPOINT 3755.0193959507,3221.19583486282 3753.95480473907,3249.65453839735 3755.21573353132,3215.94794484579 PathPoint;PointKind.SMOOTHPOINT 3752.97029859321,3646.32331455922 3752.81412097227,3650.81327830248 3753.70280686347,3625.28171389003 PathPoint;PointKind.SMOOTHPOINT 3752.50669765525,3660.44585796806 3752.44375689975,3662.49209367884 3752.65653422993,3655.58295012248 PathPoint;PointKind.SMOOTHPOINT 3752.32257246004,3666.62020722662 3752.99989014244,3669.03419414715 3751.76432553525,3664.63038521233 PathPoint;PointKind.SMOOTHPOINT 3752.18306944223,3671.60373180402 3751.62858017449,3692.06915743918 3752.22816132677,3669.94578283269 PathPoint;PointKind.SMOOTHPOINT 3751.94586734125,3716.83713060415 3753.05085336612,3726.07528647545 3751.32984643939,3711.68625326184 PathPoint;PointKind.SMOOTHPOINT 3769.18576301131,3740.34181463266 3770.82245750809,3750.62893480187 3767.54883366098,3730.05445842287 PathPoint;PointKind.SMOOTHPOINT 3770.21019426328,3767.93424927128 3769.10403397058,3769.19234551519 3771.31635455597,3766.67591698681 PathPoint;PointKind.SMOOTHPOINT 3754.84255121601,3766.91219359847 3749.13701869992,3765.94466329757 3764.18948826252,3768.49720603333 PathPoint;PointKind.SMOOTHPOINT 3720.48417916915,3763.52642764676 3718.47171896785,3763.39920177895 3734.52513442588,3764.41488435634 PathPoint;PointKind.SMOOTHPOINT 3714.10720030979,3763.18770942725 3712.58135669585,3763.63972712089 3717.63728425024,3762.14181365675 PathPoint;PointKind.SMOOTHPOINT 3709.15531288484,3763.00690234979 3705.01202628532,3762.88321709054 3710.86716052252,3763.05788711315 PathPoint;PointKind.SMOOTHPOINT 3695.59768626556,3762.82444298834 3665.86686886994,3762.87235922427 3700.5049515131,3762.8166536495 PathPoint;PointKind.SMOOTHPOINT 3243.78780640808,3764.86831829341 3205.22062361698,3765.46715322226 3282.35522405276,3764.26948336455 PathPoint;PointKind.SMOOTHPOINT 2670.06121342443,3766.91219359847 2653.50544619017,3767.17585091637 2708.92853907203,3766.29353126164 PathPoint;PointKind.SMOOTHPOINT 2101.10614032756,3766.68960733993 2095.97623390009,3766.68465048794 2395.97277661865,3766.98017328294 PathPoint;PointKind.SMOOTHPOINT 2085.68377639957,3766.67450074338 2084.42989321428,3766.99055906807 2093.675138667,3764.65965842856 PathPoint;PointKind.SMOOTHPOINT 2081.80164696469,3766.67048805367 1748.67102383534,3766.33955917301 2083.09639467035,3766.6719042971 PathPoint;PointKind.SMOOTHPOINT 1246.85400916604,3765.86582574683 1245.75818243021,3765.86535366569 1373.97766068911,3765.89887142678 PathPoint;PointKind.SMOOTHPOINT 1243.62195439999,3765.86488158454 1241.10221049758,3767.34296764071 1244.53459535485,3765.32954156931 PathPoint;PointKind.SMOOTHPOINT 1236.25342378781,3765.86393742226 1219.3951651614,3765.86252117883 1238.59867149118,3765.86393742226 PathPoint;PointKind.SMOOTHPOINT 1203.98454391168,3765.89037396622 1143.78640833956,3766.16182062297 1208.31242541355,3765.87078259882 PathPoint;PointKind.SMOOTHPOINT 478.630148105717,3762.82444298834 455.47570024642,3762.24307506175 517.417388687537,3763.79858242523 PathPoint;PointKind.SMOOTHPOINT 378.200187671443,3761.33408282249 375.813840594141,3761.30859044081 414.176700783412,3761.71694062879 PathPoint;PointKind.SMOOTHPOINT 371.117943555398,3761.25973004259 368.312852571115,3762.09224513682 375.195471156631,3760.04955003462 PathPoint;PointKind.SMOOTHPOINT 362.495060050799,3761.17215899072 344.697622016644,3760.99418440012 365.31283312761,3761.20024781868 PathPoint;PointKind.SMOOTHPOINT 319.830621958972,3760.78056768328 289.523473914031,3760.52918447507 329.340312526251,3760.85940523402 PathPoint;PointKind.SMOOTHPOINT 237.869780755692,3760.78056768328 230.576403284417,3760.8383976232 249.41964424498,3759.93837492563 PathPoint;PointKind.SMOOTHPOINT 219.074215068891,3763.8004707498 218.026768167526,3764.08301131339 224.347147317646,3762.37809026841 PathPoint;PointKind.SMOOTHPOINT 215.281799695968,3765.13433601702 207.718105771,3768.04424417741 216.472272418617,3764.67641730911 PathPoint;PointKind.SMOOTHPOINT 202.011868694214,3770.99994420859 200.531116964818,3770.62015492971 203.146681121881,3771.29121827332 PathPoint;PointKind.SMOOTHPOINT 201.301671512661,3761.89987207139 201.467478129783,3759.99360841927 200.896549112469,3766.55931294469 PathPoint;PointKind.SMOOTHPOINT 204.934856168292,3752.99949025732 207.425713082166,3748.10849358378 204.17933224863,3754.48347732776 PathPoint;PointKind.SMOOTHPOINT 210.208023270612,3741.3636342649 210.33930641363,3739.58388835889 209.847053340702,3746.25109032988 PathPoint;PointKind.SMOOTHPOINT 210.95368334053,3728.93940276505 211.071344976759,3726.84454269663 210.602577260364,3735.18031546465 PathPoint;PointKind.SMOOTHPOINT 211.335085530623,3722.06330488864 212.565953066509,3719.85561742724 210.125119962051,3724.23322585867 PathPoint;PointKind.SMOOTHPOINT 211.68666131792,3715.59437699737 213.788835581175,3676.60236297798 211.564537463949,3717.85989439868 PathPoint;PointKind.SMOOTHPOINT 217.379511741481,3591.13844528196 217.402997098014,3587.83128084043 217.267251737254,3606.90855187701 PathPoint;PointKind.SMOOTHPOINT 217.276176172737,3568.51372050248 216.826666448698,3510.01909033741 217.364246259735,3579.9985105294 PathPoint;PointKind.SMOOTHPOINT 213.889822614266,3234.98603314757 213.856003700859,3231.60357176386 215.220972622547,3367.53532396449 PathPoint;PointKind.SMOOTHPOINT 213.660605534505,3214.1320847324 212.358577368324,3210.53270206386 215.365172711659,3218.8446347342 PathPoint;PointKind.SMOOTHPOINT 213.547406116017,3202.7157464711 212.542937417107,3100.91215628199 213.584747832904,3206.49924078509 PathPoint;PointKind.SMOOTHPOINT 212.256885774537,3002.50070514001 212.872436969263,2982.9468681904 211.842369231732,3015.67342129079 PathPoint;PointKind.SMOOTHPOINT 210.592008849924,2168.21931931454 210.586842071487,2167.45738035106 213.112457313029,2545.89414676142 PathPoint;PointKind.SMOOTHPOINT 210.576743368177,2165.93468262696 210.421974868626,2165.32546191298 210.731511867729,2166.54390334095 PathPoint;PointKind.SMOOTHPOINT 209.203319718137,2164.28074634534 204.273273674762,2159.15654158756 210.067111131415,2165.17864467777 PathPoint;PointKind.SMOOTHPOINT 191.984560868951,2141.95744537514 192.22692974837,2139.73890004747 191.752290692841,2144.08251863666 PathPoint;PointKind.SMOOTHPOINT 209.643905006693,2117.06602299149 210.221409923835,2116.3352413834 205.483474096899,2122.33374041649 PathPoint;PointKind.SMOOTHPOINT 210.540341065552,2115.64741915924 210.713193289633,2114.99429489904 210.491491523963,2115.83176684526 PathPoint;PointKind.SMOOTHPOINT 210.677730401269,2113.82943468071 211.00793451412,2111.83961266643 210.58214500018,2114.40419347131 PathPoint;PointKind.SMOOTHPOINT 210.53587884781,2106.95970989973 209.575797472748,2104.42723061251 211.71578316002,2110.07237691068 PathPoint;PointKind.SMOOTHPOINT 210.531651483634,2098.85077212053 210.483271649177,2007.64965230361 210.533060605026,2101.54918792922 PathPoint;PointKind.SMOOTHPOINT 210.948516562092,1848.2056627762 210.963077483143,1847.69156641237 208.863486609106,1921.59752150443 PathPoint;PointKind.SMOOTHPOINT 210.904833798941,1846.94969089744 210.888159195803,1846.46273919928 210.922447816341,1847.456233963 PathPoint;PointKind.SMOOTHPOINT 209.89238007881,1845.0901632784 205.37285806763,1839.63620984281 210.594827092708,1845.93778496918 PathPoint;PointKind.SMOOTHPOINT 191.984560868951,1817.94880217112 191.805367598605,1816.28518822608 192.435949421512,1822.14277103824 PathPoint;PointKind.SMOOTHPOINT 210.020844979045,1796.19813562638 210.775429484445,1795.46782609943 205.242044631742,1800.82217041402 PathPoint;PointKind.SMOOTHPOINT 211.220242137177,1794.91549116308 211.258288414761,1794.23829076463 210.892386559979,1795.39182103554 PathPoint;PointKind.SMOOTHPOINT 211.3332067021,1792.888138698 216.856257997929,1692.72314215339 211.296099838778,1793.5625066096 PathPoint;PointKind.SMOOTHPOINT 212.256885774537,1617.77105525026 212.247961339055,1610.93697259551 212.267454184977,1625.60996261614 PathPoint;PointKind.SMOOTHPOINT 212.307614144648,1511.20959526971 212.308788412475,1509.513879807 212.265105649324,1571.29962365477 PathPoint;PointKind.SMOOTHPOINT 214.869396835251,1504.94059374215 214.925996544495,1503.56211680699 214.774515994858,1507.25213905482 PathPoint;PointKind.SMOOTHPOINT 212.256885774537,1501.26969078057 211.519445579406,1498.38480292071 212.489390804212,1502.1789190604 PathPoint;PointKind.SMOOTHPOINT 212.403434399302,1487.23212197731 212.771449936172,1367.01713120267 212.372668582244,1497.25865335604 PathPoint;PointKind.SMOOTHPOINT 214.305983132028,582.545026688468 215.190441659055,569.141462859161 213.265346984057,598.3160774458 PathPoint;PointKind.SMOOTHPOINT 215.121864417979,481.08369532744 215.327361287641,479.825835124105 214.497623641336,484.906608416802 PathPoint;PointKind.SMOOTHPOINT 215.406037232026,467.833557869341 214.538018454572,454.042415422306 215.885373358862,475.45200334182 PathPoint;PointKind.SMOOTHPOINT 215.330414383991,427.210031422586 215.906745033307,400.950989970042 215.187858269836,433.704687736108 PathPoint;PointKind.SMOOTHPOINT 214.305983132028,255.524033716206 214.258777565397,250.858691828625 214.412841504252,266.08850155645 PathPoint;PointKind.SMOOTHPOINT 212.256885774537,244.282601518077 211.440065074325,242.04918563443 213.238808531175,246.966618851934 PathPoint;PointKind.SMOOTHPOINT 208.825205477958,239.482008383263 207.963058039637,238.856500869876 210.786467602016,240.904624905218 PathPoint;PointKind.SMOOTHPOINT 201.949867352968,227.907286898756 200.256808000515,219.296290824847 204.336684137401,240.044965145311 PathPoint;PointKind.SMOOTHPOINT 199.944452758628,211.906804706325 199.942104222975,203.60667406454 199.942573930105,204.625189128791 PathPoint;PointKind.SMOOTHPOINT 200.939527314925,195.906322513894 201.19763138322,192.693338260226 200.544973325173,200.819034919975 PathPoint";
	
	negativeSquare[2] = "PointKind.SMOOTHPOINT 204.060966051705,189.097968281393 205.548058827365,189.845272729462 202.57363842248,188.350663833325 PathPoint;PointKind.SMOOTHPOINT 218.403942993444,206.470790354138 232.479186870709,208.267295140699 204.328933969745,204.674521608148 PathPoint;PointKind.SMOOTHPOINT 251.188326445469,209.536721332017 253.843580855072,209.565990362832 238.928735481758,209.401706125354 PathPoint;PointKind.SMOOTHPOINT 259.443898973894,209.779843120239 263.457311551792,208.555028596857 256.714665691212,210.612830295613 PathPoint;PointKind.SMOOTHPOINT 267.300220441262,210.186068943084 276.267868979763,210.696860738921 264.596586197201,210.032170490733 PathPoint;PointKind.SMOOTHPOINT 297.291490440835,211.580596637079 304.6099972436,211.729774278008 286.191841236282,211.354233729405 PathPoint;PointKind.SMOOTHPOINT 328.641388315834,212.259449319532 330.218899714145,212.290370634345 315.952954741834,212.011134638746 PathPoint;PointKind.SMOOTHPOINT 333.430991927142,212.350088898831 337.028948547974,210.480175494661 331.999559446465,213.094088778904 PathPoint;PointKind.SMOOTHPOINT 348.199053822126,212.90690860603 363.644903106647,213.150266434823 345.533700709213,212.864893384376 PathPoint;PointKind.SMOOTHPOINT 385.399388863021,212.602416269325 412.17692267464,212.063535645528 372.882398391711,212.854507599248 PathPoint;PointKind.SMOOTHPOINT 522.683979890027,210.558540964263 572.152830330115,209.768277132256 473.215364303504,211.349040836841 PathPoint;PointKind.SMOOTHPOINT 847.454285800821,208.5146656592 873.152432626191,207.633998288466 796.781106277729,210.251216140704 PathPoint;PointKind.SMOOTHPOINT 1118.96590928782,207.545483074308 1120.94032321154,207.54595515545 998.742490367667,207.515269881208 PathPoint;PointKind.SMOOTHPOINT 1124.8842191341,207.546899317734 1127.57329245711,208.933637672884 1123.13338580458,206.644044133317 PathPoint;PointKind.SMOOTHPOINT 1131.99652450651,207.549259723445 1243.99325788677,207.586790174248 1129.62920056799,207.548315561161 PathPoint;PointKind.SMOOTHPOINT 1357.66144409148,207.492846026955 1378.11554565663,206.981818190546 1347.95565079715,207.735259693463 PathPoint;PointKind.SMOOTHPOINT 1701.89735291096,208.5146656592 1706.30907713565,208.62725701161 1680.47072273178,207.967759655986 PathPoint;PointKind.SMOOTHPOINT 1785.96999737367,208.90672904778 1789.29552385872,208.920183360332 1736.36728040134,208.705858521783 PathPoint;PointKind.SMOOTHPOINT 1795.92003837594,208.90672904778 1798.56660320363,207.820234299056 1792.70794616294,210.225251677885 PathPoint;PointKind.SMOOTHPOINT 1805.76627410233,209.063459986983 2005.02919072665,209.842629912149 1803.43864041636,209.054490445282 PathPoint;PointKind.SMOOTHPOINT 2453.88907495004,211.580596637079 2460.84802094428,211.697436719769 2422.72283256312,211.057058650403 PathPoint;PointKind.SMOOTHPOINT 2558.84748183097,212.044888440412 2560.1877911283,212.049137170692 2499.50374352952,211.85581994297 PathPoint;PointKind.SMOOTHPOINT 2562.90034980785,212.057634631251 2566.7230612907,213.174578613645 2561.59385942392,211.675957027799 PathPoint;PointKind.SMOOTHPOINT 2572.80623833983,212.088791986635 2613.62449255461,212.215309732739 2569.44618838068,212.078170160936 PathPoint;PointKind.SMOOTHPOINT 2717.62915910675,212.503515270039 2719.77525098672,212.509180243745 2662.92377872054,212.354573669681 PathPoint;PointKind.SMOOTHPOINT 2723.27292513516,213.907012505736 2725.0263418539,213.911733317157 2721.11039350562,213.901111491458 PathPoint;PointKind.SMOOTHPOINT 2729.36831456969,212.535380747136 2915.88760703216,213.040507569267 2727.60432944051,212.530423895143 PathPoint;PointKind.SMOOTHPOINT 3347.960628113,214.253992145237 3349.82912307875,214.259893159514 3161.08506279193,213.652560770101 PathPoint;PointKind.SMOOTHPOINT 3353.54849899286,214.27193122864 3355.06518331775,212.899591348326 3352.10790722313,215.575347262195 PathPoint;PointKind.SMOOTHPOINT 3359.66972231958,214.291994677182 3509.38558226655,214.779890537624 3357.63659500453,214.285149500621 PathPoint;PointKind.SMOOTHPOINT 3625.93095950009,215.668347247204 3642.53322774029,216.650512063507 3619.0218024617,215.259524978077 PathPoint;PointKind.SMOOTHPOINT 3713.21452190798,215.452134084086 3714.77254046037,215.411063024717 3685.76765543517,216.174890312762 PathPoint;PointKind.SMOOTHPOINT 3717.25963971719,215.906984264575 3720.18661970188,213.879395758918 3716.06916699454,216.73147397939 PathPoint;PointKind.SMOOTHPOINT 3722.07695604921,215.192017374746 3720.59338607703,215.240877772961 3720.69766106004,215.237337164395 PathPoint;PointKind.SMOOTHPOINT 3737.57987475011,215.154722964514 3738.59749524868,215.116956473139 3727.4952626549,215.528139147977 PathPoint;PointKind.SMOOTHPOINT 3741.1550505751,215.906984264575 3742.42795689918,215.845377675521 3740.07801212451,215.958913190215 PathPoint;PointKind.SMOOTHPOINT 3744.64779279867,214.802314391877 3752.76879423416,214.290578433756 3743.30818806203,214.886816916327 PathPoint;PointKind.SMOOTHPOINT 3770.23955095894,211.580596637079 3772.44294710886,211.115360671462 3761.95438688129,213.329893309422 PathPoint;PointKind.SMOOTHPOINT 3770.23955095894,226.909779445333 3767.79449049031,234.190922941725 3772.68484628114,219.628399908369 PathPoint;PointKind.SMOOTHPOINT 3757.05956887271,252.907996066823 3755.50812622015,264.872656574769 3759.15446267544,236.750074813475 PathPoint;PointKind.SMOOTHPOINT 3752.97029859321,345.454783179521 3753.74273196958,367.32276188809 3752.19786521685,323.586804470951 PathPoint;PointKind.SMOOTHPOINT 3755.0193959507,591.742583581534 3755.06190444603,596.715958414386 3754.83127824487,569.722830785754 PathPoint;PointKind.SMOOTHPOINT 3755.3716762987,649.267323039997 3755.38224470914,651.109383656778 3755.19365729618,618.293371179944 PathPoint;PointKind.SMOOTHPOINT 3755.40385123715,654.891933808484 3755.81860263352,658.102793697012 3755.15936867564,653.000540712345 PathPoint;PointKind.SMOOTHPOINT 3755.45364019299,663.654703969604 3756.07835067677,773.84599585237 3755.43673073629,660.666194299042 PathPoint;PointKind.SMOOTHPOINT 3757.06849330819,1008.69432601711 3757.0149466953,1040.40000364754 3757.12767640666,973.570780917308 PathPoint;PointKind.SMOOTHPOINT 3755.88905870311,1569.77008075411 3755.88671016746,1571.65816928225 3756.17252695647,1354.67315349698 PathPoint;PointKind.SMOOTHPOINT 3755.88177824259,1575.41145040315 3754.94682619902,1578.5845438003 3756.41113817884,1573.61494561658 PathPoint;PointKind.SMOOTHPOINT 3755.87214924641,1583.09858368181 3755.74885112461,1683.20645840821 3755.87520234276,1580.55170591976 PathPoint;PointKind.SMOOTHPOINT 3756.04382720267,1770.04011953826 3756.54758810029,1789.22762152154 3755.75801041366,1759.15015175049 PathPoint;PointKind.SMOOTHPOINT 3756.23828595476,2320.27405876399 3756.23687683337,2322.14727673616 3756.4127821538,2070.12133005096 PathPoint;PointKind.SMOOTHPOINT 3756.23429344415,2325.88804770678 3754.26363717748,2328.35089502553 3757.40339449235,2324.42695657174 PathPoint;PointKind.SMOOTHPOINT 3756.22912666571,2333.20908205969 3756.09361615852,2525.01116535601 3756.23077064067,2330.77219920376 PathPoint;PointKind.SMOOTHPOINT 3756.04382720267,2711.24741198605 3756.22231591232,2738.35242284538 3755.94072648749,2695.57620639029 PathPoint;PointKind.SMOOTHPOINT 3755.57200638992,3156.94913202088 3755.5647259294,3158.65900991785 3756.14293540723,3025.09356444239 PathPoint;PointKind.SMOOTHPOINT 3755.54946044765,3161.99969212047 3754.33972973264,3164.68819422518 3756.22983122641,3160.48808830322 PathPoint;PointKind.SMOOTHPOINT 3755.52151287337,3167.94106933536 3755.38200985557,3196.4576028098 3755.53090701599,3166.00176000329 PathPoint;PointKind.SMOOTHPOINT 3755.0193959507,3221.19583486282 3754.47923275045,3235.63915740778 3755.21573353132,3215.94794484579 PathPoint;PointKind.SMOOTHPOINT 3753.85757536302,3441.0562968851 3753.85452226667,3442.06442616423 3754.1483240769,3339.50503406649 PathPoint;PointKind.SMOOTHPOINT 3753.0950058364,3445.99143314544 3755.07435168499,3447.33592023836 3750.47239607238,3444.21003495543 PathPoint;PointKind.SMOOTHPOINT 3753.82821866736,3451.27614549156 3753.55837192079,3546.16516319117 3753.83502942075,3448.87986161386 PathPoint;PointKind.SMOOTHPOINT 3752.97029859321,3646.32331455922 3752.81412097227,3650.81327830248 3753.31858643059,3636.31944307531 PathPoint;PointKind.SMOOTHPOINT 3752.50669765525,3660.44585796806 3752.44375689975,3662.49209367884 3752.65653422993,3655.58295012248 PathPoint;PointKind.SMOOTHPOINT 3752.32257246004,3666.62020722662 3752.99989014244,3669.03419414715 3751.76432553525,3664.63038521233 PathPoint;PointKind.SMOOTHPOINT 3752.18306944223,3671.60373180402 3751.62858017449,3692.06915743918 3752.22816132677,3669.94578283269 PathPoint;PointKind.SMOOTHPOINT 3751.94586734125,3716.83713060415 3753.05085336612,3726.07528647545 3751.32984643939,3711.68625326184 PathPoint;PointKind.SMOOTHPOINT 3769.18576301131,3740.34181463266 3770.82245750809,3750.62893480187 3767.54883366098,3730.05445842287 PathPoint;PointKind.SMOOTHPOINT 3770.21019426328,3767.93424927128 3769.10403397058,3769.19234551519 3771.31635455597,3766.67591698681 PathPoint;PointKind.SMOOTHPOINT 3754.84255121601,3766.91219359847 3749.13701869992,3765.94466329757 3764.18948826252,3768.49720603333 PathPoint;PointKind.SMOOTHPOINT 3720.48417916915,3763.52642764676 3718.47171896785,3763.39920177895 3734.52513442588,3764.41488435634 PathPoint;PointKind.SMOOTHPOINT 3714.10720030979,3763.18770942725 3712.58135669585,3763.63972712089 3717.63728425024,3762.14181365675 PathPoint;PointKind.SMOOTHPOINT 3709.15531288484,3763.00690234979 3705.01202628532,3762.88321709054 3710.86716052252,3763.05788711315 PathPoint;PointKind.SMOOTHPOINT 3695.59768626556,3762.82444298834 3665.86686886994,3762.87235922427 3700.5049515131,3762.8166536495 PathPoint;PointKind.SMOOTHPOINT 3243.78780640808,3764.86831829341 3236.42068491729,3764.98279797038 3282.35522405276,3764.26948336455 PathPoint;PointKind.SMOOTHPOINT 3177.95764748582,3765.23347305688 3176.36299177724,3765.23937407116 3212.35077786035,3765.10530302678 PathPoint;PointKind.SMOOTHPOINT 3174.0067059563,3763.99992503237 3172.50458255246,3764.0053539655 3175.64504442803,3763.99378797752 PathPoint;PointKind.SMOOTHPOINT 3168.54776968381,3765.26769893969 3018.5524339941,3765.80185875206 3170.08559082958,3765.26203396598 PathPoint;PointKind.SMOOTHPOINT 2670.06121342443,3766.91219359847 2653.50544619017,3767.17585091637 2700.84417479273,3766.42217337289 PathPoint;PointKind.SMOOTHPOINT 2101.10614032756,3766.68960733993 2095.97623390009,3766.68465048794 2395.97277661865,3766.98017328294 PathPoint;PointKind.SMOOTHPOINT 2085.68377639957,3766.67450074338 2084.42989321428,3766.99055906807 2093.675138667,3764.65965842856 PathPoint;PointKind.SMOOTHPOINT 2081.80164696469,3766.67048805367 2057.89097062504,3766.64664795599 2083.09639467035,3766.6719042971 PathPoint;PointKind.SMOOTHPOINT 2009.53368210965,3766.59778755778 2007.76993183403,3766.59589923321 2033.76587298024,3766.62233577717 PathPoint;PointKind.SMOOTHPOINT 2004.88499063754,3765.99989679121 2001.74288478701,3764.83196804546 2006.54023856597,3766.61525456004 PathPoint;PointKind.SMOOTHPOINT 1998.72548617967,3766.58669365094 1688.57364044274,3766.26969116396 2000.56438959619,3766.5885819755 PathPoint;PointKind.SMOOTHPOINT 1246.85400916604,3765.86582574683 1245.75818243021,3765.86535366569 1363.49755518989,3765.89603893993 PathPoint;PointKind.SMOOTHPOINT 1243.62195439999,3765.86488158454 1241.10221049758,3767.34296764071 1244.53459535485,3765.32954156931 PathPoint;PointKind.SMOOTHPOINT 1236.25342378781,3765.86393742226 1219.3951651614,3765.86252117883 1238.59867149118,3765.86393742226 PathPoint;PointKind.SMOOTHPOINT 1203.98454391168,3765.89037396622 1143.78640833956,3766.16182062297 1208.31242541355,3765.87078259882 PathPoint;PointKind.SMOOTHPOINT 478.630148105717,3762.82444298834 455.47570024642,3762.24307506175 517.417388687537,3763.79858242523 PathPoint;PointKind.SMOOTHPOINT 378.200187671443,3761.33408282249 375.813840594141,3761.30859044081 414.176700783412,3761.71694062879 PathPoint;PointKind.SMOOTHPOINT 371.117943555398,3761.25973004259 368.312852571115,3762.09224513682 375.195471156631,3760.04955003462 PathPoint;PointKind.SMOOTHPOINT 362.495060050799,3761.17215899072 344.697622016644,3760.99418440012 365.31283312761,3761.20024781868 PathPoint;PointKind.SMOOTHPOINT 319.830621958972,3760.78056768328 305.487175310102,3760.66160323545 329.340312526251,3760.85940523402 PathPoint;PointKind.SMOOTHPOINT 274.282182084911,3760.38354744271 271.182819583271,3760.36584439988 288.949022093238,3760.46663372373 PathPoint;PointKind.SMOOTHPOINT 267.619856143674,3758.99964157441 264.661640634796,3758.99374056013 270.513721775651,3759.00554258869 PathPoint;PointKind.SMOOTHPOINT 256.821524063437,3760.35286216847 248.371492782919,3760.38496368614 259.48382408,3760.34271242391 PathPoint;PointKind.SMOOTHPOINT 237.869780755692,3760.78056768328 230.576403284417,3760.8383976232 241.617573951204,3760.50723270196 PathPoint;PointKind.SMOOTHPOINT 219.074215068891,3763.8004707498 218.026768167526,3764.08301131339 224.347147317646,3762.37809026841 PathPoint;PointKind.SMOOTHPOINT 215.281799695968,3765.13433601702 207.718105771,3768.04424417741 216.472272418617,3764.67641730911 PathPoint;PointKind.SMOOTHPOINT 202.011868694214,3770.99994420859 200.531116964818,3770.62015492971 203.146681121881,3771.29121827332 PathPoint;PointKind.SMOOTHPOINT 201.301671512661,3761.89987207139 201.467478129783,3759.99360841927 200.896549112469,3766.55931294469 PathPoint;PointKind.SMOOTHPOINT 204.934856168292,3752.99949025732 207.425713082166,3748.10849358378 204.17933224863,3754.48347732776 PathPoint;PointKind.SMOOTHPOINT 210.208023270612,3741.3636342649 210.33930641363,3739.58388835889 209.847053340702,3746.25109032988 PathPoint;PointKind.SMOOTHPOINT 210.95368334053,3728.93940276505 211.071344976759,3726.84454269663 210.602577260364,3735.18031546465 PathPoint;PointKind.SMOOTHPOINT 211.335085530623,3722.06330488864 212.565953066509,3719.85561742724 210.125119962051,3724.23322585867 PathPoint;PointKind.SMOOTHPOINT 211.68666131792,3715.59437699737 213.788835581175,3676.60236297798 211.564537463949,3717.85989439868 PathPoint;PointKind.SMOOTHPOINT 217.379511741481,3591.13844528196 217.402997098014,3587.83128084043 217.267251737254,3606.90855187701 PathPoint;PointKind.SMOOTHPOINT 217.276176172737,3568.51372050248 216.826666448698,3510.01909033741 217.364246259735,3579.9985105294 PathPoint;PointKind.SMOOTHPOINT 213.889822614266,3234.98603314757 213.856003700859,3231.60357176386 215.220972622547,3367.53532396449 PathPoint;PointKind.SMOOTHPOINT 213.660605534505,3214.1320847324 212.358577368324,3210.53270206386 215.365172711659,3218.8446347342 PathPoint;PointKind.SMOOTHPOINT 213.547406116017,3202.7157464711 212.542937417107,3100.91215628199 213.584747832904,3206.49924078509 PathPoint;PointKind.SMOOTHPOINT 212.256885774537,3002.50070514001 212.872671822828,2982.94002301383 211.842369231732,3015.67342129079 PathPoint;PointKind.SMOOTHPOINT 210.589425460705,2167.81757826254 210.587546632183,2166.08692879532 210.98280518263,2545.592250871 PathPoint;PointKind.SMOOTHPOINT 209.039157075972,2164.11079713416 203.91794023042,2158.83151372117 209.296086876441,2164.37563465492 PathPoint;PointKind.SMOOTHPOINT 191.984560868951,2140.95734147544 192.227164601935,2138.73737990434 191.75487408206,2143.05928276099 PathPoint;PointKind.SMOOTHPOINT 209.65259458861,2117.05516512522 210.668336258656,2115.90800794972 205.216915300252,2122.06441812488 PathPoint;PointKind.SMOOTHPOINT 210.537992529898,2114.30009957946 210.599524164014,2112.13584358315 210.495718888139,2115.77747751391 PathPoint;PointKind.SMOOTHPOINT 210.53587884781,2106.95970989973 210.229160091491,2104.26719510531 210.92902371617,2110.41180325191 PathPoint;PointKind.SMOOTHPOINT 210.531651483634,2098.85077212053 210.483506502742,2007.78726395655 210.533060605026,2101.54918792922 PathPoint;PointKind.SMOOTHPOINT 210.939122419479,1848.53777185973 210.941940662263,1847.75694965056 210.68571542249,1921.9267981011 PathPoint;PointKind.SMOOTHPOINT 210.24583469463,1845.52376980749 206.247217891347,1841.15701924234 210.909296016683,1846.24841436073 PathPoint;PointKind.SMOOTHPOINT 191.984560868951,1816.94869827142 191.812413205565,1815.34999548343 192.448866367605,1821.26139554579 PathPoint;PointKind.SMOOTHPOINT 209.40576349145,1796.78729289182 211.213431383783,1795.09039722626 203.476180674037,1802.35360163925 PathPoint;PointKind.SMOOTHPOINT 211.423390471186,1791.23797906551 215.624685901347,1691.92886563168 211.355987497937,1792.8333772855 PathPoint;PointKind.SMOOTHPOINT 212.256885774537,1617.77105525026 212.247961339055,1610.93697259551 212.267219331412,1625.5670032322 PathPoint;PointKind.SMOOTHPOINT 212.307614144648,1511.20959526971 212.308788412475,1509.513879807 212.265105649324,1571.29962365477 PathPoint;PointKind.SMOOTHPOINT 214.869396835251,1504.94059374215 214.925996544495,1503.56211680699 214.774515994858,1507.25213905482 PathPoint;PointKind.SMOOTHPOINT 212.256885774537,1501.26969078057 211.519445579406,1498.38480292071 212.489390804212,1502.1789190604 PathPoint;PointKind.SMOOTHPOINT 212.403434399302,1487.23212197731 212.771449936172,1367.01713120267 212.372668582244,1497.25865335604 PathPoint;PointKind.SMOOTHPOINT 214.305983132028,582.545026688468 215.190441659055,569.141462859161 213.265346984057,598.3160774458 PathPoint;PointKind.SMOOTHPOINT 215.121864417979,481.08369532744 215.327361287641,479.825835124105 214.497623641336,484.906608416802 PathPoint;PointKind.SMOOTHPOINT 215.406037232026,467.833557869341 214.538018454572,454.042415422306 215.885373358862,475.45200334182 PathPoint;PointKind.SMOOTHPOINT 215.330414383991,427.210031422586 215.74469607323,408.338587763996 215.187858269836,433.704687736108 PathPoint;PointKind.SMOOTHPOINT 214.648634483842,288.768223788996 214.640414609056,287.940901587328 215.089689479529,333.375170913454 PathPoint;PointKind.SMOOTHPOINT 215.879971726859,285.90882831082 215.861653148763,284.07998596602 215.88795674808,286.714670820519 PathPoint;PointKind.SMOOTHPOINT 214.571132807284,281.007917933292 214.435387446524,267.573668829744 214.588277117553,282.716851667979 PathPoint;PointKind.SMOOTHPOINT 214.305983132028,255.524033716206 214.258777565397,250.858691828625 214.331582170649,258.035741433167 PathPoint;PointKind.SMOOTHPOINT 212.256885774537,244.282601518077 211.440065074325,242.04918563443 213.238808531175,246.966618851934 PathPoint;PointKind.SMOOTHPOINT 208.825205477958,239.482008383263 207.963058039637,238.856500869876 210.786467602016,240.904624905218 PathPoint;PointKind.SMOOTHPOINT 201.949867352968,227.907286898756 200.256808000515,219.296290824847 204.336684137401,240.044965145311 PathPoint;PointKind.SMOOTHPOINT 199.944452758628,211.906804706325 199.942104222975,203.60667406454 199.942573930105,204.625189128791 PathPoint;PointKind.SMOOTHPOINT 200.939527314925,195.906322513894 201.19763138322,192.693338260226 200.544973325173,200.819034919975 PathPoint";
	
} else {

	negativeSquare[0] = "PointKind.SMOOTHPOINT 191.137254901961,189.191608865432 192.631875314228,189.938883440615 189.642634489693,188.444334290248 PathPoint;PointKind.SMOOTHPOINT 205.552538964304,206.564145997896 219.698340874811,208.360479111317 191.406737053796,204.767812884475 PathPoint;PointKind.SMOOTHPOINT 238.50175967823,209.629887844801 241.170316189201,209.659109751814 226.180392156863,209.494963268727 PathPoint;PointKind.SMOOTHPOINT 246.798778305761,209.873097809666 250.832338812651,208.648167636168 244.055876618919,210.706074787056 PathPoint;PointKind.SMOOTHPOINT 254.69462193876,210.279330787859 263.707251914827,210.790123443124 251.977306469736,210.125326375462 PathPoint;PointKind.SMOOTHPOINT 284.83660130719,211.673715742738 292.191963108208,211.82292465005 273.68113430561,211.447418915079 PathPoint;PointKind.SMOOTHPOINT 316.344259367597,212.352565370158 317.929610278225,212.383426107832 303.591867737303,212.104324926871 PathPoint;PointKind.SMOOTHPOINT 321.157847625982,212.443292438999 324.773935766279,210.573262324895 319.719181035806,213.187286983215 PathPoint;PointKind.SMOOTHPOINT 329.11488845495,212.578430052417 344.638294638914,212.821759909284 326.436051461802,212.536439202316 PathPoint;PointKind.SMOOTHPOINT 373.387631975867,212.695629691707 400.299648064354,212.156729757681 360.807617429156,212.94753831821 PathPoint;PointKind.SMOOTHPOINT 511.362493715435,210.65180179377 561.079939668175,209.861415223865 461.645047762695,211.442188363675 PathPoint;PointKind.SMOOTHPOINT 837.76571141277,208.607973895833 863.593039974326,207.72735988026 786.837606837607,210.344429238807 PathPoint;PointKind.SMOOTHPOINT 1110.64242764693,207.638636004566 1112.62668620089,207.639130690378 989.814451487277,207.608512971733 PathPoint;PointKind.SMOOTHPOINT 1116.59037115698,207.640237874197 1119.29312295497,209.026897983122 1114.83070521343,206.737432603372 PathPoint;PointKind.SMOOTHPOINT 1123.73860949767,207.642464106405 1236.29832311209,207.679989766081 1121.35919873928,207.641670847827 PathPoint;PointKind.SMOOTHPOINT 1350.53795877325,207.586059946864 1371.09502262443,207.07510297238 1340.78346794573,207.828513108315 PathPoint;PointKind.SMOOTHPOINT 1696.50477626948,208.607973895833 1700.93864193796,208.72057532161 1674.97033685269,208.06109025908 PathPoint;PointKind.SMOOTHPOINT 1783.71676895521,209.088839085984 1787.05911385,209.102303969912 1733.86477266633,208.88800662712 PathPoint;PointKind.SMOOTHPOINT 1793.9685671796,209.129677702261 1796.62839812572,208.043293766429 1790.74020967554,210.448271177777 PathPoint;PointKind.SMOOTHPOINT 1800.89597778141,209.156799765954 2001.16082024052,209.935861460137 1798.55656092419,209.147699066911 PathPoint;PointKind.SMOOTHPOINT 2452.27752639517,211.673715742738 2459.27138558491,211.790582934244 2420.95442135944,211.150307533416 PathPoint;PointKind.SMOOTHPOINT 2557.76355731651,212.137992083089 2559.11072946531,212.142260854744 2498.121488518,211.949004823385 PathPoint;PointKind.SMOOTHPOINT 2561.83677046358,212.150845054804 2565.67882323735,213.267629878739 2560.52366196874,211.76915856439 PathPoint;PointKind.SMOOTHPOINT 2571.79244238614,212.181837583487 2753.70205018181,212.74301698527 2568.41555199795,212.171420094543 PathPoint;PointKind.SMOOTHPOINT 3350.84423596514,214.347039584389 3352.7221163448,214.353053829277 3103.21882121942,213.553975286508 PathPoint;PointKind.SMOOTHPOINT 3356.46018016849,214.365079115046 3357.98455782562,212.992774017447 3355.0124375785,215.668394292192 PathPoint;PointKind.SMOOTHPOINT 3362.61236285261,214.384966833144 3513.08083242288,214.873020875168 3360.56901111595,214.378339091949 PathPoint;PointKind.SMOOTHPOINT 3630.21216691805,215.761371538612 3646.8980461932,216.743487406778 3623.26840431205,215.352667907975 PathPoint;PointKind.SMOOTHPOINT 3717.93466862885,215.545078506195 3719.50065866565,215.504047620276 3690.34988397389,216.267834159607 PathPoint;PointKind.SMOOTHPOINT 3722.47142762929,215.419818238237 3725.41319724814,213.392270583254 3721.27507240827,216.244378804558 PathPoint;PointKind.SMOOTHPOINT 3726.84176649607,215.284994190144 3732.37550059946,215.103748542089 3725.45556553642,215.330396243544 PathPoint;PointKind.SMOOTHPOINT 3739.35646053293,214.739457589644 3754.29864253394,213.729519194765 3736.73692152981,214.916511584566 PathPoint;PointKind.SMOOTHPOINT 3770.24635495224,211.673715742738 3772.49713423831,211.44059162313 3763.37138309563,212.385789899152 PathPoint;PointKind.SMOOTHPOINT 3770.24635495224,227.002424977266 3767.78883861237,234.283561863666 3772.70387129211,219.721288090865 PathPoint;PointKind.SMOOTHPOINT 3757.89039718452,246.418790007667 3755.37254901961,258.218702637163 3760.40824534942,234.618877378172 PathPoint;PointKind.SMOOTHPOINT 3757.89039718452,345.544443057611 3758.66666666667,367.411804824991 3757.11412770236,323.67708129023 PathPoint;PointKind.SMOOTHPOINT 3759.94972347914,591.825704759018 3759.99242011279,596.798942179434 3759.76068376068,569.806652639837 PathPoint;PointKind.SMOOTHPOINT 3760.30372000025,649.348977648359 3760.31435016567,651.191094343379 3760.12498586064,618.375880852469 PathPoint;PointKind.SMOOTHPOINT 3760.3360912295,654.97352094627 3760.75306415307,658.184377759686 3760.09045985543,653.082061989526 PathPoint;PointKind.SMOOTHPOINT 3760.38620303764,663.735985531736 3761.01406917796,773.924477866133 3760.36917501615,660.747622416168 PathPoint;PointKind.SMOOTHPOINT 3762.00904977376,1008.76659593816 3761.95526991133,1040.47141579646 3762.06862707927,973.644011869382 PathPoint;PointKind.SMOOTHPOINT 3760.82382611228,1569.82763812638 3760.82132541403,1571.71582218301 3761.10869164333,1354.73629218466 PathPoint;PointKind.SMOOTHPOINT 3760.8164547947,1575.46900439178 3759.87678340803,1578.64203118547 3761.34852019578,1573.67235739624 PathPoint;PointKind.SMOOTHPOINT 3760.80674401219,1583.15575724274 3760.68286798311,1683.26114500411 3760.80989560872,1580.60892235584 PathPoint;PointKind.SMOOTHPOINT 3760.97938662645,1770.09248791969 3761.48565241628,1789.27959458398 3760.69205409576,1759.20279316802 PathPoint;PointKind.SMOOTHPOINT 3761.17470630972,2320.31207526072 3761.17339216627,2322.1851164981 3761.35021123951,2070.16589103806 PathPoint;PointKind.SMOOTHPOINT 3761.17075739318,2325.92590568899 3759.19015032087,2328.38858487434 3762.3458431266,2324.4648086258 PathPoint;PointKind.SMOOTHPOINT 3761.16557810592,2333.24672382007 3761.02946241775,2525.04379233337 3761.16730756502,2330.80978808109 PathPoint;PointKind.SMOOTHPOINT 3760.97938662645,2711.27523491967 3761.15865012818,2738.37950780105 3760.87574234414,2695.60443253586 PathPoint;PointKind.SMOOTHPOINT 3760.50516356411,3156.96522748016 3760.49772292284,3158.67500219988 3761.07896117735,3025.11306341165 PathPoint;PointKind.SMOOTHPOINT 3760.48259187076,3162.01551673434 3759.26667508144,3164.70408898892 3761.1661832874,3160.50399478451 PathPoint;PointKind.SMOOTHPOINT 3760.45437684295,3167.95697067491 3760.31424580973,3196.4725247255 3760.46390688322,3166.01768305073 PathPoint;PointKind.SMOOTHPOINT 3759.94972347914,3221.21029545495 3758.87983911513,3249.66820382291 3760.14701452237,3215.96254100676 PathPoint;PointKind.SMOOTHPOINT 3757.89039718452,3646.32649822584 3757.73333324999,3650.81640741321 3758.62644544998,3625.28544969064 PathPoint;PointKind.SMOOTHPOINT 3757.42454087272,3660.44866011815 3757.3612176099,3662.49488533293 3757.57502338714,3655.58597456337 PathPoint;PointKind.SMOOTHPOINT 3757.23940521759,3666.62290266053 3757.92003298689,3669.03688751975 3756.67839873891,3664.63317904571 PathPoint;PointKind.SMOOTHPOINT 3757.09922119415,3671.60645018074 3756.54184823652,3692.07111370885 3757.14437910952,3669.94841935779 PathPoint;PointKind.SMOOTHPOINT 3756.86073403721,3716.83856070467 3757.97123707589,3726.07641953987 3756.24155735475,3711.68786179863 PathPoint;PointKind.SMOOTHPOINT 3768.18702865762,3740.34258153095 3769.83207642031,3750.6295824938 3766.54198089492,3730.05558056809 PathPoint;PointKind.SMOOTHPOINT 3769.21669180493,3767.93425815309 3768.10497737557,3769.19248970276 3770.32840623429,3766.67602660343 PathPoint;PointKind.SMOOTHPOINT 3753.77174459527,3766.91234420413 3748.03766328341,3765.94484915634 3763.16567148481,3768.49735447004 PathPoint;PointKind.SMOOTHPOINT 3725.24080672534,3763.526734553 3723.2183649387,3763.39942316986 3739.35245331721,3764.41505344443 PathPoint;PointKind.SMOOTHPOINT 3718.83182064887,3763.18787143456 3717.29823709542,3763.63995810222 3722.37958828692,3762.14202137606 PathPoint;PointKind.SMOOTHPOINT 3713.85502343888,3763.00703240367 3709.69084968594,3762.88354546221 3715.57546850746,3763.05805152824 PathPoint;PointKind.SMOOTHPOINT 3700.22926093514,3762.82468840825 3670.3489190548,3762.87259062461 3705.16123022667,3762.81678179657 PathPoint;PointKind.SMOOTHPOINT 3246.14781297134,3764.86851630619 3207.38662644545,3765.46729401066 3284.90899949724,3764.26973860171 PathPoint;PointKind.SMOOTHPOINT 2669.53645047763,3766.91234420413 2652.89738802126,3767.17589906736 2708.59929612871,3766.29360724284 PathPoint;PointKind.SMOOTHPOINT 2097.72077884995,3766.68978549905 2092.56514741798,3766.68473202425 2394.07003165887,3766.98026271806 PathPoint;PointKind.SMOOTHPOINT 2082.22089299929,3766.6745408793 2080.96058446868,3766.99070498771 2090.25225711849,3764.65977305509 PathPoint;PointKind.SMOOTHPOINT 2078.31913052828,3766.67068745656 1743.5136137715,3766.3397623937 2079.62035466708,3766.67197359929 PathPoint;PointKind.SMOOTHPOINT 1239.17348740591,3765.86585194992 1238.07218317537,3765.86556580035 1366.93619290201,3765.89904826659 PathPoint;PointKind.SMOOTHPOINT 1235.92522387882,3765.86508467193 1233.39276107615,3767.34312046664 1236.84251462175,3765.32972101297 PathPoint;PointKind.SMOOTHPOINT 1228.5195920024,3765.86399097909 1211.57658701506,3765.86268557393 1230.87667726611,3765.86417258509 PathPoint;PointKind.SMOOTHPOINT 1196.08848667672,3765.89043025516 1135.58773252891,3766.16187614785 1200.43818061444,3765.87091468762 PathPoint;PointKind.SMOOTHPOINT 467.086978381096,3762.82468840825 443.816253598972,3762.24324762746 506.069381598793,3763.79870014086 PathPoint;PointKind.SMOOTHPOINT 366.152153989091,3761.33426560165 363.753692726408,3761.30885848452 402.309623351756,3761.71728494552 PathPoint;PointKind.SMOOTHPOINT 359.034265842321,3761.25995670417 356.215116264166,3762.09243350602 363.132413723737,3760.04979990076 PathPoint;PointKind.SMOOTHPOINT 350.368091084274,3761.17230932986 332.481157602846,3760.99448673533 353.199881358128,3761.20046151671 PathPoint;PointKind.SMOOTHPOINT 307.489190548014,3760.78086051032 277.02966314731,3760.52937387444 317.046536919319,3760.85976997123 PathPoint;PointKind.SMOOTHPOINT 225.116138763198,3760.78086051032 217.786209534642,3760.83860550777 236.723981900453,3759.93857987269 PathPoint;PointKind.SMOOTHPOINT 206.226071456223,3763.80056521225 205.173407334422,3764.08310299741 211.525441071092,3762.37820063957 PathPoint;PointKind.SMOOTHPOINT 202.414515498863,3765.13456485774 194.812945442351,3768.04442165915 203.611105638298,3764.67651396433 PathPoint;PointKind.SMOOTHPOINT 189.07792860734,3771 187.589855980562,3770.62013583144 190.218351821043,3771.29111879896 PathPoint;PointKind.SMOOTHPOINT 188.364194355398,3761.90000575055 188.530766504602,3759.9939633763 187.956993050704,3766.55950582485 PathPoint;PointKind.SMOOTHPOINT 190.107591754651,3756.69320471444 192.610960281549,3751.8023884243 189.348098248464,3758.17702268706 PathPoint;PointKind.SMOOTHPOINT 197.315233785822,3741.36449547991 197.447336855217,3739.58462366272 196.952508269556,3746.25162586028 PathPoint;PointKind.SMOOTHPOINT 198.06463814817,3728.94043854742 198.183042016952,3726.84561356463 197.711891878372,3735.18129626737 PathPoint;PointKind.SMOOTHPOINT 198.447985286857,3722.06458486176 199.685061786505,3719.85694976742 197.232066028816,3724.23446362568 PathPoint;PointKind.SMOOTHPOINT 198.801333852117,3715.5957375016 200.9142117548,3676.60481646016 198.678571013294,3717.86119550526 PathPoint;PointKind.SMOOTHPOINT 204.522875816993,3591.14314498154 204.546554386388,3587.83614272104 204.409962974483,3606.9128065348 PathPoint;PointKind.SMOOTHPOINT 204.418947288704,3568.51899517625 203.967252357346,3510.02580519047 204.507633220669,3580.00356741161 PathPoint;PointKind.SMOOTHPOINT 200.886837693744,3224.25147363171 200.852699553251,3220.86912262336 202.224626709854,3356.79741674047 PathPoint;PointKind.SMOOTHPOINT 200.785242321873,3214.14674282192 199.476648331284,3210.54737141409 202.4984630454,3218.85906591977 PathPoint;PointKind.SMOOTHPOINT 200.671470643787,3202.73070647751 199.662017909586,3100.92963063173 200.708986742169,3206.51412203269 PathPoint;PointKind.SMOOTHPOINT 199.374560080442,3002.52071037569 200.021969162193,2982.05269152787 198.957908558867,3015.69326454115 PathPoint;PointKind.SMOOTHPOINT 197.649346848679,2115.69080464212 197.647829301801,2112.78992021818 197.852550348571,2504.12682367618 PathPoint;PointKind.SMOOTHPOINT 197.644778905617,2107.00335246149 196.679931591816,2104.47079678895 199.173103947492,2111.01493874973 PathPoint;PointKind.SMOOTHPOINT 197.64047356207,2098.89463654692 197.505344565019,1845.56914396604 197.64191283813,2101.59283844908 PathPoint;PointKind.SMOOTHPOINT 199.374560080442,1617.82730952338 199.365547539716,1610.99354898082 199.393527133086,1632.20908042433 PathPoint;PointKind.SMOOTHPOINT 199.425515386738,1511.26878467118 199.426725872674,1509.57312185366 199.382619932182,1571.35723772509 PathPoint;PointKind.SMOOTHPOINT 200.418507497484,1504.16891671562 200.475374273321,1502.79041713179 200.323153844808,1506.48037131447 PathPoint;PointKind.SMOOTHPOINT 199.374560080442,1501.32911934098 198.633275468141,1498.44427125135 199.608183579486,1502.23830900136 PathPoint;PointKind.SMOOTHPOINT 199.521675647198,1487.29194603656 199.891738946092,1367.08015348015 199.490810439921,1497.31823587797 PathPoint;PointKind.SMOOTHPOINT 201.433886375063,582.628479218301 202.322696115261,569.225286814242 200.38807729881,598.399211280492 PathPoint;PointKind.SMOOTHPOINT 202.253956303636,481.169906635759 202.460424658839,479.912046958974 201.626505323244,484.992503501119 PathPoint;PointKind.SMOOTHPOINT 202.539404461226,467.919960120988 201.667102178753,454.129281386825 203.02128790425,475.538305141514 PathPoint;PointKind.SMOOTHPOINT 202.463549522373,427.29755897509 203.042735042735,401.039160708236 202.320301057608,433.791981067279 PathPoint;PointKind.SMOOTHPOINT 201.433886375063,255.616015548384 201.386420134925,250.950739675534 201.541370546051,266.180225146017 PathPoint;PointKind.SMOOTHPOINT 199.374560080442,244.37496210973 198.553473244172,242.141439110124 200.361245581592,247.05894711941 PathPoint;PointKind.SMOOTHPOINT 195.925511208949,239.57453940035 195.132542635665,239.078929363053 197.986743176445,240.862821542552 PathPoint;PointKind.SMOOTHPOINT 193.196581196581,238.243478415919 190.30771528237,237.135876979192 194.22798285762,238.638921470576 PathPoint;PointKind.SMOOTHPOINT 188.598080446439,218.919725351655 188.507761702278,216.833295063323 189.020007557992,228.66655601441 PathPoint;PointKind.SMOOTHPOINT 188.438928232799,212.544497110982 187.313745861419,205.448861767647 188.856109854923,215.175331665291 PathPoint;PointKind.SMOOTHPOINT 189.07792860734,193.279264661306 189.337237620623,190.066497305019 188.681422612279,198.191864888268 PathPoint";
	
	negativeSquare[1] = "PointKind.SMOOTHPOINT 191.137347221375,189.191715717316 192.631916999817,189.939000606537 189.642541408539,188.444430828094 PathPoint;PointKind.SMOOTHPOINT 209,208 223.146013259888,209.796457767487 194.854222774506,206.203778266907 PathPoint;PointKind.SMOOTHPOINT 241.501660823822,210.629933834076 244.170265674591,210.659202098846 229.180429458618,210.494922161102 PathPoint;PointKind.SMOOTHPOINT 249.798741817474,210.873049259186 253.832333564758,209.648266792297 247.055786132812,211.706014633179 PathPoint;PointKind.SMOOTHPOINT 257.694564342499,211.279264450073 266.707301616669,211.790042877197 254.977336406708,211.125370025635 PathPoint;PointKind.SMOOTHPOINT 284.836628437042,211.673755645752 292.191932201385,211.822929382324 273.681170940399,211.447398662567 PathPoint;PointKind.SMOOTHPOINT 322.344151496887,212.352590560913 323.929594516754,212.383511066437 309.591921329498,212.10428237915 PathPoint;PointKind.SMOOTHPOINT 327.157836914062,212.443227767944 331.68638381958,213.182738304138 325.559382604063,212.182256753758 PathPoint;PointKind.SMOOTHPOINT 335.114792346954,212.578475475311 350.638302326202,212.821826934814 332.436038017273,212.536461353302 PathPoint;PointKind.SMOOTHPOINT 373.38752746582,212.695548534393 400.299696922302,212.156682014465 360.807602405548,212.947633266449 PathPoint;PointKind.SMOOTHPOINT 511.362376213074,210.651726722717 561.079952716827,209.861483573914 461.645035743713,211.442205905914 PathPoint;PointKind.SMOOTHPOINT 837.765605449677,208.607904911041 863.592960834503,207.7272605896 786.837644577026,210.344409942627 PathPoint;PointKind.SMOOTHPOINT 1110.64237117767,207.638747692108 1112.62671232224,207.639219760895 989.814476966858,207.608535289764 PathPoint;PointKind.SMOOTHPOINT 1116.5904378891,207.640163898468 1119.2930316925,209.026865959167 1114.83080148697,206.737332344055 PathPoint;PointKind.SMOOTHPOINT 1123.73850345612,207.642524242401 1236.29834890366,207.680053710938 1121.35927677155,207.641580104828 PathPoint;PointKind.SMOOTHPOINT 1350.53805112839,207.5861120224 1371.09499454498,207.075097560883 1340.78345775604,207.82851934433 PathPoint;PointKind.SMOOTHPOINT 1696.50475502014,208.607904911041 1700.93866109848,208.72049331665 1674.97039318085,208.061013221741 PathPoint;PointKind.SMOOTHPOINT 1783.71686697006,209.088943004608 1787.05911397934,209.102396965027 1733.86475086212,208.888077735901 PathPoint;PointKind.SMOOTHPOINT 1793.96854877472,209.129776954651 1796.62842035294,208.043310642242 1790.74030637741,210.448265075684 PathPoint;PointKind.SMOOTHPOINT 1800.89592218399,209.156684875488 2001.16071939468,209.935834407806 1798.55658531189,209.147715568542 PathPoint;PointKind.SMOOTHPOINT 2452.27744102478,211.673755645752 2459.27137613297,211.790592670441 2420.9544968605,211.150231361389 PathPoint;PointKind.SMOOTHPOINT 2557.7635717392,212.138035297394 2559.11062002182,212.142283916473 2498.12145709991,211.948971748352 PathPoint;PointKind.SMOOTHPOINT 2561.83681726456,212.150781154633 2565.67874908447,213.267695903778 2560.52375793457,211.769113540649 PathPoint;PointKind.SMOOTHPOINT 2571.79251194,212.18193769455 2683.91331534363,212.527745741731 2568.41556787491,212.171316146851 PathPoint;PointKind.SMOOTHPOINT 3036.07050705211,213.441508223223 3037.92055138852,213.446469926217 2859.70686820341,212.968511994105 PathPoint;PointKind.SMOOTHPOINT 3041.62075541671,213.456403899448 3043.38639959427,212.231074288001 3040.10815845655,214.506122675761 PathPoint;PointKind.SMOOTHPOINT 3048.0680872949,213.473733581249 3153.84125323042,213.758278503267 3045.91906642887,213.467952408214 PathPoint;PointKind.SMOOTHPOINT 3350.84432601929,214.347081184387 3352.72221565247,214.35298204422 3259.30477065981,214.053905547553 PathPoint;PointKind.SMOOTHPOINT 3356.46029233932,214.365019798279 3357.98460245132,212.992715835571 3355.01245737076,215.66840171814 PathPoint;PointKind.SMOOTHPOINT 3362.61229276657,214.38508272171 3513.08091402054,214.872965812683 3360.56894302368,214.378237724304 PathPoint;PointKind.SMOOTHPOINT 3630.21227359772,215.761399269104 3646.89801692963,216.743538379669 3623.26837778091,215.35258769989 PathPoint;PointKind.SMOOTHPOINT 3706.93469190598,216.545191764832 3708.5005440712,216.504121780396 3679.34982442856,217.267929077148 PathPoint;PointKind.SMOOTHPOINT 3711.4715089798,216.419857501984 3714.41320562363,214.392322063446 3710.27505064011,217.244325637817 PathPoint;PointKind.SMOOTHPOINT 3715.84168577194,216.285081863403 3721.37551212311,216.103807449341 3714.45545578003,216.330400466919 PathPoint;PointKind.SMOOTHPOINT 3739.35646533966,214.739370346069 3754.29862260818,213.729615211487 3736.7369556427,214.916396141052 PathPoint;PointKind.SMOOTHPOINT 3770,210 3771.95608430851,208.862315550591 3766.45158872604,212.063678264618 PathPoint;PointKind.SMOOTHPOINT 3767,229 3764.54264593124,236.28095293045 3769.45759010315,221.718811035156 PathPoint;PointKind.SMOOTHPOINT 3757.89035797119,246.418726444244 3755.37257909775,258.218793869019 3760.40813684464,234.618895053864 PathPoint;PointKind.SMOOTHPOINT 3757.89035797119,345.544438362122 3758.66667509079,367.411844730377 3757.11404085159,323.677031993866 PathPoint;PointKind.SMOOTHPOINT 3759.94975805283,591.825792789459 3759.99248027802,596.799037456512 3759.76069450378,569.806616306305 PathPoint;PointKind.SMOOTHPOINT 3760.30380964279,649.349026679993 3760.31443119049,651.191039085388 3760.12489557266,618.375885486603 PathPoint;PointKind.SMOOTHPOINT 3760.33614635468,654.97349023819 3760.75298309326,658.184266090393 3760.09043455124,653.082146644592 PathPoint;PointKind.SMOOTHPOINT 3760.38618564606,663.73603105545 3761.01403713226,773.9244389534 3760.36919116974,660.747599601746 PathPoint;PointKind.SMOOTHPOINT 3762.00915813446,1008.76662254333 3761.95534229279,1040.47147035599 3762.06863880157,973.643996715546 PathPoint;PointKind.SMOOTHPOINT 3760.82379341125,1569.8276925087 3760.82143306732,1571.71573162079 3761.10868692398,1354.7363948822 PathPoint;PointKind.SMOOTHPOINT 3760.81647634506,1575.46891450882 3759.87682342529,1578.64192485809 3761.34849786758,1573.67245674133 PathPoint;PointKind.SMOOTHPOINT 3760.80679893494,1583.15584659576 3760.68288087845,1683.26110124588 3760.80986738205,1580.60903549194 PathPoint;PointKind.SMOOTHPOINT 3760.97934007645,1770.09248971939 3761.4856338501,1789.27948951721 3760.69208621979,1759.20280694962 PathPoint;PointKind.SMOOTHPOINT 3761.17477655411,2320.31202793121 3761.17336034775,2322.18519687653 3761.35015010834,2070.16584634781 PathPoint;PointKind.SMOOTHPOINT 3761.17076396942,2325.92586994171 3759.19019937515,2328.38865280151 3762.34574317932,2324.46481704712 PathPoint;PointKind.SMOOTHPOINT 3761.16557121277,2333.24671268463 3761.10218099199,2422.5182707316 3761.16722345352,2330.80989360809 PathPoint;PointKind.SMOOTHPOINT 3760.99175255114,2573.78225506593 3760.99010611901,2576.31706071923 3761.03500678685,2507.18911742137 PathPoint;PointKind.SMOOTHPOINT 3760.98691875364,2581.30735184504 3761.87923275876,2583.80978101286 3760.15340879368,2578.96983430802 PathPoint;PointKind.SMOOTHPOINT 3760.98270209682,2588.02507940332 3760.94007489934,2656.75370497139 3760.98407682092,2585.80858609491 PathPoint;PointKind.SMOOTHPOINT 3760.97934007645,2711.27514839172 3761.15872621536,2738.37944984436 3760.927459236,2703.42896898673 PathPoint;PointKind.SMOOTHPOINT 3760.50514698029,3156.96520328522 3760.49782991409,3158.67503643036 3761.07894659042,3025.11308670044 PathPoint;PointKind.SMOOTHPOINT 3760.48248767853,3162.01563119888 3759.26667451859,3164.70406293869 3761.16627931595,3160.50406694412 PathPoint;PointKind.SMOOTHPOINT 3760.45439958572,3167.9568529129 3760.3141951561,3196.47264003754 3760.46384096146,3166.01759433746 PathPoint;PointKind.SMOOTHPOINT 3759.94975805283,3221.21022462845 3758.87981414795,3249.66818332672 3760.14708280563,3215.96247196198 PathPoint;PointKind.SMOOTHPOINT 3757.89035797119,3646.32657766342 3757.73339509964,3650.81642389297 3758.62654924393,3625.28552770615 PathPoint;PointKind.SMOOTHPOINT 3757.4244260788,3660.44875144958 3757.36116886139,3662.49493360519 3757.57501602173,3655.5859708786 PathPoint;PointKind.SMOOTHPOINT 3757.23937511444,3666.6229391098 3757.92009830475,3669.03686285019 3756.67832136154,3664.63316917419 PathPoint;PointKind.SMOOTHPOINT 3757.09917068481,3671.60633325577 3756.54189348221,3692.07122325897 3757.14448928833,3669.94842767715 PathPoint;PointKind.SMOOTHPOINT 3757,3720 3758.11054182053,3729.23791408539 3756.38088178635,3714.84925746918 PathPoint;PointKind.SMOOTHPOINT 3769,3748 3770.64492368698,3758.28685092926 3767.35484027863,3737.71291303635 PathPoint;PointKind.SMOOTHPOINT 3769.21670436859,3767.93432950974 3768.1049823761,3769.19239282608 3770.32842636108,3766.676030159 PathPoint;PointKind.SMOOTHPOINT 3756,3764 3749.58018722496,3762.76348665309 3765.35476264169,3765.80181093576 PathPoint;PointKind.SMOOTHPOINT 3725.24090051651,3763.52662324905 3723.21820637435,3763.65199726936 3737.38898824401,3762.77364010363 PathPoint;PointKind.SMOOTHPOINT 3714.83185863495,3763.18791389465 3713.29834318161,3763.63991975784 3718.3796916008,3762.14204549789 PathPoint;PointKind.SMOOTHPOINT 3709.855073452,3763.00711154938 3705.69095468521,3762.88342952728 3711.57552814484,3763.05809497833 PathPoint;PointKind.SMOOTHPOINT 3696.22927999496,3762.82465696335 3666.3489780426,3762.87257194519 3701.16121864319,3762.81686782837 PathPoint;PointKind.SMOOTHPOINT 3246.14773035049,3764.86847877502 3207.38663434982,3765.46729803085 3284.90906238556,3764.2696595192 PathPoint;PointKind.SMOOTHPOINT 2669.53647851944,3766.9123005867 2652.89746999741,3767.17595100403 2708.59922647476,3766.29365444183 PathPoint;PointKind.SMOOTHPOINT 2097.72073745728,3766.68972015381 2092.56503820419,3766.68476343155 2394.06994342804,3766.98027849197 PathPoint;PointKind.SMOOTHPOINT 2082.22083091736,3766.67461395264 2080.96064329147,3766.99066400528 2090.25237321854,3764.65982437134 PathPoint;PointKind.SMOOTHPOINT 2078.31918239594,3766.67060136795 1936.2643706751,3766.53019507829 2079.62044000626,3766.67201757431 PathPoint;PointKind.SMOOTHPOINT 1651.79070633697,3766.22962586121 1650.09677073565,3766.22786279416 1786.68971512013,3766.37003025269 PathPoint;PointKind.SMOOTHPOINT 1646.71588564258,3766.22434608578 1644.94232465168,3767.00720264674 1650.12077418853,3764.72141534293 PathPoint;PointKind.SMOOTHPOINT 1640.90930727906,3766.21831048912 1462.58017531097,3766.03304119047 1642.84168348593,3766.22031806904 PathPoint;PointKind.SMOOTHPOINT 1239.17348384857,3765.86596012115 1238.07214736938,3765.86548805237 1311.26586558226,3765.88460622969 PathPoint;PointKind.SMOOTHPOINT 1235.92517852783,3765.86501598358 1233.392765522,3767.34306335449 1236.84240818024,3765.32968997955 PathPoint;PointKind.SMOOTHPOINT 1228.51959943771,3765.86407184601 1211.5765786171,3765.86265563965 1230.87663888931,3765.86407184601 PathPoint;PointKind.SMOOTHPOINT 1196.08847379684,3765.89050769806 1135.5876660347,3766.16194725037 1200.43811559677,3765.87091684341 PathPoint;PointKind.SMOOTHPOINT 467.087044715881,3762.82465696335 443.816177845001,3762.24330425262 506.069304943085,3763.79877090454 PathPoint;PointKind.SMOOTHPOINT 366.152129173279,3761.33433580399 363.75378370285,3761.30884408951 402.309529781342,3761.71718358994 PathPoint;PointKind.SMOOTHPOINT 359.034276008606,3761.25998497009 356.215081214905,3762.0924782753 363.132305145264,3760.04983663559 PathPoint;PointKind.SMOOTHPOINT 350.368037223816,3761.17241621017 332.481114864349,3760.99444627762 353.199977874756,3761.20050430298 PathPoint;PointKind.SMOOTHPOINT 307.489085197449,3760.78083515167 277.029554843903,3760.5294585228 317.046589851379,3760.85967063904 PathPoint;PointKind.SMOOTHPOINT 225.116150379181,3760.78083515167 217.786102294922,3760.83866357803 236.7240858078,3759.93866443634 PathPoint;PointKind.SMOOTHPOINT 206.226081848145,3763.80065917969 205.173368453979,3764.08319234848 211.525526046753,3762.3783159256 PathPoint;PointKind.SMOOTHPOINT 202.414598464966,3765.13448953629 194.812874794006,3768.04432153702 203.611056804657,3764.67658281326 PathPoint;PointKind.SMOOTHPOINT 189.07794713974,3770.99994421005 187.589750289917,3770.62016487122 190.218465328217,3771.2912106514 PathPoint;PointKind.SMOOTHPOINT 188,3761 188.166640281677,3759.09378623962 187.592840671539,3765.65931892395 PathPoint;PointKind.SMOOTHPOINT 190,3752 192.503380775452,3747.10913133621 189.24067735672,3753.48394823074 PathPoint;PointKind.SMOOTHPOINT 197,3734 197.131943225861,3732.22030067444 196.637215137482,3738.88732814789 PathPoint;PointKind.SMOOTHPOINT 198.064720630646,3722.94050359726 198.182973861694,3720.84569835663 197.711849212646,3729.18125295639 PathPoint;PointKind.SMOOTHPOINT 198.448040485382,3716.06458568573 199.685096740723,3713.8569560051 197.231991291046,3718.23444986343 PathPoint;PointKind.SMOOTHPOINT 199,3706 201.112743854523,3667.00900650024 198.877262115479,3708.26545810699 PathPoint;PointKind.SMOOTHPOINT 204.522857666016,3591.14315271378 204.546461105347,3587.8360748291 204.410033226013,3606.91284656525 PathPoint;PointKind.SMOOTHPOINT 204.419002532959,3568.51902008057 203.967232704163,3510.02592086792 204.50751543045,3580.00350952148 PathPoint;PointKind.SMOOTHPOINT 200.886747837067,3224.25152778625 200.85275888443,3220.86915493011 202.224590778351,3356.79734945297 PathPoint;PointKind.SMOOTHPOINT 200.785253047943,3214.14665937424 199.476678371429,3210.54737091064 202.498390674591,3218.85908603668 PathPoint;PointKind.SMOOTHPOINT 200.671484470367,3202.73061990738 199.661965370178,3100.92969417572 200.709013938904,3206.51401519775 PathPoint;PointKind.SMOOTHPOINT 199.374475479126,3002.52081871033 199.657247465439,2993.58128595891 198.957874774933,3015.69319009781 PathPoint;PointKind.SMOOTHPOINT 199.009315378049,2759.48558968743 199.003127426568,2757.31650308549 199.402700828442,2897.38051540936 PathPoint;PointKind.SMOOTHPOINT 198.99065001472,2752.94755773336 199.733977173971,2750.95173683691 198.139092621815,2755.23397498334 PathPoint;PointKind.SMOOTHPOINT 198.972305532996,2746.52971752239 198.466830268278,2569.7741606275 198.978450443729,2748.67848165473 PathPoint;PointKind.SMOOTHPOINT 197.649300098419,2115.69074392319 197.647883892059,2112.7898812294 197.761012206657,2329.21215557944 PathPoint;PointKind.SMOOTHPOINT 197.644815444946,2107.003262043 196.679906845093,2104.47084903717 199.173138141632,2111.01490259171 PathPoint;PointKind.SMOOTHPOINT 197.640566825867,2098.89453649521 197.5053191185,1845.5692076683 197.641983032227,2101.59288167953 PathPoint;PointKind.SMOOTHPOINT 199.374475479126,1617.82741069794 199.36550617218,1610.99350690842 199.393594264984,1632.20898628235 PathPoint;PointKind.SMOOTHPOINT 199.425458908081,1511.26873970032 199.426639080048,1509.57306861877 199.382736682892,1571.35719537735 PathPoint;PointKind.SMOOTHPOINT 200.418455600739,1504.16882514954 200.475339889526,1502.7903842926 200.323097705841,1506.48030996323 PathPoint;PointKind.SMOOTHPOINT 199.374475479126,1501.32909536362 198.633327484131,1498.44428300858 199.608149528503,1502.23829984665 PathPoint;PointKind.SMOOTHPOINT 199.521760940552,1487.29189395905 199.891626834869,1367.08004951477 199.490840435028,1497.31816291809 PathPoint;PointKind.SMOOTHPOINT 201.43387556076,582.62847661972 202.322781085968,569.225263595581 200.388007164001,598.399114608765 PathPoint;PointKind.SMOOTHPOINT 202.253859043121,481.169800758362 202.460389137268,479.91197347641 201.626479625702,484.992613792419 PathPoint;PointKind.SMOOTHPOINT 202.539460659027,467.920010089874 201.667077541351,454.129228591919 203.021206855774,475.538256168365 PathPoint;PointKind.SMOOTHPOINT 202.463457584381,427.297546863556 203.042685985565,401.039192676544 202.320184707642,433.792033195496 PathPoint;PointKind.SMOOTHPOINT 201.43387556076,255.616042613983 201.386432647705,250.9508228302 201.541271209717,266.180233955383 PathPoint;PointKind.SMOOTHPOINT 199.374475479126,244.374904632568 198.553547859192,242.141547203064 200.361335277557,247.058851718903 PathPoint;PointKind.SMOOTHPOINT 195.925540924072,239.574437141418 195.132465362549,239.07900094986 197.986829280853,240.862712860107 PathPoint;PointKind.SMOOTHPOINT 192,235 188.381487560272,230.947214126587 192.735646923756,235.824165584903 PathPoint;PointKind.SMOOTHPOINT 188,219 187.4375,213.409375 188.5625,224.590625 PathPoint;PointKind.SMOOTHPOINT 189.07794713974,193.279359340668 189.337348937988,190.066459178925 188.247954603227,203.561879973081 PathPoint";
	
	negativeSquare[2] = "PointKind.CORNERPOINT 191,190 191,190 191,190 PathPoint;PointKind.SMOOTHPOINT 211,208 225.146013259888,209.796457767487 196.854222774506,206.203778266907 PathPoint;PointKind.SMOOTHPOINT 238.501660823822,209.629933834076 241.170265674591,209.659202098846 226.180429458618,209.494922161102 PathPoint;PointKind.SMOOTHPOINT 246.798741817474,209.873049259186 255.387021064758,210.101391792297 243.933110350033,209.796934246871 PathPoint;PointKind.SMOOTHPOINT 264,211 273.01273727417,211.510778427124 261.282772064209,210.846105575562 PathPoint;PointKind.SMOOTHPOINT 284.836628437042,211.673755645752 292.191932201385,211.822929382324 273.681170940399,211.447398662567 PathPoint;PointKind.SMOOTHPOINT 316.344151496887,212.352590560913 317.929594516754,212.383511066437 303.591921329498,212.10428237915 PathPoint;PointKind.SMOOTHPOINT 321.157836914062,212.443227767944 324.77388381958,210.573363304138 319.719207286835,213.187208175659 PathPoint;PointKind.SMOOTHPOINT 329.114792346954,212.578475475311 344.638302326202,212.821826934814 326.436038017273,212.536461353302 PathPoint;PointKind.SMOOTHPOINT 373.38752746582,212.695548534393 400.299696922302,212.156682014465 360.807602405548,212.947633266449 PathPoint;PointKind.SMOOTHPOINT 511.362376213074,210.651726722717 561.079952716827,209.861483573914 461.645035743713,211.442205905914 PathPoint;PointKind.SMOOTHPOINT 837.765605449677,208.607904911041 863.592960834503,207.7272605896 786.837644577026,210.344409942627 PathPoint;PointKind.SMOOTHPOINT 1110.64237117767,207.638747692108 1112.62671232224,207.639219760895 989.814476966858,207.608535289764 PathPoint;PointKind.SMOOTHPOINT 1116.5904378891,207.640163898468 1119.2930316925,209.026865959167 1114.83080148697,206.737332344055 PathPoint;PointKind.SMOOTHPOINT 1123.73850345612,207.642524242401 1236.29834890366,207.680053710938 1121.35927677155,207.641580104828 PathPoint;PointKind.SMOOTHPOINT 1350.53805112839,207.5861120224 1371.09499454498,207.075097560883 1340.78345775604,207.82851934433 PathPoint;PointKind.SMOOTHPOINT 1696.50475502014,208.607904911041 1700.93866109848,208.72049331665 1674.97039318085,208.061013221741 PathPoint;PointKind.SMOOTHPOINT 1783.71686697006,209.088943004608 1787.05911397934,209.102396965027 1733.86475086212,208.888077735901 PathPoint;PointKind.SMOOTHPOINT 1793.96854877472,209.129776954651 1796.62842035294,208.043310642242 1790.74030637741,210.448265075684 PathPoint;PointKind.SMOOTHPOINT 1800.89592218399,209.156684875488 1885.24905808521,209.484868896357 1798.55658531189,209.147715568542 PathPoint;PointKind.SMOOTHPOINT 2125.36402261332,210.288742787974 2127.51635408801,210.296084721262 2008.55018800704,209.890272853933 PathPoint;PointKind.SMOOTHPOINT 2131.8141256706,210.310760999293 2136.03252687522,212.736502780679 2129.95234071568,209.24016355395 PathPoint;PointKind.SMOOTHPOINT 2143.41679514722,210.350455098822 2296.84924510997,210.876163955729 2139.5584528657,210.337235178845 PathPoint;PointKind.SMOOTHPOINT 2452.27744102478,211.673755645752 2459.27137613297,211.790592670441 2434.82981830997,211.382140204122 PathPoint;PointKind.SMOOTHPOINT 2557.7635717392,212.138035297394 2559.11062002182,212.142283916473 2498.12145709991,211.948971748352 PathPoint;PointKind.SMOOTHPOINT 2561.83681726456,212.150781154633 2565.67874908447,213.267695903778 2560.52375793457,211.769113540649 PathPoint;PointKind.SMOOTHPOINT 2571.79251194,212.18193769455 2753.7020945549,212.742991447449 2568.41556787491,212.171316146851 PathPoint;PointKind.SMOOTHPOINT 3350.84432601929,214.347081184387 3352.72221565247,214.35298204422 3103.21875572205,213.554005622864 PathPoint;PointKind.SMOOTHPOINT 3356.46029233932,214.365019798279 3357.98460245132,212.992715835571 3355.01245737076,215.66840171814 PathPoint;PointKind.SMOOTHPOINT 3362.61229276657,214.38508272171 3513.08091402054,214.872965812683 3360.56894302368,214.378237724304 PathPoint;PointKind.SMOOTHPOINT 3630.21227359772,215.761399269104 3646.89801692963,216.743538379669 3623.26837778091,215.35258769989 PathPoint;PointKind.SMOOTHPOINT 3706.93469190598,215.545191764832 3708.5005440712,215.504121780396 3679.34982442856,216.267929077148 PathPoint;PointKind.SMOOTHPOINT 3711.4715089798,215.419857501984 3714.41320562363,213.392322063446 3710.27505064011,216.244325637817 PathPoint;PointKind.SMOOTHPOINT 3715.84168577194,215.285081863403 3721.37551212311,215.103807449341 3714.45545578003,215.330400466919 PathPoint;PointKind.SMOOTHPOINT 3743,214 3757.94215726852,212.990244865417 3740.38049030304,214.177025794983 PathPoint;PointKind.SMOOTHPOINT 3771,210 3771.90404024148,209.707174926936 3765.27068023519,211.85560142564 PathPoint;PointKind.SMOOTHPOINT 3770.24628639221,227.002537250519 3767.78893232346,234.283490180969 3772.70387649536,219.721348285675 PathPoint;PointKind.SMOOTHPOINT 3760,250 3757.48222112656,261.800067424774 3762.51777887344,238.200168609619 PathPoint;PointKind.SMOOTHPOINT 3757.89035797119,345.544438362122 3758.66667509079,367.411844730377 3757.11404085159,323.677031993866 PathPoint;PointKind.SMOOTHPOINT 3759.94975805283,591.825792789459 3759.99248027802,596.799037456512 3759.76069450378,569.806616306305 PathPoint;PointKind.SMOOTHPOINT 3760.30380964279,649.349026679993 3760.31443119049,651.191039085388 3760.12489557266,618.375885486603 PathPoint;PointKind.SMOOTHPOINT 3760.33614635468,654.97349023819 3760.75298309326,658.184266090393 3760.09043455124,653.082146644592 PathPoint;PointKind.SMOOTHPOINT 3760.38618564606,663.73603105545 3761.01403713226,773.9244389534 3760.36919116974,660.747599601746 PathPoint;PointKind.SMOOTHPOINT 3762.00915813446,1008.76662254333 3761.95534229279,1040.47147035599 3762.06863880157,973.643996715546 PathPoint;PointKind.SMOOTHPOINT 3760.82379341125,1569.8276925087 3760.82143306732,1571.71573162079 3761.10868692398,1354.7363948822 PathPoint;PointKind.SMOOTHPOINT 3760.81647634506,1575.46891450882 3759.87682342529,1578.64192485809 3761.34849786758,1573.67245674133 PathPoint;PointKind.SMOOTHPOINT 3760.80679893494,1583.15584659576 3760.68288087845,1683.26110124588 3760.80986738205,1580.60903549194 PathPoint;PointKind.SMOOTHPOINT 3760.97934007645,1770.09248971939 3761.4856338501,1789.27948951721 3760.69208621979,1759.20280694962 PathPoint;PointKind.SMOOTHPOINT 3761.17477655411,2320.31202793121 3761.17336034775,2322.18519687653 3761.35015010834,2070.16584634781 PathPoint;PointKind.SMOOTHPOINT 3761.17076396942,2325.92586994171 3759.19019937515,2328.38865280151 3762.34574317932,2324.46481704712 PathPoint;PointKind.SMOOTHPOINT 3761.16557121277,2333.24671268463 3761.02937936783,2525.04377603531 3761.16722345352,2330.80989360809 PathPoint;PointKind.SMOOTHPOINT 3760.97934007645,2711.27514839172 3761.15872621536,2738.37944984436 3760.87572097778,2695.60435295105 PathPoint;PointKind.SMOOTHPOINT 3760.50514698029,3156.96520328522 3760.49782991409,3158.67503643036 3761.07894659042,3025.11308670044 PathPoint;PointKind.SMOOTHPOINT 3760.48248767853,3162.01563119888 3759.26667451859,3164.70406293869 3761.16627931595,3160.50406694412 PathPoint;PointKind.SMOOTHPOINT 3760.45439958572,3167.9568529129 3760.3141951561,3196.47264003754 3760.46384096146,3166.01759433746 PathPoint;PointKind.SMOOTHPOINT 3759.94975805283,3221.21022462845 3758.87981414795,3249.66818332672 3760.14708280563,3215.96247196198 PathPoint;PointKind.SMOOTHPOINT 3757.89035797119,3646.32657766342 3757.73339509964,3650.81642389297 3758.62654924393,3625.28552770615 PathPoint;PointKind.SMOOTHPOINT 3757.4244260788,3660.44875144958 3757.36116886139,3662.49493360519 3757.57501602173,3655.5859708786 PathPoint;PointKind.SMOOTHPOINT 3757.23937511444,3666.6229391098 3757.92009830475,3669.03686285019 3756.67832136154,3664.63316917419 PathPoint;PointKind.SMOOTHPOINT 3757.09917068481,3671.60633325577 3756.54189348221,3692.07122325897 3757.14448928833,3669.94842767715 PathPoint;PointKind.SMOOTHPOINT 3756.86077594757,3716.83854818344 3757.9713177681,3726.07646226883 3756.24165773392,3711.68780565262 PathPoint;PointKind.SMOOTHPOINT 3770,3747 3771.34336118698,3756.83372592926 3768.58975102921,3736.67808610058 PathPoint;PointKind.SMOOTHPOINT 3769.21670436859,3767.93432950974 3766.2174823761,3766.70333032608 3770.77007759575,3768.57172629496 PathPoint;PointKind.SMOOTHPOINT 3753,3764 3747.26578044891,3763.03249502182 3762.39393281937,3765.58497095108 PathPoint;PointKind.SMOOTHPOINT 3728,3763 3725.97342433535,3763.00114592841 3741.51623973846,3762.99312095642 PathPoint;PointKind.SMOOTHPOINT 3718.83185863495,3763.18791389465 3717.29834318161,3763.63991975784 3722.3796916008,3762.14204549789 PathPoint;PointKind.SMOOTHPOINT 3706,3763 3701.83588123322,3762.87631797791 3707.72045469284,3763.05098342896 PathPoint;PointKind.SMOOTHPOINT 3691,3763 3661.11969804764,3763.04791498184 3695.93193864822,3762.99221086502 PathPoint;PointKind.SMOOTHPOINT 3246.14773035049,3764.86847877502 3228.5263832846,3765.14071054929 3284.90906238556,3764.2696595192 PathPoint;PointKind.SMOOTHPOINT 2994.47412682072,3765.78535768229 2991.74333242962,3765.79267974228 3115.82949957382,3765.45996836657 PathPoint;PointKind.SMOOTHPOINT 2986.2695753589,3765.80733271052 2984.77775911705,3766.45296268833 2989.59721622,3764.36719240701 PathPoint;PointKind.SMOOTHPOINT 2981.38960991319,3765.82038399935 2839.56190382925,3766.19952522135 2983.01732554846,3765.81603270501 PathPoint;PointKind.SMOOTHPOINT 2669.53647851944,3766.9123005867 2652.89746999741,3767.17595100403 2690.2039401041,3766.58498502129 PathPoint;PointKind.SMOOTHPOINT 2097.72073745728,3766.68972015381 2092.56503820419,3766.68476343155 2394.06994342804,3766.98027849197 PathPoint;PointKind.SMOOTHPOINT 2082.22083091736,3766.67461395264 2080.96064329147,3766.99066400528 2090.25237321854,3764.65982437134 PathPoint;PointKind.SMOOTHPOINT 2078.31918239594,3766.67060136795 1743.51360082626,3766.33968114853 2079.62044000626,3766.67201757431 PathPoint;PointKind.SMOOTHPOINT 1239.17348384857,3765.86596012115 1238.07214736938,3765.86548805237 1366.93630456924,3765.89900493622 PathPoint;PointKind.SMOOTHPOINT 1235.92517852783,3765.86501598358 1233.392765522,3767.34306335449 1236.84240818024,3765.32968997955 PathPoint;PointKind.SMOOTHPOINT 1228.51959943771,3765.86407184601 1211.5765786171,3765.86265563965 1230.87663888931,3765.86407184601 PathPoint;PointKind.SMOOTHPOINT 1196.08847379684,3765.89050769806 1135.5876660347,3766.16194725037 1200.43811559677,3765.87091684341 PathPoint;PointKind.SMOOTHPOINT 467.087044715881,3762.82465696335 443.816177845001,3762.24330425262 506.069304943085,3763.79877090454 PathPoint;PointKind.SMOOTHPOINT 366.152129173279,3761.33433580399 363.75378370285,3761.30884408951 402.309529781342,3761.71718358994 PathPoint;PointKind.SMOOTHPOINT 359.034276008606,3761.25998497009 356.215081214905,3762.0924782753 363.132305145264,3760.04983663559 PathPoint;PointKind.SMOOTHPOINT 350.368037223816,3761.17241621017 332.481114864349,3760.99444627762 353.199977874756,3761.20050430298 PathPoint;PointKind.SMOOTHPOINT 307.489085197449,3760.78083515167 277.029554843903,3760.5294585228 317.046589851379,3760.85967063904 PathPoint;PointKind.SMOOTHPOINT 233,3760 217.816182242096,3760.11978861216 244.607935428619,3759.15782928467 PathPoint;PointKind.SMOOTHPOINT 202.414598464966,3765.13448953629 194.812874794006,3768.04432153702 199.712284936249,3766.16871487574 PathPoint;PointKind.SMOOTHPOINT 189.07794713974,3770.99994421005 187.589750289917,3770.62016487122 190.218465328217,3771.2912106514 PathPoint;PointKind.SMOOTHPOINT 188.364179134369,3761.90011024475 188.530819416046,3759.99389648438 187.957019805908,3766.5594291687 PathPoint;PointKind.SMOOTHPOINT 190.107529163361,3756.69319152832 192.717159938812,3750.52419786453 189.458284890907,3758.22849446351 PathPoint;PointKind.SMOOTHPOINT 196,3740 199.2890625,3732.834375 192.7109375,3747.165625 PathPoint;PointKind.SMOOTHPOINT 198.801383972168,3715.59582710266 200.914127826691,3676.60483360291 198.576985218432,3719.73771025336 PathPoint;PointKind.SMOOTHPOINT 204.522857666016,3591.14315271378 204.546461105347,3587.8360748291 204.410033226013,3606.91284656525 PathPoint;PointKind.SMOOTHPOINT 204.419002532959,3568.51902008057 203.967232704163,3510.02592086792 204.50751543045,3580.00350952148 PathPoint;PointKind.SMOOTHPOINT 200.886747837067,3224.25152778625 200.85275888443,3220.86915493011 202.224590778351,3356.79734945297 PathPoint;PointKind.SMOOTHPOINT 200.785253047943,3214.14665937424 199.476678371429,3210.54737091064 202.498390674591,3218.85908603668 PathPoint;PointKind.SMOOTHPOINT 200.671484470367,3202.73061990738 199.661965370178,3100.92969417572 200.709013938904,3206.51401519775 PathPoint;PointKind.SMOOTHPOINT 199.374475479126,3002.52081871033 200.021917819977,2982.05262422562 198.957874774933,3015.69319009781 PathPoint;PointKind.SMOOTHPOINT 197.649300098419,2115.69074392319 197.647883892059,2112.7898812294 197.85252571106,2504.12688016891 PathPoint;PointKind.SMOOTHPOINT 197.644815444946,2107.003262043 196.679906845093,2104.47084903717 199.173138141632,2111.01490259171 PathPoint;PointKind.SMOOTHPOINT 197.640566825867,2098.89453649521 197.5053191185,1845.5692076683 197.641983032227,2101.59288167953 PathPoint;PointKind.SMOOTHPOINT 199.374475479126,1617.82741069794 199.36550617218,1610.99350690842 199.393594264984,1632.20898628235 PathPoint;PointKind.SMOOTHPOINT 199.425458908081,1511.26873970032 199.426639080048,1509.57306861877 199.382736682892,1571.35719537735 PathPoint;PointKind.SMOOTHPOINT 200.418455600739,1504.16882514954 200.475339889526,1502.7903842926 200.323097705841,1506.48030996323 PathPoint;PointKind.SMOOTHPOINT 199.374475479126,1501.32909536362 198.633327484131,1498.44428300858 199.608149528503,1502.23829984665 PathPoint;PointKind.SMOOTHPOINT 199.521760940552,1487.29189395905 199.891626834869,1367.08004951477 199.490840435028,1497.31816291809 PathPoint;PointKind.SMOOTHPOINT 201.43387556076,582.62847661972 202.322781085968,569.225263595581 200.388007164001,598.399114608765 PathPoint;PointKind.SMOOTHPOINT 202.253859043121,481.169800758362 202.460389137268,479.91197347641 201.626479625702,484.992613792419 PathPoint;PointKind.SMOOTHPOINT 202.539460659027,467.920010089874 201.667077541351,454.129228591919 203.021206855774,475.538256168365 PathPoint;PointKind.SMOOTHPOINT 202.463457584381,427.297546863556 203.042685985565,401.039192676544 202.320184707642,433.792033195496 PathPoint;PointKind.SMOOTHPOINT 201.43387556076,255.616042613983 201.386432647705,250.9508228302 201.541271209717,266.180233955383 PathPoint;PointKind.SMOOTHPOINT 199.374475479126,244.374904632568 198.553547859192,242.141547203064 200.361335277557,247.058851718903 PathPoint;PointKind.SMOOTHPOINT 195.925540924072,239.574437141418 195.132465362549,239.07900094986 197.986829280853,240.862712860107 PathPoint;PointKind.SMOOTHPOINT 191,231 189.818346382009,228.140716605109 191.683032798767,232.653406143188 PathPoint;PointKind.SMOOTHPOINT 189,211 188.84296875,205.06875 189.15703125,216.93125 PathPoint";

}

// Masks

if (mask_variant_square == 3 && fancy == true) {
		
	maskSquare[0] = "PointKind.SMOOTHPOINT 187.504777908325,184.859304257368 187.504777908325,184.859304257368 186.2460064888,191.239559844253 PathPoint;PointKind.SMOOTHPOINT 188.502495288849,176.651544235653 191.841673851013,173.963772625594 186.757729053497,178.055912017435 PathPoint;PointKind.SMOOTHPOINT 215.845191478729,176.653678893656 227.551789283752,173.876488831692 204.138829708099,179.43086895562 PathPoint;PointKind.SMOOTHPOINT 238.396389484406,175.662486027574 240.124397277832,175.758545637711 224.137079715729,174.87289975067 PathPoint;PointKind.SMOOTHPOINT 245.846343040466,176.653678893656 247.915892601013,175.245753348535 244.484424591064,177.580594835423 PathPoint;PointKind.SMOOTHPOINT 252.558453083038,175.97699230669 254.416751861572,175.704230450745 249.661130905151,176.402263617741 PathPoint;PointKind.SMOOTHPOINT 265.847425460815,175.618606946401 269.940969944,176.149899604937 262.092590332031,175.131193369038 PathPoint;PointKind.SMOOTHPOINT 277.84788608551,175.618606946401 282.392728328705,176.551689677955 272.676608562469,174.557681918886 PathPoint;PointKind.SMOOTHPOINT 295.848577022552,175.618606946401 306.666977405548,175.371698170715 289.789338111877,175.756173795486 PathPoint;PointKind.SMOOTHPOINT 320.202133655548,174.636427080776 328.351221084595,175.41012201477 314.978928565979,174.140949239847 PathPoint;PointKind.SMOOTHPOINT 358.85134935379,175.618606946401 378.091928958893,175.175309634435 340.561988353729,176.040083309891 PathPoint;PointKind.SMOOTHPOINT 391.852734088898,175.618606946401 400.863583087921,176.102699944647 381.914033889771,175.083519340303 PathPoint;PointKind.SMOOTHPOINT 428.854429721832,174.583297814923 450.018925666809,175.444513727041 407.689933776855,173.721370350137 PathPoint;PointKind.SMOOTHPOINT 467.852032184601,174.636427080776 486.236751079559,175.094904182986 451.652283668518,174.232502349755 PathPoint;PointKind.SMOOTHPOINT 501.857507228851,174.583297814923 519.802966117859,175.152302764846 484.070191383362,174.019036549451 PathPoint;PointKind.SMOOTHPOINT 549.859585762024,175.618606946401 571.713774204254,176.588453232452 528.0051612854,174.648997844572 PathPoint;PointKind.SMOOTHPOINT 586.861281394958,175.618606946401 596.366150379181,174.929349595639 577.356648445129,176.308338665607 PathPoint;PointKind.SMOOTHPOINT 615.862591266632,174.583297814923 624.874856472015,174.799609825898 592.308719158173,174.018562181006 PathPoint;PointKind.SMOOTHPOINT 638.447542190552,174.646388818124 644.883019924164,174.335203118124 629.341571331024,175.085653998307 PathPoint;PointKind.SMOOTHPOINT 658.864517211914,175.618606946401 661.18497133255,174.579265683139 653.495206832886,178.022469042054 PathPoint;PointKind.SMOOTHPOINT 676.865208148956,175.618606946401 686.093444824219,175.430045489465 673.629884719849,175.684544160273 PathPoint;PointKind.SMOOTHPOINT 697.866132259369,174.583297814923 701.61435842514,174.643305423231 682.76535987854,174.342793013246 PathPoint;PointKind.SMOOTHPOINT 711.866748332977,175.618606946401 716.743218898773,175.079724392743 710.343382358551,175.786533375974 PathPoint;PointKind.SMOOTHPOINT 727.867519855499,175.618606946401 736.606693267822,175.243855874755 722.626848220825,175.842746036721 PathPoint;PointKind.SMOOTHPOINT 751.180164813995,174.636427080776 766.631684303284,174.071691446859 743.91809463501,174.902310594267 PathPoint;PointKind.SMOOTHPOINT 788.870136737823,175.618606946401 794.29279088974,176.024903519647 777.631359100342,174.777314508978 PathPoint;PointKind.SMOOTHPOINT 812.871057987213,174.583297814923 817.08592414856,173.89854696439 805.175156593323,175.833495852041 PathPoint;PointKind.SMOOTHPOINT 845.872442722321,174.583297814923 852.244899272919,174.487238204786 833.880951404572,174.763557824069 PathPoint;PointKind.SMOOTHPOINT 864.473369121552,175.511162493581 866.034264564514,174.714697874221 859.677622318268,177.958429301963 PathPoint;PointKind.SMOOTHPOINT 869.572656154633,175.500252019343 880.170364379883,175.476533597087 867.905309200287,175.504046966904 PathPoint;PointKind.SMOOTHPOINT 900.874829292297,175.618606946401 914.700779914856,174.97109401881 883.942902088165,176.411988170866 PathPoint;PointKind.SMOOTHPOINT 936.876447200775,174.583297814923 941.924042701721,175.381185539617 926.569533348083,172.954790942821 PathPoint;PointKind.SMOOTHPOINT 962.877523899078,175.618606946401 977.0823097229,176.941383355622 953.485715389252,174.744345902042 PathPoint;PointKind.SMOOTHPOINT 1005.57661771774,174.646388818124 1009.60124015808,174.553886971325 987.560820579529,175.058852181157 PathPoint;PointKind.SMOOTHPOINT 1018.05764436722,174.78869935166 1024.66377496719,173.603964159969 1014.51406002045,175.423878699678 PathPoint;PointKind.SMOOTHPOINT 1034.5078253746,175.671736212254 1042.11261749268,176.521092913244 1028.18729639053,174.966113150136 PathPoint;PointKind.SMOOTHPOINT 1057.45390892029,175.662486027574 1069.58867311478,175.249785480319 1052.30717897415,175.837527983824 PathPoint;PointKind.SMOOTHPOINT 1095.35418748856,175.699723950516 1102.0533156395,174.857957144648 1088.65529537201,176.541490756385 PathPoint;PointKind.SMOOTHPOINT 1111.31624937057,175.699723950516 1125.10773897171,176.269203268885 1097.52475976944,175.130719000593 PathPoint;PointKind.SMOOTHPOINT 1144.23785448074,175.699723950516 1156.97379827499,175.996204228717 1131.50285482407,175.403243672315 PathPoint;PointKind.SMOOTHPOINT 1168.1906247139,175.662486027574 1192.73395299911,172.882212570717 1148.54831457138,177.887511219417 PathPoint;PointKind.SMOOTHPOINT 1200.11498451233,176.688544974372 1233.09701442719,176.465591805165 1202.16517925262,176.674551105241 PathPoint;PointKind.SMOOTHPOINT 1254.42649841309,176.520855729022 1255.59534072876,176.723173870866 1250.29259204865,175.806219666446 PathPoint;PointKind.SMOOTHPOINT 1267.89084434509,175.618606946401 1272.05142259598,175.548874784968 1262.85528659821,175.702570161187 PathPoint;PointKind.SMOOTHPOINT 1284.98634338379,175.427199278794 1289.05840873718,175.482226018428 1271.76228046417,175.249785480319 PathPoint;PointKind.SMOOTHPOINT 1292.85124540329,175.427199278794 1293.46540689468,175.819027614464 1290.89145183563,174.178187162789 PathPoint;PointKind.SMOOTHPOINT 1301.69875860214,175.427199278794 1300.38569927216,175.565003312102 1296.95517539978,175.925048961949 PathPoint;PointKind.SMOOTHPOINT 1320.89331150055,175.618606946401 1327.28370666504,176.26137618954 1314.50268030167,174.975600519038 PathPoint;PointKind.SMOOTHPOINT 1335.3298830986,176.811169217436 1336.74750566483,176.772745373381 1329.7268986702,176.96249275143 PathPoint;PointKind.SMOOTHPOINT 1353.89469623566,175.618606946401 1357.96227693558,175.700909871629 1350.38368463516,175.54721449541 PathPoint;PointKind.SMOOTHPOINT 1370.89530944824,175.618606946401 1388.22401046753,174.865784223993 1368.30294370651,175.73150663634 PathPoint;PointKind.SMOOTHPOINT 1403.89693021774,175.618606946401 1409.71187353134,175.641613815989 1399.35137987137,175.600343761263 PathPoint;PointKind.SMOOTHPOINT 1422.89769887924,175.618606946401 1432.90980577469,175.960389411111 1426.22129917145,175.73150663634 PathPoint;PointKind.SMOOTHPOINT 2129.92833852768,176.653678893656 2153.77442121506,176.713686501964 2106.08296394348,176.593434101125 PathPoint;PointKind.SMOOTHPOINT 2265.93442440033,175.618606946401 2296.72440290451,174.977260808596 2235.14397382736,176.259953084205 PathPoint;PointKind.SMOOTHPOINT 2383.93934726715,176.653678893656 2416.95937871933,177.393456483823 2349.30602073669,175.877374933214 PathPoint;PointKind.SMOOTHPOINT 2476.94350719452,176.653678893656 2491.14026784897,176.657948209662 2462.74674654007,176.650121130317 PathPoint;PointKind.SMOOTHPOINT 2511.00350618362,176.623556497391 2520.62544822693,177.569684361186 2501.38156414032,175.677665817818 PathPoint;PointKind.SMOOTHPOINT 2527.96352148056,175.597734734815 2550.68301200867,175.66580660669 2505.24379491806,175.52966286294 PathPoint;PointKind.SMOOTHPOINT 2558.89488458633,176.605293312253 2569.4673371315,176.653204525211 2548.32219600677,176.557144915074 PathPoint;PointKind.SMOOTHPOINT 2581.94812774658,174.583297814923 2597.5714802742,174.699280899755 2566.32524728775,174.467077545868 PathPoint;PointKind.SMOOTHPOINT 2611.94927930832,176.653678893656 2622.56067752838,177.367603403564 2601.33764505386,175.940465936416 PathPoint;PointKind.SMOOTHPOINT 2637.70794868469,175.578997181233 2645.6854391098,174.246259034664 2623.32778930664,177.981910539996 PathPoint;PointKind.SMOOTHPOINT 2659.95135784149,176.653678893656 2663.08471441269,175.698300845181 2656.81870937347,177.609056942131 PathPoint;PointKind.SMOOTHPOINT 2671.95205450058,176.653678893656 2679.89225149155,175.631889262864 2668.49981546402,177.097924942512 PathPoint;PointKind.SMOOTHPOINT 2684.95259284973,176.653678893656 2694.13385868073,177.952025327953 2679.9644780159,175.94829301576 PathPoint;PointKind.SMOOTHPOINT 2702.95328378677,175.618606946401 2709.52282905579,177.688039288243 2694.76430654526,173.038516973385 PathPoint;PointKind.SMOOTHPOINT 2717.51873016357,176.605293312253 2727.68543958664,174.88594488291 2707.35178470612,178.324404557374 PathPoint;PointKind.CORNERPOINT 2741.4618229866,176.605293312253 2741.4618229866,176.605293312253 2741.4618229866,176.605293312253 PathPoint;PointKind.SMOOTHPOINT 2761.95598125458,176.653678893656 2768.02017688751,177.090809415835 2755.89202165604,176.217022739921 PathPoint;PointKind.SMOOTHPOINT 2780.36973237991,175.578997181233 2785.83723306656,175.45921914884 2774.90199565887,175.699723950516 PathPoint;PointKind.SMOOTHPOINT 2802.95775175095,175.618606946401 2811.90085887909,176.916953380698 2794.01370048523,174.319786143658 PathPoint;PointKind.SMOOTHPOINT 2838.23238372803,176.605293312253 2855.19216299057,177.242370134052 2821.27236843109,175.968216490455 PathPoint;PointKind.SMOOTHPOINT 2877.13982105255,176.633043866293 2885.46026945114,176.72910347643 2868.82008075714,176.536747071933 PathPoint;PointKind.SMOOTHPOINT 2909.06441688538,177.658865628868 2920.91098308563,177.162201866826 2897.21737861633,178.156240943578 PathPoint;PointKind.SMOOTHPOINT 2939.99105930328,177.658865628868 2960.88671207428,178.344565216292 2919.09540653229,176.97364040989 PathPoint;PointKind.SMOOTHPOINT 2993.86354923248,177.658865628868 3003.87046337128,178.740900052191 2983.85569095612,176.576831205546 PathPoint;PointKind.SMOOTHPOINT 3019.80160474777,175.607222103718 3040.99749326706,175.534880915837 2998.60548019409,175.679326107376 PathPoint;PointKind.SMOOTHPOINT 3053.72139930725,177.658865628868 3069.57795381546,177.73500176431 3037.86437273026,177.582966677649 PathPoint;PointKind.SMOOTHPOINT 3084.64804172516,176.633043866293 3106.68916940689,177.021551622848 3062.60644197464,176.244061741293 PathPoint;PointKind.SMOOTHPOINT 3129.5391869545,177.640365259509 3141.08575344086,177.832721664005 3117.99238443375,177.448008855012 PathPoint;PointKind.SMOOTHPOINT 3161.46354675293,175.588247365913 3184.24511432648,175.825194404251 3138.6815071106,175.352011880242 PathPoint;PointKind.SMOOTHPOINT 3209.34973239899,177.640365259509 3226.99944019318,177.628268864158 3191.7000246048,177.652461654859 PathPoint;PointKind.SMOOTHPOINT 3240.2761387825,176.614069128488 3252.89477348328,175.480328544648 3227.65797615051,177.748995633441 PathPoint;PointKind.SMOOTHPOINT 3264.21946763992,176.614069128488 3276.28082513809,176.838682587253 3252.15811014175,176.389930038168 PathPoint;PointKind.SMOOTHPOINT 3283.17444562912,176.614069128488 3298.62242460251,175.804796561111 3267.72670269012,177.424053248533 PathPoint;PointKind.SMOOTHPOINT 3304.97953891754,175.618606946401 3315.53263664246,176.010909650516 3294.42644119263,175.225592689617 PathPoint;PointKind.SMOOTHPOINT 3325.075507164,176.614069128488 3341.88304424286,175.211836004709 3308.26749801636,178.017250989158 PathPoint;PointKind.SMOOTHPOINT 3350.9814620018,175.618606946401 3361.53479576111,175.501912308901 3340.42836427689,175.734590031233 PathPoint;PointKind.SMOOTHPOINT 3382.98300504684,175.618606946401 3398.63279342651,173.690773585427 3367.332508564,177.546203123152 PathPoint;PointKind.SMOOTHPOINT 3415.98438978195,175.618606946401 3427.62088537216,176.508522149449 3404.34813022614,174.728928927575 PathPoint;PointKind.SMOOTHPOINT 3437.98539161682,175.618606946401 3447.44706630707,175.618606946401 3428.52324485779,175.618606946401 PathPoint;PointKind.SMOOTHPOINT 3463.98646831512,176.653678893656 3477.26717948914,177.263005161414 3450.70528507233,176.044352625897 PathPoint;PointKind.SMOOTHPOINT 3493.98761987686,175.618606946401 3510.41018486023,176.985499621018 3477.56599903107,174.252188640228 PathPoint;PointKind.SMOOTHPOINT 3516.98869943619,176.653678893656 3528.56288194656,176.53366367704 3505.41451692581,176.773931294494 PathPoint;PointKind.SMOOTHPOINT 3538.57380867004,175.569984180776 3549.47765350342,175.962761253336 3527.66996383667,175.176969923992 PathPoint;PointKind.SMOOTHPOINT 3574.48856592178,176.596043127574 3593.8839840889,176.688070605927 3555.09314775467,176.503304096552 PathPoint;PointKind.SMOOTHPOINT 3602.99255132675,175.618606946401 3612.75469779968,176.558093651964 3598.80506515503,175.215156583825 PathPoint;PointKind.SMOOTHPOINT 3616.99316740036,175.618606946401 3624.02699232101,175.293901745715 3609.95863437653,175.943074962864 PathPoint;PointKind.SMOOTHPOINT 3632.99370288849,175.618606946401 3644.46662664413,175.950902042208 3621.52077913284,175.285837482148 PathPoint;PointKind.SMOOTHPOINT 3655.99478244781,176.653678893656 3680.90821266174,178.076547044798 3631.0808801651,175.231047926736 PathPoint;PointKind.SMOOTHPOINT 3685.99617004395,176.653678893656 3707.51920223236,175.671499028032 3664.47337388992,177.635384390835 PathPoint;PointKind.SMOOTHPOINT 3715.14759778976,175.607222103718 3720.15435934067,174.634055238551 3700.69285154343,177.823945847771 PathPoint;PointKind.SMOOTHPOINT 3726.99794054031,176.653678893656 3733.23703765869,175.8204507198 3720.75884342194,177.48761862018 PathPoint;PointKind.SMOOTHPOINT 3739.09092664719,176.633043866293 3746.5847826004,178.183991497618 3731.59683465958,175.081859050746 PathPoint;PointKind.SMOOTHPOINT 3751.0623550415,176.633043866293 3759.10971164703,176.416731855318 3743.01499843597,176.849593061491 PathPoint;PointKind.SMOOTHPOINT 3770.99970817566,175.618606946401 3776.05037212372,178.351917927191 3765.94928026199,172.885058781388 PathPoint;PointKind.SMOOTHPOINT 3774.02000427246,194.05588530294 3773.79411935806,209.092890644848 3774.24588918686,179.019117145254 PathPoint;PointKind.SMOOTHPOINT 3775.00001907349,234.627906861518 3774.73424434662,245.175726423018 3775.27311086655,223.783132653372 PathPoint;PointKind.SMOOTHPOINT 3773.99994134903,263.615139437561 3772.79569387436,272.896869619031 3775.20395278931,254.332934887645 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,471.143744283116 3773.95603895187,493.422221124027 3774.06508684158,448.864555889537 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,565.533340309179 3772.420399189,578.089398683102 3773.60505580902,552.977281935257 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,716.351909093121 3773.51937532425,726.671557432518 3772.50584363937,706.032260753725 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,751.23506707358 3773.74148368835,763.847100924026 3774.27940607071,738.622558854688 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,798.4297464945 3775.06233215332,809.783992412707 3772.95784950256,787.075974944738 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,850.754483465187 3776.30174875259,859.11854788957 3773.71410369873,842.390419040804 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,866.144181746043 3772.95029640198,873.11739788933 3773.07515859604,859.170728418534 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,887.689522155018 3775.88892459869,896.91575122841 3774.12739992142,878.464004634294 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,922.572442951254 3774.20151472092,940.342996458175 3773.81961107254,904.802600997001 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,961.559836718904 3775.39773702621,970.757366501366 3774.6183514595,952.361832567997 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,985.157295021475 3772.96186208725,996.434930435795 3773.06359291077,973.879659607156 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,1015.93645439896 3772.93094158173,1028.74535115414 3775.08994817734,1003.12755764379 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,1043.6379113045 3772.06186294556,1052.22255705587 3773.96359205246,1035.05350273736 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,1078.52106928496 3772.33849525452,1094.95248067131 3773.68719577789,1062.0894207144 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,1115.45610797479 3772.35053300858,1130.03202718804 3773.67256164551,1100.93047181673 PathPoint;PointKind.SMOOTHPOINT 3773.93880844116,1156.01721905913 3774.02000427246,1169.7679743621 3773.84864330292,1140.74302949467 PathPoint;PointKind.SMOOTHPOINT 3772.93943881989,1185.08058777062 3772.94463157654,1198.86668352274 3772.93353796005,1169.69041512132 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,1261.14485639319 3773.3166217804,1279.81244062984 3774.70426797867,1242.48486205167 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,1326.80717375114 3775.01252889633,1332.83141581996 3774.99647855759,1310.88452252219 PathPoint;PointKind.SMOOTHPOINT 3774.93652582169,1393.59943674537 3774.93227720261,1397.19254053294 3774.97240304947,1360.52646875149 PathPoint;PointKind.SMOOTHPOINT 3774.92472410202,1404.54857201144 3776.51229143143,1408.07858479581 3773.41457605362,1401.19099215687 PathPoint;PointKind.SMOOTHPOINT 3774.91787910461,1411.26135987835 3774.86925601959,1461.87504986749 3774.92000341415,1409.0109559747 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,1527.89836161217 3775.29624223709,1545.74481407031 3774.84754085541,1517.97813150357 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,1633.57365731612 3774.30253744125,1658.5735859267 3773.71811628342,1608.57349152133 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,1747.45671304179 3773.51229429245,1765.53109953781 3774.76256847382,1720.16937978884 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,1827.48314410224 3774.78215932846,1844.55590162639 3773.2387304306,1810.41038657809 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,1886.98981933207 3773.86634588242,1910.28249590865 3776.1497426033,1863.69690557126 PathPoint;PointKind.SMOOTHPOINT 3774.02614116669,1949.61831329924 3772.99042224884,1979.38872817818 3774.89427566528,1924.67364861252 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2020.36657194156 3774.57020044327,2039.85979445694 3775.44612407684,2000.85437468837 PathPoint;PointKind.SMOOTHPOINT 3774.00537014008,2077.79314153953 3774.43424463272,2098.85391458181 3773.57673168182,2056.73284286569 PathPoint;PointKind.SMOOTHPOINT 3775.0030875206,2145.50757679107 3775.05005836487,2158.69715422345 3774.95635271072,2132.31799935869 PathPoint;PointKind.SMOOTHPOINT 3776.00552558899,2227.61316474649 3776.15045070648,2253.02081303564 3775.87263822556,2204.28514772075 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2301.4837164946 3775.4758644104,2329.7620054294 3774.54046010971,2273.20519037556 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2370.22397350871 3772.79451370239,2395.22010717173 3775.22637605667,2345.2278398457 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2433.83464734151 3773.73770713806,2460.61796412152 3774.283182621,2407.05061900883 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2497.44532117431 3773.55454444885,2547.00449010994 3776.46178007126,2447.88567787023 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2567.211399951 3774.08939838409,2576.19997043339 3773.71056318283,2532.95322239699 PathPoint;PointKind.SMOOTHPOINT 3774.10238027573,2592.38945391272 3774.0997838974,2594.9313572259 3774.11016941071,2584.54980380442 PathPoint;PointKind.SMOOTHPOINT 3774.08680200577,2599.85767352849 3771.74486875534,2604.04587253047 3775.26862621307,2597.74388773703 PathPoint;PointKind.SMOOTHPOINT 3774.05658960342,2607.53508962856 3773.98601531982,2622.96866699059 3774.0681552887,2605.02900113298 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2649.28923735238 3774.25202608109,2672.13316137988 3773.87484312057,2636.46516080696 PathPoint;PointKind.SMOOTHPOINT 3775.00001907349,2692.31825027246 3775.53416490555,2707.77981537276 3774.46610927582,2676.85644798795 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2723.15931473204 3775.06233215332,2743.59487016366 3774.953520298,2702.72423366887 PathPoint;PointKind.SMOOTHPOINT 3775.00001907349,2761.68016713391 3775.71307897568,2796.49122111071 3774.2869591713,2726.86911315712 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,2818.57544407335 3773.71811628342,2846.54895128217 3772.3073387146,2790.60169968031 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2886.28964214067 3774.50930356979,2906.2880670501 3775.50702095032,2866.29098004701 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2940.66602263651 3775.57688713074,2968.92865741263 3774.43896532059,2912.40362504461 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,3014.53681156884 3774.7314119339,3051.98037323184 3773.28947782516,2977.09230116895 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,3091.48482860467 3775.60827970505,3124.74042844992 3774.40804481506,3058.22851720676 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,3201.26388572737 3773.50403308868,3222.64533183855 3774.51709270477,3179.88315116885 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,3320.27723618702 3773.28947782516,3350.3550418184 3772.73574113846,3290.19943055565 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,3418.77059363183 3772.69325494766,3443.82317713981 3773.33267211914,3393.7184844923 PathPoint;PointKind.SMOOTHPOINT 3772.01489210129,3509.05642823915 3771.98019504547,3538.66958997853 3772.05006122589,3479.44326649977 PathPoint;PointKind.SMOOTHPOINT 3772.01489210129,3578.82298138429 3772.8683924675,3606.52443828983 3771.16162776947,3551.12152447875 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,3650.64117805458 3773.38672399521,3672.10777330166 3772.71756649017,3633.67989711503 PathPoint;PointKind.SMOOTHPOINT 3773.99994134903,3704.7955541181 3776.04022264481,3728.59153561495 3771.66320085526,3677.54949091988 PathPoint;PointKind.SMOOTHPOINT 3773.99994134903,3765.87547229617 3773.56327772141,3788.08208231765 3774.43636894226,3743.66862509047 PathPoint;PointKind.SMOOTHPOINT 3773.99994134903,3813.4970833177 3772.34793663025,3823.42442895298 3775.6521821022,3803.57021205087 PathPoint;PointKind.SMOOTHPOINT 3772.99986362457,3849.73100544564 3773.14667701721,3865.08346580356 3772.81386852264,3830.29399559101 PathPoint;PointKind.SMOOTHPOINT 3771.99978590012,3882.85900017915 3766.89223766327,3887.24785703342 3774.08255338669,3881.06944521993 PathPoint;PointKind.SMOOTHPOINT 3722.14294910431,3884.54490563311 3715.28803825378,3884.54964931757 3745.95079421997,3884.52877710598 PathPoint;PointKind.SMOOTHPOINT 3625.85389852524,3886.42743680758 3622.10260391235,3886.41842380712 3676.95605278015,3886.54745202419 PathPoint;PointKind.SMOOTHPOINT 3614.33282375336,3886.39992343776 3609.51937437057,3884.72587719493 3618.19363832474,3887.74333487435 PathPoint;PointKind.SMOOTHPOINT 3598.66651296616,3886.3624483306 3377.95240402222,3885.83234159317 3604.02685403824,3886.37525627862 PathPoint;PointKind.SMOOTHPOINT 2890.10684251785,3884.5636431867 2840.38100481033,3884.45548718121 2928.39303731918,3884.64689484882 PathPoint;PointKind.SMOOTHPOINT 2667.63474941254,3884.5636431867 2643.90951633453,3885.44928907374 2691.35951042175,3883.67776011543 PathPoint;PointKind.SMOOTHPOINT 2578.84498357773,3885.58946494927 2571.91052913666,3885.44478257351 2619.67043638229,3886.44356533471 PathPoint;PointKind.SMOOTHPOINT 2551.55633926392,3885.14687918997 2548.11401367188,3885.10062826657 2562.50998735428,3885.29345903952 PathPoint;PointKind.SMOOTHPOINT 2540.79694747925,3885.01026107778 2537.43534564972,3886.92220309584 2546.49741411209,3881.76866430804 PathPoint;PointKind.SMOOTHPOINT 2528.90459060669,3884.87411733403 2475.52541255951,3884.29467627831 2532.98137664795,3884.91847078365 PathPoint;PointKind.SMOOTHPOINT 2386.3018155098,3884.5636431867 2360.87784290314,3885.45759052153 2404.64876890182,3883.91850210133 PathPoint;PointKind.SMOOTHPOINT 2278.55754375458,3884.5636431867 2222.18733787537,3884.0064974479 2334.9275135994,3885.12055174127 PathPoint;PointKind.SMOOTHPOINT 2135.89576005936,3885.58946494927 2083.73050689697,3883.97874689386 2188.06077718735,3887.20065737313 PathPoint;PointKind.SMOOTHPOINT 1788.71937990189,3885.58946494927 1748.21776628494,3884.2671629085 1829.22052145004,3886.91247854272 PathPoint;PointKind.SMOOTHPOINT 1579.21596050262,3884.5636431867 1577.06002235413,3884.57241900293 1607.34063863754,3884.4512178652 PathPoint;PointKind.SMOOTHPOINT 1568.85593891144,3884.60538760987 1565.63147306442,3884.61819555788 1573.53673696518,3884.58665005628 PathPoint;PointKind.SMOOTHPOINT 1557.60252714157,3884.65045261215 1554.03581142426,3886.06573086817 1561.94650411606,3882.92802078792 PathPoint;PointKind.SMOOTHPOINT 1545.01764535904,3884.70097285156 1466.10827922821,3885.01642786756 1549.56791639328,3884.68294685064 PathPoint;PointKind.SMOOTHPOINT 1261.96850538254,3885.58946494927 1233.53580236435,3885.43363491505 1285.37013530731,3885.71825598212 PathPoint;PointKind.SMOOTHPOINT 1038.4984588623,3885.58946494927 986.185212135315,3885.55365013166 1090.81194162369,3885.6255169511 PathPoint;PointKind.SMOOTHPOINT 799.066586494446,3884.5636431867 761.41744852066,3884.09472997869 836.715488433838,3885.0325563947 PathPoint;PointKind.SMOOTHPOINT 613.506731987,3885.58946494927 578.008811473846,3885.73391014081 649.004416465759,3885.44549412618 PathPoint;PointKind.SMOOTHPOINT 445.904138088226,3884.5636431867 413.255152702332,3884.07077437221 478.553123474121,3885.05651200118 PathPoint;PointKind.SMOOTHPOINT 287.280292510986,3885.58946494927 260.792512893677,3885.0766726601 313.768544197083,3886.10249442267 PathPoint;PointKind.SMOOTHPOINT 224.429526329041,3884.5636431867 205.178325176239,3884.71212051002 243.680727481842,3884.4154030476 PathPoint;PointKind.SMOOTHPOINT 198.483917713165,3885.58946494927 195.925068855286,3885.14877666375 203.694140911102,3886.48744441589 PathPoint;PointKind.SMOOTHPOINT 187.843959331512,3882.85900017915 185.361113548279,3879.64728862146 190.240180492401,3885.95828641535 PathPoint;PointKind.SMOOTHPOINT 186.512253284454,3869.17418209006 187.996437549591,3852.57555582681 186.216974258423,3872.47436336277 PathPoint;PointKind.SMOOTHPOINT 186.512253284454,3835.31684587218 187.755210399628,3818.68904594956 185.268824100494,3851.9446457948 PathPoint;PointKind.SMOOTHPOINT 185.514299869537,3775.81040782658 186.652221679688,3764.48059188329 184.376614093781,3787.14022376986 PathPoint;PointKind.SMOOTHPOINT 186.512253284454,3731.69319369338 186.373465061188,3707.95603388372 186.638059616089,3753.32036265914 PathPoint;PointKind.SMOOTHPOINT 186.512253284454,3637.30359766732 184.914536476135,3607.75044353625 187.739868164062,3660.01564726707 PathPoint;PointKind.SMOOTHPOINT 187.512331008911,3525.47242265103 186.62743806839,3496.33220625143 188.481960296631,3557.41331035062 PathPoint;PointKind.SMOOTHPOINT 188.509812355042,3470.06974602417 188.022401332855,3453.90658999354 188.997223377228,3486.23266487057 PathPoint;PointKind.SMOOTHPOINT 187.512331008911,3416.71895010668 187.960324287415,3402.1069788916 187.063865661621,3431.33068413754 PathPoint;PointKind.SMOOTHPOINT 186.514377593994,3352.08245451131 187.186367511749,3330.03428355051 185.843331813812,3374.1073814183 PathPoint;PointKind.SMOOTHPOINT 186.519334316254,3272.05626063508 187.396438121796,3243.74191969844 185.642466545105,3300.37107594016 PathPoint;PointKind.SMOOTHPOINT 187.514455318451,3203.31600362096 187.354896068573,3175.18619200948 187.674250602722,3231.44628960089 PathPoint;PointKind.SMOOTHPOINT 186.516973972321,3133.54945047582 186.622245311737,3106.65797769033 186.411938667297,3160.44139762977 PathPoint;PointKind.SMOOTHPOINT 186.516973972321,3078.14677384897 187.062449455261,3039.40059643566 185.971262454987,3116.89366281494 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,3012.48445649102 185.38684129715,2986.03272325415 185.652616024017,3038.17648866302 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2947.84819807987 185.405960083008,2920.71076525558 185.732159614563,2997.26719113996 PathPoint;PointKind.SMOOTHPOINT 186.002655029297,2881.11760298351 186.024842262268,2878.80505681354 185.825157165527,2899.59164489454 PathPoint;PointKind.SMOOTHPOINT 186.056470870972,2874.29713347955 187.166304588318,2872.11029494754 184.62468624115,2877.11867699113 PathPoint;PointKind.SMOOTHPOINT 186.07842206955,2867.01605221538 186.076533794403,2857.35743630426 186.078894138336,2869.40639481035 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2839.09496271975 184.169375896454,2809.22113551977 185.93585729599,2848.24529284192 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2758.04270989672 185.10454416275,2735.31903827007 185.93868970871,2780.76638152338 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2701.61397432307 186.012568473816,2672.23349030602 185.030665397644,2730.99469552434 PathPoint;PointKind.SMOOTHPOINT 184.5241355896,2602.09455793146 186.301002502441,2571.49138924711 182.747032642365,2632.69725224736 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2514.88690016454 185.717761516571,2493.77940183041 185.318155288696,2536.7790039069 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2473.84762568751 186.075117588043,2462.02873587731 184.96835231781,2485.66627831349 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2448.19804949135 183.978660106659,2427.29405522017 187.065281867981,2469.10251813096 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2353.80821628106 184.948761463165,2332.68387786713 186.094472408295,2374.93326624766 PathPoint;PointKind.SMOOTHPOINT 185.166857242584,2285.1180051379 184.590697288513,2253.87965710553 185.632553100586,2310.36673999794 PathPoint;PointKind.SMOOTHPOINT 184.5241355896,2195.80842079065 184.807612895966,2158.96754423717 184.237117767334,2233.1158387099 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2064.48331170631 185.728147029877,2039.85979445694 185.315086841583,2089.10682895568 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1969.06765673344 186.137430667877,1938.79275101312 184.89990234375,1999.64307486375 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1879.8076438887 185.026652812958,1839.4981852645 186.016345024109,1920.11733969713 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1664.35329106206 186.86630487442,1620.801049747 184.177165031433,1707.90482082444 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1550.46976096795 185.563867092133,1520.37985894122 185.477242469788,1581.9991340414 PathPoint;PointKind.SMOOTHPOINT 186.519334316254,1463.2618660168 187.840418815613,1422.86370049336 185.198249816895,1503.6595571718 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1369.89809175331 185.747737884521,1344.12067326119 185.295495986938,1395.67551024544 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1310.39165370771 185.86457490921,1284.12089203265 185.17865896225,1336.66217819854 PathPoint;PointKind.SMOOTHPOINT 187.517051696777,1253.96268094983 188.502967357635,1235.03016193658 186.530900001526,1272.89519996308 PathPoint;PointKind.SMOOTHPOINT 187.517051696777,1188.30036359188 188.697695732117,1163.27624219061 186.335935592651,1213.32448499316 PathPoint;PointKind.SMOOTHPOINT 187.517051696777,1095.96264827519 186.619884967804,1061.33968138688 188.38707447052,1129.53915837356 PathPoint;PointKind.SMOOTHPOINT 185.31909942627,880.57162363597 186.460325717926,838.19795072282 184.099037647247,925.875470434635 PathPoint;PointKind.SMOOTHPOINT 184.512333869934,760.459161488968 184.539241790771,728.582076345245 184.48495388031,792.336958185359 PathPoint;PointKind.SMOOTHPOINT 186.507296562195,567.57573364965 185.700767040253,535.750829034891 187.31406211853,599.401349817077 PathPoint;PointKind.SMOOTHPOINT 186.507296562195,395.212298825178 185.721302032471,354.000591418353 187.277240753174,435.599079505936 PathPoint;PointKind.SMOOTHPOINT 186.843881607056,315.377749800779 186.688098907471,295.07881248136 186.999664306641,335.67692430442 PathPoint;PointKind.SMOOTHPOINT 185.843803882599,261.544521174605 185.425078868866,238.364981472186 186.185345649719,280.456642344711 PathPoint";
	
	maskSquare[1] = "PointKind.SMOOTHPOINT 187.504777908325,134.359304428101 187.504777908325,134.359304428101 186.2460064888,140.739550113678 PathPoint;PointKind.SMOOTHPOINT 188.502495288849,126.15144443512 191.844447164384,123.452809631716 186.759925783595,127.558573828171 PathPoint;PointKind.SMOOTHPOINT 216.137427563145,125.003811674792 228.155705017634,124.439744587721 203.432837590079,125.600090225165 PathPoint;PointKind.SMOOTHPOINT 238.396389484406,125.162460327148 240.124397277832,125.258526325226 224.137079715729,124.372925281525 PathPoint;PointKind.SMOOTHPOINT 245.846343040466,126.153568744659 247.915892601013,124.745859622955 244.484424591064,127.080711841583 PathPoint;PointKind.SMOOTHPOINT 252.558453083038,125.477094173431 254.416751861572,125.204238414764 249.661130905151,125.902192115784 PathPoint;PointKind.SMOOTHPOINT 265.847425460815,125.118557929993 269.940969944,125.649871349335 262.092590332031,124.631146907806 PathPoint;PointKind.SMOOTHPOINT 277.84788608551,125.118557929993 282.392728328705,126.051601886749 272.676608562469,124.057583332062 PathPoint;PointKind.SMOOTHPOINT 295.848577022552,125.118557929993 306.666977405548,124.87166595459 289.789338111877,125.256165981293 PathPoint;PointKind.SMOOTHPOINT 320.202133655548,124.136418819427 328.351221084595,124.910139560699 314.978928565979,123.640982627869 PathPoint;PointKind.SMOOTHPOINT 358.85134935379,125.118557929993 378.091928958893,124.675285339355 340.561988353729,125.540115356445 PathPoint;PointKind.SMOOTHPOINT 391.852734088898,125.118557929993 400.863583087921,125.602664470673 381.914033889771,124.583467960358 PathPoint;PointKind.SMOOTHPOINT 428.854429721832,124.083311080933 450.018925666809,124.944600582123 407.689933776855,123.221313476562 PathPoint;PointKind.SMOOTHPOINT 467.852032184601,124.136418819427 486.236751079559,124.594797611237 451.652283668518,123.732563972473 PathPoint;PointKind.SMOOTHPOINT 501.857507228851,124.083311080933 519.802966117859,124.652390003204 484.070191383362,123.518952846527 PathPoint;PointKind.SMOOTHPOINT 549.859585762024,125.118557929993 571.713774204254,126.088423252106 528.0051612854,124.148928642273 PathPoint;PointKind.SMOOTHPOINT 586.861281394958,125.118557929993 596.366150379181,124.429337501526 577.356648445129,125.808250427246 PathPoint;PointKind.SMOOTHPOINT 615.862591266632,124.083311080933 624.874856472015,124.299518585205 592.308719158173,123.51848077774 PathPoint;PointKind.SMOOTHPOINT 638.447542190552,124.146332263947 644.883019924164,123.835238933563 629.341571331024,124.585592269897 PathPoint;PointKind.SMOOTHPOINT 658,129 660.98948724151,125.509966607683 654.172388755311,133.46745471253 PathPoint;PointKind.SMOOTHPOINT 676.865208148956,125.118557929993 686.093444824219,124.929966449738 673.629884719849,125.18464756012 PathPoint;PointKind.SMOOTHPOINT 697.866132259369,124.083311080933 701.61435842514,124.143263816833 682.76535987854,123.842792034149 PathPoint;PointKind.SMOOTHPOINT 711.866748332977,125.118557929993 716.743218898773,124.579691410065 710.343382358551,125.28661441803 PathPoint;PointKind.SMOOTHPOINT 727.867519855499,125.118557929993 736.606693267822,124.743971347809 722.626848220825,125.342790603638 PathPoint;PointKind.SMOOTHPOINT 751.180164813995,124.136418819427 766.631684303284,123.571588516235 743.91809463501,124.402193546295 PathPoint;PointKind.SMOOTHPOINT 788.870136737823,125.118557929993 794.29279088974,125.525009155273 777.631359100342,124.277331352234 PathPoint;PointKind.SMOOTHPOINT 812.871057987213,124.083311080933 817.08592414856,123.398575305939 805.175156593323,125.333585262299 PathPoint;PointKind.SMOOTHPOINT 845.872442722321,124.083311080933 852.244899272919,123.987245082855 833.880951404572,124.263641357422 PathPoint;PointKind.SMOOTHPOINT 864.473369121552,125.011162281036 866.034264564514,124.214782238007 859.677622318268,127.45836687088 PathPoint;PointKind.SMOOTHPOINT 869.572656154633,125.000304698944 880.170364379883,124.97646522522 867.905309200287,125.004081249237 PathPoint;PointKind.SMOOTHPOINT 900.874829292297,125.118557929993 914.700779914856,124.471115589142 883.942902088165,125.912105560303 PathPoint;PointKind.SMOOTHPOINT 936.876447200775,124.083311080933 941.924042701721,124.881107330322 926.569533348083,122.45467376709 PathPoint;PointKind.SMOOTHPOINT 962.877523899078,125.118557929993 977.0823097229,126.441294670105 953.485715389252,124.24428653717 PathPoint;PointKind.SMOOTHPOINT 1005.57661771774,124.146332263947 1009.60124015808,124.053806781769 987.560820579529,124.558920383453 PathPoint;PointKind.SMOOTHPOINT 1018.05764436722,124.288661003113 1024.66377496719,123.104004383087 1014.51406002045,124.923829555511 PathPoint;PointKind.SMOOTHPOINT 1034.5078253746,125.171665668488 1042.11261749268,126.021153450012 1028.18729639053,124.466158866882 PathPoint;PointKind.SMOOTHPOINT 1057.45390892029,125.162460327148 1069.58867311478,124.749872207642 1052.30717897415,125.337597846985 PathPoint;PointKind.SMOOTHPOINT 1095.35418748856,125.199753761292 1102.0533156395,124.358055114746 1088.65529537201,126.041452407837 PathPoint;PointKind.SMOOTHPOINT 1111.31624937057,125.199753761292 1125.10773897171,125.76930475235 1097.52475976944,124.63067483902 PathPoint;PointKind.SMOOTHPOINT 1144.23785448074,125.199753761292 1156.97379827499,125.49621295929 1131.50285482407,124.903294563293 PathPoint;PointKind.SMOOTHPOINT 1168.1906247139,125.162460327148 1192.73395299911,122.382211208344 1148.54831457138,127.387556552887 PathPoint;PointKind.SMOOTHPOINT 1200.11498451233,126.188501834869 1233.09701442719,125.965685367584 1202.16517925262,126.174575805664 PathPoint;PointKind.SMOOTHPOINT 1254.42649841309,126.020917415619 1255.59534072876,126.223198890686 1250.29259204865,125.306205272675 PathPoint;PointKind.SMOOTHPOINT 1267.89084434509,125.118557929993 1272.05142259598,125.048927783966 1262.85528659821,125.202586174011 PathPoint;PointKind.SMOOTHPOINT 1284.98634338379,124.927134037018 1289.05840873718,124.982130050659 1271.76228046417,124.749872207642 PathPoint;PointKind.SMOOTHPOINT 1292.85124540329,124.927134037018 1293.46540689468,125.318951129913 1290.89145183563,123.678276062012 PathPoint;PointKind.SMOOTHPOINT 1301.69875860214,124.927134037018 1300.38569927216,125.064978122711 1296.95517539978,125.425166606903 PathPoint;PointKind.SMOOTHPOINT 1320.89331150055,125.118557929993 1327.28370666504,125.761279582977 1314.50268030167,124.475600242615 PathPoint;PointKind.SMOOTHPOINT 1335.3298830986,126.311239719391 1336.74750566483,126.272766113281 1329.7268986702,126.462537765503 PathPoint;PointKind.SMOOTHPOINT 1353.89469623566,125.118557929993 1357.96227693558,125.200933933258 1350.38368463516,125.047275543213 PathPoint;PointKind.SMOOTHPOINT 1370.89530944824,125.118557929993 1388.22401046753,124.365844249725 1368.30294370651,125.231618404388 PathPoint;PointKind.SMOOTHPOINT 1403.89693021774,125.118557929993 1409.71187353134,125.141689300537 1399.35137987137,125.100383281708 PathPoint;PointKind.SMOOTHPOINT 1422.89769887924,125.118557929993 1432.90980577469,125.460335731506 1426.22129917145,125.231618404388 PathPoint;PointKind.SMOOTHPOINT 2129.92833852768,126.153568744659 2153.77442121506,126.213757514954 2106.08296394348,126.093379974365 PathPoint;PointKind.SMOOTHPOINT 2265.93442440033,125.118557929993 2296.72440290451,124.477252483368 2235.14397382736,125.759863376617 PathPoint;PointKind.SMOOTHPOINT 2383.93934726715,126.153568744659 2416.95937871933,126.893536567688 2349.30602073669,125.377487659454 PathPoint;PointKind.SMOOTHPOINT 2476.94350719452,126.153568744659 2491.14026784897,126.158053398132 2462.74674654007,126.15002822876 PathPoint;PointKind.SMOOTHPOINT 2511.00350618362,126.123592376709 2520.62544822693,127.069618225098 2501.38156414032,125.17756652832 PathPoint;PointKind.SMOOTHPOINT 2527.96352148056,125.097786903381 2550.68301200867,125.165764808655 2505.24379491806,125.029572963715 PathPoint;PointKind.SMOOTHPOINT 2558.89488458633,126.105181694031 2569.4673371315,126.153096675873 2548.32219600677,126.057030677795 PathPoint;PointKind.SMOOTHPOINT 2581.94812774658,124.083311080933 2597.5714802742,124.199203968048 2566.32524728775,123.967182159424 PathPoint;PointKind.SMOOTHPOINT 2611.94927930832,126.153568744659 2622.56067752838,126.867572784424 2601.33764505386,125.440508842468 PathPoint;PointKind.SMOOTHPOINT 2637.70794868469,125.078904151917 2641.528630693,123.746253967285 2623.94203094866,129.881322249526 PathPoint;PointKind.SMOOTHPOINT 2659,129 2662.1333565712,128.044768810272 2655.86735153198,129.955467224121 PathPoint;PointKind.SMOOTHPOINT 2671.95205450058,126.153568744659 2679.89225149155,125.131775856018 2668.49981546402,126.598021507263 PathPoint;PointKind.SMOOTHPOINT 2684.95259284973,126.153568744659 2694.13385868073,127.451993942261 2679.9644780159,125.448297977448 PathPoint;PointKind.SMOOTHPOINT 2702.95328378677,125.118557929993 2709.52282905579,127.18810749054 2694.76430654526,122.538465976715 PathPoint;PointKind.SMOOTHPOINT 2717.51873016357,126.105181694031 2727.68543958664,124.385907173157 2707.35178470612,127.824456214905 PathPoint;PointKind.CORNERPOINT 2741.4618229866,126.105181694031 2741.4618229866,126.105181694031 2741.4618229866,126.105181694031 PathPoint;PointKind.SMOOTHPOINT 2761.95598125458,126.153568744659 2768.02017688751,126.590704441071 2755.89202165604,125.716905117035 PathPoint;PointKind.SMOOTHPOINT 2780.36973237991,125.078904151917 2785.83723306656,124.959234714508 2774.90199565887,125.199753761292 PathPoint;PointKind.SMOOTHPOINT 2802.95775175095,125.118557929993 2811.90085887909,126.416983127594 2794.01370048523,123.819896697998 PathPoint;PointKind.SMOOTHPOINT 2838.23238372803,126.105181694031 2855.19216299057,126.742474555969 2821.27236843109,125.468124866486 PathPoint;PointKind.SMOOTHPOINT 2877.13982105255,126.133033752441 2885.46026945114,126.229099750519 2868.82008075714,126.036731719971 PathPoint;PointKind.SMOOTHPOINT 2909.06441688538,127.158839225769 2920.91098308563,126.662222862244 2897.21737861633,127.656163692474 PathPoint;PointKind.SMOOTHPOINT 2939.99105930328,127.158839225769 2960.88671207428,127.844519138336 2919.09540653229,126.473631381989 PathPoint;PointKind.SMOOTHPOINT 2993.86354923248,127.158839225769 3003.87046337128,128.240820884705 2983.85569095612,126.076857566833 PathPoint;PointKind.SMOOTHPOINT 3019.80160474777,125.107228279114 3040.99749326706,125.034765720367 2998.60548019409,125.179218769073 PathPoint;PointKind.SMOOTHPOINT 3053.72139930725,127.158839225769 3069.57795381546,127.235078334808 3037.86437273026,127.083072185516 PathPoint;PointKind.SMOOTHPOINT 3084.64804172516,126.133033752441 3106.68916940689,126.521546363831 3062.60644197464,125.744049072266 PathPoint;PointKind.SMOOTHPOINT 3130,130 3132.25281811435,129.242306717046 3124.40552636441,131.881598804951 PathPoint;PointKind.SMOOTHPOINT 3161.46354675293,125.088345527649 3184.24511432648,125.325088024139 3138.6815071106,124.852075099945 PathPoint;PointKind.SMOOTHPOINT 3209.34973239899,127.140428543091 3226.99944019318,127.128154754639 3191.7000246048,127.15246629715 PathPoint;PointKind.SMOOTHPOINT 3240.2761387825,126.114151000977 3252.89477348328,124.980241775513 3227.65797615051,127.249004364014 PathPoint;PointKind.SMOOTHPOINT 3264.21946763992,126.114151000977 3276.28082513809,126.338619709015 3252.15811014175,125.889918327332 PathPoint;PointKind.SMOOTHPOINT 3283.17444562912,126.114151000977 3298.62242460251,125.304789066315 3267.72670269012,126.923985004425 PathPoint;PointKind.SMOOTHPOINT 3304.97953891754,125.118557929993 3315.53263664246,125.510847091675 3294.42644119263,124.725560665131 PathPoint;PointKind.SMOOTHPOINT 3326,128 3342.80753707886,126.597719669342 3309.19199085236,129.402988433838 PathPoint;PointKind.SMOOTHPOINT 3350.9814620018,125.118557929993 3361.53479576111,125.001956939697 3340.42836427689,125.234686851501 PathPoint;PointKind.SMOOTHPOINT 3382.98300504684,125.118557929993 3398.63279342651,123.190865039825 3367.332508564,127.04625082016 PathPoint;PointKind.SMOOTHPOINT 3415.98438978195,125.118557929993 3427.62088537216,126.008407592773 3404.34813022614,124.228944301605 PathPoint;PointKind.SMOOTHPOINT 3437.98539161682,125.118557929993 3447.44706630707,125.118557929993 3428.52324485779,125.118557929993 PathPoint;PointKind.SMOOTHPOINT 3463.98646831512,126.153568744659 3477.26717948914,126.763009548187 3450.70528507233,125.544363975525 PathPoint;PointKind.SMOOTHPOINT 3493.98761987686,125.118557929993 3510.41018486023,126.485433101654 3477.56599903107,123.752154827118 PathPoint;PointKind.SMOOTHPOINT 3516.98869943619,126.153568744659 3528.56288194656,126.033663272858 3505.41451692581,126.273946285248 PathPoint;PointKind.SMOOTHPOINT 3538.57380867004,125.069934844971 3549.47765350342,125.462696075439 3527.66996383667,124.676937580109 PathPoint;PointKind.SMOOTHPOINT 3574.48856592178,126.095976352692 3593.8839840889,126.188029766083 3555.09314775467,126.003214836121 PathPoint;PointKind.SMOOTHPOINT 3602.99255132675,125.118557929993 3612.75469779968,126.058210849762 3598.80506515503,124.715175151825 PathPoint;PointKind.SMOOTHPOINT 3616.99316740036,125.118557929993 3624.02699232101,124.794010639191 3609.95863437653,125.443105220795 PathPoint;PointKind.SMOOTHPOINT 3632.99370288849,125.118557929993 3644.46662664413,125.450894355774 3621.52077913284,124.785749435425 PathPoint;PointKind.SMOOTHPOINT 3655.99478244781,126.153568744659 3680.90821266174,127.576620101929 3631.0808801651,124.730989456177 PathPoint;PointKind.SMOOTHPOINT 3685.99617004395,126.153568744659 3707.51920223236,125.171429634094 3664.47337388992,127.135471820831 PathPoint;PointKind.SMOOTHPOINT 3715.14759778976,125.107228279114 3720.15435934067,124.134058475494 3700.69285154343,127.324063301086 PathPoint;PointKind.SMOOTHPOINT 3726.99794054031,126.153568744659 3733.23703765869,125.320367336273 3720.75884342194,126.987714290619 PathPoint;PointKind.SMOOTHPOINT 3739.09092664719,126.133033752441 3746.5847826004,127.684015750885 3731.59683465958,124.581815719604 PathPoint;PointKind.SMOOTHPOINT 3751.0623550415,126.133033752441 3759.10971164703,125.916826248169 3743.01499843597,126.349477291107 PathPoint;PointKind.SMOOTHPOINT 3770.99970817566,125.118557929993 3776.05037212372,127.851836204529 3765.94928026199,122.385043621063 PathPoint;PointKind.SMOOTHPOINT 3774.02000427246,143.555912494659 3773.79411935806,158.592955589294 3774.24588918686,128.519105434418 PathPoint;PointKind.SMOOTHPOINT 3775.00001907349,184.127864360809 3774.73424434662,194.675769329071 3775.27311086655,173.283028125763 PathPoint;PointKind.SMOOTHPOINT 3773.99994134903,213.115248203278 3772.79569387436,222.396828651428 3775.20395278931,203.832959651947 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,420.64376783371 3773.95603895187,442.922110080719 3774.06508684158,398.364481449127 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,515.033449649811 3772.420399189,527.589299201965 3773.60505580902,502.477364063263 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,665.851873874664 3773.51937532425,676.171533584595 3772.50584363937,655.532214164734 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,700.735160827637 3773.74148368835,713.347186565399 3774.27940607071,688.122663021088 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,747.929765701294 3775.06233215332,759.283964157104 3772.95784950256,736.57603931427 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,800.254578113556 3776.30174875259,808.618456840515 3773.71410369873,791.890463352203 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,815.644256591797 3772.95029640198,822.61742067337 3773.07515859604,808.670620441437 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,837.189476013184 3775.88892459869,846.4158244133 3774.12739992142,827.964071750641 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,872.072526931763 3774.20151472092,889.843084335327 3773.81961107254,854.302677631378 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,911.059743881226 3775.39773702621,920.257296085358 3774.6183514595,901.861719608307 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,934.657282352448 3772.96186208725,945.935005664825 3773.06359291077,923.37955904007 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,965.436403274536 3772.93094158173,978.24528169632 3775.08994817734,952.627524852753 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,993.137871742249 3772.06186294556,1001.72244262695 3773.96359205246,984.553536891937 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,1028.02115869522 3772.33849525452,1044.45245695114 3773.68719577789,1011.58938837051 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,1064.95605659485 3772.35053300858,1079.53212451935 3773.67256164551,1050.43050003052 PathPoint;PointKind.SMOOTHPOINT 3773.93880844116,1105.51715087891 3774.02000427246,1119.26804256439 3773.84864330292,1090.24312925339 PathPoint;PointKind.SMOOTHPOINT 3772.93943881989,1134.58053779602 3772.94463157654,1148.36659860611 3772.93353796005,1119.19038724899 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,1210.64474534988 3773.3166217804,1229.31246948242 3774.70426797867,1191.98481035233 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,1276.30715322495 3775.01252889633,1282.33145904541 3774.99647855759,1260.38450908661 PathPoint;PointKind.SMOOTHPOINT 3774.93652582169,1343.09945774078 3774.93227720261,1346.69260931015 3774.97240304947,1310.0265545845 PathPoint;PointKind.SMOOTHPOINT 3774.92472410202,1354.04862117767 3776.51229143143,1357.57851552963 3773.41457605362,1350.69103193283 PathPoint;PointKind.SMOOTHPOINT 3774.91787910461,1360.76143932343 3774.86925601959,1411.37500238419 3774.92000341415,1358.51085138321 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,1477.39830684662 3775.29624223709,1495.24486732483 3774.84754085541,1467.47801733017 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,1583.07373714447 3774.30253744125,1608.07355594635 3773.71811628342,1558.0734462738 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,1696.95679140091 3773.51229429245,1715.03112506866 3774.76256847382,1669.66932725906 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,1776.98307228088 3774.78215932846,1794.05591201782 3773.2387304306,1759.91046857834 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,1836.48970317841 3773.86634588242,1859.78252124786 3776.1497426033,1813.19688510895 PathPoint;PointKind.SMOOTHPOINT 3774.02614116669,1899.11836099625 3772.99042224884,1928.88867092133 3774.89427566528,1874.17353820801 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,1969.86660194397 3774.57020044327,1989.35973834991 3775.44612407684,1950.35434675217 PathPoint;PointKind.SMOOTHPOINT 3774.00537014008,2027.29306173325 3774.43424463272,2048.35393857956 3773.57673168182,2006.23289299011 PathPoint;PointKind.SMOOTHPOINT 3775.0030875206,2095.00755262375 3775.05005836487,2108.19715452194 3774.95635271072,2081.81795072556 PathPoint;PointKind.SMOOTHPOINT 3776.00552558899,2177.1130604744 3776.15045070648,2202.52074670792 3775.87263822556,2153.78507328033 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2250.98380041122 3775.4758644104,2279.26190090179 3774.54046010971,2222.70522785187 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2319.72386074066 3772.79451370239,2344.72013902664 3775.22637605667,2294.72781848907 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2383.33465766907 3773.73770713806,2410.1179523468 3774.283182621,2356.55065488815 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2446.94521856308 3773.55454444885,2496.50441598892 3776.46178007126,2397.38578510284 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2516.71132040024 3774.08939838409,2525.69998216629 3773.71056318283,2482.45328855515 PathPoint;PointKind.SMOOTHPOINT 3774.10238027573,2541.88934516907 3774.0997838974,2544.43143558502 3774.11016941071,2534.04969882965 PathPoint;PointKind.SMOOTHPOINT 3774.08680200577,2549.35770940781 3771.74486875534,2553.54590368271 3775.26862621307,2547.24378538132 PathPoint;PointKind.SMOOTHPOINT 3774.05658960342,2557.03520011902 3773.98601531982,2572.46878099442 3774.0681552887,2554.52898693085 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2598.78921222687 3774.25202608109,2621.63309288025 3773.87484312057,2585.96522760391 PathPoint;PointKind.SMOOTHPOINT 3775.00001907349,2641.81828212738 3775.53416490555,2657.27971506119 3774.46610927582,2626.35637712479 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2672.65924406052 3775.06233215332,2693.09486579895 3774.953520298,2652.22433042526 PathPoint;PointKind.SMOOTHPOINT 3775.00001907349,2711.1800570488 3775.71307897568,2745.99111747742 3774.2869591713,2676.36899662018 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,2768.07543945312 3773.71811628342,2796.04905557632 3772.3073387146,2740.10158729553 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2835.78969430923 3774.50930356979,2855.78818035126 3775.50702095032,2815.79097223282 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2890.16611766815 3775.57688713074,2918.42863988876 3774.43896532059,2861.90359544754 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2964.03685760498 3774.7314119339,3001.48040962219 3773.28947782516,2926.5923614502 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,3040.9847779274 3775.60827970505,3074.2403717041 3774.40804481506,3007.72847604752 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,3150.76390218735 3773.50403308868,3172.14531373978 3774.51709270477,3129.3831987381 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,3269.77716398239 3773.28947782516,3299.85502672195 3772.73574113846,3239.69953727722 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,3368.27053976059 3772.69325494766,3393.32323026657 3773.33267211914,3343.21855735779 PathPoint;PointKind.SMOOTHPOINT 3772.01489210129,3458.55652761459 3771.98019504547,3488.16963863373 3772.05006122589,3428.94318056107 PathPoint;PointKind.SMOOTHPOINT 3772.01489210129,3528.32286548615 3772.8683924675,3556.02433395386 3771.16162776947,3500.62163305283 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,3600.14128637314 3773.38672399521,3621.60767030716 3772.71756649017,3583.17985486984 PathPoint;PointKind.SMOOTHPOINT 3773.99994134903,3654.29560136795 3776.04022264481,3678.09164476395 3771.66320085526,3627.04944324493 PathPoint;PointKind.SMOOTHPOINT 3773.99994134903,3715.37540149689 3773.56327772141,3737.58198928833 3774.43636894226,3693.16857767105 PathPoint;PointKind.SMOOTHPOINT 3773.99994134903,3762.99699258804 3772.34793663025,3772.92436313629 3775.6521821022,3753.07009410858 PathPoint;PointKind.SMOOTHPOINT 3772.99986362457,3799.23110437393 3773.14667701721,3814.58348941803 3772.81386852264,3779.7939081192 PathPoint;PointKind.SMOOTHPOINT 3771.99978590012,3832.35900354385 3766.89223766327,3836.74782705307 3774.08255338669,3830.56939077377 PathPoint;PointKind.SMOOTHPOINT 3722.14294910431,3834.04499721527 3715.28803825378,3834.04971790314 3745.95079421997,3834.02871084213 PathPoint;PointKind.SMOOTHPOINT 3625.85389852524,3835.92737150192 3622.10260391235,3835.91840219498 3676.95605278015,3836.04751300812 PathPoint;PointKind.SMOOTHPOINT 3611,3835 3606.18655061722,3833.32580804825 3614.86081457138,3836.34327173233 PathPoint;PointKind.SMOOTHPOINT 3598.66651296616,3835.86246204376 3377.95240402222,3835.33232879639 3604.02685403824,3835.875207901 PathPoint;PointKind.SMOOTHPOINT 2890.10684251785,3834.06364393234 2840.38100481033,3833.95554018021 2928.39303731918,3834.14696407318 PathPoint;PointKind.SMOOTHPOINT 2667.63474941254,3834.06364393234 2643.90951633453,3834.94924497604 2691.35951042175,3833.17780685425 PathPoint;PointKind.SMOOTHPOINT 2578.84498357773,3835.08944940567 2571.91052913666,3834.94476032257 2619.67043638229,3835.94365787506 PathPoint;PointKind.SMOOTHPOINT 2551.55633926392,3834.64688491821 2548.11401367188,3834.60062217712 2562.50998735428,3834.79346227646 PathPoint;PointKind.SMOOTHPOINT 2540.79694747925,3834.51022100449 2537.43534564972,3836.4220995903 2546.49741411209,3831.26876068115 PathPoint;PointKind.SMOOTHPOINT 2528.90459060669,3834.37402915955 2475.52541255951,3833.79456472397 2532.98137664795,3834.41840362549 PathPoint;PointKind.SMOOTHPOINT 2386.3018155098,3834.06364393234 2360.87784290314,3834.95750617981 2404.64876890182,3833.41856193542 PathPoint;PointKind.SMOOTHPOINT 2278.55754375458,3834.06364393234 2222.18733787537,3833.50660276413 2334.9275135994,3834.62044906616 PathPoint;PointKind.SMOOTHPOINT 2135.89576005936,3835.08944940567 2083.73050689697,3833.47875070572 2188.06077718735,3836.70062017441 PathPoint;PointKind.SMOOTHPOINT 1788.71937990189,3835.08944940567 1748.21776628494,3833.76718473434 1829.22052145004,3836.41242218018 PathPoint;PointKind.SMOOTHPOINT 1579.21596050262,3834.06364393234 1577.06002235413,3834.0723772049 1607.34063863754,3833.95129156113 PathPoint;PointKind.SMOOTHPOINT 1568.85593891144,3834.10542201996 1565.63147306442,3834.1181678772 1573.53673696518,3834.08653926849 PathPoint;PointKind.SMOOTHPOINT 1557.60252714157,3834.15050458908 1554.03581142426,3835.56576681137 1561.94650411606,3832.4279255867 PathPoint;PointKind.SMOOTHPOINT 1545.01764535904,3834.20101594925 1466.10827922821,3834.51635789871 1549.56791639328,3834.18284130096 PathPoint;PointKind.SMOOTHPOINT 1261.96850538254,3835.08944940567 1233.53580236435,3834.93366670609 1285.37013530731,3835.21832418442 PathPoint;PointKind.SMOOTHPOINT 1038.4984588623,3835.08944940567 986.185212135315,3835.05357217789 1090.81194162369,3835.12556266785 PathPoint;PointKind.SMOOTHPOINT 799.066586494446,3834.06364393234 761.41744852066,3833.59464359283 836.715488433838,3834.53264427185 PathPoint;PointKind.SMOOTHPOINT 613.506731987,3835.08944940567 578.008811473846,3835.23390245438 649.004416465759,3834.94546842575 PathPoint;PointKind.SMOOTHPOINT 445.904138088226,3834.06364393234 413.255152702332,3833.57080411911 478.553123474121,3834.55648374557 PathPoint;PointKind.SMOOTHPOINT 287.280292510986,3835.08944940567 260.792512893677,3834.5767827034 313.768544197083,3835.60258817673 PathPoint;PointKind.SMOOTHPOINT 224.429526329041,3834.06364393234 205.178325176239,3834.21210956573 243.680727481842,3833.91541433334 PathPoint;PointKind.SMOOTHPOINT 198.483917713165,3835.08944940567 195.925068855286,3834.64877319336 203.694140911102,3835.98756027222 PathPoint;PointKind.SMOOTHPOINT 187.843959331512,3832.35900354385 185.361113548279,3829.14728355408 190.240180492401,3835.45837116241 PathPoint;PointKind.SMOOTHPOINT 186.512253284454,3818.67420148849 187.996437549591,3802.07555484772 186.216974258423,3821.97443437576 PathPoint;PointKind.SMOOTHPOINT 186.512253284454,3784.81695604324 187.755210399628,3768.1890411377 185.268824100494,3801.4446349144 PathPoint;PointKind.SMOOTHPOINT 185.514299869537,3725.31032514572 186.652221679688,3713.98067426682 184.376614093781,3736.64021205902 PathPoint;PointKind.SMOOTHPOINT 186.512253284454,3681.19313669205 186.373465061188,3657.45610189438 186.638059616089,3702.82026004791 PathPoint;PointKind.SMOOTHPOINT 186.512253284454,3586.80369091034 184.914536476135,3557.25053262711 187.739868164062,3609.51562833786 PathPoint;PointKind.SMOOTHPOINT 187.512331008911,3474.97248363495 186.62743806839,3445.83214950562 188.481960296631,3506.91336584091 PathPoint;PointKind.SMOOTHPOINT 188.509812355042,3419.56978273392 188.022401332855,3403.4066195488 188.997223377228,3435.73270988464 PathPoint;PointKind.SMOOTHPOINT 187.512331008911,3366.21892881393 187.960324287415,3351.60698366165 187.063865661621,3380.83063793182 PathPoint;PointKind.SMOOTHPOINT 186.514377593994,3301.58256244659 187.186367511749,3279.53435373306 185.843331813812,3323.60740375519 PathPoint;PointKind.SMOOTHPOINT 186.519334316254,3221.55628156662 187.396438121796,3193.24183177948 185.642466545105,3249.87096738815 PathPoint;PointKind.SMOOTHPOINT 187.514455318451,3152.81598520279 187.354896068573,3124.68611431122 187.674250602722,3180.94632816315 PathPoint;PointKind.SMOOTHPOINT 186.516973972321,3083.04941129684 186.622245311737,3056.15801286697 186.411938667297,3109.9412817955 PathPoint;PointKind.SMOOTHPOINT 186.516973972321,3027.64671039581 187.062449455261,2988.90048456192 185.971262454987,3066.39364433289 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2961.98453855515 185.38684129715,2935.53263616562 185.652616024017,2987.67641019821 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2897.34817218781 185.405960083008,2870.2108259201 185.732159614563,2946.76716518402 PathPoint;PointKind.SMOOTHPOINT 186.002655029297,2830.61770868301 186.024842262268,2828.30504369736 185.825157165527,2849.09164857864 PathPoint;PointKind.SMOOTHPOINT 186.056470870972,2823.79702281952 187.166304588318,2821.61040019989 184.62468624115,2826.61857795715 PathPoint;PointKind.SMOOTHPOINT 186.07842206955,2816.51606988907 186.076533794403,2806.8575425148 186.078894138336,2818.90639019012 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2788.59485340118 184.169375896454,2758.72116041183 185.93585729599,2797.74519872665 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2707.54276704788 185.10454416275,2684.8190279007 185.93868970871,2730.26627016068 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2651.11402463913 186.012568473816,2621.73340749741 185.030665397644,2680.49464178085 PathPoint;PointKind.SMOOTHPOINT 184.5241355896,2551.59460735321 186.301002502441,2520.99133205414 182.747032642365,2582.1971745491 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2464.38698005676 185.717761516571,2443.27936840057 185.318155288696,2486.27893400192 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2423.34768009186 186.075117588043,2411.52872991562 184.96835231781,2435.1663942337 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2397.69805860519 183.978660106659,2376.79414463043 187.065281867981,2418.60244464874 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2303.3081407547 184.948761463165,2282.18377065659 186.094472408295,2324.43321895599 PathPoint;PointKind.SMOOTHPOINT 185.166857242584,2234.61811971664 184.590697288513,2203.37967586517 185.632553100586,2259.86671876907 PathPoint;PointKind.SMOOTHPOINT 184.5241355896,2145.30837011337 184.807612895966,2108.46764993668 184.237117767334,2182.61573028564 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2013.98331832886 185.728147029877,1989.35973834991 185.315086841583,2038.6068983078 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1918.56759500504 186.137430667877,1888.29264354706 184.89990234375,1949.1430182457 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1829.30764865875 185.026652812958,1788.99816703796 186.016345024109,1869.61736631393 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1613.85333013535 186.86630487442,1570.30097198486 184.177165031433,1657.40474414825 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1499.96980381012 185.563867092133,1469.8799033165 185.477242469788,1531.49904203415 PathPoint;PointKind.SMOOTHPOINT 186.519334316254,1412.76194047928 187.840418815613,1372.36370992661 185.198249816895,1453.15946292877 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1319.39806413651 185.747737884521,1293.62074804306 185.295495986938,1345.17561626434 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1259.89166927338 185.86457490921,1233.62080526352 185.17865896225,1286.16206121445 PathPoint;PointKind.SMOOTHPOINT 187.517051696777,1203.46269083023 188.502967357635,1184.5301361084 186.530900001526,1222.39524555206 PathPoint;PointKind.SMOOTHPOINT 187.517051696777,1137.80028295517 188.697695732117,1112.77615261078 186.335935592651,1162.82441329956 PathPoint;PointKind.SMOOTHPOINT 187.517051696777,1045.46268415451 186.619884967804,1010.83974313736 188.38707447052,1079.03904867172 PathPoint;PointKind.SMOOTHPOINT 185.31909942627,830.071622848511 186.460325717926,787.698020458221 184.099037647247,875.375356197357 PathPoint;PointKind.SMOOTHPOINT 184.512333869934,709.95914888382 184.539241790771,678.08199596405 184.48495388031,741.837009906769 PathPoint;PointKind.SMOOTHPOINT 186.507296562195,517.075619220734 185.700767040253,485.250865936279 187.31406211853,548.901316642761 PathPoint;PointKind.SMOOTHPOINT 186.507296562195,344.712211608887 185.721302032471,303.500606536865 187.277240753174,385.099112510681 PathPoint;PointKind.SMOOTHPOINT 186.843881607056,264.877826690674 186.688098907471,244.578868865967 186.999664306641,285.177020549774 PathPoint;PointKind.SMOOTHPOINT 185.843803882599,211.044518470764 185.425078868866,187.864996910095 186.185345649719,229.956538200378 PathPoint";
	
	maskSquare[2] = "PointKind.SMOOTHPOINT 187.504777908325,134.359304428101 187.504777908325,134.359304428101 186.2460064888,140.739550113678 PathPoint;PointKind.SMOOTHPOINT 188.502495288849,126.15144443512 191.841673851013,123.463720798492 186.757729053497,127.555849075317 PathPoint;PointKind.SMOOTHPOINT 215.845191478729,126.153568744659 223.608328489869,124.311903521499 204.138829708099,128.930985450745 PathPoint;PointKind.SMOOTHPOINT 228,126 230.639088243363,124.745967545213 224.351037702737,127.733900773712 PathPoint;PointKind.SMOOTHPOINT 238.396389484406,125.162460327148 240.124397277832,125.258526325226 233.593027315724,124.896499152974 PathPoint;PointKind.SMOOTHPOINT 245.846343040466,126.153568744659 247.915892601013,124.745859622955 244.484424591064,127.080711841583 PathPoint;PointKind.SMOOTHPOINT 252.558453083038,125.477094173431 254.416751861572,125.204238414764 249.661130905151,125.902192115784 PathPoint;PointKind.SMOOTHPOINT 265.847425460815,125.118557929993 269.940969944,125.649871349335 262.092590332031,124.631146907806 PathPoint;PointKind.SMOOTHPOINT 277.84788608551,125.118557929993 282.392728328705,126.051601886749 272.676608562469,124.057583332062 PathPoint;PointKind.SMOOTHPOINT 295.848577022552,125.118557929993 306.666977405548,124.87166595459 289.789338111877,125.256165981293 PathPoint;PointKind.SMOOTHPOINT 320.202133655548,124.136418819427 328.351221084595,124.910139560699 314.978928565979,123.640982627869 PathPoint;PointKind.SMOOTHPOINT 358.85134935379,125.118557929993 378.091928958893,124.675285339355 340.561988353729,125.540115356445 PathPoint;PointKind.SMOOTHPOINT 391.852734088898,125.118557929993 400.863583087921,125.602664470673 381.914033889771,124.583467960358 PathPoint;PointKind.SMOOTHPOINT 428.854429721832,124.083311080933 450.018925666809,124.944600582123 407.689933776855,123.221313476562 PathPoint;PointKind.SMOOTHPOINT 467.852032184601,124.136418819427 486.236751079559,124.594797611237 451.652283668518,123.732563972473 PathPoint;PointKind.SMOOTHPOINT 501.857507228851,124.083311080933 519.802966117859,124.652390003204 484.070191383362,123.518952846527 PathPoint;PointKind.SMOOTHPOINT 549.859585762024,125.118557929993 571.713774204254,126.088423252106 528.0051612854,124.148928642273 PathPoint;PointKind.SMOOTHPOINT 586.861281394958,125.118557929993 596.366150379181,124.429337501526 577.356648445129,125.808250427246 PathPoint;PointKind.SMOOTHPOINT 615.862591266632,124.083311080933 624.874856472015,124.299518585205 592.308719158173,123.51848077774 PathPoint;PointKind.SMOOTHPOINT 638.447542190552,124.146332263947 644.883019924164,123.835238933563 629.341571331024,124.585592269897 PathPoint;PointKind.SMOOTHPOINT 658.864517211914,125.118557929993 661.18497133255,124.079298496246 653.495206832886,127.522568225861 PathPoint;PointKind.SMOOTHPOINT 676.865208148956,125.118557929993 686.093444824219,124.929966449738 673.629884719849,125.18464756012 PathPoint;PointKind.SMOOTHPOINT 697.866132259369,124.083311080933 701.61435842514,124.143263816833 682.76535987854,123.842792034149 PathPoint;PointKind.SMOOTHPOINT 711.866748332977,125.118557929993 716.743218898773,124.579691410065 710.343382358551,125.28661441803 PathPoint;PointKind.SMOOTHPOINT 727.867519855499,125.118557929993 736.606693267822,124.743971347809 722.626848220825,125.342790603638 PathPoint;PointKind.SMOOTHPOINT 751.180164813995,124.136418819427 766.631684303284,123.571588516235 743.91809463501,124.402193546295 PathPoint;PointKind.SMOOTHPOINT 788.870136737823,125.118557929993 794.29279088974,125.525009155273 777.631359100342,124.277331352234 PathPoint;PointKind.SMOOTHPOINT 812.871057987213,124.083311080933 817.08592414856,123.398575305939 805.175156593323,125.333585262299 PathPoint;PointKind.SMOOTHPOINT 845.872442722321,124.083311080933 852.244899272919,123.987245082855 833.880951404572,124.263641357422 PathPoint;PointKind.SMOOTHPOINT 864.473369121552,125.011162281036 866.034264564514,124.214782238007 859.677622318268,127.45836687088 PathPoint;PointKind.SMOOTHPOINT 869.572656154633,125.000304698944 880.170364379883,124.97646522522 867.905309200287,125.004081249237 PathPoint;PointKind.SMOOTHPOINT 900.874829292297,125.118557929993 914.700779914856,124.471115589142 883.942902088165,125.912105560303 PathPoint;PointKind.SMOOTHPOINT 936.876447200775,124.083311080933 941.924042701721,124.881107330322 926.569533348083,122.45467376709 PathPoint;PointKind.SMOOTHPOINT 962.877523899078,125.118557929993 977.0823097229,126.441294670105 953.485715389252,124.24428653717 PathPoint;PointKind.SMOOTHPOINT 1005.57661771774,124.146332263947 1009.60124015808,124.053806781769 987.560820579529,124.558920383453 PathPoint;PointKind.SMOOTHPOINT 1018.05764436722,124.288661003113 1024.66377496719,123.104004383087 1014.51406002045,124.923829555511 PathPoint;PointKind.SMOOTHPOINT 1034.5078253746,125.171665668488 1042.11261749268,126.021153450012 1028.18729639053,124.466158866882 PathPoint;PointKind.SMOOTHPOINT 1057.45390892029,125.162460327148 1069.58867311478,124.749872207642 1052.30717897415,125.337597846985 PathPoint;PointKind.SMOOTHPOINT 1095.35418748856,125.199753761292 1102.0533156395,124.358055114746 1088.65529537201,126.041452407837 PathPoint;PointKind.SMOOTHPOINT 1111.31624937057,125.199753761292 1125.10773897171,125.76930475235 1097.52475976944,124.63067483902 PathPoint;PointKind.SMOOTHPOINT 1144.23785448074,125.199753761292 1156.97379827499,125.49621295929 1131.50285482407,124.903294563293 PathPoint;PointKind.SMOOTHPOINT 1168.1906247139,125.162460327148 1192.73395299911,122.382211208344 1148.54831457138,127.387556552887 PathPoint;PointKind.SMOOTHPOINT 1200.11498451233,126.188501834869 1233.09701442719,125.965685367584 1202.16517925262,126.174575805664 PathPoint;PointKind.SMOOTHPOINT 1254.42649841309,126.020917415619 1255.59534072876,126.223198890686 1250.29259204865,125.306205272675 PathPoint;PointKind.SMOOTHPOINT 1267.89084434509,125.118557929993 1272.05142259598,125.048927783966 1262.85528659821,125.202586174011 PathPoint;PointKind.SMOOTHPOINT 1284.98634338379,124.927134037018 1289.05840873718,124.982130050659 1271.76228046417,124.749872207642 PathPoint;PointKind.SMOOTHPOINT 1292.85124540329,124.927134037018 1293.46540689468,125.318951129913 1290.89145183563,123.678276062012 PathPoint;PointKind.SMOOTHPOINT 1301.69875860214,124.927134037018 1300.38569927216,125.064978122711 1296.95517539978,125.425166606903 PathPoint;PointKind.SMOOTHPOINT 1320.89331150055,125.118557929993 1327.28370666504,125.761279582977 1314.50268030167,124.475600242615 PathPoint;PointKind.SMOOTHPOINT 1335.3298830986,126.311239719391 1336.74750566483,126.272766113281 1329.7268986702,126.462537765503 PathPoint;PointKind.SMOOTHPOINT 1353.89469623566,125.118557929993 1357.96227693558,125.200933933258 1350.38368463516,125.047275543213 PathPoint;PointKind.SMOOTHPOINT 1370.89530944824,125.118557929993 1388.22401046753,124.365844249725 1368.30294370651,125.231618404388 PathPoint;PointKind.SMOOTHPOINT 1403.89693021774,125.118557929993 1409.71187353134,125.141689300537 1399.35137987137,125.100383281708 PathPoint;PointKind.SMOOTHPOINT 1422.89769887924,125.118557929993 1432.90980577469,125.460335731506 1426.22129917145,125.231618404388 PathPoint;PointKind.SMOOTHPOINT 2129.92833852768,126.153568744659 2153.77442121506,126.213757514954 2106.08296394348,126.093379974365 PathPoint;PointKind.SMOOTHPOINT 2265.93442440033,125.118557929993 2296.72440290451,124.477252483368 2235.14397382736,125.759863376617 PathPoint;PointKind.SMOOTHPOINT 2383.93934726715,126.153568744659 2416.95937871933,126.893536567688 2349.30602073669,125.377487659454 PathPoint;PointKind.SMOOTHPOINT 2476.94350719452,126.153568744659 2491.14026784897,126.158053398132 2462.74674654007,126.15002822876 PathPoint;PointKind.SMOOTHPOINT 2511.00350618362,126.123592376709 2520.62544822693,127.069618225098 2501.38156414032,125.17756652832 PathPoint;PointKind.SMOOTHPOINT 2527.96352148056,125.097786903381 2550.68301200867,125.165764808655 2505.24379491806,125.029572963715 PathPoint;PointKind.SMOOTHPOINT 2558.89488458633,126.105181694031 2569.4673371315,126.153096675873 2548.32219600677,126.057030677795 PathPoint;PointKind.SMOOTHPOINT 2581.94812774658,124.083311080933 2597.5714802742,124.199203968048 2566.32524728775,123.967182159424 PathPoint;PointKind.SMOOTHPOINT 2611.94927930832,126.153568744659 2622.56067752838,126.867572784424 2601.33764505386,125.440508842468 PathPoint;PointKind.SMOOTHPOINT 2637.70794868469,125.078904151917 2645.6854391098,123.746253967285 2623.32778930664,127.481970310211 PathPoint;PointKind.SMOOTHPOINT 2659.95135784149,126.153568744659 2663.08471441269,125.198337554932 2656.81870937347,127.109035968781 PathPoint;PointKind.SMOOTHPOINT 2671.95205450058,126.153568744659 2679.89225149155,125.131775856018 2668.49981546402,126.598021507263 PathPoint;PointKind.SMOOTHPOINT 2684.95259284973,126.153568744659 2692.88565022192,127.275470863133 2679.9644780159,125.448297977448 PathPoint;PointKind.SMOOTHPOINT 2699.99199879003,124.447325973322 2700.86637668128,124.555525800213 2694.43484210891,123.759656034597 PathPoint;PointKind.SMOOTHPOINT 2704,127 2706.991376267,127.942348547013 2702.88669483599,126.649232179978 PathPoint;PointKind.SMOOTHPOINT 2710,126 2711.3402991447,125.803866060752 2708.87949980846,126.163969452166 PathPoint;PointKind.SMOOTHPOINT 2717.51873016357,126.105181694031 2727.68543958664,124.385907173157 2711.98120091438,127.041601879088 PathPoint;PointKind.CORNERPOINT 2741.4618229866,126.105181694031 2741.4618229866,126.105181694031 2741.4618229866,126.105181694031 PathPoint;PointKind.SMOOTHPOINT 2761.95598125458,126.153568744659 2768.02017688751,126.590704441071 2755.89202165604,125.716905117035 PathPoint;PointKind.SMOOTHPOINT 2780.36973237991,125.078904151917 2785.83723306656,124.959234714508 2774.90199565887,125.199753761292 PathPoint;PointKind.SMOOTHPOINT 2802.95775175095,125.118557929993 2811.90085887909,126.416983127594 2794.01370048523,123.819896697998 PathPoint;PointKind.SMOOTHPOINT 2838.23238372803,126.105181694031 2855.19216299057,126.742474555969 2821.27236843109,125.468124866486 PathPoint;PointKind.SMOOTHPOINT 2877.13982105255,126.133033752441 2885.46026945114,126.229099750519 2868.82008075714,126.036731719971 PathPoint;PointKind.SMOOTHPOINT 2909.06441688538,127.158839225769 2920.91098308563,126.662222862244 2897.21737861633,127.656163692474 PathPoint;PointKind.SMOOTHPOINT 2939.99105930328,127.158839225769 2960.88671207428,127.844519138336 2919.09540653229,126.473631381989 PathPoint;PointKind.SMOOTHPOINT 2993.86354923248,127.158839225769 3003.87046337128,128.240820884705 2983.85569095612,126.076857566833 PathPoint;PointKind.SMOOTHPOINT 3019.80160474777,125.107228279114 3040.99749326706,125.034765720367 2998.60548019409,125.179218769073 PathPoint;PointKind.SMOOTHPOINT 3053.72139930725,127.158839225769 3069.57795381546,127.235078334808 3037.86437273026,127.083072185516 PathPoint;PointKind.SMOOTHPOINT 3084.64804172516,126.133033752441 3106.68916940689,126.521546363831 3062.60644197464,125.744049072266 PathPoint;PointKind.SMOOTHPOINT 3129.5391869545,127.140428543091 3141.08575344086,127.332796573639 3117.99238443375,126.948060512543 PathPoint;PointKind.SMOOTHPOINT 3161.46354675293,125.088345527649 3184.24511432648,125.325088024139 3138.6815071106,124.852075099945 PathPoint;PointKind.SMOOTHPOINT 3209.34973239899,127.140428543091 3226.99944019318,127.128154754639 3191.7000246048,127.15246629715 PathPoint;PointKind.SMOOTHPOINT 3240.2761387825,126.114151000977 3252.89477348328,124.980241775513 3227.65797615051,127.249004364014 PathPoint;PointKind.SMOOTHPOINT 3264.21946763992,126.114151000977 3276.28082513809,126.338619709015 3252.15811014175,125.889918327332 PathPoint;PointKind.SMOOTHPOINT 3283.17444562912,126.114151000977 3298.62242460251,125.304789066315 3267.72670269012,126.923985004425 PathPoint;PointKind.SMOOTHPOINT 3304.97953891754,125.118557929993 3315.53263664246,125.510847091675 3294.42644119263,124.725560665131 PathPoint;PointKind.SMOOTHPOINT 3325.075507164,126.114151000977 3341.88304424286,124.711870670319 3308.26749801636,127.517139434814 PathPoint;PointKind.SMOOTHPOINT 3350.9814620018,125.118557929993 3361.53479576111,125.001956939697 3340.42836427689,125.234686851501 PathPoint;PointKind.SMOOTHPOINT 3382.98300504684,125.118557929993 3398.63279342651,123.190865039825 3367.332508564,127.04625082016 PathPoint;PointKind.SMOOTHPOINT 3415.98438978195,125.118557929993 3427.62088537216,126.008407592773 3404.34813022614,124.228944301605 PathPoint;PointKind.SMOOTHPOINT 3437.98539161682,125.118557929993 3447.44706630707,125.118557929993 3428.52324485779,125.118557929993 PathPoint;PointKind.SMOOTHPOINT 3463.98646831512,126.153568744659 3473.8417720359,126.605820445634 3450.70528507233,125.544363975525 PathPoint;PointKind.SMOOTHPOINT 3483.99935434701,124.797636655499 3486.58913793935,124.704898018094 3476.54823963379,125.064456720193 PathPoint;PointKind.SMOOTHPOINT 3497,127 3501.81036355604,125.411005669768 3492.96435232813,128.333191050986 PathPoint;PointKind.SMOOTHPOINT 3516.98869943619,126.153568744659 3528.56288194656,126.033663272858 3505.41451692581,126.273946285248 PathPoint;PointKind.SMOOTHPOINT 3538.57380867004,125.069934844971 3549.47765350342,125.462696075439 3527.66996383667,124.676937580109 PathPoint;PointKind.SMOOTHPOINT 3574.48856592178,126.095976352692 3593.8839840889,126.188029766083 3555.09314775467,126.003214836121 PathPoint;PointKind.SMOOTHPOINT 3602.99255132675,125.118557929993 3612.75469779968,126.058210849762 3598.80506515503,124.715175151825 PathPoint;PointKind.SMOOTHPOINT 3616.99316740036,125.118557929993 3624.02699232101,124.794010639191 3609.95863437653,125.443105220795 PathPoint;PointKind.SMOOTHPOINT 3632.99370288849,125.118557929993 3644.46662664413,125.450894355774 3621.52077913284,124.785749435425 PathPoint;PointKind.SMOOTHPOINT 3655.99478244781,126.153568744659 3680.90821266174,127.576620101929 3631.0808801651,124.730989456177 PathPoint;PointKind.SMOOTHPOINT 3685.99617004395,126.153568744659 3707.51920223236,125.171429634094 3664.47337388992,127.135471820831 PathPoint;PointKind.SMOOTHPOINT 3715.14759778976,125.107228279114 3720.15435934067,124.134058475494 3700.69285154343,127.324063301086 PathPoint;PointKind.SMOOTHPOINT 3726.99794054031,126.153568744659 3733.23703765869,125.320367336273 3720.75884342194,126.987714290619 PathPoint;PointKind.SMOOTHPOINT 3739.09092664719,126.133033752441 3746.5847826004,127.684015750885 3731.59683465958,124.581815719604 PathPoint;PointKind.SMOOTHPOINT 3751.0623550415,126.133033752441 3757.46001167122,125.961148568162 3743.01499843597,126.349477291107 PathPoint;PointKind.SMOOTHPOINT 3765,126 3766.18070006291,126.116313844401 3760.42115918291,125.548926441975 PathPoint;PointKind.SMOOTHPOINT 3770.99970817566,125.118557929993 3776.05037212372,127.851836204529 3769.9643755546,124.558190257679 PathPoint;PointKind.SMOOTHPOINT 3774.02000427246,143.555912494659 3773.79411935806,158.592955589294 3774.24588918686,128.519105434418 PathPoint;PointKind.SMOOTHPOINT 3775.00001907349,184.127864360809 3774.73424434662,194.675769329071 3775.27311086655,173.283028125763 PathPoint;PointKind.SMOOTHPOINT 3773.99994134903,213.115248203278 3772.79569387436,222.396828651428 3775.20395278931,203.832959651947 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,420.64376783371 3773.95603895187,442.922110080719 3774.06508684158,398.364481449127 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,515.033449649811 3772.420399189,527.589299201965 3773.60505580902,502.477364063263 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,665.851873874664 3773.51937532425,676.171533584595 3772.50584363937,655.532214164734 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,700.735160827637 3773.74148368835,713.347186565399 3774.27940607071,688.122663021088 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,747.929765701294 3775.06233215332,759.283964157104 3772.95784950256,736.57603931427 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,800.254578113556 3776.30174875259,808.618456840515 3773.71410369873,791.890463352203 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,815.644256591797 3772.95029640198,822.61742067337 3773.07515859604,808.670620441437 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,837.189476013184 3775.88892459869,846.4158244133 3774.12739992142,827.964071750641 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,872.072526931763 3774.20151472092,889.843084335327 3773.81961107254,854.302677631378 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,911.059743881226 3775.39773702621,920.257296085358 3774.6183514595,901.861719608307 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,934.657282352448 3772.96186208725,945.935005664825 3773.06359291077,923.37955904007 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,965.436403274536 3772.93094158173,978.24528169632 3775.08994817734,952.627524852753 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,993.137871742249 3772.06186294556,1001.72244262695 3773.96359205246,984.553536891937 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,1028.02115869522 3772.33849525452,1044.45245695114 3773.68719577789,1011.58938837051 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,1064.95605659485 3772.35053300858,1079.53212451935 3773.67256164551,1050.43050003052 PathPoint;PointKind.SMOOTHPOINT 3773.93880844116,1105.51715087891 3774.02000427246,1119.26804256439 3773.84864330292,1090.24312925339 PathPoint;PointKind.SMOOTHPOINT 3772.93943881989,1134.58053779602 3772.94463157654,1148.36659860611 3772.93353796005,1119.19038724899 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,1210.64474534988 3773.3166217804,1229.31246948242 3774.70426797867,1191.98481035233 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,1276.30715322495 3775.01252889633,1282.33145904541 3774.99647855759,1260.38450908661 PathPoint;PointKind.SMOOTHPOINT 3774.93652582169,1343.09945774078 3774.93227720261,1346.69260931015 3774.97240304947,1310.0265545845 PathPoint;PointKind.SMOOTHPOINT 3774.92472410202,1354.04862117767 3776.51229143143,1357.57851552963 3773.41457605362,1350.69103193283 PathPoint;PointKind.SMOOTHPOINT 3774.91787910461,1360.76143932343 3774.86925601959,1411.37500238419 3774.92000341415,1358.51085138321 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,1477.39830684662 3775.29624223709,1495.24486732483 3774.84754085541,1467.47801733017 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,1583.07373714447 3774.30253744125,1608.07355594635 3773.71811628342,1558.0734462738 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,1696.95679140091 3773.51229429245,1715.03112506866 3774.76256847382,1669.66932725906 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,1776.98307228088 3774.78215932846,1794.05591201782 3773.2387304306,1759.91046857834 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,1836.48970317841 3773.86634588242,1859.78252124786 3776.1497426033,1813.19688510895 PathPoint;PointKind.SMOOTHPOINT 3774.02614116669,1899.11836099625 3772.99042224884,1928.88867092133 3774.89427566528,1874.17353820801 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,1969.86660194397 3774.57020044327,1989.35973834991 3775.44612407684,1950.35434675217 PathPoint;PointKind.SMOOTHPOINT 3774.00537014008,2027.29306173325 3774.43424463272,2048.35393857956 3773.57673168182,2006.23289299011 PathPoint;PointKind.SMOOTHPOINT 3775.0030875206,2095.00755262375 3775.05005836487,2108.19715452194 3774.95635271072,2081.81795072556 PathPoint;PointKind.SMOOTHPOINT 3776.00552558899,2177.1130604744 3776.15045070648,2202.52074670792 3775.87263822556,2153.78507328033 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2250.98380041122 3775.4758644104,2279.26190090179 3774.54046010971,2222.70522785187 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2319.72386074066 3772.79451370239,2344.72013902664 3775.22637605667,2294.72781848907 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2383.33465766907 3773.73770713806,2410.1179523468 3774.283182621,2356.55065488815 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2446.94521856308 3773.55454444885,2496.50441598892 3776.46178007126,2397.38578510284 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2516.71132040024 3774.08939838409,2525.69998216629 3773.71056318283,2482.45328855515 PathPoint;PointKind.SMOOTHPOINT 3774.10238027573,2541.88934516907 3774.0997838974,2544.43143558502 3774.11016941071,2534.04969882965 PathPoint;PointKind.SMOOTHPOINT 3774.08680200577,2549.35770940781 3771.74486875534,2553.54590368271 3775.26862621307,2547.24378538132 PathPoint;PointKind.SMOOTHPOINT 3774.05658960342,2557.03520011902 3773.98601531982,2572.46878099442 3774.0681552887,2554.52898693085 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2598.78921222687 3774.25202608109,2621.63309288025 3773.87484312057,2585.96522760391 PathPoint;PointKind.SMOOTHPOINT 3775.00001907349,2641.81828212738 3775.53416490555,2657.27971506119 3774.46610927582,2626.35637712479 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2672.65924406052 3775.06233215332,2693.09486579895 3774.953520298,2652.22433042526 PathPoint;PointKind.SMOOTHPOINT 3775.00001907349,2711.1800570488 3775.71307897568,2745.99111747742 3774.2869591713,2676.36899662018 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,2768.07543945312 3773.71811628342,2796.04905557632 3772.3073387146,2740.10158729553 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2835.78969430923 3774.50930356979,2855.78818035126 3775.50702095032,2815.79097223282 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,2890.16611766815 3775.57688713074,2918.42863988876 3774.43896532059,2861.90359544754 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,2964.03685760498 3774.7314119339,3001.48040962219 3773.28947782516,2926.5923614502 PathPoint;PointKind.SMOOTHPOINT 3775.00804424286,3040.9847779274 3775.60827970505,3074.2403717041 3774.40804481506,3007.72847604752 PathPoint;PointKind.SMOOTHPOINT 3774.01056289673,3150.76390218735 3773.50403308868,3172.14531373978 3774.51709270477,3129.3831987381 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,3269.77716398239 3773.28947782516,3299.85502672195 3772.73574113846,3239.69953727722 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,3368.27053976059 3772.69325494766,3393.32323026657 3773.33267211914,3343.21855735779 PathPoint;PointKind.SMOOTHPOINT 3772.01489210129,3458.55652761459 3771.98019504547,3488.16963863373 3772.05006122589,3428.94318056107 PathPoint;PointKind.SMOOTHPOINT 3772.01489210129,3528.32286548615 3772.8683924675,3556.02433395386 3771.16162776947,3500.62163305283 PathPoint;PointKind.SMOOTHPOINT 3773.01260948181,3600.14128637314 3773.38672399521,3621.60767030716 3772.71756649017,3583.17985486984 PathPoint;PointKind.SMOOTHPOINT 3773.99994134903,3654.29560136795 3776.04022264481,3678.09164476395 3771.66320085526,3627.04944324493 PathPoint;PointKind.SMOOTHPOINT 3773.99994134903,3715.37540149689 3773.56327772141,3737.58198928833 3774.43636894226,3693.16857767105 PathPoint;PointKind.SMOOTHPOINT 3773.99994134903,3762.99699258804 3772.34793663025,3772.92436313629 3775.6521821022,3753.07009410858 PathPoint;PointKind.SMOOTHPOINT 3772.99986362457,3799.23110437393 3773.14667701721,3814.58348941803 3772.81386852264,3779.7939081192 PathPoint;PointKind.SMOOTHPOINT 3771.99978590012,3832.35900354385 3766.89223766327,3836.74782705307 3774.08255338669,3830.56939077377 PathPoint;PointKind.SMOOTHPOINT 3722.14294910431,3834.04499721527 3715.59620657232,3834.07107086793 3745.95061097476,3833.95017865424 PathPoint;PointKind.SMOOTHPOINT 3625.85389852524,3835.92737150192 3622.10266753117,3835.90375476458 3680.15609055963,3836.26924343898 PathPoint;PointKind.SMOOTHPOINT 3610,3836 3605.18655061722,3834.32580804825 3613.86081457138,3837.34327173233 PathPoint;PointKind.SMOOTHPOINT 3598.66651296616,3835.86246204376 3377.95240402222,3835.33232879639 3604.02685403824,3835.875207901 PathPoint;PointKind.SMOOTHPOINT 2890.10684251785,3834.06364393234 2840.38100481033,3833.95554018021 2928.39303731918,3834.14696407318 PathPoint;PointKind.SMOOTHPOINT 2667.63474941254,3834.06364393234 2643.90951633453,3834.94924497604 2691.35951042175,3833.17780685425 PathPoint;PointKind.SMOOTHPOINT 2578.84498357773,3835.08944940567 2571.91052913666,3834.94476032257 2619.67043638229,3835.94365787506 PathPoint;PointKind.SMOOTHPOINT 2551.55633926392,3834.64688491821 2548.11401367188,3834.60062217712 2562.50998735428,3834.79346227646 PathPoint;PointKind.SMOOTHPOINT 2540.79694747925,3834.51022100449 2537.43534564972,3836.4220995903 2546.49741411209,3831.26876068115 PathPoint;PointKind.SMOOTHPOINT 2528.90459060669,3834.37402915955 2475.52541255951,3833.79456472397 2532.98137664795,3834.41840362549 PathPoint;PointKind.SMOOTHPOINT 2386.3018155098,3834.06364393234 2360.87784290314,3834.95750617981 2404.64876890182,3833.41856193542 PathPoint;PointKind.SMOOTHPOINT 2278.55754375458,3834.06364393234 2222.18733787537,3833.50660276413 2334.9275135994,3834.62044906616 PathPoint;PointKind.SMOOTHPOINT 2135.89576005936,3835.08944940567 2083.73050689697,3833.47875070572 2188.06077718735,3836.70062017441 PathPoint;PointKind.SMOOTHPOINT 1788.71937990189,3835.08944940567 1748.21776628494,3833.76718473434 1829.22052145004,3836.41242218018 PathPoint;PointKind.SMOOTHPOINT 1579.21596050262,3834.06364393234 1577.06002235413,3834.0723772049 1607.34063863754,3833.95129156113 PathPoint;PointKind.SMOOTHPOINT 1568.85593891144,3834.10542201996 1565.63147306442,3834.1181678772 1573.53673696518,3834.08653926849 PathPoint;PointKind.SMOOTHPOINT 1557.60252714157,3834.15050458908 1554.03581142426,3835.56576681137 1561.94650411606,3832.4279255867 PathPoint;PointKind.SMOOTHPOINT 1545.01764535904,3834.20101594925 1466.10827922821,3834.51635789871 1549.56791639328,3834.18284130096 PathPoint;PointKind.SMOOTHPOINT 1261.96850538254,3835.08944940567 1233.53580236435,3834.93366670609 1285.37013530731,3835.21832418442 PathPoint;PointKind.SMOOTHPOINT 1038.4984588623,3835.08944940567 986.185212135315,3835.05357217789 1090.81194162369,3835.12556266785 PathPoint;PointKind.SMOOTHPOINT 799.066586494446,3834.06364393234 767.729806339941,3833.67327747716 836.715488433838,3834.53264427185 PathPoint;PointKind.SMOOTHPOINT 637.13322012284,3834.9295177368 633.612777849115,3834.95813688264 684.597698941192,3834.54365916105 PathPoint;PointKind.SMOOTHPOINT 627.196223988191,3835.00666669409 624.309665775344,3835.02774056724 630.288550147367,3834.98409057249 PathPoint;PointKind.SMOOTHPOINT 622,3834 620.286436283606,3835.13693862972 625.715759155124,3831.53461742812 PathPoint;PointKind.SMOOTHPOINT 613.506731987,3835.08944940567 578.008811473846,3835.23390245438 615.221329589688,3835.08249488324 PathPoint;PointKind.SMOOTHPOINT 445.904138088226,3834.06364393234 413.255152702332,3833.57080411911 478.553123474121,3834.55648374557 PathPoint;PointKind.SMOOTHPOINT 287.280292510986,3835.08944940567 267.432056449295,3834.70528999802 313.768544197083,3835.60258817673 PathPoint;PointKind.SMOOTHPOINT 238.684390254872,3834.08969069279 236.620476432623,3834.06813319238 252.848477060723,3834.23763403412 PathPoint;PointKind.SMOOTHPOINT 232.504379168662,3834.04663080923 231.193557853924,3834.39887676809 234.999109814468,3833.37624287873 PathPoint;PointKind.SMOOTHPOINT 228.420231265207,3834.0441396381 227.307966864191,3834.75953475123 229.814088441756,3833.14762743148 PathPoint;PointKind.SMOOTHPOINT 224.429526329041,3834.06364393234 205.178325176239,3834.21210956573 225.768823454328,3834.05333166797 PathPoint;PointKind.SMOOTHPOINT 198.483917713165,3835.08944940567 195.925068855286,3834.64877319336 203.694140911102,3835.98756027222 PathPoint;PointKind.SMOOTHPOINT 187.843959331512,3832.35900354385 185.361113548279,3829.14728355408 190.240180492401,3835.45837116241 PathPoint;PointKind.SMOOTHPOINT 186.512253284454,3818.67420148849 187.996437549591,3802.07555484772 186.216974258423,3821.97443437576 PathPoint;PointKind.SMOOTHPOINT 186.512253284454,3784.81695604324 187.755210399628,3768.1890411377 185.268824100494,3801.4446349144 PathPoint;PointKind.SMOOTHPOINT 185.514299869537,3725.31032514572 186.652221679688,3713.98067426682 184.376614093781,3736.64021205902 PathPoint;PointKind.SMOOTHPOINT 186.512253284454,3681.19313669205 186.373465061188,3657.45610189438 186.638059616089,3702.82026004791 PathPoint;PointKind.SMOOTHPOINT 186.512253284454,3586.80369091034 184.914536476135,3557.25053262711 187.739868164062,3609.51562833786 PathPoint;PointKind.SMOOTHPOINT 187.512331008911,3474.97248363495 186.62743806839,3445.83214950562 188.481960296631,3506.91336584091 PathPoint;PointKind.SMOOTHPOINT 188.509812355042,3419.56978273392 188.022401332855,3403.4066195488 188.997223377228,3435.73270988464 PathPoint;PointKind.SMOOTHPOINT 187.512331008911,3366.21892881393 187.960324287415,3351.60698366165 187.063865661621,3380.83063793182 PathPoint;PointKind.SMOOTHPOINT 186.514377593994,3301.58256244659 187.186367511749,3279.53435373306 185.843331813812,3323.60740375519 PathPoint;PointKind.SMOOTHPOINT 186.519334316254,3221.55628156662 187.396438121796,3193.24183177948 185.642466545105,3249.87096738815 PathPoint;PointKind.SMOOTHPOINT 187.514455318451,3152.81598520279 187.354896068573,3124.68611431122 187.674250602722,3180.94632816315 PathPoint;PointKind.SMOOTHPOINT 186.516973972321,3083.04941129684 186.622245311737,3056.15801286697 186.411938667297,3109.9412817955 PathPoint;PointKind.SMOOTHPOINT 186.516973972321,3027.64671039581 187.062449455261,2988.90048456192 185.971262454987,3066.39364433289 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2961.98453855515 185.38684129715,2935.53263616562 185.652616024017,2987.67641019821 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2897.34817218781 185.405960083008,2870.2108259201 185.732159614563,2946.76716518402 PathPoint;PointKind.SMOOTHPOINT 186.002655029297,2830.61770868301 186.024842262268,2828.30504369736 185.825157165527,2849.09164857864 PathPoint;PointKind.SMOOTHPOINT 186.056470870972,2823.79702281952 187.166304588318,2821.61040019989 184.62468624115,2826.61857795715 PathPoint;PointKind.SMOOTHPOINT 186.07842206955,2816.51606988907 186.076533794403,2806.8575425148 186.078894138336,2818.90639019012 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2788.59485340118 184.169375896454,2758.72116041183 185.93585729599,2797.74519872665 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2707.54276704788 185.10454416275,2684.8190279007 185.93868970871,2730.26627016068 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2651.11402463913 186.012568473816,2621.73340749741 185.030665397644,2680.49464178085 PathPoint;PointKind.SMOOTHPOINT 184.5241355896,2551.59460735321 186.301002502441,2520.99133205414 182.747032642365,2582.1971745491 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2464.38698005676 185.717761516571,2443.27936840057 185.318155288696,2486.27893400192 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2423.34768009186 186.075117588043,2411.52872991562 184.96835231781,2435.1663942337 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2397.69805860519 183.978660106659,2376.79414463043 187.065281867981,2418.60244464874 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2303.3081407547 184.948761463165,2282.18377065659 186.094472408295,2324.43321895599 PathPoint;PointKind.SMOOTHPOINT 185.166857242584,2234.61811971664 184.590697288513,2203.37967586517 185.632553100586,2259.86671876907 PathPoint;PointKind.SMOOTHPOINT 184.5241355896,2145.30837011337 184.807612895966,2108.46764993668 184.237117767334,2182.61573028564 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,2013.98331832886 185.728147029877,1989.35973834991 185.315086841583,2038.6068983078 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1918.56759500504 186.137430667877,1888.29264354706 184.89990234375,1949.1430182457 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1829.30764865875 185.026652812958,1788.99816703796 186.016345024109,1869.61736631393 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1613.85333013535 186.86630487442,1570.30097198486 184.177165031433,1657.40474414825 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1499.96980381012 185.563867092133,1469.8799033165 185.477242469788,1531.49904203415 PathPoint;PointKind.SMOOTHPOINT 186.519334316254,1412.76194047928 187.840418815613,1372.36370992661 185.198249816895,1453.15946292877 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1319.39806413651 185.747737884521,1293.62074804306 185.295495986938,1345.17561626434 PathPoint;PointKind.SMOOTHPOINT 185.521852970123,1259.89166927338 185.86457490921,1233.62080526352 185.17865896225,1286.16206121445 PathPoint;PointKind.SMOOTHPOINT 187.517051696777,1203.46269083023 188.502967357635,1184.5301361084 186.530900001526,1222.39524555206 PathPoint;PointKind.SMOOTHPOINT 187.517051696777,1137.80028295517 188.697695732117,1112.77615261078 186.335935592651,1162.82441329956 PathPoint;PointKind.SMOOTHPOINT 187.517051696777,1045.46268415451 186.619884967804,1010.83974313736 188.38707447052,1079.03904867172 PathPoint;PointKind.SMOOTHPOINT 185.31909942627,830.071622848511 186.460325717926,787.698020458221 184.099037647247,875.375356197357 PathPoint;PointKind.SMOOTHPOINT 184.512333869934,709.95914888382 184.539241790771,678.08199596405 184.48495388031,741.837009906769 PathPoint;PointKind.SMOOTHPOINT 186.507296562195,517.075619220734 185.700767040253,485.250865936279 187.31406211853,548.901316642761 PathPoint;PointKind.SMOOTHPOINT 186.507296562195,344.712211608887 185.721302032471,303.500606536865 187.277240753174,385.099112510681 PathPoint;PointKind.SMOOTHPOINT 186.843881607056,264.877826690674 186.688098907471,244.578868865967 186.999664306641,285.177020549774 PathPoint;PointKind.SMOOTHPOINT 185.843803882599,211.044518470764 185.425078868866,187.864996910095 186.185345649719,229.956538200378 PathPoint";
	
	subshadowSquare[0] = "PointKind.SMOOTHPOINT 184.245851039886,157.049496173859 183.701083660126,147.114808559418 184.31312084198,158.276402950287 PathPoint;PointKind.SMOOTHPOINT 186.034283638,125.053145885468 189.35316324234,124.216876029968 183.363790512085,125.726079940796 PathPoint;PointKind.SMOOTHPOINT 207.975096702576,123.382966518402 219.507501125336,121.258420944214 197.934193611145,125.23300409317 PathPoint;PointKind.SMOOTHPOINT 245.866878032684,122.910189628601 255.78763961792,121.063928604126 234.523065090179,125.021517276764 PathPoint;PointKind.SMOOTHPOINT 266.160643100739,122.963297367096 412.082061767578,122.733399868011 264.245223999023,122.966365814209 PathPoint;PointKind.SMOOTHPOINT 1481.14650249481,123.301298618317 1487.87820339203,123.305547237396 907.454760074615,122.941346168518 PathPoint;PointKind.SMOOTHPOINT 1499.82815265656,125.359282493591 1506.11516475677,127.454795837402 1493.42170715332,123.224115371704 PathPoint;PointKind.SMOOTHPOINT 1521.7699098587,123.326790332794 1989.64412927628,123.624193668365 1514.96102571487,123.322541713715 PathPoint;PointKind.SMOOTHPOINT 2922.79855012894,124.352595806122 2929.57368135452,124.358024597168 2504.78281974792,124.016954898834 PathPoint;PointKind.SMOOTHPOINT 2941.84204101562,126.044254302979 2950.46319723129,121.50484085083 2935.84889173508,129.200270175934 PathPoint;PointKind.SMOOTHPOINT 2964.14894342422,124.385876655579 3081.6225528717,124.480762481689 2957.14415073395,124.380211830139 PathPoint;PointKind.SMOOTHPOINT 3288.27750921249,124.65117931366 3293.79174470901,124.655900001526 3190.78586339951,124.570219516754 PathPoint;PointKind.SMOOTHPOINT 3304.36655759811,128.124189376831 3313.31013679504,123.877222537994 3299.42234516144,130.472259521484 PathPoint;PointKind.SMOOTHPOINT 3326.6526889801,124.68327999115 3334.71916437149,124.690124988556 3319.40855741501,124.677379131317 PathPoint;PointKind.SMOOTHPOINT 3347.5483417511,125.004286766052 3352.64880895615,121.781945228577 3340.81498861313,129.258098602295 PathPoint;PointKind.SMOOTHPOINT 3367.63250827789,128.124189376831 3377.19591379166,122.117350101471 3362.75037288666,131.190984249115 PathPoint;PointKind.SMOOTHPOINT 3388.67898702621,124.735207557678 3429.48673725128,124.769432544708 3381.81723117828,124.729306697845 PathPoint;PointKind.SMOOTHPOINT 3502.59107351303,124.831509590149 3510.83363056183,124.838354587555 3467.56663799286,124.801533222198 PathPoint;PointKind.SMOOTHPOINT 3523.28727722168,128.124189376831 3529.23864841461,128.129382133484 3515.38744211197,128.117580413818 PathPoint;PointKind.SMOOTHPOINT 3544.36373233795,124.866914749146 3680.15738725662,124.982571601868 3538.61110210419,124.861958026886 PathPoint;PointKind.CORNERPOINT 3760.06399869919,125.053145885468 3760.06399869919,125.053145885468 3760.06399869919,125.053145885468 PathPoint;PointKind.SMOOTHPOINT 3771.40615940094,125.859439373016 3775.95619440079,127.600429058075 3764.83991861343,123.346381187439 PathPoint;PointKind.SMOOTHPOINT 3775.40623426437,135.859272480011 3776.09238624573,137.489562034607 3773.77051591873,131.974146366119 PathPoint;PointKind.SMOOTHPOINT 3775.38097858429,139.604666233063 3775.433614254,140.127954483032 3775.05855560303,136.409940719604 PathPoint;PointKind.SMOOTHPOINT 3774,145 3772.41951370239,146.529974937439 3775.58025026321,143.470025062561 PathPoint;PointKind.CORNERPOINT 3774,151 3774,151 3774,151 PathPoint;PointKind.SMOOTHPOINT 3774,175 3774.07694721222,180.1833152771 3773.78520870209,160.592460632324 PathPoint;PointKind.CORNERPOINT 3723.40620517731,222.859425544739 3723.40620517731,222.859425544739 3723.40620517731,222.859425544739 PathPoint;PointKind.CORNERPOINT 3718.40628862381,3731.85930490494 3718.40628862381,3731.85930490494 3718.40628862381,3731.85930490494 PathPoint;PointKind.SMOOTHPOINT 3773.40631484985,3774.85934257507 3772.85895109177,3777.66767978668 3774.36154603958,3769.9573802948 PathPoint;PointKind.SMOOTHPOINT 3773.40631484985,3822.85929679871 3771.34101390839,3830.37793636322 3775.39065599442,3815.63499212265 PathPoint;PointKind.SMOOTHPOINT 3770.6666636467,3836.14567279816 3770.6666636467,3836.14567279816 3768.53763341904,3836.62010192871 PathPoint;PointKind.SMOOTHPOINT 3717.82824039459,3836.3592839241 3698.16067457199,3836.56345367432 3752.1705365181,3836.0031080246 PathPoint;PointKind.SMOOTHPOINT 3643.82815361023,3837.35936164856 3591.57485961914,3837.37682819366 3673.11718940735,3837.34968423843 PathPoint;PointKind.SMOOTHPOINT 3446.49891614914,3836.25424861908 3440.33110141754,3836.25637292862 3525.58672428131,3836.22757673264 PathPoint;PointKind.SMOOTHPOINT 3427.77761220932,3836.2606215477 3422.30114221573,3834.64520215988 3434.00703191757,3838.09791326523 PathPoint;PointKind.SMOOTHPOINT 3410.47345876694,3836.26652240753 3218.62800836563,3836.3311958313 3416.29949569702,3836.26439809799 PathPoint;PointKind.SMOOTHPOINT 2682.2721862793,3836.51648283005 2671.52860879898,3836.52025938034 2964.19591426849,3836.41805648804 PathPoint;PointKind.SMOOTHPOINT 2649.92367267609,3836.52781248093 2635.45594453812,3837.9048371315 2662.24962472916,3835.35448551178 PathPoint;PointKind.SMOOTHPOINT 2606.12347841263,3836.5429186821 2365.24943590164,3836.6274189949 2620.78900337219,3836.53796195984 PathPoint;PointKind.SMOOTHPOINT 1852.71326065063,3836.81223392487 1844.90831136703,3836.81506633759 2107.16447353363,3836.7192363739 PathPoint;PointKind.SMOOTHPOINT 1829.30903434753,3836.82073116302 1821.52037143707,3837.65558481216 1838.69446992874,3835.81498861313 PathPoint;PointKind.SMOOTHPOINT 1805.82172393799,3836.82946443558 1739.94924545288,3836.8535399437 1813.64626407623,3836.82663202286 PathPoint;PointKind.SMOOTHPOINT 1609.56077814102,3836.90192699432 1603.87116909027,3836.90405130386 1674.40768718719,3836.87785148621 PathPoint;PointKind.SMOOTHPOINT 1589.82806682587,3836.3592839241 1583.27362775803,3836.36188030243 1595.50705432892,3836.35715961456 PathPoint;PointKind.SMOOTHPOINT 1572.86710739136,3836.91561698914 1140.5625629425,3837.07753658295 1579.40644025803,3836.9132566452 PathPoint;PointKind.SMOOTHPOINT 487.828094959259,3837.35936164856 479.56689119339,3837.36337423325 742.480645179749,3837.23615169525 PathPoint;PointKind.SMOOTHPOINT 456.099407672882,3837.74834632874 367.181711196899,3836.54858350754 462.13103055954,3837.82977819443 PathPoint;PointKind.SMOOTHPOINT 252.818562984467,3837.84653663635 245.698821544647,3837.85007715225 297.670290470123,3837.82482147217 PathPoint;PointKind.SMOOTHPOINT 234.828021526337,3835.35944223404 225.900256633759,3835.36369085312 240.684506893158,3835.35660982132 PathPoint;PointKind.SMOOTHPOINT 211.110813617706,3837.86683559418 202.316172122955,3837.20381498337 216.963758468628,3838.30798387527 PathPoint;PointKind.CORNERPOINT 195.072276592255,3837.87438869476 195.072276592255,3837.87438869476 195.072276592255,3837.87438869476 PathPoint;PointKind.SMOOTHPOINT 183.828070163727,3826.35945081711 182.662768363953,3806.90266370773 184.433498382568,3836.47258043289 PathPoint;PointKind.SMOOTHPOINT 185.82822561264,3772.35926628113 185.744905471802,3772.22047805786 185.82822561264,3772.35926628113 PathPoint;PointKind.CORNERPOINT 248.406136035919,3738.85937690735 248.406136035919,3738.85937690735 248.406136035919,3738.85937690735 PathPoint;PointKind.CORNERPOINT 233.406150341034,213.859434127808 233.406150341034,213.859434127808 233.406150341034,213.859434127808 PathPoint;PointKind.SMOOTHPOINT 184.226968288422,184.114379882812 184.289989471436,168.494095802307 184.213042259216,187.579600811005 PathPoint";
	
} else if (mask_variant_square == 2) {

	maskSquare[0] = "PointKind.SMOOTHPOINT 192.660929310854,203.926058422565 192.660929310854,203.926058422565 191.402237654733,210.089120129585 PathPoint;PointKind.SMOOTHPOINT 193.658592180291,195.997810200691 196.997496985589,193.401670269012 191.913920100178,197.354593957901 PathPoint;PointKind.SMOOTHPOINT 216.603187588789,193.024864491462 228.309161469737,190.342186562061 204.897213707842,195.707542420864 PathPoint;PointKind.SMOOTHPOINT 238.550355926214,191.042507688045 240.278286322628,191.1351764431 224.29162897873,190.279935795307 PathPoint;PointKind.SMOOTHPOINT 243.591017509749,191.256612597942 246.777360774862,186.73164209032 242.652775827526,192.589109124183 PathPoint;PointKind.SMOOTHPOINT 252.711698150211,191.346215974331 256.431417310068,188.290033444404 250.450863455776,193.203835445881 PathPoint;PointKind.SMOOTHPOINT 264.487468346298,190.051447185516 268.580927909855,190.564780212879 260.732851028871,189.580793661117 PathPoint;PointKind.SMOOTHPOINT 276.458715384446,190.051447185516 281.003493012788,190.952668513298 271.287893105111,189.026667517662 PathPoint;PointKind.SMOOTHPOINT 293.417805173052,189.060858279705 304.235762422873,188.822466138839 287.35896626259,189.193848554134 PathPoint;PointKind.SMOOTHPOINT 320.352580462571,190.051447185516 328.501064456688,190.798692184925 315.129410946882,189.572776516914 PathPoint;PointKind.SMOOTHPOINT 358.260939920803,190.051447185516 377.500671466248,189.623237365722 339.972418967489,190.458435153007 PathPoint;PointKind.SMOOTHPOINT 396.169535177398,189.060858279705 406.048071753186,187.852627488613 386.291234399971,190.26838167572 PathPoint;PointKind.SMOOTHPOINT 426.097299075226,189.060858279705 447.26090945587,189.892990688324 404.933688694581,188.228490072727 PathPoint;PointKind.SMOOTHPOINT 467.996074212841,190.051447185516 485.169504712464,187.062938784599 450.822879511579,193.040427183151 PathPoint;PointKind.SMOOTHPOINT 501.914253790052,189.060858279705 519.851199385689,189.819185801983 483.97683659769,188.30182336235 PathPoint;PointKind.SMOOTHPOINT 548.800871678124,185.096380471229 570.65419226749,186.033207351207 526.947551088758,184.15978938961 PathPoint;PointKind.SMOOTHPOINT 588.704556875228,190.051447185516 598.208881450592,189.385788418293 579.200232299864,190.717577549457 PathPoint;PointKind.SMOOTHPOINT 613.644242224238,186.087440973758 622.656455618199,186.296358319759 590.091758638616,185.541803571224 PathPoint;PointKind.SMOOTHPOINT 638.583927573247,189.060858279705 645.01910066939,188.760451170444 629.478573826313,189.485295325756 PathPoint;PointKind.SMOOTHPOINT 657.538107302363,188.069797777176 659.858363184011,187.066004163265 652.168978600623,190.391940015793 PathPoint;PointKind.SMOOTHPOINT 674.496961292606,193.024864491462 683.724930187758,192.842828158378 671.262043564931,193.08853004837 PathPoint;PointKind.SMOOTHPOINT 699.436882439978,190.051447185516 703.18489740327,190.10945358181 684.336826937034,189.819185801983 PathPoint;PointKind.SMOOTHPOINT 711.645814226978,190.225230576038 715.493807695739,193.265378817558 707.454969939932,186.913678423404 PathPoint;PointKind.SMOOTHPOINT 725.374466456785,189.060858279705 734.11338954924,188.699143597126 720.134083660673,189.27755697155 PathPoint;PointKind.SMOOTHPOINT 751.311578876869,190.051447185516 766.762738140765,189.505809782982 744.049932522069,190.308231598377 PathPoint;PointKind.SMOOTHPOINT 786.227185525154,185.096380471229 791.649604656696,185.488748940468 774.989035594327,184.283583528042 PathPoint;PointKind.SMOOTHPOINT 808.676132776821,189.289582687854 812.890556900062,188.628404089451 800.98038163766,190.49710608387 PathPoint;PointKind.SMOOTHPOINT 842.09253343979,193.024864491462 848.464512574929,192.932195736408 830.101479339237,193.199119478702 PathPoint;PointKind.SMOOTHPOINT 858.60006936525,192.896354385853 860.160818723037,192.126944340706 853.804402279787,195.260232933998 PathPoint;PointKind.SMOOTHPOINT 863.69920894255,192.885743459701 874.29645892558,192.862871018886 862.031878725158,192.889516233444 PathPoint;PointKind.SMOOTHPOINT 900.95039836601,192.033568190574 914.775492125858,191.407995144367 884.019132784116,192.799912857055 PathPoint;PointKind.SMOOTHPOINT 936.593914557654,189.214127213001 941.641178495324,189.984716249942 926.287403954916,187.641116360664 PathPoint;PointKind.SMOOTHPOINT 964.795870244326,190.051447185516 983.777402583429,193.562720548153 955.523571257127,188.336485721111 PathPoint;PointKind.SMOOTHPOINT 1005.69721831087,189.060858279705 1009.72158895437,188.971490701675 987.682223457422,189.459357506275 PathPoint;PointKind.SMOOTHPOINT 1018.17755401248,189.198328722953 1024.78344512268,188.053999287128 1014.63421202736,189.812111851215 PathPoint;PointKind.SMOOTHPOINT 1034.6270835409,190.051447185516 1042.23158071398,190.871789676189 1028.30674424703,189.369754129886 PathPoint;PointKind.SMOOTHPOINT 1057.57215054612,191.042507688045 1069.70657005074,190.643772663116 1052.42561549807,191.211575111389 PathPoint;PointKind.SMOOTHPOINT 1099.47092568373,187.078501476288 1106.16948555018,186.265468734741 1092.77213001892,187.891534217834 PathPoint;PointKind.SMOOTHPOINT 1115.43211680454,187.078501476288 1129.22301980191,187.628383249283 1101.64121380718,186.528855501651 PathPoint;PointKind.SMOOTHPOINT 1148.35239771395,187.078501476288 1161.08763144484,187.364760684013 1135.61787137815,186.792006470203 PathPoint;PointKind.SMOOTHPOINT 1168.30424031251,191.042507688045 1188.05754069029,191.530374492645 1148.55141153145,190.554876681804 PathPoint;PointKind.SMOOTHPOINT 1188.25608291106,188.069797777176 1188.74041274652,188.083002485275 1174.68093541489,187.697943765163 PathPoint;PointKind.SMOOTHPOINT 1194.57099884261,188.928103803634 1196.72784645942,188.928339601993 1193.37833072783,188.928103803634 PathPoint;PointKind.SMOOTHPOINT 1200.22709415085,192.033568190574 1201.8177899006,192.023193062782 1198.29095380082,192.046301301956 PathPoint;PointKind.SMOOTHPOINT 1203.4181533832,189.909496573448 1205.95133518569,190.387459846973 1202.35541016586,189.708832170009 PathPoint;PointKind.SMOOTHPOINT 1211.28250035116,188.928103803634 1212.05851276035,188.975499273777 1208.293520315,188.745360075473 PathPoint;PointKind.SMOOTHPOINT 1214.1934311295,188.069797777176 1218.22416832878,189.309861346721 1213.13846925811,187.744631840229 PathPoint;PointKind.SMOOTHPOINT 1222.0240589317,190.626795181274 1223.04648062915,190.108274590015 1220.20982633481,191.547823571205 PathPoint;PointKind.SMOOTHPOINT 1230.15485804867,193.024864491462 1232.23955136673,193.622377532959 1226.17434590049,191.883364635944 PathPoint;PointKind.SMOOTHPOINT 1234.79489821525,194.043041805267 1238.84567827529,194.462291287422 1233.71399852404,193.931037584781 PathPoint;PointKind.SMOOTHPOINT 1241.75660905364,191.871574717998 1243.38762632329,191.779849156379 1237.368637336,192.118691398143 PathPoint;PointKind.SMOOTHPOINT 1246.67182590861,189.909496573448 1248.64027063422,190.473762046337 1246.49356234697,189.858092531204 PathPoint;PointKind.SMOOTHPOINT 1254.53617287657,191.871574717998 1255.70478955843,192.067051557541 1251.46961517933,191.35942068243 PathPoint;PointKind.SMOOTHPOINT 1266.0681275664,194.015924993992 1268.08561835129,193.262077640533 1261.3507455371,195.778753525257 PathPoint;PointKind.SMOOTHPOINT 1271.24201522444,193.185678972244 1272.0666020962,192.732710324764 1270.02293769312,193.854403118133 PathPoint;PointKind.SMOOTHPOINT 1280.09482892572,194.815281430721 1284.16659503997,194.868336061477 1277.23530219027,194.778261088371 PathPoint;PointKind.SMOOTHPOINT 1287.95917589367,194.815281430721 1288.57343062657,195.193501998424 1285.99969150582,193.608701228141 PathPoint;PointKind.SMOOTHPOINT 1296.80656623263,194.815281430721 1301.62227617886,194.326943029403 1292.06301058516,195.296074284553 PathPoint;PointKind.SMOOTHPOINT 1303.56666947155,195.404541529655 1304.94278871192,195.014766842365 1300.92124764876,196.153908714294 PathPoint;PointKind.SMOOTHPOINT 1308.97918507189,192.004329194069 1309.03035331643,191.981692551613 1306.22930457476,193.207136622905 PathPoint;PointKind.SMOOTHPOINT 1313.51806774118,192.852967487812 1313.44473445061,193.017083145618 1313.54612774625,192.79024512434 PathPoint;PointKind.SMOOTHPOINT 1318.43304879779,192.852967487812 1319.8945270452,192.931488341331 1316.3820746455,192.742613855838 PathPoint;PointKind.SMOOTHPOINT 1323.34850145113,192.852967487812 1324.62888655655,193.718819061756 1321.9082450563,191.879120265484 PathPoint;PointKind.SMOOTHPOINT 1327.91898110092,194.015924993992 1331.42035097761,194.785806635856 1326.29621677394,193.658926278591 PathPoint;PointKind.SMOOTHPOINT 1335.43599708172,192.15217476511 1337.48296266186,192.25451125288 1332.80778853936,192.020127684116 PathPoint;PointKind.SMOOTHPOINT 1340.88765521015,192.033568190574 1343.75496329153,192.743557049274 1338.45869628364,191.432046576976 PathPoint;PointKind.SMOOTHPOINT 1348.54308482941,193.96617154026 1350.18259084009,193.998240117073 1346.19500474106,193.920190860271 PathPoint;PointKind.SMOOTHPOINT 1358.84417206983,195.997810200691 1361.67846838054,196.294444536209 1355.66796813428,195.665334514618 PathPoint;PointKind.SMOOTHPOINT 1366.53945161226,193.383513795376 1368.72176545217,193.291788233757 1363.79688086435,193.498819192886 PathPoint;PointKind.SMOOTHPOINT 1373.48324177515,193.834360257625 1380.68216576567,197.115966018676 1371.14176404092,192.766665288448 PathPoint;PointKind.SMOOTHPOINT 1386.77661022878,195.997810200691 1393.91587723373,195.26636369133 1379.6375790222,196.72972830677 PathPoint;PointKind.SMOOTHPOINT 1401.75499377696,194.006021462917 1404.17169118865,192.396933461666 1395.60678728731,198.099716772079 PathPoint;PointKind.SMOOTHPOINT 1406.90648059061,193.834360257625 1407.3361052061,192.882678081035 1406.38725259759,194.984820450782 PathPoint;PointKind.SMOOTHPOINT 1413.78754838921,193.834360257625 1415.65577881099,193.911937917709 1411.45597418619,193.736739737034 PathPoint;PointKind.SMOOTHPOINT 1419.69736273492,195.997810200691 1429.70888958685,196.327927903175 1416.51337745343,195.893115729332 PathPoint;PointKind.SMOOTHPOINT 2127.98612439499,196.989106501579 2151.83099794944,197.046877099514 2104.14148663891,196.930864306926 PathPoint;PointKind.SMOOTHPOINT 2268.64668545429,195.997810200691 2299.43558496998,195.378367911815 2237.85755014024,196.617252489566 PathPoint;PointKind.SMOOTHPOINT 2382.37199962735,196.989106501579 2415.38990105861,196.249407049656 2349.35409819609,197.728098558426 PathPoint;PointKind.SMOOTHPOINT 2473.15248259355,199.961816412449 2487.34872297511,199.96582498455 2458.95647801034,199.958279437065 PathPoint;PointKind.SMOOTHPOINT 2512.05850492122,198.970755909919 2521.68002128247,199.884710349083 2502.43722435832,198.057273067474 PathPoint;PointKind.SMOOTHPOINT 2529.01783050818,197.979931205749 2551.73629528757,198.045718947887 2506.29912993044,197.914143463611 PathPoint;PointKind.SMOOTHPOINT 2557.94793153658,200.953112713337 2568.51995109488,200.999329191684 2547.37567617991,200.90666043663 PathPoint;PointKind.SMOOTHPOINT 2579.89462827728,197.979931205749 2595.51721295031,198.092171224594 2564.27251520096,197.867691186905 PathPoint;PointKind.SMOOTHPOINT 2610.82005504454,198.970755909919 2621.43098133256,199.660230311393 2600.20889295815,198.281988903522 PathPoint;PointKind.SMOOTHPOINT 2636.75740326299,199.961816412449 2647.77461012866,196.502654487133 2622.86086259947,204.325500842571 PathPoint;PointKind.SMOOTHPOINT 2656.70924586154,201.944173215866 2659.84229869685,201.021258439064 2653.57642882459,202.866852194309 PathPoint;PointKind.SMOOTHPOINT 2671.67324570963,197.979931205749 2678.82218044742,201.57302659893 2665.36658272076,194.810093866825 PathPoint;PointKind.SMOOTHPOINT 2681.64893121055,202.935233718395 2690.82974043331,204.189445189476 2676.66085266173,202.253776461124 PathPoint;PointKind.SMOOTHPOINT 2700.60311093966,197.979931205749 2707.17245330376,199.97902969265 2692.41430542565,195.488014148712 PathPoint;PointKind.SMOOTHPOINT 2716.5647736572,200.953112713337 2726.73122003293,199.292384871483 2706.3980914831,202.613840555191 PathPoint;PointKind.CORNERPOINT 2740.50679613677,200.953112713337 2740.50679613677,200.953112713337 2740.50679613677,200.953112713337 PathPoint;PointKind.SMOOTHPOINT 2760.45863873532,197.979931205749 2766.52242941138,198.402010268211 2754.39508385762,197.558087941646 PathPoint;PointKind.SMOOTHPOINT 2779.4130542628,199.961816412449 2784.88027508311,199.84603941822 2773.94559764412,200.078300801754 PathPoint;PointKind.SMOOTHPOINT 2799.36489686135,196.989106501579 2808.3077855369,198.24331797266 2790.42130079072,195.734659232139 PathPoint;PointKind.SMOOTHPOINT 2837.27325631958,200.953112713337 2854.23211030983,201.568546430111 2820.31393073262,200.337678996563 PathPoint;PointKind.SMOOTHPOINT 2876.17904284889,197.979931205749 2884.49895225215,198.072835759163 2867.85960504235,197.887026652336 PathPoint;PointKind.SMOOTHPOINT 2908.10213248559,198.970755909919 2919.94817059354,198.490906249523 2896.25562278092,199.451077167034 PathPoint;PointKind.SMOOTHPOINT 2939.02732345449,198.970755909919 2959.92235950087,199.633113500118 2918.13252320648,198.309105714798 PathPoint;PointKind.SMOOTHPOINT 2992.89734563026,198.970755909919 3002.90415651495,200.016050035 2982.89006314884,197.925697583198 PathPoint;PointKind.SMOOTHPOINT 3018.83445805034,196.989106501579 3040.02942961312,196.919310187339 2997.63948648755,197.05866701746 PathPoint;PointKind.SMOOTHPOINT 3052.75263762755,198.970755909919 3068.60889847729,199.044560796261 3036.89637677781,198.897422620296 PathPoint;PointKind.SMOOTHPOINT 3083.67806439481,197.979931205749 3105.71837308521,198.355322193145 3061.63751990606,197.604304419994 PathPoint;PointKind.SMOOTHPOINT 3129.56725521181,200.953112713337 3141.11335780335,201.138921820163 3118.02091682191,200.767067808151 PathPoint;PointKind.SMOOTHPOINT 3161.49010905015,198.970755909919 3184.27082459709,199.199480318069 3138.70915770485,198.742503098488 PathPoint;PointKind.SMOOTHPOINT 3209.37438980766,200.953112713337 3227.02318980499,200.941322795391 3191.72558981033,200.964666832924 PathPoint;PointKind.SMOOTHPOINT 3240.29958077656,199.961816412449 3252.91738692319,198.866533035278 3227.68177462993,201.057807184696 PathPoint;PointKind.SMOOTHPOINT 3264.24160325614,199.961816412449 3276.30245367183,200.178750902652 3252.18098863881,199.745117720604 PathPoint;PointKind.SMOOTHPOINT 3283.19601878361,199.961816412449 3298.64316947536,199.179909054279 3267.74886809187,200.743959568977 PathPoint;PointKind.SMOOTHPOINT 3307.13827706155,202.935233718395 3317.69096115417,203.314397479534 3296.58559296893,202.555834158897 PathPoint;PointKind.SMOOTHPOINT 3325.09502971959,199.961816412449 3341.90202956473,198.607154840469 3308.28779407608,201.316949581146 PathPoint;PointKind.SMOOTHPOINT 3350.03447927024,201.944173215866 3360.58739916122,201.831697398662 3339.48179517762,202.05641323471 PathPoint;PointKind.SMOOTHPOINT 3380.9599060375,200.953112713337 3396.6093717238,199.091013072967 3365.31020455284,202.815212353706 PathPoint;PointKind.SMOOTHPOINT 3413.88042274528,200.953112713337 3425.51636451272,201.81259773159 3402.24448097783,200.093627695083 PathPoint;PointKind.SMOOTHPOINT 3437.82244522485,200.953112713337 3447.28385449834,200.953112713337 3428.360800153,200.953112713337 PathPoint;PointKind.SMOOTHPOINT 3463.7597934433,201.944173215866 3477.04019298702,202.532725919723 3450.47939389957,201.355620512008 PathPoint;PointKind.SMOOTHPOINT 3491.69223160225,199.961816412449 3508.1137011256,201.282051424026 3475.27123367563,198.64181719923 PathPoint;PointKind.SMOOTHPOINT 3514.63682701075,203.926058422565 3526.21051801064,203.810045629978 3503.06313601086,204.042307013511 PathPoint;PointKind.SMOOTHPOINT 3536.58399534817,200.953112713337 3547.48731160502,201.332512272834 3525.68067909133,200.57347735548 PathPoint;PointKind.SMOOTHPOINT 3572.4972648659,201.944173215866 3591.89191593515,202.033069197178 3553.10261379665,201.854805637836 PathPoint;PointKind.SMOOTHPOINT 3601.42736589429,197.979931205749 3614.83957672235,202.915662454605 3597.48080871023,196.527413314819 PathPoint;PointKind.SMOOTHPOINT 3615.39370287295,201.944173215866 3622.42733221174,201.630561398506 3608.3598377358,202.257549234867 PathPoint;PointKind.SMOOTHPOINT 3628.36214118381,197.979931205749 3639.83467468642,198.301088570594 3616.88984347956,197.658538042545 PathPoint;PointKind.SMOOTHPOINT 3655.29738807005,198.970755909919 3680.20948501071,200.345224544048 3630.38458373431,197.596758872509 PathPoint;PointKind.SMOOTHPOINT 3685.22491616952,196.989106501579 3706.74694006034,196.040253905296 3663.7028922787,197.937251702785 PathPoint;PointKind.SMOOTHPOINT 3716.15034293678,196.989106501579 3721.15681375783,196.048978444576 3701.69613914724,199.130391398906 PathPoint;PointKind.SMOOTHPOINT 3729.11901704601,195.997810200691 3735.35777010664,195.192794603347 3722.88002818701,196.803061596393 PathPoint;PointKind.SMOOTHPOINT 3740.09236541636,197.979931205749 3747.58603735932,199.478193978309 3732.59869347339,196.481668433189 PathPoint;PointKind.SMOOTHPOINT 3752.06337665614,197.979931205749 3760.11046735462,197.771013859749 3744.01652175603,198.189084350109 PathPoint;PointKind.SMOOTHPOINT 3763.03696082485,201.944173215866 3768.08729014123,204.584407440662 3757.98663150848,199.303938991069 PathPoint;PointKind.SMOOTHPOINT 3770.02012931418,216.809609157085 3769.79423448343,231.334552268028 3770.24602414494,202.284666046142 PathPoint;PointKind.SMOOTHPOINT 3771.01779218362,250.504958847999 3772.67003130585,260.852734030723 3769.36555306139,240.156947866916 PathPoint;PointKind.SMOOTHPOINT 3771.01779218362,275.28099981451 3769.81356994911,284.24676081562 3772.22177861977,266.315003015041 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,476.461801659107 3773.95607557195,497.981938885689 3774.06501441518,454.941428634166 PathPoint;PointKind.SMOOTHPOINT 3773.01288212413,567.637245706558 3772.4205566389,579.765770095825 3773.604971811,555.508721317291 PathPoint;PointKind.SMOOTHPOINT 3773.01288212413,713.320074199676 3773.51937700561,723.288449822903 3772.50615144429,703.35169857645 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,747.01542389059 3773.74149906257,759.197946104049 3774.2793551262,734.832430080414 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,792.603028015137 3775.06244148625,803.570481285095 3772.95817690416,781.635810543537 PathPoint;PointKind.SMOOTHPOINT 3775.00797206464,843.145934652328 3776.30179767669,851.225329622269 3773.71414645259,835.066775480747 PathPoint;PointKind.SMOOTHPOINT 3773.01288212413,858.011606391907 3772.95063135657,864.747422312736 3773.07536869005,851.275554672718 PathPoint;PointKind.SMOOTHPOINT 3775.00797206464,878.823405348301 3775.88891474491,887.735168525219 3774.1275009811,869.911877969742 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,912.518519240856 3774.20154166675,929.683696576595 3773.81954832038,895.353577703476 PathPoint;PointKind.SMOOTHPOINT 3775.00797206464,950.178110941887 3775.39774675695,959.06252150917 3774.61843317069,941.293464576244 PathPoint;PointKind.SMOOTHPOINT 3773.01288212413,972.972030903339 3772.96218547631,983.865679286957 3773.06381457031,962.078382519722 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,1002.70313858414 3772.93106009253,1015.07571427488 3775.0900298946,990.330562893391 PathPoint;PointKind.SMOOTHPOINT 3773.01288212413,1029.46106475735 3772.06214312872,1037.75362144375 3773.96362111954,1021.16897966766 PathPoint;PointKind.SMOOTHPOINT 3773.01288212413,1063.15641444826 3772.3387346073,1079.0284735837 3773.68726543933,1047.28435531282 PathPoint;PointKind.SMOOTHPOINT 3773.01288212413,1098.83388514423 3772.32317191541,1112.86318010473 3773.70259233285,1084.80435438538 PathPoint;PointKind.SMOOTHPOINT 3772.01521925469,1134.51135584021 3771.28660231625,1147.77407033586 3772.7440719915,1121.24840554619 PathPoint;PointKind.SMOOTHPOINT 3772.01521925469,1164.24222772264 3772.78675149501,1179.08856399679 3771.24368701437,1149.39636304522 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,1239.56141112471 3773.32083478485,1257.59361902618 3774.70025520229,1221.52896742487 PathPoint;PointKind.SMOOTHPOINT 3775.00797206464,1302.98786849642 3775.01245223352,1308.80690039778 3774.99641794491,1287.60744893932 PathPoint;PointKind.SMOOTHPOINT 3774.93652516097,1367.5056006732 3774.93228079045,1370.97655251646 3774.97236651199,1335.55916741037 PathPoint;PointKind.SMOOTHPOINT 3774.92473524287,1378.08210026407 3776.51236561392,1381.49174453402 3773.4146825329,1374.83869383717 PathPoint;PointKind.SMOOTHPOINT 3774.91789709037,1384.56608353758 3774.86932262781,1433.45651527548 3774.92001927563,1382.39249426508 PathPoint;PointKind.SMOOTHPOINT 3775.00797206464,1497.23148262167 3775.29635346131,1514.46999324703 3774.84762917851,1487.64910891199 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,1599.30812060022 3774.30246336567,1623.45693793201 3773.71815502474,1575.15953906679 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,1709.31347839737 3773.51230305475,1726.77222468996 3774.76250596984,1682.95523044252 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,1786.61454700613 3774.78207723389,1803.10604843044 3773.23901275325,1770.12328138018 PathPoint;PointKind.SMOOTHPOINT 3775.00797206464,1844.09487716103 3773.86623639605,1866.59452077055 3776.14970773323,1821.5952335515 PathPoint;PointKind.SMOOTHPOINT 3773.01288212413,1906.53027403021 3772.61674087604,1934.06279781246 3773.35950571621,1882.42177821779 PathPoint;PointKind.SMOOTHPOINT 3775.00797206464,1972.92991290951 3774.57952644097,1991.75935506248 3775.43688928504,1954.09999915981 PathPoint;PointKind.SMOOTHPOINT 3776.00563493408,2031.40106776857 3776.43431635611,2051.74457118416 3775.57695351204,2011.05780015135 PathPoint;PointKind.SMOOTHPOINT 3777.00329780351,2096.80964614534 3777.05022167754,2109.550067276 3776.95660972785,2084.06922501469 PathPoint;PointKind.SMOOTHPOINT 3776.00563493408,2173.11941845322 3776.15041512832,2197.66178324604 3775.87264465793,2150.58558408165 PathPoint;PointKind.SMOOTHPOINT 3775.00797206464,2244.47435984516 3775.47579601476,2271.78971333885 3774.54038391288,2217.15877055311 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,2310.87399872446 3772.79476863932,2335.01880748415 3775.22632134781,2286.72871836805 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,2372.31833509111 3773.73772628878,2398.1896594348 3774.28312789999,2346.44653915071 PathPoint;PointKind.SMOOTHPOINT 3775.00797206464,2433.76290725613 3773.55451096154,2481.63445428514 3776.4616689661,2385.89088863039 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,2501.1533708396 3774.08930164646,2509.83593801165 3773.71060947716,2468.06166494751 PathPoint;PointKind.SMOOTHPOINT 3774.10227055637,2525.47408517504 3774.09967677439,2527.92921768808 3774.11005190231,2517.90142087841 PathPoint;PointKind.SMOOTHPOINT 3774.08670786448,2532.68810016775 3771.74499433189,2536.73369261169 3775.2685292546,2530.64608637953 PathPoint;PointKind.SMOOTHPOINT 3774.05652567415,2540.1039585557 3773.98602196392,2555.01183820152 3774.06807979388,2537.68325260305 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,2580.43632465506 3774.25200251621,2602.50233508253 3773.87472513708,2568.04865786934 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,2626.02416457796 3774.5446282834,2640.95939683342 3773.4766975021,2611.0889323225 PathPoint;PointKind.SMOOTHPOINT 3775.00797206464,2651.79103024864 3775.06244148625,2671.53041826868 3774.95350264303,2632.0516422286 PathPoint;PointKind.SMOOTHPOINT 3772.01521925469,2685.48661573792 3772.72827350125,2719.11216911459 3771.30216500814,2651.86082656288 PathPoint;PointKind.SMOOTHPOINT 3773.01288212413,2743.95777059698 3773.71815502474,2770.97884773874 3772.30760922352,2716.93669345522 PathPoint;PointKind.SMOOTHPOINT 3775.00797206464,2809.36634897375 3774.5092585291,2828.68365793133 3775.50692139854,2790.04856841946 PathPoint;PointKind.SMOOTHPOINT 3775.00797206464,2861.89114081764 3775.57695351204,2889.191167418 3774.43899061724,2834.59111421728 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,2933.24631800795 3774.73138058607,2969.41495668554 3773.28947360271,2897.07697193527 PathPoint;PointKind.SMOOTHPOINT 3775.00797206464,3007.57396931076 3775.60831469418,3039.69725134277 3774.40810103182,2975.45021568203 PathPoint;PointKind.SMOOTHPOINT 3774.01054499357,3113.61484929943 3773.50405011209,3134.26819175863 3774.51703987505,3092.96221423531 PathPoint;PointKind.SMOOTHPOINT 3773.01288212413,3228.57550960922 3773.28947360271,3257.62916860485 3772.73605484719,3199.52185061359 PathPoint;PointKind.SMOOTHPOINT 3773.01288212413,3323.71495986843 3772.69337534368,3347.91447384739 3773.33262470294,3299.51591748619 PathPoint;PointKind.SMOOTHPOINT 3772.01521925469,3410.92639770412 3771.98032109712,3439.53109662437 3772.05035321063,3382.32169878387 PathPoint;PointKind.SMOOTHPOINT 3772.01521925469,3478.31709708595 3772.86857352661,3505.07525905752 3771.16186498278,3451.55893511438 PathPoint;PointKind.SMOOTHPOINT 3773.01288212413,3547.68968167448 3771.78932442394,3564.03050794745 3774.23667562268,3531.34932699823 PathPoint;PointKind.SMOOTHPOINT 3771.01779218362,3601.20600561762 3769.7591005275,3624.24774965429 3772.27624804138,3578.16426158094 PathPoint;PointKind.SMOOTHPOINT 3771.01779218362,3661.65928148174 3770.58132941564,3683.10985819244 3771.4542549516,3640.20870477104 PathPoint;PointKind.SMOOTHPOINT 3768.02480357531,3707.24688560629 3766.37280025145,3716.83609746838 3769.67704269754,3697.65790954256 PathPoint;PointKind.SMOOTHPOINT 3768.02480357531,3740.9422352972 3767.11556509161,3755.66689961815 3769.18257353252,3722.2019249239 PathPoint;PointKind.SMOOTHPOINT 3763.03696082485,3770.67357877636 3759.24909593839,3776.12429364109 3766.82482571132,3765.22286391163 PathPoint;PointKind.SMOOTHPOINT 3718.14519707893,3775.62864549065 3711.29077449523,3775.63312565947 3741.9521070971,3775.61308279896 PathPoint;PointKind.SMOOTHPOINT 3625.86055636182,3775.44684495592 3622.10924022146,3775.438356215 3676.96018358296,3775.56285774851 PathPoint;PointKind.SMOOTHPOINT 3614.33991999337,3775.42043553972 3609.52680382912,3773.80333039427 3618.20041077531,3776.71803390884 PathPoint;PointKind.SMOOTHPOINT 3598.67418422009,3775.38412259245 3377.96974700954,3774.87220435524 3604.03435258407,3775.39661990547 PathPoint;PointKind.SMOOTHPOINT 2890.14537982755,3773.64652448559 2840.42163604842,3773.54206581259 2928.4298376731,3773.72716752434 PathPoint;PointKind.SMOOTHPOINT 2667.68283003025,3773.64652448559 2643.95892103549,3774.50200093174 2691.40673902501,3772.79104803944 PathPoint;PointKind.SMOOTHPOINT 2578.8972012062,3774.63758498812 2571.9628429778,3774.49775656128 2619.7207358133,3775.46240764761 PathPoint;PointKind.SMOOTHPOINT 2551.6096715672,3774.2100825634 2548.167251281,3774.16551667356 2562.56274127842,3774.35156157875 PathPoint;PointKind.SMOOTHPOINT 2540.85066390786,3774.07803548241 2537.48912245982,3775.92480822945 2546.55108930815,3770.94686907434 PathPoint;PointKind.SMOOTHPOINT 2528.95888091769,3773.94669579649 2475.58214891514,3773.38667469406 2533.03536299919,3773.98937529945 PathPoint;PointKind.SMOOTHPOINT 2386.36217950837,3773.64652448559 2360.93934331571,3774.51001807594 2404.70847106036,3773.02354522133 PathPoint;PointKind.SMOOTHPOINT 2278.62260675357,3773.64652448559 2222.2547725296,3773.10843263054 2334.99020517917,3774.18461634064 PathPoint;PointKind.SMOOTHPOINT 2135.96695575376,3774.63758498812 2083.80411371855,3773.08155161762 2188.13003358732,3776.19385415697 PathPoint;PointKind.SMOOTHPOINT 1788.80574341305,3774.63758498812 1748.30595995692,3773.36026527786 1829.30529107082,3775.91537629509 PathPoint;PointKind.SMOOTHPOINT 1579.31163192661,3773.64652448559 1577.15572750325,3773.65501322651 1607.43506675875,3773.53805724049 PathPoint;PointKind.SMOOTHPOINT 1568.95206669244,3773.68684600496 1565.72752409269,3773.69934331799 1573.63266417726,3773.66868953133 PathPoint;PointKind.SMOOTHPOINT 1557.69906146481,3773.73046870136 1554.13237544186,3775.09739178801 1562.0427030904,3772.06667548084 PathPoint;PointKind.SMOOTHPOINT 1545.11473868557,3773.77927896166 1466.20882542912,3774.08393044138 1549.66470387788,3773.7618298831 PathPoint;PointKind.SMOOTHPOINT 1262.07771188701,3774.63758498812 1233.64656019252,3774.48690983677 1285.4785771259,3774.76185072327 PathPoint;PointKind.SMOOTHPOINT 1038.61773501864,3774.63758498812 986.30657581377,3774.60292262936 1090.92889422351,3774.67248314524 PathPoint;PointKind.SMOOTHPOINT 799.196095432739,3773.64652448559 761.548764761192,3773.19355583811 836.843426104286,3774.09949313307 PathPoint;PointKind.SMOOTHPOINT 613.644242224238,3774.63758498812 578.147864210454,3774.77694181824 649.140384439659,3774.49846395636 PathPoint;PointKind.SMOOTHPOINT 446.049141673778,3773.64652448559 413.401443670786,3773.17044759893 478.696603878408,3774.12260137224 PathPoint;PointKind.SMOOTHPOINT 287.432063754796,3774.63758498812 260.945541151355,3774.14217263603 313.919057954962,3775.13323313856 PathPoint;PointKind.SMOOTHPOINT 224.584018947555,3773.64652448559 205.333676475822,3773.79012568617 243.834361419288,3773.50339488173 PathPoint;PointKind.SMOOTHPOINT 201.639423539056,3774.63758498812 199.080775513471,3774.21196895027 206.849388346476,3775.50485135222 PathPoint;PointKind.SMOOTHPOINT 194.656255049727,3768.6914577713 192.173534096691,3765.58905876303 197.052438003925,3771.68538953447 PathPoint;PointKind.SMOOTHPOINT 189.66841229927,3758.78108854437 191.152527189421,3742.74774333143 189.373192750101,3761.96908235693 PathPoint;PointKind.SMOOTHPOINT 189.66841229927,3726.07679935598 190.91130546514,3710.01515833998 188.425047536675,3742.13844037199 PathPoint;PointKind.SMOOTHPOINT 188.670513631472,3668.59670499945 189.808476526272,3657.65259576702 187.532786535033,3679.54057843351 PathPoint;PointKind.SMOOTHPOINT 189.66841229927,3625.98181078577 189.52976286244,3603.05301416302 189.794328624554,3646.8726021924 PathPoint;PointKind.SMOOTHPOINT 189.66841229927,3534.80636673832 188.070878397017,3506.259438416 190.895978571613,3556.74481025362 PathPoint;PointKind.SMOOTHPOINT 189.66841229927,3426.78312994623 188.78369684521,3398.63540824556 190.638015163633,3457.63640201712 PathPoint;PointKind.SMOOTHPOINT 190.665839370344,3373.26704180145 190.178679954543,3357.65436086082 191.153234584507,3388.87995854044 PathPoint;PointKind.SMOOTHPOINT 189.66841229927,3321.73331046009 190.116429186986,3307.61865649366 189.219923814829,3335.8474928298 PathPoint;PointKind.SMOOTHPOINT 188.670513631472,3259.29767779255 189.342538963046,3238.00037001514 187.999431493345,3280.57258472586 PathPoint;PointKind.SMOOTHPOINT 186.675659489323,3181.99660918379 187.552357799076,3154.64635753298 185.798725381208,3209.34709663296 PathPoint;PointKind.SMOOTHPOINT 188.670513631472,3115.59720610285 188.510878140427,3088.42498221302 188.830384920878,3142.76942999268 PathPoint;PointKind.SMOOTHPOINT 187.673086560397,3048.20627092266 187.77825262983,3022.23048790598 187.567920490965,3074.18252553606 PathPoint;PointKind.SMOOTHPOINT 187.673086560397,2994.69018277788 188.218488171602,2957.2633240571 187.127449150831,3032.11774889374 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,2931.26396120453 185.543119956848,2905.7126152339 185.808864710773,2956.08103108549 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,2868.82856433535 185.562219624166,2842.61533237124 185.888328758752,2916.56476310635 PathPoint;PointKind.SMOOTHPOINT 186.159025278277,2804.37048914337 186.181190324301,2802.13653549099 185.981469111724,2822.21523734951 PathPoint;PointKind.SMOOTHPOINT 186.212787304803,2797.78204719687 187.322218597807,2795.66976549768 184.781019651006,2800.50740462923 PathPoint;PointKind.SMOOTHPOINT 186.234716552465,2790.74888954544 186.23283016557,2781.41905587816 186.235188149189,2793.05806287432 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,2763.7787448492 184.325693014069,2734.92197748327 186.092058543482,2772.61741053486 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,2685.48661573792 185.260869317587,2663.53638230467 186.094888123825,2707.43637757444 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,2630.97923129225 186.168928809479,2602.59924820805 185.186828631932,2659.35945017481 PathPoint;PointKind.SMOOTHPOINT 184.680333750451,2534.84872053051 186.457310206152,2505.28762346649 182.90335729475,2564.40934599781 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,2450.6104642024 185.873945058672,2430.22192330027 185.474502633519,2471.75733262682 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,2410.96875149631 186.231415375398,2399.55257394934 185.124577864376,2422.38516484165 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,2386.1927105298 184.134932139246,2366.00058966064 187.221296898889,2406.38530299568 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,2295.01726648235 185.105006600334,2274.61198389673 186.250750841078,2315.42278486633 PathPoint;PointKind.SMOOTHPOINT 183.682670881015,2229.60868810558 182.23321835007,2205.25873477364 185.132359210321,2253.95887723589 PathPoint;PointKind.SMOOTHPOINT 184.680333750451,2142.39748606825 185.93878960821,2106.83225539112 183.421642094329,2177.96248094702 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,2015.54433552647 185.884320186598,1991.75935506248 185.471437254813,2039.32931599045 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,1923.37783097649 186.293666142954,1894.13388270521 185.056196339409,1952.91228282595 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,1837.15745364332 185.182820059779,1798.22054223204 186.172701583271,1876.09436505461 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,1629.03969987774 187.022283081399,1586.97067886496 184.333474360013,1671.1082492938 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,1519.03434208059 185.720204526677,1489.96889316702 185.633430729477,1549.49005811834 PathPoint;PointKind.SMOOTHPOINT 186.675659489323,1434.79584995413 187.996366114639,1395.77357953691 185.354481267283,1473.81812037134 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,1344.61146640921 185.903891450641,1319.71163130426 185.451865990771,1369.51130151415 PathPoint;PointKind.SMOOTHPOINT 185.677996619887,1287.13137205267 186.020847438171,1261.75522426271 185.334910003241,1312.50728404427 PathPoint;PointKind.SMOOTHPOINT 187.673086560397,1232.623987607 188.658959511736,1214.33617428446 186.687213609059,1250.91180092955 PathPoint;PointKind.SMOOTHPOINT 187.673086560397,1169.19753023529 188.853728958711,1145.02560466433 186.492208363721,1193.36969160461 PathPoint;PointKind.SMOOTHPOINT 187.673086560397,1080.0042071929 189.407383512584,1047.60551267767 185.93878960821,1112.40266590977 PathPoint;PointKind.SMOOTHPOINT 188.670513631472,874.859399136543 189.944767979482,833.932349575996 187.396495081823,915.785977100372 PathPoint;PointKind.SMOOTHPOINT 189.66841229927,756.925557319164 189.695529110895,726.133828619957 189.641059689283,787.71752181673 PathPoint;PointKind.SMOOTHPOINT 191.66350223978,570.610191415787 190.856836043528,539.868923565387 192.470168436032,601.351930862903 PathPoint;PointKind.SMOOTHPOINT 191.66350223978,404.116035562992 194.313168433081,365.186905497551 189.013364449756,443.045165628433 PathPoint;PointKind.SMOOTHPOINT 193.658592180291,327.805791658401 193.5029652614,308.198214920997 193.814454897544,347.413839992523 PathPoint;PointKind.SMOOTHPOINT 193.658592180291,278.253945523739 193.303951443909,258.518330277443 194.013468715035,297.989560770034 PathPoint";
		
	maskSquare[1] = "PointKind.SMOOTHPOINT 192.629792690277,203.582496643066 192.629792690277,203.582496643066 191.371021270752,209.745354652405 PathPoint;PointKind.SMOOTHPOINT 193.627510070801,195.654101371765 196.966452598572,193.057959079742 191.882743835449,197.010827064514 PathPoint;PointKind.SMOOTHPOINT 216.571941375732,192.681248188019 228.278067111969,189.998481273651 204.866051673889,195.363779067993 PathPoint;PointKind.SMOOTHPOINT 233.968856334686,189.656231403351 235.696864128113,189.748992919922 219.710254669189,188.893604278564 PathPoint;PointKind.SMOOTHPOINT 244.968767166138,190.656309127808 247.08292722702,189.283769130707 243.601891994476,191.543798446655 PathPoint;PointKind.SMOOTHPOINT 252.68048286438,191.002571582794 255.159080028534,189.368977546692 250.237290859222,192.612562179565 PathPoint;PointKind.SMOOTHPOINT 264.456238746643,189.707686901093 268.549783229828,190.221061706543 260.701639652252,189.237034320831 PathPoint;PointKind.SMOOTHPOINT 276.968657970428,189.656231403351 281.51326417923,190.557646751404 271.797616481781,188.63160610199 PathPoint;PointKind.SMOOTHPOINT 292.968721389771,189.656231403351 303.786649703979,189.417836666107 286.909718513489,189.789118766785 PathPoint;PointKind.SMOOTHPOINT 320.32133102417,189.707686901093 328.46994638443,190.454971790314 315.098361968994,189.229009151459 PathPoint;PointKind.SMOOTHPOINT 358.229870796204,189.707686901093 377.469506263733,189.279520511627 339.941217899323,190.114846229553 PathPoint;PointKind.SMOOTHPOINT 396.138410568237,188.717286586761 406.01692199707,187.509026527405 386.260135173798,189.924602508545 PathPoint;PointKind.SMOOTHPOINT 426.066155433655,188.717286586761 447.229707241058,189.549307823181 404.902603626251,187.884793281555 PathPoint;PointKind.SMOOTHPOINT 466.968791484833,191.656150817871 483.374598026276,185.764968395233 461.094603538513,193.765826225281 PathPoint;PointKind.SMOOTHPOINT 501.882998943329,188.717286586761 519.819960594177,189.475429058075 483.945565223694,187.958199977875 PathPoint;PointKind.SMOOTHPOINT 548.769814968109,184.752616882324 570.20480632782,186.744747161865 526.989977359772,182.728621959686 PathPoint;PointKind.SMOOTHPOINT 588.673317432404,189.707686901093 598.177714347839,189.042069911957 579.169156551361,190.374011993408 PathPoint;PointKind.SMOOTHPOINT 613.613183498383,185.743725299835 622.606565952301,186.356942653656 597.870161533356,184.670476913452 PathPoint;PointKind.SMOOTHPOINT 638.552813529968,188.717286586761 644.988055229187,188.416814804077 629.447314739227,189.141676425934 PathPoint;PointKind.SMOOTHPOINT 657.506847381592,187.72617816925 659.827301502228,186.722323894501 652.137773036957,190.04828453064 PathPoint;PointKind.SMOOTHPOINT 674.968671798706,191.656150817871 684.196436405182,191.474168300629 671.733584403992,191.719880104065 PathPoint;PointKind.SMOOTHPOINT 699.405784606934,189.707686901093 703.153774738312,189.765751361847 684.305720329285,189.475429058075 PathPoint;PointKind.SMOOTHPOINT 711.614663600922,189.881644248962 715.462732315063,192.921767234802 707.423872947693,186.570081710815 PathPoint;PointKind.SMOOTHPOINT 725.343368053436,188.717286586761 734.082305431366,188.355445861816 720.102932453156,188.933966159821 PathPoint;PointKind.SMOOTHPOINT 751.280479431152,189.707686901093 766.731526851654,189.162211418152 744.018881320953,189.964492321014 PathPoint;PointKind.SMOOTHPOINT 786.196103096008,184.752616882324 791.618521213531,185.1451420784 774.957797527313,183.939950466156 PathPoint;PointKind.SMOOTHPOINT 808.644862174988,188.946003913879 812.859492301941,188.284635543823 800.949196815491,190.153555870056 PathPoint;PointKind.SMOOTHPOINT 842.061431407928,192.681248188019 848.43341588974,192.588486671448 830.070412158966,192.855441570282 PathPoint;PointKind.SMOOTHPOINT 858.568968772888,192.552609443665 860.129628181458,191.783373355865 853.773221969604,194.91649389267 PathPoint;PointKind.SMOOTHPOINT 863.668019771576,192.541987895966 874.26525592804,192.519092559814 862.00067281723,192.545764446259 PathPoint;PointKind.SMOOTHPOINT 900.91920375824,191.689903736115 914.744446277618,191.064412593842 883.987984657288,192.456307411194 PathPoint;PointKind.SMOOTHPOINT 936.562757492065,188.87047290802 941.610116958618,189.641125202179 926.25631570816,187.297539710999 PathPoint;PointKind.SMOOTHPOINT 964.764618873596,189.707686901093 983.746268749237,193.219170570374 955.492479801178,187.992897033691 PathPoint;PointKind.SMOOTHPOINT 1005.66607475281,188.717286586761 1009.69046115875,188.627829551697 987.650985717773,189.11571264267 PathPoint;PointKind.SMOOTHPOINT 1018.1463932991,188.854658603668 1024.75228786469,187.710363864899 1014.60304498672,189.468348026276 PathPoint;PointKind.SMOOTHPOINT 1034.59586620331,189.707686901093 1042.20042228699,190.52814245224 1028.27557325363,189.026019573212 PathPoint;PointKind.SMOOTHPOINT 1057.54100561142,190.698795318604 1069.67529773712,190.300133228302 1052.39451169968,190.867795944214 PathPoint;PointKind.SMOOTHPOINT 1099.43970680237,186.734833717346 1106.13836288452,185.921695232391 1092.74105072021,187.547972202301 PathPoint;PointKind.SMOOTHPOINT 1115.40106058121,186.734833717346 1129.19184207916,187.28479385376 1101.61004304886,186.185109615326 PathPoint;PointKind.SMOOTHPOINT 1148.32124948502,186.734833717346 1161.05648517609,187.021143436432 1135.58672189713,186.448287963867 PathPoint;PointKind.SMOOTHPOINT 1168.27300071716,190.698795318604 1188.02648305893,191.186678409576 1148.52022647858,190.211148262024 PathPoint;PointKind.SMOOTHPOINT 1188.2249879837,187.72617816925 1188.70933055878,187.739396095276 1174.64970588684,187.354187965393 PathPoint;PointKind.SMOOTHPOINT 1194.53985214233,188.584399223328 1196.69673442841,188.584635257721 1193.34717035294,188.584399223328 PathPoint;PointKind.SMOOTHPOINT 1199.96864318848,190.656309127808 1201.559278965,190.645923614502 1198.03245306015,190.669054985046 PathPoint;PointKind.SMOOTHPOINT 1203.3868932724,189.565830230713 1205.9202504158,190.043799877167 1202.32426643372,189.365200996399 PathPoint;PointKind.SMOOTHPOINT 1211.25132322311,188.584399223328 1212.02740430832,188.631842136383 1208.26241970062,188.401708602905 PathPoint;PointKind.SMOOTHPOINT 1214.16233539581,187.72617816925 1218.19309473038,188.966302871704 1213.10726165771,187.400922775269 PathPoint;PointKind.SMOOTHPOINT 1221.99301242828,190.283138751984 1223.01527738571,189.76457118988 1220.17861604691,191.204144954681 PathPoint;PointKind.SMOOTHPOINT 1230.12368917465,192.681248188019 1232.20834493637,193.278651237488 1226.14320516586,191.539785861969 PathPoint;PointKind.SMOOTHPOINT 1234.76365327835,193.699264526367 1238.81447553635,194.11869764328 1233.68285179138,193.587384223938 PathPoint;PointKind.SMOOTHPOINT 1241.72548770905,191.527984142303 1243.35648536682,191.436166763306 1237.33737230301,191.7751121521 PathPoint;PointKind.SMOOTHPOINT 1246.64066791534,189.565830230713 1248.60919475555,190.130188465118 1246.46246194839,189.514374732971 PathPoint;PointKind.SMOOTHPOINT 1254.50509786606,191.527984142303 1255.67370414734,191.723420619965 1251.43853902817,191.01578950882 PathPoint;PointKind.SMOOTHPOINT 1263.96866083145,192.656228542328 1265.98604679108,191.902334690094 1259.25127744675,194.418933391571 PathPoint;PointKind.SMOOTHPOINT 1271.2109041214,192.841987609863 1272.03537225723,192.3890376091 1269.99178647995,193.510673046112 PathPoint;PointKind.SMOOTHPOINT 1280.0636100769,194.471569061279 1284.1354393959,194.524676799774 1277.20405340195,194.43451166153 PathPoint;PointKind.SMOOTHPOINT 1287.92804002762,194.471569061279 1288.54220151901,194.849932193756 1285.96848249435,193.264961242676 PathPoint;PointKind.SMOOTHPOINT 1296.77531719208,194.471569061279 1301.59112691879,193.98321390152 1292.03197002411,194.952371120453 PathPoint;PointKind.SMOOTHPOINT 1303.53557825089,195.060946941376 1304.91165876389,194.671018123627 1300.89010477066,195.810356140137 PathPoint;PointKind.SMOOTHPOINT 1308.94808292389,191.660635471344 1308.99930238724,191.637976169586 1306.19804620743,192.863466739655 PathPoint;PointKind.SMOOTHPOINT 1313.48702430725,192.509415149689 1313.41361761093,192.67345905304 1313.51487636566,192.446630001068 PathPoint;PointKind.SMOOTHPOINT 1318.40196847916,192.509415149689 1319.86325740814,192.587778568268 1316.35082960129,192.398951053619 PathPoint;PointKind.SMOOTHPOINT 1323.31738471985,192.509415149689 1324.59763526917,193.375189304352 1321.87710285187,191.535537242889 PathPoint;PointKind.SMOOTHPOINT 1327.88771867752,193.67235660553 1331.38928890228,194.442064762115 1326.26498222351,193.315236568451 PathPoint;PointKind.SMOOTHPOINT 1335.40494203568,191.808393001556 1337.45183229446,191.910831928253 1332.77669906616,191.676449775696 PathPoint;PointKind.SMOOTHPOINT 1340.85639238358,191.689903736115 1343.72373819351,192.399895191193 1338.42759847641,191.088488101959 PathPoint;PointKind.SMOOTHPOINT 1348.51193189621,193.622553348541 1350.15142679214,193.654654026031 1346.16386175156,193.576526641846 PathPoint;PointKind.SMOOTHPOINT 1358.96872758865,194.656147956848 1361.80302858353,194.95284318924 1355.79264879227,194.323811531067 PathPoint;PointKind.SMOOTHPOINT 1366.50837421417,193.039784431458 1368.69051218033,192.948203086853 1363.7656545639,193.155205249786 PathPoint;PointKind.SMOOTHPOINT 1373.45203399658,193.490610122681 1380.65108299255,196.772196292877 1371.11057281494,192.423026561737 PathPoint;PointKind.SMOOTHPOINT 1386.74549102783,195.654101371765 1393.8848233223,194.922630786896 1379.60639476776,196.386044025421 PathPoint;PointKind.SMOOTHPOINT 1401.72376155853,193.662443161011 1404.14051771164,192.053160667419 1395.57553768158,197.755987644196 PathPoint;PointKind.SMOOTHPOINT 1406.87521219254,193.490610122681 1407.30503082275,192.538919448853 1406.35617256165,194.641041755676 PathPoint;PointKind.SMOOTHPOINT 1413.75632286072,193.490610122681 1415.62453508377,193.56826543808 1411.4247751236,193.393127918243 PathPoint;PointKind.SMOOTHPOINT 1419.66615200043,195.654101371765 1429.67778682709,195.984313488007 1416.48228406906,195.549538135529 PathPoint;PointKind.SMOOTHPOINT 2127.95485496521,196.645445823669 2151.79975748062,196.703274250031 2104.11042451859,196.587145328522 PathPoint;PointKind.SMOOTHPOINT 2268.61553907394,195.654101371765 2299.40433740616,195.034747123718 2237.82650470734,196.273691654205 PathPoint;PointKind.SMOOTHPOINT 2382.34092235565,196.645445823669 2415.35882949829,195.905714035034 2349.32301521301,197.384469509125 PathPoint;PointKind.SMOOTHPOINT 2473.12140226364,199.618062973022 2487.31745481491,199.622075557709 2458.92534971237,199.614522457123 PathPoint;PointKind.SMOOTHPOINT 2512.02742338181,198.627190589905 2521.64889335632,199.541115760803 2502.40595340729,197.7135014534 PathPoint;PointKind.SMOOTHPOINT 2528.98673057556,197.636318206787 2551.7050409317,197.701935768127 2506.26794815063,197.570464611053 PathPoint;PointKind.SMOOTHPOINT 2557.91675806046,200.609407424927 2568.48873853683,200.655670166016 2547.34454154968,200.562908649445 PathPoint;PointKind.SMOOTHPOINT 2579.86347198486,197.636318206787 2595.4861164093,197.74843454361 2564.24129962921,197.523965835571 PathPoint;PointKind.SMOOTHPOINT 2610.7889342308,198.627190589905 2621.39986038208,199.316647052765 2600.17777204514,197.938206195831 PathPoint;PointKind.SMOOTHPOINT 2636.72628164291,199.618062973022 2647.74342298508,196.158978939056 2622.82975673676,203.981866836548 PathPoint;PointKind.SMOOTHPOINT 2656.67803287506,201.600515842438 2659.81115341187,200.677621364594 2653.54538440704,202.523174285889 PathPoint;PointKind.SMOOTHPOINT 2671.64214134216,197.636318206787 2678.49492788315,201.765975952148 2668.28148365021,195.611143112183 PathPoint;PointKind.SMOOTHPOINT 2681.9686460495,201.656219959259 2691.1496758461,202.910270690918 2676.98076725006,200.974788665771 PathPoint;PointKind.SMOOTHPOINT 2698.9687871933,198.656222820282 2705.53809642792,200.655198097229 2690.78004598618,196.164171695709 PathPoint;PointKind.SMOOTHPOINT 2716.5335226059,200.609407424927 2726.69999599457,198.948669433594 2706.36704921722,202.27014541626 PathPoint;PointKind.CORNERPOINT 2740.47567129135,200.609407424927 2740.47567129135,200.609407424927 2740.47567129135,200.609407424927 PathPoint;PointKind.SMOOTHPOINT 2760.4274225235,197.636318206787 2766.49138212204,198.058347702026 2754.36393499374,197.214524745941 PathPoint;PointKind.SMOOTHPOINT 2779.38192844391,199.618062973022 2784.84919309616,199.5024061203 2773.91442775726,199.734663963318 PathPoint;PointKind.SMOOTHPOINT 2799.33367967606,196.645445823669 2808.27655076981,197.899732589722 2790.39010047913,195.390923023224 PathPoint;PointKind.SMOOTHPOINT 2837.2419834137,200.609407424927 2854.20105457306,201.224985122681 2820.28267621994,199.994065761566 PathPoint;PointKind.SMOOTHPOINT 2876.14776849747,197.636318206787 2884.46774482727,197.729079723358 2867.82850027084,197.543320655823 PathPoint;PointKind.SMOOTHPOINT 2908.07094812393,198.627190589905 2919.9170422554,198.147332668304 2896.22438192368,199.107520580292 PathPoint;PointKind.SMOOTHPOINT 2938.99617433548,198.627190589905 2959.8911190033,199.289503097534 2918.10146570206,197.965350151062 PathPoint;PointKind.SMOOTHPOINT 2992.86630392075,198.627190589905 3002.87298202515,199.672350883484 2982.85891771317,197.582030296326 PathPoint;PointKind.SMOOTHPOINT 3018.80341529846,196.645445823669 3039.99835968018,196.57557964325 2997.60823488235,196.715075969696 PathPoint;PointKind.SMOOTHPOINT 3052.72155761719,198.627190589905 3068.57764005661,198.700833320618 3036.86523914337,198.553783893585 PathPoint;PointKind.SMOOTHPOINT 3083.64701986313,197.636318206787 3105.68720340729,198.011612892151 3061.60636425018,197.260551452637 PathPoint;PointKind.SMOOTHPOINT 3129.53611850739,200.609407424927 3141.08221292496,200.795166492462 3117.98978805542,200.423412322998 PathPoint;PointKind.SMOOTHPOINT 3161.45906209946,198.627190589905 3184.23968553543,198.855907917023 3138.6779665947,198.398945331573 PathPoint;PointKind.SMOOTHPOINT 3209.34312343597,200.609407424927 3226.99212312698,200.597605705261 3191.69435977936,200.620973110199 PathPoint;PointKind.SMOOTHPOINT 3240.26834964752,199.618062973022 3252.88627624512,198.522863388062 3227.65065908432,200.714206695557 PathPoint;PointKind.SMOOTHPOINT 3264.21049833298,199.618062973022 3276.27138376236,199.834978580475 3252.14984893799,199.401383399963 PathPoint;PointKind.SMOOTHPOINT 3283.16476821899,199.618062973022 3298.6120390892,198.836317062378 3267.71773338318,200.400280952454 PathPoint;PointKind.SMOOTHPOINT 3307.10715293884,202.591624259949 3317.65977859497,202.970695495605 3296.55452728271,202.212080955505 PathPoint;PointKind.SMOOTHPOINT 3325.06394147873,199.618062973022 3341.87077045441,198.263461589813 3308.25664043427,200.973372459412 PathPoint;PointKind.SMOOTHPOINT 3350.00333547592,201.600515842438 3360.55619716644,201.487927436829 3339.45070981979,201.71263217926 PathPoint;PointKind.SMOOTHPOINT 3380.92879772186,200.609407424927 3396.57811403275,198.7473320961 3365.27900934219,202.471482753754 PathPoint;PointKind.SMOOTHPOINT 3413.84922266006,200.609407424927 3425.48524618149,201.469044685364 3402.21343517303,199.750006198883 PathPoint;PointKind.SMOOTHPOINT 3437.79137134552,200.609407424927 3447.25281000137,200.609407424927 3428.32969665527,200.609407424927 PathPoint;PointKind.SMOOTHPOINT 3463.72871875763,201.600515842438 3477.00895786285,202.188949584961 3450.44824361801,201.011846065521 PathPoint;PointKind.SMOOTHPOINT 3491.661028862,199.618062973022 3508.08264970779,200.938439369202 3475.24011611938,198.29815864563 PathPoint;PointKind.SMOOTHPOINT 3514.60569620132,203.582496643066 3526.17940664291,203.466367721558 3503.03198575974,203.698625564575 PathPoint;PointKind.SMOOTHPOINT 3536.55288219452,200.609407424927 3547.45625495911,200.98895072937 3525.64950942993,200.229864120483 PathPoint;PointKind.SMOOTHPOINT 3566.9687461853,201.656219959259 3586.36322021484,201.745204925537 3547.57403612137,201.566762924194 PathPoint;PointKind.SMOOTHPOINT 3601.39625072479,197.636318206787 3614.80843305588,202.572033405304 3597.44975566864,196.183762550354 PathPoint;PointKind.SMOOTHPOINT 3615.36264181137,201.600515842438 3622.39623069763,201.286826133728 3608.32858085632,201.913969516754 PathPoint;PointKind.SMOOTHPOINT 3631.96884155273,197.656145095825 3643.44129323959,197.977151870728 3620.49638986588,197.334666252136 PathPoint;PointKind.SMOOTHPOINT 3655.26614427567,198.627190589905 3680.17839431763,200.001618862152 3630.35342216492,197.252998352051 PathPoint;PointKind.SMOOTHPOINT 3685.19365310669,196.645445823669 3706.71574115753,195.696587562561 3663.67180109024,197.593595981598 PathPoint;PointKind.SMOOTHPOINT 3716.11911535263,196.645445823669 3721.12564086914,195.705320835114 3701.66507720947,198.786749839783 PathPoint;PointKind.SMOOTHPOINT 3729.08778905869,195.654101371765 3735.32665014267,194.849224090576 3722.8489279747,196.459450721741 PathPoint;PointKind.SMOOTHPOINT 3740.06126403809,197.636318206787 3747.55488395691,199.134428501129 3732.56764411926,196.137971878052 PathPoint;PointKind.SMOOTHPOINT 3748.96872997284,197.656145095825 3757.01585054398,197.447254657745 3740.9218454361,197.865271568298 PathPoint;PointKind.SMOOTHPOINT 3763.00569534302,201.600515842438 3768.05612325668,204.24079656601 3757.95550346375,198.960235118866 PathPoint;PointKind.SMOOTHPOINT 3770.96878767014,217.656283378601 3770.74290275574,232.181131839752 3771.19467258453,203.13143491745 PathPoint;PointKind.SMOOTHPOINT 3770.98672628403,250.161287784576 3772.6389670372,260.509035587311 3769.33448553085,239.813303947449 PathPoint;PointKind.SMOOTHPOINT 3770.98672628403,274.937345981598 3769.78247880936,283.903112411499 3772.1907377243,265.971343517303 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,476.118192672729 3773.92488241196,497.638156414032 3774.03393030167,454.59775686264 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,567.293558120728 3772.38947868347,579.42218542099 3773.5738992691,555.165166854858 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,712.97634601593 3773.48821878433,722.944786548615 3772.47492313385,703.008141517639 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,746.671671867371 3773.71032714844,758.854351043701 3774.24824953079,734.488756656647 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,792.25935459137 3775.0311756134,803.226928710938 3772.92692899704,781.292252540588 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,842.80234336853 3776.27059221268,850.881564617157 3773.68294715881,834.723122119904 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,857.668025493622 3772.91937589645,864.403738975525 3773.04423809052,850.931839942932 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,878.479650020599 3775.85776805878,887.391600608826 3774.0962433815,869.56817150116 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,912.174739837646 3774.170358181,929.340105056763 3773.78845453262,895.009846687317 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,949.834499359131 3775.3665804863,958.71883392334 3774.58719491959,940.949692726135 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,972.62834072113 3772.93094158173,983.522036075592 3773.03267240524,961.734645366669 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,1002.35946893692 3772.9000210762,1014.73215579987 3775.05879163742,989.986782073975 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,1029.11750793457 3772.58444309235,1032.58060455322 3773.93243551254,1020.82538366318 PathPoint;PointKind.SMOOTHPOINT 3772.78318405151,1040.52623033524 3772.81740903854,1041.52725219727 3772.63684272766,1036.25967264175 PathPoint;PointKind.SMOOTHPOINT 3771.96886539459,1044.65636014938 3772.0495891571,1046.81489467621 3771.92873954773,1043.58570814133 PathPoint;PointKind.SMOOTHPOINT 3773.10938358307,1050.59970617294 3773.17924976349,1054.22944307327 3773.06123256683,1048.099629879 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,1062.81283378601 3772.30757474899,1078.68473052979 3773.17500114441,1058.26020240784 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,1098.49014043808 3772.29199647903,1112.51955270767 3773.67138147354,1084.46072816849 PathPoint;PointKind.SMOOTHPOINT 3771.98397159576,1134.16768312454 3771.25533342361,1147.43045568466 3772.71284580231,1120.90467453003 PathPoint;PointKind.SMOOTHPOINT 3771.98397159576,1163.89857530594 3772.7555680275,1178.74490261078 3771.21261119843,1149.05272006989 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,1239.21785831451 3773.28971385956,1257.24994182587 3774.66909885406,1221.18530273438 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,1302.64431238174 3774.98137235641,1308.46326828003 3774.96532201767,1287.26383924484 PathPoint;PointKind.SMOOTHPOINT 3774.90536928177,1367.16195344925 3774.90112066269,1370.63283920288 3774.94124650955,1335.21540641785 PathPoint;PointKind.SMOOTHPOINT 3774.8935675621,1377.7384185791 3776.48113489151,1381.14817142487 3773.3834195137,1374.49506998062 PathPoint;PointKind.SMOOTHPOINT 3774.8867225647,1384.22251939774 3774.83809947968,1433.11279535294 3774.88884687424,1382.04887866974 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,1496.88787221909 3775.26508569717,1514.12640810013 3774.81638431549,1487.30534791946 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,1598.96448612213 3774.27138090134,1623.11316490173 3773.6869597435,1574.81580734253 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,1708.96973133087 3773.48113775253,1726.42848730087 3774.7314119339,1682.61153459549 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,1786.27099514008 3774.75100278854,1802.76248216629 3773.20780992508,1769.77950811386 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,1843.75127077103 3773.8351893425,1866.25077724457 3776.11858606339,1821.25152826309 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,1906.18661642075 3772.58562326431,1933.71908426285 3773.32842350006,1882.07806348801 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,1972.58615970612 3774.54848527908,1991.41580343246 3775.40576219559,1953.75627994537 PathPoint;PointKind.SMOOTHPOINT 3775.97436904907,2031.05730772018 3776.40324354172,2051.40087604523 3775.54573059082,2010.71421146393 PathPoint;PointKind.SMOOTHPOINT 3776.9720864296,2096.46597862244 3777.01905727386,2109.20640707016 3776.92535161972,2083.72555017471 PathPoint;PointKind.SMOOTHPOINT 3775.97436904907,2172.77566194534 3776.11929416656,2197.31804609299 3775.84148168564,2150.24193048477 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,2244.13074731827 3775.44470787048,2271.44606351852 3774.50930356979,2216.81519508362 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,2310.53029060364 3772.76359319687,2334.67519283295 3775.19521951675,2286.38515233994 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,2371.97476387024 3773.70655059814,2397.84602165222 3774.25202608109,2346.10279798508 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,2433.41923713684 3773.52338790894,2481.29078865051 3776.43062353134,2385.54721355438 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,2500.80965280533 3774.05824184418,2509.49217796326 3773.67940664291,2467.71810293198 PathPoint;PointKind.SMOOTHPOINT 3774.07122373581,2525.13040065765 3774.06862735748,2527.58563041687 3774.07901287079,2517.55770921707 PathPoint;PointKind.SMOOTHPOINT 3774.05564546585,2532.3443198204 3771.71394824982,2536.38994932175 3775.23746967316,2530.30238628387 PathPoint;PointKind.SMOOTHPOINT 3774.02543306351,2539.76028442383 3773.95485877991,2554.66821670532 3774.03699874878,2537.33951568604 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,2580.09266138077 3774.22086954117,2602.1585726738 3773.84368658066,2567.70510435104 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,2625.68058013916 3774.51355218887,2640.61565637589 3773.44549655914,2610.74526786804 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,2651.44727468491 3775.0311756134,2671.18683099747 3774.92236375809,2631.70795440674 PathPoint;PointKind.SMOOTHPOINT 3771.98397159576,2685.14283657074 3772.69703149796,2718.76853227615 3771.27091169357,2651.51714086533 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,2743.6142206192 3773.6869597435,2770.635201931 3772.27641820908,2716.59300327301 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,2809.02265548706 3774.47814702988,2828.33994626999 3775.4758644104,2789.70489263535 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,2861.54738903046 3775.54573059082,2888.84759902954 3774.40780878067,2834.24741506577 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,2932.90271043777 3774.70025539398,2969.07120466232 3773.25832128525,2896.73327207565 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,3007.23041296005 3775.57712316513,3039.35351371765 3774.37688827515,2975.10660409927 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,3113.27122449875 3773.47287654877,3133.92446994781 3774.48593616486,3092.61845111847 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,3228.23177576065 3773.25832128525,3257.28548526764 3772.70482063293,3199.17830228806 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,3323.3713388443 3772.66233444214,3347.57076501846 3773.30151557922,3299.17214870453 PathPoint;PointKind.SMOOTHPOINT 3771.98397159576,3410.58274269104 3771.94927453995,3439.18751478195 3772.01914072037,3381.97797060013 PathPoint;PointKind.SMOOTHPOINT 3771.98397159576,3477.97339439392 3772.83747196198,3504.73166942596 3771.13070726395,3451.21535539627 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,3547.34602689743 3771.75808668137,3563.68692398071 3774.2055273056,3531.00560188293 PathPoint;PointKind.SMOOTHPOINT 3770.98672628403,3600.86234092712 3769.7279548645,3623.9040184021 3772.24502563477,3577.82066345215 PathPoint;PointKind.SMOOTHPOINT 3770.98672628403,3661.31570577621 3770.5500626564,3682.76627540588 3771.42315387726,3639.86513614655 PathPoint;PointKind.SMOOTHPOINT 3767.99357414246,3706.90315246582 3767.17123031616,3711.67576789856 3769.64581489563,3697.31425523758 PathPoint;PointKind.SMOOTHPOINT 3767.80333042145,3720.25231361389 3768.15549373627,3725.14695882797 3767.45423555374,3715.40251493454 PathPoint;PointKind.SMOOTHPOINT 3767.99357414246,3740.59847831726 3767.60482549667,3746.89469575882 3768.57492685318,3731.18566274643 PathPoint;PointKind.SMOOTHPOINT 3767.96879053116,3758.65628957748 3767.32040405273,3764.66572523117 3768.45313310623,3754.16691541672 PathPoint;PointKind.SMOOTHPOINT 3763.00569534302,3770.32984256744 3759.21805143356,3775.78058481216 3765.17390727997,3767.20970392227 PathPoint;PointKind.SMOOTHPOINT 3718.11407804489,3775.28491258621 3711.25963926315,3775.28939723969 3741.92097902298,3775.26933431625 PathPoint;PointKind.SMOOTHPOINT 3625.82935094833,3775.10316610336 3622.07805633545,3775.0946688652 3676.92914485931,3775.21929502487 PathPoint;PointKind.SMOOTHPOINT 3614.30874824524,3775.07673025131 3609.49553489685,3773.45965862274 3618.16932678223,3776.37444734573 PathPoint;PointKind.SMOOTHPOINT 3598.64314556122,3775.04038095474 3377.93847799301,3774.52842235565 3604.00325059891,3775.05289077759 PathPoint;PointKind.SMOOTHPOINT 2890.11415958405,3773.30293178558 2840.39044618607,3773.19836854935 2928.39870214462,3773.3834195137 PathPoint;PointKind.SMOOTHPOINT 2667.65174388885,3773.30293178558 2643.92769098282,3774.15832042694 2691.3755607605,3772.44730710983 PathPoint;PointKind.SMOOTHPOINT 2578.86599063873,3774.2938041687 2571.93177223206,3774.15407180786 2619.68955516815,3775.11874437332 PathPoint;PointKind.SMOOTHPOINT 2555.96876621246,3773.65627527237 2552.52644062042,3773.61166477203 2566.92194223404,3773.79789590836 PathPoint;PointKind.SMOOTHPOINT 2540.81960678101,3773.73440265656 2537.36005067825,3775.39041996002 2544.65492963791,3771.89829111099 PathPoint;PointKind.SMOOTHPOINT 2528.92772197723,3773.60293149948 2475.55090427399,3773.04305791855 2533.0042719841,3773.64565372467 PathPoint;PointKind.SMOOTHPOINT 2386.33108377457,3773.30293178558 2360.90829133987,3774.16634559631 2404.67732906342,3772.67980098724 PathPoint;PointKind.SMOOTHPOINT 2278.59153270721,3773.30293178558 2222.22368717194,3772.76477336884 2334.9591422081,3773.84085416794 PathPoint;PointKind.SMOOTHPOINT 2135.93588590622,3774.2938041687 2083.77299308777,3772.737865448 2188.09877872467,3775.85021495819 PathPoint;PointKind.SMOOTHPOINT 1788.77461194992,3774.2938041687 1748.27488660812,3773.0166220665 1829.27410125732,3775.57169437408 PathPoint;PointKind.SMOOTHPOINT 1579.280397892,3773.30293178558 1577.1244597435,3773.31142902374 1607.40389585495,3773.19435596466 PathPoint;PointKind.SMOOTHPOINT 1568.9208483696,3773.34329366684 1565.69638252258,3773.35556745529 1573.60141038895,3773.32511901855 PathPoint;PointKind.SMOOTHPOINT 1557.96885251999,3772.65619754791 1554.40213680267,3774.02330875397 1562.31259346008,3770.99239110947 PathPoint;PointKind.SMOOTHPOINT 1545.08349895477,3773.43558311462 1466.17767333984,3773.74030351639 1549.63353395462,3773.41811656952 PathPoint;PointKind.SMOOTHPOINT 1262.04663276672,3774.2938041687 1233.6153459549,3774.14321422577 1285.44731855392,3774.41819429398 PathPoint;PointKind.SMOOTHPOINT 1038.58649969101,3774.2938041687 986.27537727356,3774.25934314728 1090.89762210846,3774.32873725891 PathPoint;PointKind.SMOOTHPOINT 799.165012836456,3773.30293178558 761.517527103424,3772.84998178482 836.812262535095,3773.75588178635 PathPoint;PointKind.SMOOTHPOINT 613.613183498383,3774.2938041687 578.116679191589,3774.43330049515 649.109215736389,3774.15477991104 PathPoint;PointKind.SMOOTHPOINT 446.017906665802,3773.30293178558 413.370337486267,3772.82685041428 478.665475845337,3773.77901315689 PathPoint;PointKind.SMOOTHPOINT 287.400906085968,3774.2938041687 260.914306640625,3773.79860401154 313.887977600098,3774.78947639465 PathPoint;PointKind.SMOOTHPOINT 224.552972316742,3773.30293178558 205.30247926712,3773.44644069672 243.80322933197,3773.15965890884 PathPoint;PointKind.SMOOTHPOINT 201.608304977417,3774.2938041687 199.049692153931,3773.86823415756 206.818292140961,3775.16123056412 PathPoint;PointKind.SMOOTHPOINT 194.624991416931,3768.34786176682 192.142381668091,3765.24542570114 197.02121257782,3771.34172201157 PathPoint;PointKind.SMOOTHPOINT 189.637348651886,3758.43748569489 191.121296882629,3742.40414142609 189.342069625854,3761.62536621094 PathPoint;PointKind.SMOOTHPOINT 189.637348651886,3725.73303222656 190.880069732666,3709.67159986496 188.393919467926,3741.79470062256 PathPoint;PointKind.SMOOTHPOINT 188.639395236969,3668.25299263 189.777317047119,3657.30902194977 187.501709461212,3679.19696331024 PathPoint;PointKind.SMOOTHPOINT 189.637348651886,3625.63816308975 189.498560428619,3602.70931005478 189.763154983521,3646.52885913849 PathPoint;PointKind.SMOOTHPOINT 189.637348651886,3534.46279764175 188.039631843567,3505.9158539772 190.864727497101,3556.4012503624 PathPoint;PointKind.SMOOTHPOINT 189.637348651886,3426.43953323364 188.752455711365,3398.29172372818 190.606741905212,3457.29276895523 PathPoint;PointKind.SMOOTHPOINT 190.634593963623,3372.92345523834 190.14741897583,3357.31072425842 191.122004985809,3388.53618621826 PathPoint;PointKind.SMOOTHPOINT 189.637348651886,3321.38959407806 190.085341930389,3307.27497339249 189.188883304596,3335.50374269485 PathPoint;PointKind.SMOOTHPOINT 188.639395236969,3258.95401239395 189.311385154724,3237.65662908554 187.968349456787,3280.228972435 PathPoint;PointKind.SMOOTHPOINT 186.644432544708,3181.65298461914 187.521300315857,3154.30273532867 185.76756477356,3209.003469944 PathPoint;PointKind.SMOOTHPOINT 188.639395236969,3115.25344133377 188.479835987091,3088.08139801025 188.79919052124,3142.42572069168 PathPoint;PointKind.SMOOTHPOINT 187.641913890839,3047.8625535965 187.747185230255,3021.88673257828 187.536878585815,3073.8388466835 PathPoint;PointKind.SMOOTHPOINT 187.641913890839,2994.3464756012 188.187389373779,2956.91968202591 187.096202373505,3031.77397727966 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2930.92025756836 185.511939525604,2905.36906242371 185.777714252472,2955.73738574982 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2868.48491191864 185.531058311462,2842.27164030075 185.857257843018,2916.22097969055 PathPoint;PointKind.SMOOTHPOINT 186.127753257751,2804.02675151825 186.149940490723,2801.79292201996 185.950255393982,2821.87165975571 PathPoint;PointKind.SMOOTHPOINT 186.181569099426,2797.43832349777 187.291166782379,2795.32605171204 184.749784469604,2800.16381263733 PathPoint;PointKind.SMOOTHPOINT 186.203520298004,2790.4052066803 186.201632022858,2781.07547521591 186.203992366791,2792.71433115005 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2763.43497276306 184.294474124908,2734.57835197449 186.060955524445,2772.27375268936 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2685.14283657074 185.229642391205,2663.19281816483 186.063787937164,2707.09261894226 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2630.63565015793 186.137666702271,2602.25558280945 185.155763626099,2659.01571750641 PathPoint;PointKind.SMOOTHPOINT 184.649233818054,2534.50497865677 186.426100730896,2504.94403123856 182.872130870819,2564.06569004059 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2450.26690006256 185.842859745026,2429.8782491684 185.443253517151,2471.41369342804 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2410.62515974045 186.200215816498,2399.2088842392 185.093450546265,2422.0414352417 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2385.84910154343 184.103758335114,2365.6568312645 187.190144062042,2406.04160785675 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2294.67350006104 185.07385969162,2274.26832675934 186.219570636749,2315.07914543152 PathPoint;PointKind.SMOOTHPOINT 183.651516437531,2229.26506519318 182.20202922821,2204.91504907608 185.101239681244,2253.61531734467 PathPoint;PointKind.SMOOTHPOINT 184.968824386597,2135.65618515015 186.227123737335,2100.0909948349 183.710052967072,2171.221139431 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2015.20075321198 185.853245258331,1991.41580343246 185.440185070038,2038.98570299149 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,1923.03427934647 186.262528896332,1893.79032611847 185.025000572205,1952.56855487823 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,1836.81374788284 185.151751041412,1797.87680625916 186.141443252563,1875.75068950653 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,1628.69608640671 186.991167068481,1586.62696838379 184.302263259888,1670.76449632645 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,1518.69060516357 185.675511360168,1498.93334627151 185.602340698242,1549.14635896683 PathPoint;PointKind.SMOOTHPOINT 185.825393199921,1466.08113527298 185.854425430298,1464.28774595261 185.515716075897,1485.14350891113 PathPoint;PointKind.SMOOTHPOINT 186.968743801117,1459.65627908707 186.554267406464,1457.97524213791 187.422873973846,1461.49781942368 PathPoint;PointKind.SMOOTHPOINT 186.100845336914,1452.77682065964 186.238925457001,1447.22599983215 186.033575534821,1455.47870635986 PathPoint;PointKind.SMOOTHPOINT 186.644432544708,1434.45229053497 187.965281009674,1395.42990446091 186.416659355164,1441.17903470993 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,1344.26779747009 185.872836112976,1319.36805725098 185.420594215393,1369.16753768921 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,1286.78775787354 185.989673137665,1261.41146421432 185.303757190704,1312.16357946396 PathPoint;PointKind.SMOOTHPOINT 187.641913890839,1232.28033542633 188.627829551697,1213.99239063263 186.65599822998,1250.56804418564 PathPoint;PointKind.SMOOTHPOINT 187.641913890839,1168.8538813591 188.822557926178,1144.68183517456 186.461033821106,1193.02592754364 PathPoint;PointKind.SMOOTHPOINT 187.641913890839,1079.66049671173 189.376294612885,1047.26194381714 185.907533168793,1112.05904960632 PathPoint;PointKind.SMOOTHPOINT 188.639395236969,874.515688419342 189.913508892059,833.588740825653 187.365281581879,915.442399978638 PathPoint;PointKind.SMOOTHPOINT 189.637348651886,756.581811904907 189.664256572723,725.790181159973 189.609968662262,787.373914718628 PathPoint;PointKind.SMOOTHPOINT 191.632311344147,570.266411304474 190.825781822205,539.525291919708 192.439076900482,601.008238792419 PathPoint;PointKind.SMOOTHPOINT 191.632311344147,403.77247095108 194.282033443451,364.843318462372 188.982117176056,442.701387405396 PathPoint;PointKind.SMOOTHPOINT 193.627510070801,327.462079524994 193.471727371216,307.854466438293 193.783292770386,347.070164680481 PathPoint;PointKind.SMOOTHPOINT 193.627510070801,277.910199165344 193.272750377655,258.174655437469 193.982269763947,297.645978927612 PathPoint";
		
	maskSquare[2] = "PointKind.SMOOTHPOINT 192.629792690277,203.582496643066 192.629792690277,203.582496643066 192.313506603241,205.130882263184 PathPoint;PointKind.SMOOTHPOINT 193.627510070801,195.654101371765 195.057406425476,194.542143344879 191.882743835449,197.010827064514 PathPoint;PointKind.SMOOTHPOINT 201.000044345856,195.000050067902 205.063140392303,194.879200458527 197.956144809723,195.09045124054 PathPoint;PointKind.SMOOTHPOINT 216.571941375732,192.681248188019 228.278067111969,189.998481273651 209.879422187805,194.214763641357 PathPoint;PointKind.SMOOTHPOINT 234.000012874603,190.999975204468 235.72802066803,191.092736721039 219.741411209106,190.237348079681 PathPoint;PointKind.SMOOTHPOINT 244.968767166138,190.656309127808 247.08292722702,189.283769130707 243.601891994476,191.543798446655 PathPoint;PointKind.SMOOTHPOINT 252.68048286438,191.002571582794 255.159080028534,189.368977546692 250.237290859222,192.612562179565 PathPoint;PointKind.SMOOTHPOINT 264.456238746643,189.707686901093 268.549783229828,190.221061706543 260.701639652252,189.237034320831 PathPoint;PointKind.SMOOTHPOINT 276.968657970428,189.656231403351 281.51326417923,190.557646751404 271.797616481781,188.63160610199 PathPoint;PointKind.SMOOTHPOINT 292.968721389771,189.656231403351 303.786649703979,189.417836666107 286.909718513489,189.789118766785 PathPoint;PointKind.SMOOTHPOINT 320.32133102417,189.707686901093 328.46994638443,190.454971790314 315.098361968994,189.229009151459 PathPoint;PointKind.SMOOTHPOINT 358.229870796204,189.707686901093 377.469506263733,189.279520511627 339.941217899323,190.114846229553 PathPoint;PointKind.SMOOTHPOINT 396.138410568237,188.717286586761 401.659963130951,188.041756153107 386.260135173798,189.924602508545 PathPoint;PointKind.SMOOTHPOINT 408.000082969666,189.000055789948 411.521480083466,189.092817306519 403.536908626556,188.882510662079 PathPoint;PointKind.SMOOTHPOINT 426.066155433655,188.717286586761 447.229707241058,189.549307823181 416.732175350189,188.35001707077 PathPoint;PointKind.SMOOTHPOINT 466.968791484833,191.656150817871 483.374598026276,185.764968395233 461.094603538513,193.765826225281 PathPoint;PointKind.SMOOTHPOINT 501.882998943329,188.717286586761 519.819960594177,189.475429058075 483.945565223694,187.958199977875 PathPoint;PointKind.SMOOTHPOINT 551.0001039505,186.999900341034 572.435095310211,188.992266654968 529.220266342163,184.975905418396 PathPoint;PointKind.SMOOTHPOINT 588.673317432404,189.707686901093 598.177714347839,189.042069911957 579.169156551361,190.374011993408 PathPoint;PointKind.SMOOTHPOINT 613.613183498383,185.743725299835 622.606565952301,186.356942653656 597.870161533356,184.670476913452 PathPoint;PointKind.SMOOTHPOINT 638.552813529968,188.717286586761 641.665871143341,188.571889400482 629.447314739227,189.141676425934 PathPoint;PointKind.SMOOTHPOINT 648.000090122223,187.999978065491 651.377506256104,188.098876476288 644.834868907928,187.907452583313 PathPoint;PointKind.SMOOTHPOINT 657.506847381592,187.72617816925 659.827301502228,186.722323894501 654.735095500946,188.924760818481 PathPoint;PointKind.SMOOTHPOINT 674.968671798706,191.656150817871 684.196436405182,191.474168300629 671.733584403992,191.719880104065 PathPoint;PointKind.SMOOTHPOINT 699.405784606934,189.707686901093 703.153774738312,189.765751361847 684.305720329285,189.475429058075 PathPoint;PointKind.SMOOTHPOINT 711.614663600922,189.881644248962 715.462732315063,192.921767234802 707.423872947693,186.570081710815 PathPoint;PointKind.SMOOTHPOINT 725.343368053436,188.717286586761 734.082305431366,188.355445861816 720.102932453156,188.933966159821 PathPoint;PointKind.SMOOTHPOINT 751.280479431152,189.707686901093 766.731526851654,189.162211418152 744.018881320953,189.964492321014 PathPoint;PointKind.SMOOTHPOINT 786.196103096008,184.752616882324 791.618521213531,185.1451420784 774.957797527313,183.939950466156 PathPoint;PointKind.SMOOTHPOINT 808.644862174988,188.946003913879 812.859492301941,188.284635543823 800.949196815491,190.153555870056 PathPoint;PointKind.SMOOTHPOINT 842.061431407928,192.681248188019 848.43341588974,192.588486671448 830.070412158966,192.855441570282 PathPoint;PointKind.SMOOTHPOINT 858.568968772888,192.552609443665 860.129628181458,191.783373355865 853.773221969604,194.91649389267 PathPoint;PointKind.SMOOTHPOINT 863.668019771576,192.541987895966 874.26525592804,192.519092559814 862.00067281723,192.545764446259 PathPoint;PointKind.SMOOTHPOINT 900.91920375824,191.689903736115 914.744446277618,191.064412593842 883.987984657288,192.456307411194 PathPoint;PointKind.SMOOTHPOINT 936.562757492065,188.87047290802 939.715940952301,189.35174703598 926.25631570816,187.297539710999 PathPoint;PointKind.SMOOTHPOINT 952.000114917755,189.999897480011 956.067223548889,190.001785755157 945.228288173676,189.996829032898 PathPoint;PointKind.SMOOTHPOINT 964.764618873596,189.707686901093 983.746268749237,193.219170570374 961.285235881805,189.064257144928 PathPoint;PointKind.SMOOTHPOINT 1005.66607475281,188.717286586761 1009.69046115875,188.627829551697 987.650985717773,189.11571264267 PathPoint;PointKind.SMOOTHPOINT 1018.1463932991,188.854658603668 1024.75228786469,187.710363864899 1014.60304498672,189.468348026276 PathPoint;PointKind.SMOOTHPOINT 1034.59586620331,189.707686901093 1042.20042228699,190.52814245224 1028.27557325363,189.026019573212 PathPoint;PointKind.SMOOTHPOINT 1057.54100561142,190.698795318604 1069.67529773712,190.300133228302 1052.39451169968,190.867795944214 PathPoint;PointKind.SMOOTHPOINT 1099.43970680237,186.734833717346 1106.13836288452,185.921695232391 1092.74105072021,187.547972202301 PathPoint;PointKind.SMOOTHPOINT 1115.40106058121,186.734833717346 1129.19184207916,187.28479385376 1101.61004304886,186.185109615326 PathPoint;PointKind.SMOOTHPOINT 1148.32124948502,186.734833717346 1161.05648517609,187.021143436432 1135.58672189713,186.448287963867 PathPoint;PointKind.SMOOTHPOINT 1168.27300071716,190.698795318604 1188.02648305893,191.186678409576 1148.52022647858,190.211148262024 PathPoint;PointKind.SMOOTHPOINT 1188.2249879837,187.72617816925 1188.70933055878,187.739396095276 1174.64970588684,187.354187965393 PathPoint;PointKind.SMOOTHPOINT 1194.53985214233,188.584399223328 1196.69673442841,188.584635257721 1193.34717035294,188.584399223328 PathPoint;PointKind.SMOOTHPOINT 1199.96864318848,190.656309127808 1201.559278965,190.645923614502 1198.03245306015,190.669054985046 PathPoint;PointKind.SMOOTHPOINT 1203.3868932724,189.565830230713 1205.9202504158,190.043799877167 1202.32426643372,189.365200996399 PathPoint;PointKind.SMOOTHPOINT 1211.25132322311,188.584399223328 1212.02740430832,188.631842136383 1208.26241970062,188.401708602905 PathPoint;PointKind.SMOOTHPOINT 1214.16233539581,187.72617816925 1218.19309473038,188.966302871704 1213.10726165771,187.400922775269 PathPoint;PointKind.SMOOTHPOINT 1221.99301242828,190.283138751984 1223.01527738571,189.76457118988 1220.17861604691,191.204144954681 PathPoint;PointKind.SMOOTHPOINT 1230.12368917465,192.681248188019 1232.20834493637,193.278651237488 1226.14320516586,191.539785861969 PathPoint;PointKind.SMOOTHPOINT 1234.76365327835,193.699264526367 1238.81447553635,194.11869764328 1233.68285179138,193.587384223938 PathPoint;PointKind.SMOOTHPOINT 1241.72548770905,191.527984142303 1243.35648536682,191.436166763306 1237.33737230301,191.7751121521 PathPoint;PointKind.SMOOTHPOINT 1246.64066791534,189.565830230713 1248.60919475555,190.130188465118 1246.46246194839,189.514374732971 PathPoint;PointKind.SMOOTHPOINT 1254.50509786606,191.527984142303 1255.67370414734,191.723420619965 1251.43853902817,191.01578950882 PathPoint;PointKind.SMOOTHPOINT 1263.96866083145,192.656228542328 1265.98604679108,191.902334690094 1259.25127744675,194.418933391571 PathPoint;PointKind.SMOOTHPOINT 1271.2109041214,192.841987609863 1272.03537225723,192.3890376091 1269.99178647995,193.510673046112 PathPoint;PointKind.SMOOTHPOINT 1280.0636100769,194.471569061279 1284.1354393959,194.524676799774 1277.20405340195,194.43451166153 PathPoint;PointKind.SMOOTHPOINT 1287.92804002762,194.471569061279 1288.54220151901,194.849932193756 1285.96848249435,193.264961242676 PathPoint;PointKind.SMOOTHPOINT 1296.77531719208,194.471569061279 1301.59112691879,193.98321390152 1292.03197002411,194.952371120453 PathPoint;PointKind.SMOOTHPOINT 1303.53557825089,195.060946941376 1304.91165876389,194.671018123627 1300.89010477066,195.810356140137 PathPoint;PointKind.SMOOTHPOINT 1308.94808292389,191.660635471344 1308.99930238724,191.637976169586 1306.19804620743,192.863466739655 PathPoint;PointKind.SMOOTHPOINT 1313.48702430725,192.509415149689 1313.41361761093,192.67345905304 1313.51487636566,192.446630001068 PathPoint;PointKind.SMOOTHPOINT 1318.40196847916,192.509415149689 1319.86325740814,192.587778568268 1316.35082960129,192.398951053619 PathPoint;PointKind.SMOOTHPOINT 1323.31738471985,192.509415149689 1324.59763526917,193.375189304352 1321.87710285187,191.535537242889 PathPoint;PointKind.SMOOTHPOINT 1327.88771867752,193.67235660553 1331.38928890228,194.442064762115 1326.26498222351,193.315236568451 PathPoint;PointKind.SMOOTHPOINT 1335.40494203568,191.808393001556 1337.45183229446,191.910831928253 1332.77669906616,191.676449775696 PathPoint;PointKind.SMOOTHPOINT 1340.85639238358,191.689903736115 1343.72373819351,192.399895191193 1338.42759847641,191.088488101959 PathPoint;PointKind.SMOOTHPOINT 1348.51193189621,193.622553348541 1350.15142679214,193.654654026031 1346.16386175156,193.576526641846 PathPoint;PointKind.SMOOTHPOINT 1358.96872758865,194.656147956848 1361.80302858353,194.95284318924 1355.79264879227,194.323811531067 PathPoint;PointKind.SMOOTHPOINT 1366.50837421417,193.039784431458 1368.69051218033,192.948203086853 1363.7656545639,193.155205249786 PathPoint;PointKind.SMOOTHPOINT 1373.45203399658,193.490610122681 1380.65108299255,196.772196292877 1371.11057281494,192.423026561737 PathPoint;PointKind.SMOOTHPOINT 1386.74549102783,195.654101371765 1393.8848233223,194.922630786896 1379.60639476776,196.386044025421 PathPoint;PointKind.SMOOTHPOINT 1401.72376155853,193.662443161011 1404.14051771164,192.053160667419 1395.57553768158,197.755987644196 PathPoint;PointKind.SMOOTHPOINT 1406.87521219254,193.490610122681 1407.30503082275,192.538919448853 1406.35617256165,194.641041755676 PathPoint;PointKind.SMOOTHPOINT 1413.75632286072,193.490610122681 1415.62453508377,193.56826543808 1411.4247751236,193.393127918243 PathPoint;PointKind.SMOOTHPOINT 1419.66615200043,195.654101371765 1423.54254484177,195.781795978546 1416.48228406906,195.549538135529 PathPoint;PointKind.SMOOTHPOINT 1653.79692792892,196.112716197968 1654.65703725815,196.113896369934 1527.03206062317,195.950560569763 PathPoint;PointKind.SMOOTHPOINT 1656.00007295609,196.999969482422 1657.90463447571,197.451267242432 1655.16097068787,196.801228523254 PathPoint;PointKind.SMOOTHPOINT 1660.31714200974,196.120977401733 1859.98453617096,196.374478340149 1659.00266647339,196.11932516098 PathPoint;PointKind.SMOOTHPOINT 2127.95485496521,196.645445823669 2151.79975748062,196.703274250031 2113.50081682205,196.610040664673 PathPoint;PointKind.SMOOTHPOINT 2268.61553907394,195.654101371765 2299.40433740616,195.034747123718 2237.82650470734,196.273691654205 PathPoint;PointKind.SMOOTHPOINT 2382.34092235565,196.645445823669 2415.35882949829,195.905714035034 2349.32301521301,197.384469509125 PathPoint;PointKind.SMOOTHPOINT 2473.12140226364,199.618062973022 2487.31745481491,199.622075557709 2458.92534971237,199.614522457123 PathPoint;PointKind.SMOOTHPOINT 2512.02742338181,198.627190589905 2521.64889335632,199.541115760803 2502.40595340729,197.7135014534 PathPoint;PointKind.SMOOTHPOINT 2528.98673057556,197.636318206787 2551.7050409317,197.701935768127 2506.26794815063,197.570464611053 PathPoint;PointKind.SMOOTHPOINT 2557.91675806046,200.609407424927 2568.48873853683,200.655670166016 2547.34454154968,200.562908649445 PathPoint;PointKind.SMOOTHPOINT 2579.86347198486,197.636318206787 2595.4861164093,197.74843454361 2564.24129962921,197.523965835571 PathPoint;PointKind.SMOOTHPOINT 2610.7889342308,198.627190589905 2621.39986038208,199.316647052765 2600.17777204514,197.938206195831 PathPoint;PointKind.SMOOTHPOINT 2636.72628164291,199.618062973022 2647.74342298508,196.158978939056 2622.82975673676,203.981866836548 PathPoint;PointKind.SMOOTHPOINT 2656.67803287506,201.600515842438 2658.66261005402,201.015858650208 2653.54538440704,202.523174285889 PathPoint;PointKind.SMOOTHPOINT 2664.99989748001,198.999888896942 2665.62680482864,198.816962242126 2661.38762712479,200.05425453186 PathPoint;PointKind.SMOOTHPOINT 2668.99997234344,198.000047206879 2670.35905838013,197.775342464447 2668.41791152954,198.096113204956 PathPoint;PointKind.SMOOTHPOINT 2671.64214134216,197.636318206787 2678.49492788315,201.765975952148 2670.77943563461,197.116570472717 PathPoint;PointKind.SMOOTHPOINT 2681.9686460495,201.656219959259 2691.1496758461,202.910270690918 2676.98076725006,200.974788665771 PathPoint;PointKind.SMOOTHPOINT 2698.99994373322,199.999966621399 2705.56925296783,201.998941898346 2690.81120252609,197.507915496826 PathPoint;PointKind.SMOOTHPOINT 2716.5335226059,200.609407424927 2726.69999599457,198.948669433594 2706.36704921722,202.27014541626 PathPoint;PointKind.CORNERPOINT 2740.47567129135,200.609407424927 2740.47567129135,200.609407424927 2740.47567129135,200.609407424927 PathPoint;PointKind.SMOOTHPOINT 2760.4274225235,197.636318206787 2766.49138212204,198.058347702026 2754.36393499374,197.214524745941 PathPoint;PointKind.SMOOTHPOINT 2779.38192844391,199.618062973022 2784.84919309616,199.5024061203 2773.91442775726,199.734663963318 PathPoint;PointKind.SMOOTHPOINT 2799.33367967606,196.645445823669 2808.27655076981,197.899732589722 2790.39010047913,195.390923023224 PathPoint;PointKind.SMOOTHPOINT 2837.2419834137,200.609407424927 2854.20105457306,201.224985122681 2820.28267621994,199.994065761566 PathPoint;PointKind.SMOOTHPOINT 2876.14776849747,197.636318206787 2884.46774482727,197.729079723358 2867.82850027084,197.543320655823 PathPoint;PointKind.SMOOTHPOINT 2908.07094812393,198.627190589905 2919.9170422554,198.147332668304 2896.22438192368,199.107520580292 PathPoint;PointKind.SMOOTHPOINT 2938.99617433548,198.627190589905 2959.8911190033,199.289503097534 2918.10146570206,197.965350151062 PathPoint;PointKind.SMOOTHPOINT 2992.86630392075,198.627190589905 3002.87298202515,199.672350883484 2982.85891771317,197.582030296326 PathPoint;PointKind.SMOOTHPOINT 3018.80341529846,196.645445823669 3039.99835968018,196.57557964325 2997.60823488235,196.715075969696 PathPoint;PointKind.SMOOTHPOINT 3052.72155761719,198.627190589905 3068.57764005661,198.700833320618 3036.86523914337,198.553783893585 PathPoint;PointKind.SMOOTHPOINT 3083.64701986313,197.636318206787 3105.68720340729,198.011612892151 3061.60636425018,197.260551452637 PathPoint;PointKind.SMOOTHPOINT 3129.53611850739,200.609407424927 3141.08221292496,200.795166492462 3117.98978805542,200.423412322998 PathPoint;PointKind.SMOOTHPOINT 3161.45906209946,198.627190589905 3184.23968553543,198.855907917023 3138.6779665947,198.398945331573 PathPoint;PointKind.SMOOTHPOINT 3209.34312343597,200.609407424927 3226.99212312698,200.597605705261 3191.69435977936,200.620973110199 PathPoint;PointKind.SMOOTHPOINT 3240.26834964752,199.618062973022 3252.88627624512,198.522863388062 3227.65065908432,200.714206695557 PathPoint;PointKind.SMOOTHPOINT 3264.21049833298,199.618062973022 3276.27138376236,199.834978580475 3252.14984893799,199.401383399963 PathPoint;PointKind.SMOOTHPOINT 3283.16476821899,199.618062973022 3298.6120390892,198.836317062378 3267.71773338318,200.400280952454 PathPoint;PointKind.SMOOTHPOINT 3307.10715293884,202.591624259949 3317.65977859497,202.970695495605 3296.55452728271,202.212080955505 PathPoint;PointKind.SMOOTHPOINT 3325.06394147873,199.618062973022 3341.87077045441,198.263461589813 3308.25664043427,200.973372459412 PathPoint;PointKind.SMOOTHPOINT 3350.00333547592,201.600515842438 3360.55619716644,201.487927436829 3339.45070981979,201.71263217926 PathPoint;PointKind.SMOOTHPOINT 3380.92879772186,200.609407424927 3396.57811403275,198.7473320961 3365.27900934219,202.471482753754 PathPoint;PointKind.SMOOTHPOINT 3413.84922266006,200.609407424927 3425.48524618149,201.469044685364 3402.21343517303,199.750006198883 PathPoint;PointKind.SMOOTHPOINT 3437.79137134552,200.609407424927 3447.25281000137,200.609407424927 3428.32969665527,200.609407424927 PathPoint;PointKind.SMOOTHPOINT 3463.72871875763,201.600515842438 3477.00895786285,202.188949584961 3450.44824361801,201.011846065521 PathPoint;PointKind.SMOOTHPOINT 3491.661028862,199.618062973022 3508.08264970779,200.938439369202 3475.24011611938,198.29815864563 PathPoint;PointKind.SMOOTHPOINT 3514.60569620132,203.582496643066 3526.17940664291,203.466367721558 3503.03198575974,203.698625564575 PathPoint;PointKind.SMOOTHPOINT 3536.55288219452,200.609407424927 3547.45625495911,200.98895072937 3525.64950942993,200.229864120483 PathPoint;PointKind.SMOOTHPOINT 3566.9687461853,201.656219959259 3576.03270292282,201.697762012482 3547.57403612137,201.566762924194 PathPoint;PointKind.SMOOTHPOINT 3581.9998884201,201.000044345856 3583.09343576431,200.810036659241 3576.41507863998,201.970381736755 PathPoint;PointKind.SMOOTHPOINT 3588.99996042252,198.000047206879 3594.6638417244,196.964328289032 3586.1953997612,198.512949943542 PathPoint;PointKind.SMOOTHPOINT 3601.39625072479,197.636318206787 3610.17578601837,201.189579963684 3601.11843824387,197.523729801178 PathPoint;PointKind.SMOOTHPOINT 3615.36264181137,201.600515842438 3622.39623069763,201.286826133728 3608.32858085632,201.913969516754 PathPoint;PointKind.SMOOTHPOINT 3631.96884155273,197.656145095825 3643.44129323959,197.977151870728 3620.49638986588,197.334666252136 PathPoint;PointKind.SMOOTHPOINT 3655.26614427567,198.627190589905 3680.17839431763,200.001618862152 3630.35342216492,197.252998352051 PathPoint;PointKind.SMOOTHPOINT 3685.19365310669,196.645445823669 3706.71574115753,195.696587562561 3663.67180109024,197.593595981598 PathPoint;PointKind.SMOOTHPOINT 3716.11911535263,196.645445823669 3721.12564086914,195.705320835114 3701.66507720947,198.786749839783 PathPoint;PointKind.SMOOTHPOINT 3729.08778905869,195.654101371765 3735.32665014267,194.849224090576 3722.8489279747,196.459450721741 PathPoint;PointKind.SMOOTHPOINT 3740.06126403809,197.636318206787 3747.55488395691,199.134428501129 3732.56764411926,196.137971878052 PathPoint;PointKind.SMOOTHPOINT 3748.96872997284,197.656145095825 3757.01585054398,197.447254657745 3740.9218454361,197.865271568298 PathPoint;PointKind.SMOOTHPOINT 3763.00569534302,201.600515842438 3768.05612325668,204.24079656601 3757.95550346375,198.960235118866 PathPoint;PointKind.SMOOTHPOINT 3770.00010251999,219.000027179718 3769.77421760559,233.524875640869 3770.22598743439,204.475178718567 PathPoint;PointKind.SMOOTHPOINT 3770.98672628403,250.161287784576 3772.6389670372,260.509035587311 3769.33448553085,239.813303947449 PathPoint;PointKind.SMOOTHPOINT 3770.98672628403,274.937345981598 3769.78247880936,283.903112411499 3772.1907377243,265.971343517303 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,476.118192672729 3773.92488241196,497.638156414032 3774.03393030167,454.59775686264 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,567.293558120728 3772.38947868347,579.42218542099 3773.5738992691,555.165166854858 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,712.97634601593 3773.48821878433,722.944786548615 3772.47492313385,703.008141517639 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,746.671671867371 3773.71032714844,758.854351043701 3774.24824953079,734.488756656647 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,792.25935459137 3775.0311756134,803.226928710938 3772.92692899704,781.292252540588 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,842.80234336853 3776.27059221268,850.881564617157 3773.68294715881,834.723122119904 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,857.668025493622 3772.91937589645,864.403738975525 3773.04423809052,850.931839942932 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,878.479650020599 3775.85776805878,887.391600608826 3774.0962433815,869.56817150116 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,912.174739837646 3774.170358181,929.340105056763 3773.78845453262,895.009846687317 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,949.834499359131 3775.3665804863,958.71883392334 3774.58719491959,940.949692726135 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,972.62834072113 3772.93094158173,983.522036075592 3773.03267240524,961.734645366669 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,1002.35946893692 3772.9000210762,1014.73215579987 3775.05879163742,989.986782073975 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,1029.11750793457 3772.58444309235,1032.58060455322 3773.93243551254,1020.82538366318 PathPoint;PointKind.SMOOTHPOINT 3772.78318405151,1040.52623033524 3772.81740903854,1041.52725219727 3772.63684272766,1036.25967264175 PathPoint;PointKind.SMOOTHPOINT 3771.96886539459,1044.65636014938 3772.0495891571,1046.81489467621 3771.92873954773,1043.58570814133 PathPoint;PointKind.SMOOTHPOINT 3773.10938358307,1050.59970617294 3773.17924976349,1054.22944307327 3773.06123256683,1048.099629879 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,1062.81283378601 3772.30757474899,1078.68473052979 3773.17500114441,1058.26020240784 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,1098.49014043808 3772.29199647903,1112.51955270767 3773.67138147354,1084.46072816849 PathPoint;PointKind.SMOOTHPOINT 3771.98397159576,1134.16768312454 3771.25533342361,1147.43045568466 3772.71284580231,1120.90467453003 PathPoint;PointKind.SMOOTHPOINT 3771.98397159576,1163.89857530594 3772.7555680275,1178.74490261078 3771.21261119843,1149.05272006989 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,1239.21785831451 3773.28971385956,1257.24994182587 3774.66909885406,1221.18530273438 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,1302.64431238174 3774.98137235641,1308.46326828003 3774.96532201767,1287.26383924484 PathPoint;PointKind.SMOOTHPOINT 3774.90536928177,1367.16195344925 3774.90112066269,1370.63283920288 3774.94124650955,1335.21540641785 PathPoint;PointKind.SMOOTHPOINT 3774.8935675621,1377.7384185791 3776.48113489151,1381.14817142487 3773.3834195137,1374.49506998062 PathPoint;PointKind.SMOOTHPOINT 3774.8867225647,1384.22251939774 3774.83809947968,1433.11279535294 3774.88884687424,1382.04887866974 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,1496.88787221909 3775.26508569717,1514.12640810013 3774.81638431549,1487.30534791946 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,1598.96448612213 3774.27138090134,1623.11316490173 3773.6869597435,1574.81580734253 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,1708.96973133087 3773.48113775253,1726.42848730087 3774.7314119339,1682.61153459549 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,1786.27099514008 3774.75100278854,1802.76248216629 3773.20780992508,1769.77950811386 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,1843.75127077103 3773.8351893425,1866.25077724457 3776.11858606339,1821.25152826309 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,1906.18661642075 3772.58562326431,1933.71908426285 3773.32842350006,1882.07806348801 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,1972.58615970612 3774.54848527908,1991.41580343246 3775.40576219559,1953.75627994537 PathPoint;PointKind.SMOOTHPOINT 3775.97436904907,2031.05730772018 3776.40324354172,2051.40087604523 3775.54573059082,2010.71421146393 PathPoint;PointKind.SMOOTHPOINT 3776.9720864296,2096.46597862244 3777.01905727386,2109.20640707016 3776.92535161972,2083.72555017471 PathPoint;PointKind.SMOOTHPOINT 3775.97436904907,2172.77566194534 3776.11929416656,2197.31804609299 3775.84148168564,2150.24193048477 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,2244.13074731827 3775.44470787048,2271.44606351852 3774.50930356979,2216.81519508362 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,2310.53029060364 3772.76359319687,2334.67519283295 3775.19521951675,2286.38515233994 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,2371.97476387024 3773.70655059814,2397.84602165222 3774.25202608109,2346.10279798508 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,2433.41923713684 3773.52338790894,2481.29078865051 3776.43062353134,2385.54721355438 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,2500.80965280533 3774.05824184418,2509.49217796326 3773.67940664291,2467.71810293198 PathPoint;PointKind.SMOOTHPOINT 3774.07122373581,2525.13040065765 3774.06862735748,2527.58563041687 3774.07901287079,2517.55770921707 PathPoint;PointKind.SMOOTHPOINT 3774.05564546585,2532.3443198204 3771.71394824982,2536.38994932175 3775.23746967316,2530.30238628387 PathPoint;PointKind.SMOOTHPOINT 3774.02543306351,2539.76028442383 3773.95485877991,2554.66821670532 3774.03699874878,2537.33951568604 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,2580.09266138077 3774.22086954117,2602.1585726738 3773.84368658066,2567.70510435104 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,2625.68058013916 3774.51355218887,2640.61565637589 3773.44549655914,2610.74526786804 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,2651.44727468491 3775.0311756134,2671.18683099747 3774.92236375809,2631.70795440674 PathPoint;PointKind.SMOOTHPOINT 3771.98397159576,2685.14283657074 3772.69703149796,2718.76853227615 3771.27091169357,2651.51714086533 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,2743.6142206192 3773.6869597435,2770.635201931 3772.27641820908,2716.59300327301 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,2809.02265548706 3774.47814702988,2828.33994626999 3775.4758644104,2789.70489263535 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,2861.54738903046 3775.54573059082,2888.84759902954 3774.40780878067,2834.24741506577 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,2932.90271043777 3774.70025539398,2969.07120466232 3773.25832128525,2896.73327207565 PathPoint;PointKind.SMOOTHPOINT 3774.97688770294,3007.23041296005 3775.57712316513,3039.35351371765 3774.37688827515,2975.10660409927 PathPoint;PointKind.SMOOTHPOINT 3773.97940635681,3113.27122449875 3773.47287654877,3133.92446994781 3774.48593616486,3092.61845111847 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,3228.23177576065 3773.25832128525,3257.28548526764 3772.70482063293,3199.17830228806 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,3323.3713388443 3772.66233444214,3347.57076501846 3773.30151557922,3299.17214870453 PathPoint;PointKind.SMOOTHPOINT 3771.98397159576,3410.58274269104 3771.94927453995,3439.18751478195 3772.01914072037,3381.97797060013 PathPoint;PointKind.SMOOTHPOINT 3771.98397159576,3477.97339439392 3772.83747196198,3504.73166942596 3771.13070726395,3451.21535539627 PathPoint;PointKind.SMOOTHPOINT 3772.98168897629,3547.34602689743 3771.75808668137,3563.68692398071 3774.2055273056,3531.00560188293 PathPoint;PointKind.SMOOTHPOINT 3770.98672628403,3600.86234092712 3769.7279548645,3623.9040184021 3772.24502563477,3577.82066345215 PathPoint;PointKind.SMOOTHPOINT 3770.98672628403,3661.31570577621 3770.5500626564,3682.76627540588 3771.42315387726,3639.86513614655 PathPoint;PointKind.SMOOTHPOINT 3767.99357414246,3706.90315246582 3767.17123031616,3711.67576789856 3769.64581489563,3697.31425523758 PathPoint;PointKind.SMOOTHPOINT 3767.80333042145,3720.25231361389 3768.15549373627,3725.14695882797 3767.45423555374,3715.40251493454 PathPoint;PointKind.SMOOTHPOINT 3767.99357414246,3740.59847831726 3767.60482549667,3746.89469575882 3768.57492685318,3731.18566274643 PathPoint;PointKind.SMOOTHPOINT 3767.00010538101,3764.00010824203 3766.35148286819,3770.00954389572 3767.48444795609,3759.51073408127 PathPoint;PointKind.SMOOTHPOINT 3763.00569534302,3770.32984256744 3758.42662811279,3775.13503074646 3764.00742530823,3769.27854537964 PathPoint;PointKind.SMOOTHPOINT 3718.11407804489,3775.28491258621 3711.25963926315,3775.28939723969 3741.92097902298,3775.26933431625 PathPoint;PointKind.SMOOTHPOINT 3625.82935094833,3775.10316610336 3622.07805633545,3775.0946688652 3676.92914485931,3775.21929502487 PathPoint;PointKind.SMOOTHPOINT 3614.00001525879,3776.00009679794 3609.1868019104,3774.38302516937 3617.86059379578,3777.29781389236 PathPoint;PointKind.SMOOTHPOINT 3598.64314556122,3775.04038095474 3377.93847799301,3774.52842235565 3604.00325059891,3775.05289077759 PathPoint;PointKind.SMOOTHPOINT 2890.11415958405,3773.30293178558 2840.39044618607,3773.19836854935 2928.39870214462,3773.3834195137 PathPoint;PointKind.SMOOTHPOINT 2667.65174388885,3773.30293178558 2643.92769098282,3774.15832042694 2691.3755607605,3772.44730710983 PathPoint;PointKind.SMOOTHPOINT 2578.86599063873,3774.2938041687 2571.93177223206,3774.15407180786 2619.68955516815,3775.11874437332 PathPoint;PointKind.SMOOTHPOINT 2555.96876621246,3773.65627527237 2552.52644062042,3773.61166477203 2566.92194223404,3773.79789590836 PathPoint;PointKind.SMOOTHPOINT 2540.81960678101,3773.73440265656 2537.36005067825,3775.39041996002 2544.65492963791,3771.89829111099 PathPoint;PointKind.SMOOTHPOINT 2528.92772197723,3773.60293149948 2475.55090427399,3773.04305791855 2533.0042719841,3773.64565372467 PathPoint;PointKind.SMOOTHPOINT 2386.33108377457,3773.30293178558 2360.90829133987,3774.16634559631 2404.67732906342,3772.67980098724 PathPoint;PointKind.SMOOTHPOINT 2278.59153270721,3773.30293178558 2222.22368717194,3772.76477336884 2334.9591422081,3773.84085416794 PathPoint;PointKind.SMOOTHPOINT 2135.93588590622,3774.2938041687 2083.77299308777,3772.737865448 2188.09877872467,3775.85021495819 PathPoint;PointKind.SMOOTHPOINT 1788.77461194992,3774.2938041687 1748.27488660812,3773.0166220665 1829.27410125732,3775.57169437408 PathPoint;PointKind.SMOOTHPOINT 1579.280397892,3773.30293178558 1577.1244597435,3773.31142902374 1607.40389585495,3773.19435596466 PathPoint;PointKind.SMOOTHPOINT 1568.9208483696,3773.34329366684 1565.69638252258,3773.35556745529 1573.60141038895,3773.32511901855 PathPoint;PointKind.SMOOTHPOINT 1557.96885251999,3772.65619754791 1554.40213680267,3774.02330875397 1562.31259346008,3770.99239110947 PathPoint;PointKind.SMOOTHPOINT 1545.08349895477,3773.43558311462 1466.17767333984,3773.74030351639 1549.63353395462,3773.41811656952 PathPoint;PointKind.SMOOTHPOINT 1262.04663276672,3774.2938041687 1233.6153459549,3774.14321422577 1285.44731855392,3774.41819429398 PathPoint;PointKind.SMOOTHPOINT 1038.58649969101,3774.2938041687 986.27537727356,3774.25934314728 1090.89762210846,3774.32873725891 PathPoint;PointKind.SMOOTHPOINT 799.165012836456,3773.30293178558 761.517527103424,3772.84998178482 836.812262535095,3773.75588178635 PathPoint;PointKind.SMOOTHPOINT 613.613183498383,3774.2938041687 578.116679191589,3774.43330049515 649.109215736389,3774.15477991104 PathPoint;PointKind.SMOOTHPOINT 446.017906665802,3773.30293178558 413.370337486267,3772.82685041428 478.665475845337,3773.77901315689 PathPoint;PointKind.SMOOTHPOINT 287.400906085968,3774.2938041687 260.914306640625,3773.79860401154 313.887977600098,3774.78947639465 PathPoint;PointKind.SMOOTHPOINT 224.552972316742,3773.30293178558 205.30247926712,3773.44644069672 243.80322933197,3773.15965890884 PathPoint;PointKind.SMOOTHPOINT 201.608304977417,3774.2938041687 199.049692153931,3773.86823415756 206.818292140961,3775.16123056412 PathPoint;PointKind.SMOOTHPOINT 194.624991416931,3768.34786176682 194.074559211731,3767.65982151031 197.02121257782,3771.34172201157 PathPoint;PointKind.SMOOTHPOINT 193.04497718811,3766.12677812576 192.573616504669,3765.38775444031 193.541357517242,3766.90474748611 PathPoint;PointKind.SMOOTHPOINT 192.000052928925,3764.00010824203 190.951116085052,3763.38075399399 192.721610069275,3764.42615032196 PathPoint;PointKind.SMOOTHPOINT 190.49462556839,3761.10278606415 190.182824134827,3760.2433848381 190.798401832581,3761.94047212601 PathPoint;PointKind.SMOOTHPOINT 189.999897480011,3758.99995565414 189.870550632477,3742.89863348007 190.004146099091,3759.51026201248 PathPoint;PointKind.SMOOTHPOINT 189.637348651886,3725.73303222656 189.445452690125,3709.62462902069 189.827828407288,3741.79470062256 PathPoint;PointKind.SMOOTHPOINT 188.639395236969,3668.25299263 189.777317047119,3657.30902194977 187.501709461212,3679.19696331024 PathPoint;PointKind.SMOOTHPOINT 189.637348651886,3625.63816308975 189.498560428619,3602.70931005478 189.763154983521,3646.52885913849 PathPoint;PointKind.SMOOTHPOINT 189.637348651886,3534.46279764175 188.039631843567,3505.9158539772 190.864727497101,3556.4012503624 PathPoint;PointKind.SMOOTHPOINT 189.637348651886,3426.43953323364 188.752455711365,3398.29172372818 190.606741905212,3457.29276895523 PathPoint;PointKind.SMOOTHPOINT 190.634593963623,3372.92345523834 190.14741897583,3357.31072425842 191.122004985809,3388.53618621826 PathPoint;PointKind.SMOOTHPOINT 189.637348651886,3321.38959407806 190.085341930389,3307.27497339249 189.188883304596,3335.50374269485 PathPoint;PointKind.SMOOTHPOINT 188.639395236969,3258.95401239395 189.311385154724,3237.65662908554 187.968349456787,3280.228972435 PathPoint;PointKind.SMOOTHPOINT 186.644432544708,3181.65298461914 187.521300315857,3154.30273532867 185.76756477356,3209.003469944 PathPoint;PointKind.SMOOTHPOINT 188.639395236969,3115.25344133377 188.479835987091,3088.08139801025 188.79919052124,3142.42572069168 PathPoint;PointKind.SMOOTHPOINT 187.641913890839,3047.8625535965 187.747185230255,3021.88673257828 187.536878585815,3073.8388466835 PathPoint;PointKind.SMOOTHPOINT 187.641913890839,2994.3464756012 188.187389373779,2956.91968202591 187.096202373505,3031.77397727966 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2930.92025756836 185.511939525604,2905.36906242371 185.777714252472,2955.73738574982 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2868.48491191864 185.531058311462,2842.27164030075 185.857257843018,2916.22097969055 PathPoint;PointKind.SMOOTHPOINT 186.127753257751,2804.02675151825 186.149940490723,2801.79292201996 185.950255393982,2821.87165975571 PathPoint;PointKind.SMOOTHPOINT 186.181569099426,2797.43832349777 187.291166782379,2795.32605171204 184.749784469604,2800.16381263733 PathPoint;PointKind.SMOOTHPOINT 186.203520298004,2790.4052066803 186.201632022858,2781.07547521591 186.203992366791,2792.71433115005 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2763.43497276306 184.294474124908,2734.57835197449 186.060955524445,2772.27375268936 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2685.14283657074 185.229642391205,2663.19281816483 186.063787937164,2707.09261894226 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2630.63565015793 186.137666702271,2602.25558280945 185.155763626099,2659.01571750641 PathPoint;PointKind.SMOOTHPOINT 184.649233818054,2534.50497865677 186.426100730896,2504.94403123856 182.872130870819,2564.06569004059 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2450.26690006256 185.842859745026,2429.8782491684 185.443253517151,2471.41369342804 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2410.62515974045 186.200215816498,2399.2088842392 185.093450546265,2422.0414352417 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2385.84910154343 184.103758335114,2365.6568312645 187.190144062042,2406.04160785675 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2294.67350006104 185.07385969162,2274.26832675934 186.219570636749,2315.07914543152 PathPoint;PointKind.SMOOTHPOINT 183.651516437531,2229.26506519318 182.20202922821,2204.91504907608 185.101239681244,2253.61531734467 PathPoint;PointKind.SMOOTHPOINT 184.968824386597,2135.65618515015 186.227123737335,2100.0909948349 183.710052967072,2171.221139431 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,2015.20075321198 185.853245258331,1991.41580343246 185.440185070038,2038.98570299149 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,1923.03427934647 186.262528896332,1893.79032611847 185.025000572205,1952.56855487823 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,1836.81374788284 185.151751041412,1797.87680625916 186.141443252563,1875.75068950653 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,1628.69608640671 186.991167068481,1586.62696838379 184.302263259888,1670.76449632645 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,1518.69060516357 185.675511360168,1498.93334627151 185.602340698242,1549.14635896683 PathPoint;PointKind.SMOOTHPOINT 185.825393199921,1466.08113527298 185.854425430298,1464.28774595261 185.515716075897,1485.14350891113 PathPoint;PointKind.SMOOTHPOINT 186.968743801117,1459.65627908707 186.554267406464,1457.97524213791 187.422873973846,1461.49781942368 PathPoint;PointKind.SMOOTHPOINT 186.100845336914,1452.77682065964 186.238925457001,1447.22599983215 186.033575534821,1455.47870635986 PathPoint;PointKind.SMOOTHPOINT 186.644432544708,1434.45229053497 187.965281009674,1395.42990446091 186.416659355164,1441.17903470993 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,1344.26779747009 185.872836112976,1319.36805725098 185.420594215393,1369.16753768921 PathPoint;PointKind.SMOOTHPOINT 185.646951198578,1286.78775787354 185.989673137665,1261.41146421432 185.303757190704,1312.16357946396 PathPoint;PointKind.SMOOTHPOINT 187.641913890839,1232.28033542633 188.627829551697,1213.99239063263 186.65599822998,1250.56804418564 PathPoint;PointKind.SMOOTHPOINT 187.641913890839,1168.8538813591 188.822557926178,1144.68183517456 186.461033821106,1193.02592754364 PathPoint;PointKind.SMOOTHPOINT 187.641913890839,1079.66049671173 189.376294612885,1047.26194381714 185.907533168793,1112.05904960632 PathPoint;PointKind.SMOOTHPOINT 188.639395236969,874.515688419342 189.913508892059,833.588740825653 187.365281581879,915.442399978638 PathPoint;PointKind.SMOOTHPOINT 189.637348651886,756.581811904907 189.664256572723,725.790181159973 189.609968662262,787.373914718628 PathPoint;PointKind.SMOOTHPOINT 191.632311344147,570.266411304474 190.825781822205,539.525291919708 192.439076900482,601.008238792419 PathPoint;PointKind.SMOOTHPOINT 191.632311344147,403.77247095108 194.282033443451,364.843318462372 188.982117176056,442.701387405396 PathPoint;PointKind.SMOOTHPOINT 193.627510070801,327.462079524994 193.471727371216,307.854466438293 193.783292770386,347.070164680481 PathPoint;PointKind.SMOOTHPOINT 193.627510070801,277.910199165344 193.383450508118,264.341053962708 193.982269763947,297.645978927612 PathPoint;PointKind.SMOOTHPOINT 192.231838703156,219.573826789856 192.224757671356,218.867139816284 192.408392429352,237.207720279694 PathPoint;PointKind.SMOOTHPOINT 192.999894618988,217.000107765198 192.994701862335,216.176347732544 193.004379272461,217.674694061279 PathPoint;PointKind.SMOOTHPOINT 192.204694747925,215.10734796524 192.196669578552,209.347636699677 192.205874919891,215.878472328186 PathPoint";
		
	subshadowSquare[0] = "PointKind.SMOOTHPOINT 192.000052928925,226.812529563904 191.457645893097,217.259981632233 192.278573513031,231.715908050537 PathPoint;PointKind.SMOOTHPOINT 193.781168460846,196.046862602234 204.423487186432,193.457565307617 191.121768951416,196.693832874298 PathPoint;PointKind.SMOOTHPOINT 273.570470809937,194.037501811981 540.077376365662,193.631994724274 267.717053890228,194.046471118927 PathPoint;PointKind.SMOOTHPOINT 2919.03663396835,195.373220443726 2925.78320503235,195.378413200378 1977.14776039124,194.642930030823 PathPoint;PointKind.SMOOTHPOINT 2938.00010919571,196.999969482422 2946.58491611481,192.63498544693 2932.03197956085,200.034427642822 PathPoint;PointKind.SMOOTHPOINT 2960.21306991577,195.405321121216 3077.19265937805,195.496430397034 2953.23778152466,195.39989233017 PathPoint;PointKind.SMOOTHPOINT 3282.97853708267,195.660474300385 3288.46964120865,195.664958953857 3185.89688301086,195.582582950592 PathPoint;PointKind.SMOOTHPOINT 3299.00007963181,198.999888896942 3307.90589332581,194.916257858276 3294.07663822174,201.257557868958 PathPoint;PointKind.SMOOTHPOINT 3321.19250535965,195.691158771515 3329.2249917984,195.697767734528 3313.97882223129,195.685493946075 PathPoint;PointKind.SMOOTHPOINT 3342.00011730194,195.999891757965 3347.07934141159,192.901468276978 3335.29508829117,200.090131759644 PathPoint;PointKind.SMOOTHPOINT 3362.00001955032,198.999888896942 3371.52306318283,193.224127292633 3357.13841915131,201.948666572571 PathPoint;PointKind.SMOOTHPOINT 3382.95798540115,195.741198062897 3423.59413862228,195.774006843567 3376.12502574921,195.735533237457 PathPoint;PointKind.SMOOTHPOINT 3496.39092206955,195.833723545074 3504.59878206253,195.840332508087 3461.5137720108,195.804927349091 PathPoint;PointKind.SMOOTHPOINT 3517.00002908707,198.999888896942 3522.92638063431,199.004845619202 3509.13347482681,198.993515968323 PathPoint;PointKind.SMOOTHPOINT 3537.98797130585,195.867712497711 3673.2106590271,195.979120731354 3532.2594165802,195.862991809845 PathPoint;PointKind.CORNERPOINT 3752.78115749359,196.046862602234 3752.78115749359,196.046862602234 3752.78115749359,196.046862602234 PathPoint;PointKind.SMOOTHPOINT 3765,201 3769.53076779848,202.674217546632 3758.46128883775,198.583803574333 PathPoint;PointKind.SMOOTHPOINT 3775,207 3775.68338465825,208.567427744865 3773.37106691451,203.264399761776 PathPoint;PointKind.SMOOTHPOINT 3776,211 3776.05257208347,211.503375279845 3775.67920317349,207.928385149628 PathPoint;PointKind.SMOOTHPOINT 3778,218 3776.426457855,219.471207728529 3779.573542145,216.528792271471 PathPoint;PointKind.CORNERPOINT 3778.80135297775,221.951637268066 3778.80135297775,221.951637268066 3778.80135297775,221.951637268066 PathPoint;PointKind.SMOOTHPOINT 3779.15247325983,244.870825540234 3779.22937115755,249.854896937584 3778.93873373134,231.017481015112 PathPoint;PointKind.SMOOTHPOINT 3779.40997628011,261.482847917553 3780.23246611091,314.293063060238 3779.31615272426,255.458649216587 PathPoint;PointKind.SMOOTHPOINT 3781.58655881882,382.624969482422 3781.71678211872,604.848128991307 3781.59612461518,399.414096591593 PathPoint;PointKind.SMOOTHPOINT 3781.724914813,1692.85871477802 3781.72465079471,1712.36035945032 3781.73255024591,1128.86937580093 PathPoint;PointKind.SMOOTHPOINT 3780,1747 3779.99970298808,1765.39675341574 3780.00031621845,1727.41360518627 PathPoint;PointKind.SMOOTHPOINT 3781.72309056314,1806.7753037162 3781.72268028329,1829.26600122648 3781.72342718653,1788.32230218139 PathPoint;PointKind.SMOOTHPOINT 3781.72178405745,1874.33650398071 3781.72154200712,1886.22939122869 3781.72224289889,1851.79181467509 PathPoint;PointKind.SMOOTHPOINT 3780,1910 3779.99979788536,1919.50124290354 3780.00025316352,1898.09899116675 PathPoint;PointKind.SMOOTHPOINT 3781.72042506788,1938.5365411238 3781.71491096705,2190.18068808869 3781.72063331546,1929.03285441007 PathPoint;PointKind.SMOOTHPOINT 3781.70570833762,2672.24205996221 3781.70565321231,2679.75958658726 3781.70739480177,2442.25625947514 PathPoint;PointKind.SMOOTHPOINT 3780,2689 3779.99985291073,2714.91583957549 3780.00004239449,2681.53046284804 PathPoint;PointKind.SMOOTHPOINT 3781.70536689007,2771.55699257301 3781.70555398939,2998.26491103962 3781.70534601371,2746.26115284285 PathPoint;PointKind.SMOOTHPOINT 3781.73576490764,3349.3761262699 3781.73715720355,3358.56617089589 3781.71294554335,3198.75370903074 PathPoint;PointKind.SMOOTHPOINT 3779.67755924818,3373.78286927641 3778.78655468774,3378.82003589712 3781.12712188746,3365.58797458627 PathPoint;PointKind.SMOOTHPOINT 3781,3389 3779.24369381961,3396.45490144323 3782.57835923045,3382.30042071458 PathPoint;PointKind.SMOOTHPOINT 3781.74735218326,3414.92654520383 3781.75026485435,3429.08501861394 3781.74584112293,3407.58129168503 PathPoint;PointKind.SMOOTHPOINT 3781.75665188505,3455.6046988322 3781.75787768002,3460.42962194097 3781.75336157941,3442.65353479181 PathPoint;PointKind.SMOOTHPOINT 3780,3468 3778.59751783312,3471.00702309392 3782.77314924712,3462.05416765651 PathPoint;PointKind.SMOOTHPOINT 3782,3478 3782.00139864069,3482.90568260775 3781.99942326448,3475.97712063565 PathPoint;PointKind.SMOOTHPOINT 3781.76641609958,3490.35365479999 3781.77104328549,3505.22912898367 3781.76495342999,3485.65146558454 PathPoint;PointKind.SMOOTHPOINT 3781.7812871933,3531.84376001358 3781.77750031936,3522.51611573564 3781.77599390692,3519.07759625295 PathPoint;PointKind.SMOOTHPOINT 3777.804767068,3602.46844747032 3777.69475114646,3604.72771900548 3779.87059547856,3560.04488496261 PathPoint;PointKind.SMOOTHPOINT 3777.47363056891,3609.28157078117 3776.46271054745,3612.09297480148 3778.24625400881,3607.13287790832 PathPoint;PointKind.SMOOTHPOINT 3777.1072200349,3616.84591470438 3775.93652256401,3618.99297242898 3778.31737578005,3614.62649055323 PathPoint;PointKind.SMOOTHPOINT 3776.77162747245,3623.79145759898 3775.73276348112,3627.99901049967 3777.32632279755,3621.54485944601 PathPoint;PointKind.SMOOTHPOINT 3776.32442984611,3633.06320161218 3774.99624649976,3636.00884041068 3777.58744112305,3630.26210112368 PathPoint;PointKind.SMOOTHPOINT 3775.90277339784,3641.81201674784 3774.6638841465,3644.74105962003 3777.02685261038,3639.15441341348 PathPoint;PointKind.SMOOTHPOINT 3775.49747973253,3650.2162802786 3774.40437748711,3652.50884233411 3776.68442365874,3647.72690417617 PathPoint;PointKind.SMOOTHPOINT 3775.14698698199,3657.4706249894 3773.98866120973,3681.41324827776 3775.26167969211,3655.09992374266 PathPoint;PointKind.SMOOTHPOINT 3772.78129577637,3703.84367465973 3772.60143756866,3706.18584394455 3773.06209205475,3700.1910493867 PathPoint;PointKind.SMOOTHPOINT 3769.78129863739,3733.8436460495 3768.83952140808,3739.31728363037 3770.59632539749,3729.10643577576 PathPoint;PointKind.CORNERPOINT 3766.00002765656,3763.81246089935 3766.00002765656,3763.81246089935 3766.00002765656,3763.81246089935 PathPoint;PointKind.CORNERPOINT 202.781159877777,3766.04699850082 202.781159877777,3766.04699850082 202.781159877777,3766.04699850082 PathPoint;PointKind.SMOOTHPOINT 194.781246185303,3752.046854496 193.620901107788,3733.33853244781 195.384078025818,3761.77099943161 PathPoint;PointKind.SMOOTHPOINT 194.729318618774,3702.26177215576 193.021845817566,3699.51291561127 194.729318618774,3702.26177215576 PathPoint;PointKind.SMOOTHPOINT 188.781251907349,712.84369468689 191.916732788086,604.457881450653 162.637374401093,1616.60664081573 PathPoint;PointKind.SMOOTHPOINT 191.781249046326,441.843638420105 191.002571582794,385.981850624084 192.094230651855,464.303255081177 PathPoint";

} else {

	maskSquare[0] = "PointKind.SMOOTHPOINT 161.799216270447,169.285519123077 161.799216270447,169.285519123077 160.518729686737,175.566866397858 PathPoint;PointKind.SMOOTHPOINT 162.813928127289,161.205117702484 166.210463047028,158.559172153473 161.039185523987,162.587807178497 PathPoint;PointKind.SMOOTHPOINT 186.154661178589,158.175144195557 198.062596321106,155.440921783447 174.246490001678,160.909366607666 PathPoint;PointKind.SMOOTHPOINT 208.480446338654,156.154925823212 210.238194465637,156.249103546143 193.975660800934,155.37766456604 PathPoint;PointKind.SMOOTHPOINT 213.608057498932,156.373021602631 216.849517822266,151.761381626129 212.653770446777,157.730927467346 PathPoint;PointKind.SMOOTHPOINT 222.886333465576,156.464366912842 226.669964790344,153.349421024323 220.586414337158,158.357598781586 PathPoint;PointKind.SMOOTHPOINT 234.86531496048,155.144934654236 239.029197692871,155.667986869812 231.045806407928,154.665076732635 PathPoint;PointKind.SMOOTHPOINT 247.043037414551,155.144934654236 251.666243076324,156.063108444214 241.783010959625,154.100482463837 PathPoint;PointKind.SMOOTHPOINT 264.294791221619,154.13494348526 275.299422740936,153.892300128937 258.131461143494,154.270663261414 PathPoint;PointKind.SMOOTHPOINT 291.69460773468,155.144934654236 299.983427524567,155.906381607056 286.381237506866,154.65681552887 PathPoint;PointKind.SMOOTHPOINT 330.257198810577,155.144934654236 349.828698635101,154.708507061005 311.652731895447,155.559647083282 PathPoint;PointKind.SMOOTHPOINT 368.819789886475,154.13494348526 378.868718147278,152.903788089752 358.770861625671,155.365862846375 PathPoint;PointKind.SMOOTHPOINT 399.263978004456,154.13494348526 420.792911052704,154.983251094818 377.735044956207,153.286635875702 PathPoint;PointKind.SMOOTHPOINT 441.885888576508,155.144934654236 459.355738162994,152.098910808563 424.416275024414,158.190958499908 PathPoint;PointKind.SMOOTHPOINT 476.389396190643,154.13494348526 494.636034965515,154.908192157745 458.142521381378,153.361458778381 PathPoint;PointKind.SMOOTHPOINT 524.085338115692,150.094742774963 546.315765380859,151.049501895905 501.854674816132,149.139983654022 PathPoint;PointKind.SMOOTHPOINT 564.677588939667,155.144934654236 574.346029758453,154.466335773468 555.00914812088,155.823533535004 PathPoint;PointKind.SMOOTHPOINT 590.047745704651,151.104733943939 599.215557575226,151.317636966705 566.088838577271,150.548400878906 PathPoint;PointKind.SMOOTHPOINT 615.417902469635,154.13494348526 621.963844299316,153.82904291153 606.155440807343,154.567594528198 PathPoint;PointKind.SMOOTHPOINT 634.699079990387,153.124952316284 637.059423923492,152.101979255676 629.237480163574,155.491669178009 PathPoint;PointKind.SMOOTHPOINT 651.950833797455,158.175144195557 661.337921619415,157.989621162415 648.659806251526,158.240053653717 PathPoint;PointKind.SMOOTHPOINT 677.320990562439,155.144934654236 681.133654117584,155.20370721817 661.960344314575,154.908192157745 PathPoint;PointKind.SMOOTHPOINT 689.740648269653,155.321960449219 693.655042648315,158.420383930206 685.477395057678,151.946904659271 PathPoint;PointKind.SMOOTHPOINT 703.706095218658,154.13494348526 712.595858573914,153.766493797302 698.37525844574,154.355871677399 PathPoint;PointKind.SMOOTHPOINT 730.090963840485,155.144934654236 745.808730125427,154.588601589203 722.704031467438,155.406460762024 PathPoint;PointKind.SMOOTHPOINT 765.609183311462,150.094742774963 771.12530708313,150.494585037231 754.176857471466,149.26602602005 PathPoint;PointKind.SMOOTHPOINT 788.445274829865,154.368145465851 792.732603549957,153.694267272949 780.616958141327,155.598828792572 PathPoint;PointKind.SMOOTHPOINT 822.438476085663,158.175144195557 828.920452594757,158.080730438232 810.24069070816,158.352642059326 PathPoint;PointKind.SMOOTHPOINT 839.230906963348,158.044145107269 840.818710327148,157.260038852692 834.352548122406,160.45334815979 PathPoint;PointKind.SMOOTHPOINT 844.418234825134,158.03352355957 855.19816160202,158.010156154633 842.721855640411,158.037300109863 PathPoint;PointKind.SMOOTHPOINT 882.312140464783,157.164916992188 896.375777721405,156.527388095856 865.088710784912,157.945954799652 PathPoint;PointKind.SMOOTHPOINT 918.570799827576,154.291434288025 923.70525598526,155.076720714569 908.086624145508,152.688052654266 PathPoint;PointKind.SMOOTHPOINT 947.259600162506,155.144934654236 966.568865776062,158.723452091217 937.82719373703,153.396863937378 PathPoint;PointKind.SMOOTHPOINT 988.866798877716,154.13494348526 992.960579395294,154.044070243835 970.540852546692,154.541158676147 PathPoint;PointKind.SMOOTHPOINT 1001.5626168251,154.27538394928 1008.28251600266,153.108901977539 997.957899570465,154.900875091553 PathPoint;PointKind.SMOOTHPOINT 1018.29603910446,155.144934654236 1026.03159427643,155.980968475342 1011.86646223068,154.45004940033 PathPoint;PointKind.SMOOTHPOINT 1041.63677215576,156.154925823212 1053.98089885712,155.748474597931 1036.40152931213,156.327230930328 PathPoint;PointKind.SMOOTHPOINT 1084.25868272781,152.114725112915 1091.0727596283,151.286244392395 1077.44436979294,152.943441867828 PathPoint;PointKind.SMOOTHPOINT 1100.49548864365,152.114725112915 1114.52442884445,152.675070762634 1086.46654844284,151.554615497589 PathPoint;PointKind.SMOOTHPOINT 1133.98404836655,152.114725112915 1146.9387960434,152.40669965744 1121.02953672409,151.82275056839 PathPoint;PointKind.SMOOTHPOINT 1154.28017377853,156.154925823212 1174.37425374985,156.652014255524 1134.18632984161,155.6578373909 PathPoint;PointKind.SMOOTHPOINT 1174.57629919052,153.124952316284 1175.06890296936,153.138406276703 1160.76687097549,152.746117115021 PathPoint;PointKind.SMOOTHPOINT 1180.99997520447,153.999931812286 1183.19415092468,154.00016784668 1179.78675842285,153.999931812286 PathPoint;PointKind.SMOOTHPOINT 1186.75402164459,157.164916992188 1188.37203741074,157.154295444489 1184.78407859802,157.17789888382 PathPoint;PointKind.SMOOTHPOINT 1189.9999666214,155.000009536743 1192.57675409317,155.487184524536 1188.91869306564,154.795603752136 PathPoint;PointKind.SMOOTHPOINT 1198.00011634827,153.999931812286 1198.7894153595,154.048318862915 1194.95952129364,153.813700675964 PathPoint;PointKind.SMOOTHPOINT 1200.96140384674,153.124952316284 1205.06155729294,154.388916492462 1199.88791942596,152.793796062469 PathPoint;PointKind.SMOOTHPOINT 1208.92685651779,155.731244087219 1209.96706008911,155.202527046204 1207.0813035965,156.669716835022 PathPoint;PointKind.SMOOTHPOINT 1217.19820976257,158.175144195557 1219.31874275208,158.784112930298 1213.14880371094,157.011966705322 PathPoint;PointKind.SMOOTHPOINT 1221.9181895256,159.21275138855 1226.03911399841,159.640209674835 1220.81850528717,159.098746776581 PathPoint;PointKind.SMOOTHPOINT 1228.9999294281,156.999928951263 1230.65925121307,156.906223297119 1224.5362830162,157.251777648926 PathPoint;PointKind.SMOOTHPOINT 1234.00008201599,155.000009536743 1236.00259780884,155.575225353241 1233.81857156754,154.947845935822 PathPoint;PointKind.SMOOTHPOINT 1241.99999570847,156.999928951263 1243.18890094757,157.199141979218 1238.88080120087,156.47782087326 PathPoint;PointKind.SMOOTHPOINT 1253.73137712479,159.185135364532 1255.78346014023,158.416843414307 1248.93232584,160.981829166412 PathPoint;PointKind.SMOOTHPOINT 1258.99423599243,158.338952064514 1259.83333826065,157.877504825592 1257.75434732437,159.020619392395 PathPoint;PointKind.SMOOTHPOINT 1267.9998922348,159.99992609024 1272.14182376862,160.053977966309 1265.09100437164,159.962160587311 PathPoint;PointKind.SMOOTHPOINT 1276.00004196167,159.99992609024 1276.62482500076,160.385370254517 1274.00673151016,158.770186901093 PathPoint;PointKind.SMOOTHPOINT 1285.0000333786,159.99992609024 1289.89892721176,159.502365589142 1280.17454624176,160.489933490753 PathPoint;PointKind.SMOOTHPOINT 1291.8768954277,160.600633621216 1293.27657938004,160.203387737274 1289.18586730957,161.364204883575 PathPoint;PointKind.SMOOTHPOINT 1297.38263368607,157.134940624237 1297.43479728699,157.112045288086 1294.58562612534,158.360903263092 PathPoint;PointKind.SMOOTHPOINT 1301.99993848801,158.00000667572 1301.92535161972,158.167119026184 1302.0284986496,157.936041355133 PathPoint;PointKind.SMOOTHPOINT 1306.9998550415,158.00000667572 1308.48639965057,158.080022335052 1304.91331100464,157.887654304504 PathPoint;PointKind.SMOOTHPOINT 1312.00000762939,158.00000667572 1313.30268144608,158.882539272308 1310.53494215012,157.007482051849 PathPoint;PointKind.SMOOTHPOINT 1316.64941310883,159.185135364532 1320.21140813828,159.96994972229 1314.99858856201,158.821406364441 PathPoint;PointKind.SMOOTHPOINT 1324.29621934891,157.285530567169 1326.37851476669,157.390093803406 1321.62265777588,157.151226997375 PathPoint;PointKind.SMOOTHPOINT 1329.84184741974,157.164916992188 1332.75876045227,157.888598442078 1327.37080335617,156.55193567276 PathPoint;PointKind.SMOOTHPOINT 1337.62933015823,159.134624004364 1339.29714918137,159.167432785034 1335.24089813232,159.087653160095 PathPoint;PointKind.SMOOTHPOINT 1348.10831308365,161.205117702484 1350.99147319794,161.507477760315 1344.87723827362,160.866408348083 PathPoint;PointKind.SMOOTHPOINT 1355.93639373779,158.540761470795 1358.15629720688,158.447291851044 1353.14670324326,158.658306598663 PathPoint;PointKind.SMOOTHPOINT 1362.999958992,159.000084400177 1370.32316207886,162.344927787781 1360.61813592911,157.912201881409 PathPoint;PointKind.SMOOTHPOINT 1376.52284145355,161.205117702484 1383.78514766693,160.459485054016 1369.26077127457,161.950986385345 PathPoint;PointKind.SMOOTHPOINT 1391.75980567932,159.175221920013 1394.21810388565,157.535254955292 1385.50536632538,163.347365856171 PathPoint;PointKind.SMOOTHPOINT 1397.00000524521,159.000084400177 1397.43714094162,158.030219078064 1396.47199630737,160.172703266144 PathPoint;PointKind.SMOOTHPOINT 1404.00007724762,159.000084400177 1405.90039014816,159.079391956329 1401.62816762924,158.900713920593 PathPoint;PointKind.SMOOTHPOINT 1410.01163721085,161.205117702484 1420.19604921341,161.541466712952 1406.77277326584,161.098430156708 PathPoint;PointKind.SMOOTHPOINT 2130.52432537079,162.215344905853 2154.78063583374,162.274353504181 2106.26801490784,162.156100273132 PathPoint;PointKind.SMOOTHPOINT 2273.61215114594,161.205117702484 2304.93249893188,160.573961734772 2242.29180335999,161.83650970459 PathPoint;PointKind.SMOOTHPOINT 2389.30016040802,162.215344905853 2422.88785457611,161.461687088013 2355.71246623993,162.968766689301 PathPoint;PointKind.SMOOTHPOINT 2481.6474366188,165.245318412781 2496.08872890472,165.249330997467 2467.20638036728,165.241541862488 PathPoint;PointKind.SMOOTHPOINT 2521.22497558594,164.235327243805 2531.01237773895,165.166482925415 2511.43757343292,163.304171562195 PathPoint;PointKind.SMOOTHPOINT 2538.47672939301,163.225336074829 2561.58732891083,163.292369842529 2515.36612987518,163.158302307129 PathPoint;PointKind.SMOOTHPOINT 2567.90620565414,166.25554561615 2578.66064071655,166.302752494812 2557.15153455734,166.208102703094 PathPoint;PointKind.SMOOTHPOINT 2590.23175477982,163.225336074829 2606.12395048141,163.339812755585 2574.33979511261,163.110859394073 PathPoint;PointKind.SMOOTHPOINT 2621.69089078903,164.235327243805 2632.48497962952,164.937765598297 2610.89656591415,163.533124923706 PathPoint;PointKind.SMOOTHPOINT 2648.07575941086,165.245318412781 2659.28314447403,161.719672679901 2633.9394235611,169.692678451538 PathPoint;PointKind.SMOOTHPOINT 2668.37188482285,167.265536785126 2671.55905723572,166.324939727783 2665.18494844437,168.206133842468 PathPoint;PointKind.SMOOTHPOINT 2683.59397888184,163.225336074829 2690.86667060852,166.887409687042 2677.17856407166,159.994733333588 PathPoint;PointKind.SMOOTHPOINT 2693.74204158783,168.275527954102 2703.08145046234,169.553890228271 2688.66801023483,167.581114768982 PathPoint;PointKind.SMOOTHPOINT 2713.02345514297,163.225336074829 2719.70606088638,165.262784957886 2704.69332933426,160.685606002808 PathPoint;PointKind.SMOOTHPOINT 2729.2604970932,166.25554561615 2739.6025800705,164.56294298172 2718.91817808151,167.94814825058 PathPoint;PointKind.CORNERPOINT 2753.61570596695,166.25554561615 2753.61570596695,166.25554561615 2753.61570596695,166.25554561615 PathPoint;PointKind.SMOOTHPOINT 2773.91183137894,163.225336074829 2780.08011817932,163.655390739441 2767.74378061295,162.795281410217 PathPoint;PointKind.SMOOTHPOINT 2793.19324493408,165.245318412781 2798.75492334366,165.127065181732 2787.63156652451,165.363807678223 PathPoint;PointKind.SMOOTHPOINT 2813.48937034607,162.215344905853 2822.58684396744,163.493707180023 2804.39166069031,160.936982631683 PathPoint;PointKind.SMOOTHPOINT 2852.05196142197,166.25554561615 2869.30371522903,166.882688999176 2834.8002076149,165.62816619873 PathPoint;PointKind.SMOOTHPOINT 2891.6295003891,163.225336074829 2900.09274959564,163.319985866547 2883.16625118256,163.130686283112 PathPoint;PointKind.SMOOTHPOINT 2924.10334825516,164.235327243805 2936.15408420563,163.746027946472 2912.05237627029,164.724626541138 PathPoint;PointKind.SMOOTHPOINT 2955.56224822998,164.235327243805 2976.81785345078,164.91014957428 2934.30687904358,163.560740947723 PathPoint;PointKind.SMOOTHPOINT 3010.3618812561,164.235327243805 3020.5415725708,165.300550460815 3000.18218994141,163.170104026794 PathPoint;PointKind.SMOOTHPOINT 3036.74674987793,162.215344905853 3058.30754756927,162.144298553467 3015.18618822098,162.28639125824 PathPoint;PointKind.SMOOTHPOINT 3071.25025749207,164.235327243805 3087.38013982773,164.310386180878 3055.1203751564,164.160504341125 PathPoint;PointKind.SMOOTHPOINT 3102.70939350128,163.225336074829 3125.13006448746,163.607947826385 3080.28848648071,162.842488288879 PathPoint;PointKind.SMOOTHPOINT 3149.3903875351,166.25554561615 3161.13593101501,166.444845199585 3137.64484405518,166.066009998322 PathPoint;PointKind.SMOOTHPOINT 3181.86423540115,164.235327243805 3205.03832817078,164.468057155609 3158.69014263153,164.002597332001 PathPoint;PointKind.SMOOTHPOINT 3230.57488918304,166.25554561615 3248.52837324142,166.243507862091 3212.62164115906,166.267347335815 PathPoint;PointKind.SMOOTHPOINT 3262.03402519226,165.245318412781 3274.86957550049,164.128875732422 3249.19823884964,166.361997127533 PathPoint;PointKind.SMOOTHPOINT 3286.38923406601,165.245318412781 3298.6580657959,165.466246604919 3274.12040233612,165.024390220642 PathPoint;PointKind.SMOOTHPOINT 3305.67064762115,165.245318412781 3321.38440132141,164.448466300964 3289.9568939209,166.04240655899 PathPoint;PointKind.SMOOTHPOINT 3330.0260925293,168.275527954102 3340.76070070267,168.662152290344 3319.29124832153,167.888903617859 PathPoint;PointKind.SMOOTHPOINT 3348.29255819321,165.245318412781 3365.38970947266,163.864517211914 3331.19540691376,166.626355648041 PathPoint;PointKind.SMOOTHPOINT 3373.66271495819,167.265536785126 3384.39755916595,167.15106010437 3362.92787075043,167.380013465881 PathPoint;PointKind.SMOOTHPOINT 3405.12161493301,166.25554561615 3421.04142665863,164.35759305954 3389.20203924179,168.153262138367 PathPoint;PointKind.SMOOTHPOINT 3438.61041069031,166.25554561615 3450.44706344604,167.131469249725 3426.77352190018,165.379621982574 PathPoint;PointKind.SMOOTHPOINT 3462.96561956406,166.25554561615 3472.59039402008,166.25554561615 3453.34084510803,166.25554561615 PathPoint;PointKind.SMOOTHPOINT 3489.35072422028,167.265536785126 3502.8603887558,167.865300178528 3475.84105968475,166.665773391724 PathPoint;PointKind.SMOOTHPOINT 3517.76525259018,165.245318412781 3534.46987867355,166.590714454651 3501.06062650681,163.899922370911 PathPoint;PointKind.SMOOTHPOINT 3541.10574960709,169.285519123077 3552.87914514542,169.167265892029 3529.33235406876,169.404008388519 PathPoint;PointKind.SMOOTHPOINT 3563.43153476715,166.25554561615 3574.52302694321,166.642169952393 3552.34004259109,165.868685245514 PathPoint;PointKind.SMOOTHPOINT 3599.96470212936,167.265536785126 3619.69387292862,167.356173992157 3580.23529529572,167.174663543701 PathPoint;PointKind.SMOOTHPOINT 3629.39394235611,163.225336074829 3643.03767442703,168.255937099457 3625.37923336029,161.744928359985 PathPoint;PointKind.SMOOTHPOINT 3643.60132455826,167.265536785126 3650.75647115707,166.945946216583 3636.44617795944,167.585127353668 PathPoint;PointKind.SMOOTHPOINT 3656.79375886917,163.225336074829 3668.46400737762,163.552715778351 3645.12351036072,162.897720336914 PathPoint;PointKind.SMOOTHPOINT 3684.19357538223,164.235327243805 3709.53588008881,165.63595533371 3658.85103464127,162.8346991539 PathPoint;PointKind.SMOOTHPOINT 3714.63776350021,162.215344905853 3736.53136968613,161.248548030853 3692.7441573143,163.18190574646 PathPoint;PointKind.SMOOTHPOINT 3746.09689950943,162.215344905853 3751.18981361389,161.257281303406 3731.39313697815,164.397954940796 PathPoint;PointKind.SMOOTHPOINT 3759.28933382034,161.205117702484 3765.63582658768,160.384662151337 3752.94284105301,162.025809288025 PathPoint;PointKind.SMOOTHPOINT 3770.45210838318,163.225336074829 3778.07507514954,164.752242565155 3762.82914161682,161.698429584503 PathPoint;PointKind.SMOOTHPOINT 3782.62983083725,163.225336074829 3790.81573963165,163.01219701767 3774.44392204285,163.438475131989 PathPoint;PointKind.SMOOTHPOINT 3793.79260540009,167.265536785126 3798.93013000488,169.956328868866 3788.65531682968,164.574744701385 PathPoint;PointKind.SMOOTHPOINT 3800.89629650116,182.416112422943 3800.66639900208,197.219717502594 3801.12619400024,167.612743377686 PathPoint;PointKind.SMOOTHPOINT 3801.9112443924,216.757936477661 3803.59204530716,227.30418920517 3800.23044347763,206.211447715759 PathPoint;PointKind.SMOOTHPOINT 3801.9112443924,242.009131908417 3800.68622589111,251.146731376648 3803.13602685928,232.871296405792 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,447.048668861389 3804.90014791489,468.981692790985 3805.01108407974,425.115644931793 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,539.973049163818 3803.33830833435,552.334406375885 3804.5432639122,527.611927986145 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,688.450248241425 3804.45616722107,698.60987663269 3803.42540502548,678.290619850159 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,722.791836261749 3804.68205213547,735.208189487457 3805.22917985916,710.375247001648 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,769.254026412964 3806.02579593658,780.431671142578 3803.88520002365,758.07638168335 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,820.766408443451 3807.28645563126,829.000704288483 3804.65420007706,812.532112598419 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,835.917220115662 3803.87741088867,842.782280445099 3804.00416135788,829.051923751831 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,857.128214836121 3806.86631441116,866.21081829071 3805.07457733154,848.045611381531 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,891.469802856445 3805.14987230301,908.964200019836 3804.76135969162,873.975405693054 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,929.851591587067 3806.36686563492,938.906579017639 3805.57402610779,920.796604156494 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,953.082804679871 3803.88921260834,964.185390472412 3803.99235963821,941.979982852936 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,983.384191989899 3803.85758399963,995.994093418121 3806.053647995,970.774290561676 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,1010.65536975861 3802.97363519669,1019.10681724548 3804.90793704987,1002.20415830612 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,1044.99719381332 3803.25498819351,1061.17357492447 3804.62658405304,1028.82057666779 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,1081.3587641716 3803.23917388916,1095.65725564957 3804.64239835739,1067.06027269363 PathPoint;PointKind.SMOOTHPOINT 3802.92595624924,1117.72057056427 3802.18457221985,1131.23778820038 3803.66734027863,1104.20335292816 PathPoint;PointKind.SMOOTHPOINT 3802.92595624924,1148.0219578743 3803.71077060699,1163.15294265747 3802.14114189148,1132.89097309113 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,1224.78553533554 3804.253885746,1243.16364526749 3805.65711021423,1206.40742540359 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,1289.42874670029 3805.97481250763,1295.35934686661 3805.95852613449,1273.75323057175 PathPoint;PointKind.SMOOTHPOINT 3805.89739322662,1355.18415212631 3805.89338064194,1358.72159957886 3805.93397855759,1322.62485980988 PathPoint;PointKind.SMOOTHPOINT 3805.88559150696,1365.96313476562 3807.50053882599,1369.43850517273 3804.34947967529,1362.6577091217 PathPoint;PointKind.SMOOTHPOINT 3805.87874650955,1372.57162570953 3805.82917928696,1422.39990234375 3805.88087081909,1370.35644292831 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,1487.39810943604 3806.26371860504,1504.96732950211 3805.80722808838,1477.63218641281 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,1591.43286466599 3805.25278329849,1616.04487895966 3804.65821266174,1566.82085037231 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,1703.54825735092 3804.44885015488,1721.34194612503 3805.72060346603,1676.68423891068 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,1782.33205318451 3805.74043035507,1799.13982629776 3804.17080163956,1765.52428007126 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,1840.91484546661 3804.80880260468,1863.84605884552 3807.13185310364,1817.98363208771 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,1904.54782962799 3803.5377573967,1932.60854244232 3804.29353952408,1879.97688531876 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,1972.22101449966 3805.53437232971,1991.41179084778 3806.40651941299,1953.03000211716 PathPoint;PointKind.SMOOTHPOINT 3806.98527574539,2031.81379795074 3807.42123126984,2052.54753112793 3806.54908418655,2011.08030080795 PathPoint;PointKind.SMOOTHPOINT 3807.99998760223,2098.47699165344 3808.04766654968,2111.46171569824 3807.95254468918,2085.49226760864 PathPoint;PointKind.SMOOTHPOINT 3806.98527574539,2176.25056028366 3807.13256120682,2201.26359701157 3806.84979200363,2153.28441381454 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,2248.974173069 3806.44617319107,2276.81348562241 3805.49471855164,2221.1346244812 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2316.64735794067 3803.71879577637,2341.25535964966 3806.19243621826,2292.0391201973 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2379.27035093307 3804.67803955078,2405.63798904419 3805.23295640945,2352.90247678757 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,2441.89334392548 3804.49180841446,2490.68330526352 3807.44908332825,2393.10314655304 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2510.57651996613 3805.03563165665,2519.42568540573 3804.65042352676,2476.85027360916 PathPoint;PointKind.SMOOTHPOINT 3805.04884958267,2535.36390781403 3805.04625320435,2537.86610841751 3805.05687475204,2527.64581918716 PathPoint;PointKind.SMOOTHPOINT 3805.03303527832,2542.71637916565 3802.65097618103,2546.839427948 3806.23539447784,2540.63502788544 PathPoint;PointKind.SMOOTHPOINT 3805.00258684158,2550.27443647385 3804.93083238602,2565.46820640564 3805.01415252686,2547.80716896057 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2591.38029813766 3805.20132780075,2613.86965513229 3804.81753587723,2578.75505447388 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2637.84248828888 3805.49873113632,2653.06434631348 3804.41250085831,2622.62086629868 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,2664.10367488861 3806.02579593658,2684.22183036804 3805.91485977173,2643.98575544357 PathPoint;PointKind.SMOOTHPOINT 3802.92595624924,2698.44549894333 3803.65128993988,2732.71604061127 3802.20062255859,2664.174721241 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,2758.03828239441 3804.65821266174,2785.57783126831 3803.22335958481,2730.49873352051 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,2824.70147609711 3805.46308994293,2844.38934087753 3806.47780179977,2805.01337528229 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,2878.23384046555 3806.54908418655,2906.05757474899 3805.39157152176,2850.41034221649 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2950.95745325089 3805.68897485733,2987.82012462616 3804.2222571373,2914.09454584122 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,3026.71103954315 3806.58094882965,3059.45066213608 3805.35994291306,2993.97118091583 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,3134.7859954834 3804.44035291672,3155.83530664444 3805.47087907791,3113.73692035675 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,3251.95158004761 3804.2222571373,3281.5625667572 3803.65931510925,3222.34059333801 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,3348.91616106033 3803.61564874649,3373.57963085175 3804.26592350006,3324.25292730331 PathPoint;PointKind.SMOOTHPOINT 3802.92595624924,3437.80034065247 3802.89031505585,3466.95365667343 3802.96159744263,3408.6470246315 PathPoint;PointKind.SMOOTHPOINT 3802.92595624924,3506.48375272751 3803.79409074783,3533.75493049622 3802.05782175064,3479.21233892441 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,3577.18691110611 3802.69605875015,3593.84102582932 3805.1855134964,3560.5330324173 PathPoint;PointKind.SMOOTHPOINT 3801.9112443924,3631.72950267792 3800.63075780869,3655.21327257156 3803.19149494171,3608.24596881866 PathPoint;PointKind.SMOOTHPOINT 3801.9112443924,3693.34250450134 3801.46726369858,3715.20448207855 3802.35522508621,3671.48052692413 PathPoint;PointKind.SMOOTHPOINT 3798.86663675308,3739.80469465256 3797.18607187271,3749.57769870758 3800.54743766785,3730.03169059753 PathPoint;PointKind.SMOOTHPOINT 3798.86663675308,3774.14628267288 3797.9416179657,3789.15334939957 3800.04421234131,3755.04637956619 PathPoint;PointKind.SMOOTHPOINT 3793.79260540009,3804.44766998291 3789.93957996368,3810.00297546387 3797.64586687088,3798.89260053635 PathPoint;PointKind.SMOOTHPOINT 3748.12632322311,3809.49809789658 3741.15339517593,3809.50258255005 3772.34392404556,3809.48228359222 PathPoint;PointKind.SMOOTHPOINT 3654.24907207489,3809.31257486343 3650.43286800385,3809.30384159088 3706.23045444489,3809.43106412888 PathPoint;PointKind.SMOOTHPOINT 3642.52925634384,3809.28590297699 3637.6331949234,3807.63743877411 3646.45663261414,3810.60816764832 PathPoint;PointKind.SMOOTHPOINT 3626.59339427948,3809.24884557724 3402.08007574081,3808.72697353363 3632.04578876495,3809.26159143448 PathPoint;PointKind.SMOOTHPOINT 2905.83688259125,3807.47787952423 2855.25494813919,3807.37142801285 2944.78184938431,3807.5600194931 PathPoint;PointKind.SMOOTHPOINT 2679.53489542007,3807.47787952423 2655.40155887604,3808.34979057312 2703.66823196411,3806.60596847534 PathPoint;PointKind.SMOOTHPOINT 2589.21704292297,3808.48787069321 2582.16315507889,3808.34530591965 2630.74493408203,3809.32838916779 PathPoint;PointKind.SMOOTHPOINT 2561.45869016647,3808.05215120316 2557.95688390732,3808.00683259964 2572.6006937027,3808.19636821747 PathPoint;PointKind.SMOOTHPOINT 2550.51401138306,3807.91761159897 2547.09434509277,3809.79974985123 2556.31290435791,3804.72642660141 PathPoint;PointKind.SMOOTHPOINT 2538.4167766571,3807.78378009796 2484.11895275116,3807.21281290054 2542.56366491318,3807.82721042633 PathPoint;PointKind.SMOOTHPOINT 2393.35924386978,3807.47787952423 2367.49766349792,3808.35781574249 2412.02224731445,3806.84294700623 PathPoint;PointKind.SMOOTHPOINT 2283.76021385193,3807.47787952423 2226.41967058182,3806.92957162857 2341.10075712204,3808.02642345428 PathPoint;PointKind.SMOOTHPOINT 2138.6427283287,3808.48787069321 2085.57960033417,3806.90195560455 2191.70609235764,3810.07402181625 PathPoint;PointKind.SMOOTHPOINT 1785.490193367,3808.48787069321 1744.29133415222,3807.18590497971 1826.68881654739,3809.7900724411 PathPoint;PointKind.SMOOTHPOINT 1572.38064050674,3807.47787952423 1570.1874089241,3807.48637676239 1600.98942518234,3807.36741542816 PathPoint;PointKind.SMOOTHPOINT 1561.84217691422,3807.51894950867 1558.56200695038,3807.53169536591 1566.60346269608,3807.5003027916 PathPoint;PointKind.SMOOTHPOINT 1550.39521694183,3807.563560009 1546.76666021347,3808.95639896393 1554.81354475021,3805.86765289307 PathPoint;PointKind.SMOOTHPOINT 1537.59341955185,3807.6131272316 1457.32591152191,3807.9235124588 1542.22205400467,3807.5954246521 PathPoint;PointKind.SMOOTHPOINT 1249.67205762863,3808.48787069321 1220.75005531311,3808.33421230316 1273.47659826279,3808.61462116241 PathPoint;PointKind.SMOOTHPOINT 1022.35535860062,3808.48787069321 969.141404628754,3808.45246553421 1075.56931257248,3808.5235118866 PathPoint;PointKind.SMOOTHPOINT 778.801853656769,3807.47787952423 740.504801273346,3807.01619625092 817.098906040192,3807.93956279755 PathPoint;PointKind.SMOOTHPOINT 590.047745704651,3808.48787069321 553.938732147217,3808.62996339798 626.156523227692,3808.34601402283 PathPoint;PointKind.SMOOTHPOINT 419.560103416443,3807.47787952423 386.349120140076,3806.99259281158 452.771322727203,3807.96316623688 PathPoint;PointKind.SMOOTHPOINT 258.205811977386,3808.48787069321 231.262013912201,3807.98299312592 285.149846076965,3808.99298429489 PathPoint;PointKind.SMOOTHPOINT 194.273064136505,3807.47787952423 174.690470695496,3807.62398481369 213.855657577515,3807.33201026917 PathPoint;PointKind.SMOOTHPOINT 170.932567119598,3808.48787069321 168.32957983017,3808.0540394783 176.232483386993,3809.37181949615 PathPoint;PointKind.SMOOTHPOINT 163.828876018524,3802.42768764496 161.303308010101,3799.26577091217 166.266167163849,3805.47914028168 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3792.32730388641 160.264520645142,3775.98640680313 158.454608917236,3795.57631731033 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3758.99570703506 160.019280910492,3742.62577772141 157.490172386169,3775.36540031433 PathPoint;PointKind.SMOOTHPOINT 157.739896774292,3700.41291475296 158.897409439087,3689.25887346268 156.582384109497,3711.56672000885 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3656.98069810867 158.613932132721,3633.61187696457 158.883247375488,3678.27218055725 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3564.05631780624 157.129983901978,3534.96201038361 160.00346660614,3586.41561985016 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3453.96114349365 157.854845523834,3425.27352333069 159.741232395172,3485.40611743927 PathPoint;PointKind.SMOOTHPOINT 159.769556522369,3399.41855192184 159.274120330811,3383.50629329681 160.265228748322,3415.33081054688 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3346.89617872238 159.21062707901,3332.51082658768 158.298826217651,3361.28129482269 PathPoint;PointKind.SMOOTHPOINT 157.739896774292,3283.263194561 158.423452377319,3261.55723571777 157.057285308838,3304.94602203369 PathPoint;PointKind.SMOOTHPOINT 155.710473060608,3204.47939872742 156.602210998535,3176.60444498062 154.818499088287,3232.35435247421 PathPoint;PointKind.SMOOTHPOINT 157.739896774292,3136.80621385574 157.577505111694,3109.1127705574 157.902524471283,3164.49965715408 PathPoint;PointKind.SMOOTHPOINT 156.72518491745,3068.1228017807 156.83210849762,3041.6487121582 156.61826133728,3094.59712743759 PathPoint;PointKind.SMOOTHPOINT 156.72518491745,3013.58021020889 157.280101776123,2975.43516397476 156.170268058777,3051.72549247742 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2948.93723487854 154.558389186859,2922.89579629898 154.828884601593,2974.23020839691 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2885.30425071716 154.577980041504,2858.58822584152 154.909608364105,2933.95613193512 PathPoint;PointKind.SMOOTHPOINT 155.184824466705,2819.60974216461 155.207483768463,2817.33295440674 155.004258155823,2837.79690027237 PathPoint;PointKind.SMOOTHPOINT 155.239584445953,2812.89503574371 156.368300914764,2810.74216604233 153.783252239227,2815.67268848419 PathPoint;PointKind.SMOOTHPOINT 155.262007713318,2805.72690725327 155.260119438171,2796.21802568436 155.262479782104,2808.08040618896 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2778.23928594589 153.320152759552,2748.8294005394 155.116846561432,2787.24777460098 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2698.44549894333 154.271371364594,2676.07439517975 155.119678974152,2720.81636667252 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2642.89268016815 155.194973945618,2613.9683175087 154.196076393127,2671.817278862 PathPoint;PointKind.SMOOTHPOINT 153.680813312531,2544.91810798645 155.488364696503,2514.79020595551 151.873261928558,2575.0460100174 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2459.06413793564 154.89497423172,2438.28461408615 154.488759040833,2480.61667442322 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2418.66213083267 155.258467197418,2407.02681541443 154.132583141327,2430.29744625092 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2393.41093540192 153.125896453857,2372.83133268356 156.265389919281,2413.99077415466 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2300.48655509949 154.112756252289,2279.68980073929 155.278294086456,2321.28330945969 PathPoint;PointKind.SMOOTHPOINT 152.665865421295,2233.82336139679 151.191358566284,2209.00623321533 154.140608310699,2258.64048957825 PathPoint;PointKind.SMOOTHPOINT 153.680813312531,2144.93918180466 154.961063861847,2108.69185209274 152.400326728821,2181.18651151657 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2015.65299510956 154.905595779419,1991.41179084778 154.485454559326,2039.89419937134 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1921.71862363815 155.321960449219,1891.91385269165 154.0629529953,1951.81961774826 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1833.844435215 154.192063808441,1794.16068077087 155.198986530304,1873.52818965912 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1621.73448801041 156.063108444214,1578.85860443115 153.327941894531,1664.61013555527 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1509.61909532547 154.738719463348,1479.99607086182 154.65044260025,1540.65903425217 PathPoint;PointKind.SMOOTHPOINT 155.710473060608,1423.76512527466 157.054216861725,1383.9942741394 154.366493225098,1463.53574037552 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1331.8507361412 154.925422668457,1306.47326231003 154.465627670288,1357.22820997238 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1273.2679438591 155.044384002686,1247.40518331528 154.34666633606,1299.13070440292 PathPoint;PointKind.SMOOTHPOINT 156.72518491745,1217.71536111832 157.728095054626,1199.07666921616 155.722274780273,1236.35381698608 PathPoint;PointKind.SMOOTHPOINT 156.72518491745,1153.07214975357 157.926363945007,1128.43653202057 155.524005889893,1177.70800352097 PathPoint;PointKind.SMOOTHPOINT 156.72518491745,1062.16798782349 158.489305973053,1029.14795637131 154.961063861847,1095.18778324127 PathPoint;PointKind.SMOOTHPOINT 157.739896774292,853.088014125824 159.036197662354,811.376252174377 156.443831920624,894.799776077271 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,732.892220020294 158.782460689545,701.509795188904 158.726992607117,764.274880886078 PathPoint;PointKind.SMOOTHPOINT 160.784504413605,543.003258705139 159.963812828064,511.672053337097 161.604959964752,574.334464073181 PathPoint;PointKind.SMOOTHPOINT 160.784504413605,373.315300941467 163.480017185211,333.639335632324 158.088755607605,412.99126625061 PathPoint;PointKind.SMOOTHPOINT 162.813928127289,295.541496276855 162.655549049377,275.557644367218 162.972543239594,315.525584220886 PathPoint;PointKind.SMOOTHPOINT 162.813928127289,245.039105415344 162.45326757431,224.924962520599 163.174824714661,265.153248310089 PathPoint";
	
	maskSquare[1] = "PointKind.SMOOTHPOINT 162,174 162,174 160.71951341629,180.28134727478 PathPoint;PointKind.SMOOTHPOINT 162.813928127289,161.205117702484 166.210463047028,158.559172153473 161.039185523987,162.587807178497 PathPoint;PointKind.SMOOTHPOINT 183,158 194.907935142517,155.265777587891 171.09182882309,160.734222412109 PathPoint;PointKind.SMOOTHPOINT 204,157 205.757748126984,157.094177722931 189.49521446228,156.222738742828 PathPoint;PointKind.SMOOTHPOINT 213.608057498932,156.373021602631 216.849517822266,151.761381626129 212.653770446777,157.730927467346 PathPoint;PointKind.SMOOTHPOINT 222.886333465576,156.464366912842 226.669964790344,153.349421024323 220.586414337158,158.357598781586 PathPoint;PointKind.SMOOTHPOINT 234.86531496048,155.144934654236 239.029197692871,155.667986869812 231.045806407928,154.665076732635 PathPoint;PointKind.SMOOTHPOINT 252,155 256.623205661774,155.918173789978 246.739973545074,153.955547809601 PathPoint;PointKind.SMOOTHPOINT 272,154 283.004631519318,153.757356643677 265.836669921875,154.135719776154 PathPoint;PointKind.SMOOTHPOINT 291.69460773468,155.144934654236 299.983427524567,155.906381607056 286.381237506866,154.65681552887 PathPoint;PointKind.SMOOTHPOINT 333,156 352.571499824524,155.563572406769 314.395533084869,156.414712429047 PathPoint;PointKind.SMOOTHPOINT 368.819789886475,154.13494348526 378.868718147278,152.903788089752 358.770861625671,155.365862846375 PathPoint;PointKind.SMOOTHPOINT 400,152 421.528933048248,152.848307609558 378.471066951752,151.151692390442 PathPoint;PointKind.SMOOTHPOINT 441.885888576508,155.144934654236 459.355738162994,152.098910808563 424.416275024414,158.190958499908 PathPoint;PointKind.SMOOTHPOINT 476.389396190643,154.13494348526 494.636034965515,154.908192157745 458.142521381378,153.361458778381 PathPoint;PointKind.SMOOTHPOINT 524.085338115692,150.094742774963 546.315765380859,151.049501895905 501.854674816132,149.139983654022 PathPoint;PointKind.SMOOTHPOINT 564.677588939667,155.144934654236 574.346029758453,154.466335773468 555.00914812088,155.823533535004 PathPoint;PointKind.SMOOTHPOINT 590.047745704651,151.104733943939 599.215557575226,151.317636966705 566.088838577271,150.548400878906 PathPoint;PointKind.SMOOTHPOINT 615.417902469635,154.13494348526 621.963844299316,153.82904291153 606.155440807343,154.567594528198 PathPoint;PointKind.SMOOTHPOINT 634.699079990387,153.124952316284 637.059423923492,152.101979255676 629.237480163574,155.491669178009 PathPoint;PointKind.SMOOTHPOINT 654,157 663.38708782196,156.814476966858 650.708972454071,157.06490945816 PathPoint;PointKind.SMOOTHPOINT 677.320990562439,155.144934654236 681.133654117584,155.20370721817 661.960344314575,154.908192157745 PathPoint;PointKind.SMOOTHPOINT 687,155 690.914394378662,158.098423480988 682.736746788025,151.624944210052 PathPoint;PointKind.SMOOTHPOINT 706,154 714.889763355255,153.631550312042 700.669163227081,154.220928192139 PathPoint;PointKind.SMOOTHPOINT 730.090963840485,155.144934654236 745.808730125427,154.588601589203 722.704031467438,155.406460762024 PathPoint;PointKind.SMOOTHPOINT 765,152 770.326989274983,153.486835755311 754.148924160004,148.971283245087 PathPoint;PointKind.SMOOTHPOINT 788.445274829865,154.368145465851 792.732603549957,153.694267272949 780.616958141327,155.598828792572 PathPoint;PointKind.SMOOTHPOINT 822.438476085663,158.175144195557 828.920452594757,158.080730438232 810.24069070816,158.352642059326 PathPoint;PointKind.SMOOTHPOINT 839.230906963348,158.044145107269 840.818710327148,157.260038852692 834.352548122406,160.45334815979 PathPoint;PointKind.SMOOTHPOINT 844.418234825134,158.03352355957 855.19816160202,158.010156154633 842.721855640411,158.037300109863 PathPoint;PointKind.SMOOTHPOINT 882.312140464783,157.164916992188 896.375777721405,156.527388095856 865.088710784912,157.945954799652 PathPoint;PointKind.SMOOTHPOINT 918,156 923.134456157684,156.785286426544 907.515824317932,154.396618366241 PathPoint;PointKind.SMOOTHPOINT 947.259600162506,155.144934654236 966.568865776062,158.723452091217 937.82719373703,153.396863937378 PathPoint;PointKind.SMOOTHPOINT 987,154 991.093780517578,153.909126758575 968.674053668976,154.406215190887 PathPoint;PointKind.SMOOTHPOINT 1001.5626168251,154.27538394928 1008.28251600266,153.108901977539 997.957899570465,154.900875091553 PathPoint;PointKind.SMOOTHPOINT 1018.29603910446,155.144934654236 1026.03159427643,155.980968475342 1011.86646223068,154.45004940033 PathPoint;PointKind.SMOOTHPOINT 1041.63677215576,156.154925823212 1053.98089885712,155.748474597931 1036.40152931213,156.327230930328 PathPoint;PointKind.SMOOTHPOINT 1080,152 1086.81407690048,151.17151927948 1073.18568706512,152.828716754913 PathPoint;PointKind.SMOOTHPOINT 1103,153 1117.02894020081,153.560345649719 1088.97105979919,152.439890384674 PathPoint;PointKind.SMOOTHPOINT 1133.98404836655,152.114725112915 1146.9387960434,152.40669965744 1121.02953672409,151.82275056839 PathPoint;PointKind.SMOOTHPOINT 1154.28017377853,156.154925823212 1174.37425374985,156.652014255524 1134.18632984161,155.6578373909 PathPoint;PointKind.SMOOTHPOINT 1174.57629919052,153.124952316284 1175.06890296936,153.138406276703 1160.76687097549,152.746117115021 PathPoint;PointKind.SMOOTHPOINT 1180.99997520447,153.999931812286 1183.19415092468,154.00016784668 1179.78675842285,153.999931812286 PathPoint;PointKind.SMOOTHPOINT 1186.75402164459,157.164916992188 1188.37203741074,157.154295444489 1184.78407859802,157.17789888382 PathPoint;PointKind.SMOOTHPOINT 1189.9999666214,155.000009536743 1192.57675409317,155.487184524536 1188.91869306564,154.795603752136 PathPoint;PointKind.SMOOTHPOINT 1198.00011634827,153.999931812286 1198.7894153595,154.048318862915 1194.95952129364,153.813700675964 PathPoint;PointKind.SMOOTHPOINT 1203,155 1207.1001534462,156.263964176178 1201.92651557922,154.668843746185 PathPoint;PointKind.SMOOTHPOINT 1208.92685651779,155.731244087219 1209.96706008911,155.202527046204 1207.0813035965,156.669716835022 PathPoint;PointKind.SMOOTHPOINT 1217.19820976257,158.175144195557 1219.31874275208,158.784112930298 1213.14880371094,157.011966705322 PathPoint;PointKind.SMOOTHPOINT 1221.9181895256,159.21275138855 1226.03911399841,159.640209674835 1220.81850528717,159.098746776581 PathPoint;PointKind.SMOOTHPOINT 1228.9999294281,156.999928951263 1230.65925121307,156.906223297119 1224.5362830162,157.251777648926 PathPoint;PointKind.SMOOTHPOINT 1234.00008201599,155.000009536743 1236.00259780884,155.575225353241 1233.81857156754,154.947845935822 PathPoint;PointKind.SMOOTHPOINT 1241.99999570847,156.999928951263 1243.18890094757,157.199141979218 1238.88080120087,156.47782087326 PathPoint;PointKind.SMOOTHPOINT 1253.73137712479,159.185135364532 1255.78346014023,158.416843414307 1248.93232584,160.981829166412 PathPoint;PointKind.SMOOTHPOINT 1258.99423599243,158.338952064514 1259.83333826065,157.877504825592 1257.75434732437,159.020619392395 PathPoint;PointKind.SMOOTHPOINT 1269,158 1273.14193153381,158.054051876068 1266.09111213684,157.96223449707 PathPoint;PointKind.SMOOTHPOINT 1276.00004196167,159.99992609024 1276.62482500076,160.385370254517 1274.00673151016,158.770186901093 PathPoint;PointKind.SMOOTHPOINT 1285.0000333786,159.99992609024 1289.89892721176,159.502365589142 1280.17454624176,160.489933490753 PathPoint;PointKind.SMOOTHPOINT 1292,162 1293.39968395233,161.602754116058 1289.30897188187,162.76357126236 PathPoint;PointKind.SMOOTHPOINT 1297.38263368607,157.134940624237 1297.43479728699,157.112045288086 1294.58562612534,158.360903263092 PathPoint;PointKind.SMOOTHPOINT 1301.99993848801,158.00000667572 1301.92535161972,158.167119026184 1302.0284986496,157.936041355133 PathPoint;PointKind.SMOOTHPOINT 1306.9998550415,158.00000667572 1308.48639965057,158.080022335052 1304.91331100464,157.887654304504 PathPoint;PointKind.SMOOTHPOINT 1312.00000762939,158.00000667572 1313.30268144608,158.882539272308 1310.53494215012,157.007482051849 PathPoint;PointKind.SMOOTHPOINT 1316.64941310883,159.185135364532 1320.21140813828,159.96994972229 1314.99858856201,158.821406364441 PathPoint;PointKind.SMOOTHPOINT 1324.29621934891,157.285530567169 1326.37851476669,157.390093803406 1321.62265777588,157.151226997375 PathPoint;PointKind.SMOOTHPOINT 1329.84184741974,157.164916992188 1332.75876045227,157.888598442078 1327.37080335617,156.55193567276 PathPoint;PointKind.SMOOTHPOINT 1337.62933015823,159.134624004364 1339.29714918137,159.167432785034 1335.24089813232,159.087653160095 PathPoint;PointKind.SMOOTHPOINT 1348.10831308365,161.205117702484 1350.99147319794,161.507477760315 1344.87723827362,160.866408348083 PathPoint;PointKind.SMOOTHPOINT 1355.93639373779,158.540761470795 1358.15629720688,158.447291851044 1353.14670324326,158.658306598663 PathPoint;PointKind.SMOOTHPOINT 1362.999958992,159.000084400177 1370.32316207886,162.344927787781 1360.61813592911,157.912201881409 PathPoint;PointKind.SMOOTHPOINT 1376.52284145355,161.205117702484 1383.78514766693,160.459485054016 1369.26077127457,161.950986385345 PathPoint;PointKind.SMOOTHPOINT 1396.75980567932,159.175221920013 1399.21810388565,157.535254955292 1390.50536632538,163.347365856171 PathPoint;PointKind.SMOOTHPOINT 1402.00000524521,159.000084400177 1402.43714094162,158.030219078064 1401.47199630737,160.172703266144 PathPoint;PointKind.SMOOTHPOINT 1409.00007724762,159.000084400177 1410.90039014816,159.079391956329 1406.62816762924,158.900713920593 PathPoint;PointKind.SMOOTHPOINT 1415.01163721085,161.205117702484 1425.19604921341,161.541466712952 1411.77277326584,161.098430156708 PathPoint;PointKind.SMOOTHPOINT 2130.52432537079,162.215344905853 2154.78063583374,162.274353504181 2106.26801490784,162.156100273132 PathPoint;PointKind.SMOOTHPOINT 2273.61215114594,161.205117702484 2304.93249893188,160.573961734772 2242.29180335999,161.83650970459 PathPoint;PointKind.SMOOTHPOINT 2389.30016040802,162.215344905853 2422.88785457611,161.461687088013 2355.71246623993,162.968766689301 PathPoint;PointKind.SMOOTHPOINT 2481.6474366188,165.245318412781 2496.08872890472,165.249330997467 2467.20638036728,165.241541862488 PathPoint;PointKind.SMOOTHPOINT 2521.22497558594,164.235327243805 2531.01237773895,165.166482925415 2511.43757343292,163.304171562195 PathPoint;PointKind.SMOOTHPOINT 2538.47672939301,163.225336074829 2561.58732891083,163.292369842529 2515.36612987518,163.158302307129 PathPoint;PointKind.SMOOTHPOINT 2562,167 2572.75443506241,167.047206878662 2551.2453289032,166.952557086945 PathPoint;PointKind.SMOOTHPOINT 2590.23175477982,163.225336074829 2606.12395048141,163.339812755585 2574.33979511261,163.110859394073 PathPoint;PointKind.SMOOTHPOINT 2621.69089078903,164.235327243805 2632.48497962952,164.937765598297 2610.89656591415,163.533124923706 PathPoint;PointKind.SMOOTHPOINT 2644,165 2655.20738506317,161.47435426712 2629.86366415024,169.447360038757 PathPoint;PointKind.SMOOTHPOINT 2668.37188482285,167.265536785126 2671.55905723572,166.324939727783 2665.18494844437,168.206133842468 PathPoint;PointKind.SMOOTHPOINT 2683.59397888184,163.225336074829 2690.86667060852,166.887409687042 2677.17856407166,159.994733333588 PathPoint;PointKind.SMOOTHPOINT 2693.74204158783,168.275527954102 2703.08145046234,169.553890228271 2688.66801023483,167.581114768982 PathPoint;PointKind.SMOOTHPOINT 2713,166 2719.68260574341,168.037448883057 2704.66987419128,163.460269927979 PathPoint;PointKind.SMOOTHPOINT 2729.2604970932,166.25554561615 2739.6025800705,164.56294298172 2718.91817808151,167.94814825058 PathPoint;PointKind.CORNERPOINT 2753.61570596695,166.25554561615 2753.61570596695,166.25554561615 2753.61570596695,166.25554561615 PathPoint;PointKind.SMOOTHPOINT 2772,163 2778.16828680038,163.430054664612 2765.83194923401,162.569945335388 PathPoint;PointKind.SMOOTHPOINT 2793.19324493408,165.245318412781 2798.75492334366,165.127065181732 2787.63156652451,165.363807678223 PathPoint;PointKind.SMOOTHPOINT 2817,162 2826.09747362137,163.27836227417 2807.90229034424,160.72163772583 PathPoint;PointKind.SMOOTHPOINT 2852.05196142197,166.25554561615 2869.30371522903,166.882688999176 2834.8002076149,165.62816619873 PathPoint;PointKind.SMOOTHPOINT 2888,163 2896.46324920654,163.094649791718 2879.53675079346,162.905350208282 PathPoint;PointKind.SMOOTHPOINT 2924.10334825516,164.235327243805 2936.15408420563,163.746027946472 2912.05237627029,164.724626541138 PathPoint;PointKind.SMOOTHPOINT 2955.56224822998,164.235327243805 2976.81785345078,164.91014957428 2934.30687904358,163.560740947723 PathPoint;PointKind.SMOOTHPOINT 3004.47429917853,163.203629495405 3016.75940999427,164.637791358203 2994.30806532195,162.016824988382 PathPoint;PointKind.SMOOTHPOINT 3036.74674987793,162.215344905853 3058.30759639817,162.161104682321 3015.09163415656,162.269822280674 PathPoint;PointKind.SMOOTHPOINT 3071.25025749207,164.235327243805 3087.38013982773,164.310386180878 3055.1203751564,164.160504341125 PathPoint;PointKind.SMOOTHPOINT 3102.70939350128,163.225336074829 3125.13006448746,163.607947826385 3080.28848648071,162.842488288879 PathPoint;PointKind.SMOOTHPOINT 3149.3903875351,166.25554561615 3161.13593101501,166.444845199585 3137.64484405518,166.066009998322 PathPoint;PointKind.SMOOTHPOINT 3181.86423540115,164.235327243805 3205.03832817078,164.468057155609 3158.69014263153,164.002597332001 PathPoint;PointKind.SMOOTHPOINT 3230.57488918304,166.25554561615 3248.52837324142,166.243507862091 3212.62164115906,166.267347335815 PathPoint;PointKind.SMOOTHPOINT 3264,165 3276.83555030823,163.883557319641 3251.16421365738,166.116678714752 PathPoint;PointKind.SMOOTHPOINT 3286.38923406601,165.245318412781 3298.6580657959,165.466246604919 3274.12040233612,165.024390220642 PathPoint;PointKind.SMOOTHPOINT 3305.67064762115,165.245318412781 3321.38440132141,164.448466300964 3289.9568939209,166.04240655899 PathPoint;PointKind.SMOOTHPOINT 3330.0260925293,168.275527954102 3340.76070070267,168.662152290344 3319.29124832153,167.888903617859 PathPoint;PointKind.SMOOTHPOINT 3348.29255819321,165.245318412781 3365.38970947266,163.864517211914 3331.19540691376,166.626355648041 PathPoint;PointKind.SMOOTHPOINT 3379,168 3389.73484420776,167.885523319244 3368.26515579224,168.114476680756 PathPoint;PointKind.SMOOTHPOINT 3405.12161493301,166.25554561615 3421.04142665863,164.35759305954 3389.20203924179,168.153262138367 PathPoint;PointKind.SMOOTHPOINT 3436,166 3447.83665275574,166.875923633575 3424.16311120987,165.124076366425 PathPoint;PointKind.SMOOTHPOINT 3462.96561956406,166.25554561615 3472.59039402008,166.25554561615 3453.34084510803,166.25554561615 PathPoint;PointKind.SMOOTHPOINT 3487,167 3500.50966453552,167.599763393402 3473.49033546448,166.400236606598 PathPoint;PointKind.SMOOTHPOINT 3517.76525259018,165.245318412781 3534.46987867355,166.590714454651 3501.06062650681,163.899922370911 PathPoint;PointKind.SMOOTHPOINT 3541.10574960709,169.285519123077 3552.87914514542,169.167265892029 3529.33235406876,169.404008388519 PathPoint;PointKind.SMOOTHPOINT 3565,164 3576.09149217606,164.386624336243 3553.90850782394,163.613139629364 PathPoint;PointKind.SMOOTHPOINT 3599.96470212936,167.265536785126 3619.69387292862,167.356173992157 3580.23529529572,167.174663543701 PathPoint;PointKind.SMOOTHPOINT 3627,165 3640.64373207092,170.030601024628 3622.98529100418,163.519592285156 PathPoint;PointKind.SMOOTHPOINT 3643.60132455826,167.265536785126 3650.75647115707,166.945946216583 3636.44617795944,167.585127353668 PathPoint;PointKind.SMOOTHPOINT 3656.79375886917,163.225336074829 3668.46400737762,163.552715778351 3645.12351036072,162.897720336914 PathPoint;PointKind.SMOOTHPOINT 3687,165 3712.34230470657,166.400628089905 3661.65745925903,163.599371910095 PathPoint;PointKind.SMOOTHPOINT 3714.63776350021,162.215344905853 3736.53136968613,161.248548030853 3692.7441573143,163.18190574646 PathPoint;PointKind.SMOOTHPOINT 3743,162 3748.09291410446,161.041936397552 3728.29623746872,164.182610034943 PathPoint;PointKind.SMOOTHPOINT 3759.28933382034,161.205117702484 3765.63582658768,160.384662151337 3752.94284105301,162.025809288025 PathPoint;PointKind.SMOOTHPOINT 3770.45210838318,163.225336074829 3778.07507514954,164.752242565155 3762.82914161682,161.698429584503 PathPoint;PointKind.SMOOTHPOINT 3782.62983083725,163.225336074829 3790.81573963165,163.01219701767 3774.44392204285,163.438475131989 PathPoint;PointKind.SMOOTHPOINT 3795,168 3800.1375246048,170.69079208374 3789.8627114296,165.30920791626 PathPoint;PointKind.SMOOTHPOINT 3800,190 3799.77010250092,204.803605079651 3800.22989749908,175.196630954742 PathPoint;PointKind.SMOOTHPOINT 3801.9112443924,216.757936477661 3803.59204530716,227.30418920517 3800.23044347763,206.211447715759 PathPoint;PointKind.SMOOTHPOINT 3801.9112443924,242.009131908417 3800.68622589111,251.146731376648 3803.13602685928,232.871296405792 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,447.048668861389 3804.90014791489,468.981692790985 3805.01108407974,425.115644931793 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,539.973049163818 3803.33830833435,552.334406375885 3804.5432639122,527.611927986145 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,688.450248241425 3804.45616722107,698.60987663269 3803.42540502548,678.290619850159 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,722.791836261749 3804.68205213547,735.208189487457 3805.22917985916,710.375247001648 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,769.254026412964 3806.02579593658,780.431671142578 3803.88520002365,758.07638168335 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,820.766408443451 3807.28645563126,829.000704288483 3804.65420007706,812.532112598419 PathPoint;PointKind.SMOOTHPOINT 3803,838 3802.93674278259,844.865060329437 3803.0634932518,831.134703636169 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,857.128214836121 3806.86631441116,866.21081829071 3805.07457733154,848.045611381531 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,891.469802856445 3805.14987230301,908.964200019836 3804.76135969162,873.975405693054 PathPoint;PointKind.SMOOTHPOINT 3806,927 3806.39653778076,936.054987430573 3805.60369825363,917.945012569427 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,953.082804679871 3803.88921260834,964.185390472412 3803.99235963821,941.979982852936 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,983.384191989899 3803.85758399963,995.994093418121 3806.053647995,970.774290561676 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,1010.65536975861 3802.97363519669,1019.10681724548 3804.90793704987,1002.20415830612 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,1044.99719381332 3803.25498819351,1061.17357492447 3804.62658405304,1028.82057666779 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,1081.3587641716 3803.23917388916,1095.65725564957 3804.64239835739,1067.06027269363 PathPoint;PointKind.SMOOTHPOINT 3803,1120 3802.25861597061,1133.51721763611 3803.74138402939,1106.48278236389 PathPoint;PointKind.SMOOTHPOINT 3802.92595624924,1148.0219578743 3803.71077060699,1163.15294265747 3802.14114189148,1132.89097309113 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,1224.78553533554 3804.253885746,1243.16364526749 3805.65711021423,1206.40742540359 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,1289.42874670029 3805.97481250763,1295.35934686661 3805.95852613449,1273.75323057175 PathPoint;PointKind.SMOOTHPOINT 3806,1351 3805.99598741531,1354.53744745255 3806.03658533096,1318.44070768356 PathPoint;PointKind.SMOOTHPOINT 3805.88559150696,1365.96313476562 3807.50053882599,1369.43850517273 3804.34947967529,1362.6577091217 PathPoint;PointKind.SMOOTHPOINT 3805.87874650955,1372.57162570953 3805.82917928696,1422.39990234375 3805.88087081909,1370.35644292831 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,1487.39810943604 3806.26371860504,1504.96732950211 3805.80722808838,1477.63218641281 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,1591.43286466599 3805.25278329849,1616.04487895966 3804.65821266174,1566.82085037231 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,1703.54825735092 3804.44885015488,1721.34194612503 3805.72060346603,1676.68423891068 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,1782.33205318451 3805.74043035507,1799.13982629776 3804.17080163956,1765.52428007126 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,1840.91484546661 3804.80880260468,1863.84605884552 3807.13185310364,1817.98363208771 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,1904.54782962799 3803.5377573967,1932.60854244232 3804.29353952408,1879.97688531876 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,1972.22101449966 3805.53437232971,1991.41179084778 3806.40651941299,1953.03000211716 PathPoint;PointKind.SMOOTHPOINT 3806.98527574539,2031.81379795074 3807.42123126984,2052.54753112793 3806.54908418655,2011.08030080795 PathPoint;PointKind.SMOOTHPOINT 3808,2101 3808.04767894745,2113.9847240448 3807.95255708694,2088.0152759552 PathPoint;PointKind.SMOOTHPOINT 3806.98527574539,2176.25056028366 3807.13256120682,2201.26359701157 3806.84979200363,2153.28441381454 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,2248.974173069 3806.44617319107,2276.81348562241 3805.49471855164,2221.1346244812 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2316.64735794067 3803.71879577637,2341.25535964966 3806.19243621826,2292.0391201973 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2379.27035093307 3804.67803955078,2405.63798904419 3805.23295640945,2352.90247678757 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,2441.89334392548 3804.49180841446,2490.68330526352 3807.44908332825,2393.10314655304 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2510.57651996613 3805.03563165665,2519.42568540573 3804.65042352676,2476.85027360916 PathPoint;PointKind.SMOOTHPOINT 3805.04884958267,2535.36390781403 3805.04625320435,2537.86610841751 3805.05687475204,2527.64581918716 PathPoint;PointKind.SMOOTHPOINT 3805.03303527832,2542.71637916565 3802.65097618103,2546.839427948 3806.23539447784,2540.63502788544 PathPoint;PointKind.SMOOTHPOINT 3805.00258684158,2550.27443647385 3804.93083238602,2565.46820640564 3805.01415252686,2547.80716896057 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2591.38029813766 3805.20132780075,2613.86965513229 3804.81753587723,2578.75505447388 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2637.84248828888 3805.49873113632,2653.06434631348 3804.41250085831,2622.62086629868 PathPoint;PointKind.SMOOTHPOINT 3806,2659 3806.05546808243,2679.11815547943 3805.94453191757,2638.88208055496 PathPoint;PointKind.SMOOTHPOINT 3802.92595624924,2698.44549894333 3803.65128993988,2732.71604061127 3802.20062255859,2664.174721241 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,2758.03828239441 3804.65821266174,2785.57783126831 3803.22335958481,2730.49873352051 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,2824.70147609711 3805.46308994293,2844.38934087753 3806.47780179977,2805.01337528229 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,2878.23384046555 3806.54908418655,2906.05757474899 3805.39157152176,2850.41034221649 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2950.95745325089 3805.68897485733,2987.82012462616 3804.2222571373,2914.09454584122 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,3026.71103954315 3806.58094882965,3059.45066213608 3805.35994291306,2993.97118091583 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,3134.7859954834 3804.44035291672,3155.83530664444 3805.47087907791,3113.73692035675 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,3251.95158004761 3804.2222571373,3281.5625667572 3803.65931510925,3222.34059333801 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,3348.91616106033 3803.61564874649,3373.57963085175 3804.26592350006,3324.25292730331 PathPoint;PointKind.SMOOTHPOINT 3802.92595624924,3437.80034065247 3802.89031505585,3466.95365667343 3802.96159744263,3408.6470246315 PathPoint;PointKind.SMOOTHPOINT 3802.92595624924,3506.48375272751 3803.79409074783,3533.75493049622 3802.05782175064,3479.21233892441 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,3577.18691110611 3802.69605875015,3593.84102582932 3805.1855134964,3560.5330324173 PathPoint;PointKind.SMOOTHPOINT 3801.9112443924,3631.72950267792 3800.63075780869,3655.21327257156 3803.19149494171,3608.24596881866 PathPoint;PointKind.SMOOTHPOINT 3801.9112443924,3693.34250450134 3801.46726369858,3715.20448207855 3802.35522508621,3671.48052692413 PathPoint;PointKind.SMOOTHPOINT 3798.86663675308,3739.80469465256 3797.18607187271,3749.57769870758 3800.54743766785,3730.03169059753 PathPoint;PointKind.SMOOTHPOINT 3798.86663675308,3774.14628267288 3797.9416179657,3789.15334939957 3800.04421234131,3755.04637956619 PathPoint;PointKind.SMOOTHPOINT 3793.79260540009,3804.44766998291 3790.3306607795,3810.25474871875 3798.29899187088,3796.88947553635 PathPoint;PointKind.SMOOTHPOINT 3748.12632322311,3809.49809789658 3741.15339517593,3809.50258255005 3772.34392404556,3809.48228359222 PathPoint;PointKind.SMOOTHPOINT 3654.24907207489,3809.31257486343 3650.43286800385,3809.30384159088 3706.23045444489,3809.43106412888 PathPoint;PointKind.SMOOTHPOINT 3623.52925634384,3809.28590297699 3615.3410074234,3806.98743877411 3627.51905558381,3810.40580040722 PathPoint;PointKind.SMOOTHPOINT 3607.59339427948,3809.24884557724 3383.08007574081,3808.72697353363 3613.04578876495,3809.26159143448 PathPoint;PointKind.SMOOTHPOINT 2905.83688259125,3807.47787952423 2855.25494813919,3807.37142801285 2944.78184938431,3807.5600194931 PathPoint;PointKind.SMOOTHPOINT 2679.53489542007,3807.47787952423 2655.40155887604,3808.34979057312 2703.66823196411,3806.60596847534 PathPoint;PointKind.SMOOTHPOINT 2589.21704292297,3808.48787069321 2582.16315507889,3808.34530591965 2630.74493408203,3809.32838916779 PathPoint;PointKind.SMOOTHPOINT 2561.45869016647,3808.05215120316 2557.95688390732,3808.00683259964 2572.6006937027,3808.19636821747 PathPoint;PointKind.SMOOTHPOINT 2550.51401138306,3807.91761159897 2547.09434509277,3809.79974985123 2556.31290435791,3804.72642660141 PathPoint;PointKind.SMOOTHPOINT 2538.4167766571,3807.78378009796 2484.11895275116,3807.21281290054 2542.56366491318,3807.82721042633 PathPoint;PointKind.SMOOTHPOINT 2393.35924386978,3807.47787952423 2367.49766349792,3808.35781574249 2412.02224731445,3806.84294700623 PathPoint;PointKind.SMOOTHPOINT 2283.76021385193,3807.47787952423 2226.41967058182,3806.92957162857 2341.10075712204,3808.02642345428 PathPoint;PointKind.SMOOTHPOINT 2138.6427283287,3808.48787069321 2085.57960033417,3806.90195560455 2191.70609235764,3810.07402181625 PathPoint;PointKind.SMOOTHPOINT 1785.490193367,3808.48787069321 1744.29133415222,3807.18590497971 1826.68881654739,3809.7900724411 PathPoint;PointKind.SMOOTHPOINT 1572.38064050674,3807.47787952423 1570.1874089241,3807.48637676239 1600.98942518234,3807.36741542816 PathPoint;PointKind.SMOOTHPOINT 1561.84217691422,3807.51894950867 1558.56200695038,3807.53169536591 1566.60346269608,3807.5003027916 PathPoint;PointKind.SMOOTHPOINT 1550.39521694183,3807.563560009 1546.76666021347,3808.95639896393 1554.81354475021,3805.86765289307 PathPoint;PointKind.SMOOTHPOINT 1537.59341955185,3807.6131272316 1457.32591152191,3807.9235124588 1542.22205400467,3807.5954246521 PathPoint;PointKind.SMOOTHPOINT 1249.67205762863,3808.48787069321 1220.75005531311,3808.33421230316 1273.47659826279,3808.61462116241 PathPoint;PointKind.SMOOTHPOINT 1022.35535860062,3808.48787069321 969.141404628754,3808.45246553421 1075.56931257248,3808.5235118866 PathPoint;PointKind.SMOOTHPOINT 778.801853656769,3807.47787952423 740.504801273346,3807.01619625092 817.098906040192,3807.93956279755 PathPoint;PointKind.SMOOTHPOINT 590.047745704651,3808.48787069321 553.938732147217,3808.62996339798 626.156523227692,3808.34601402283 PathPoint;PointKind.SMOOTHPOINT 419.560103416443,3807.47787952423 386.349120140076,3806.99259281158 452.771322727203,3807.96316623688 PathPoint;PointKind.SMOOTHPOINT 258.205811977386,3808.48787069321 231.262013912201,3807.98299312592 285.149846076965,3808.99298429489 PathPoint;PointKind.SMOOTHPOINT 194.273064136505,3807.47787952423 174.690470695496,3807.62398481369 213.855657577515,3807.33201026917 PathPoint;PointKind.SMOOTHPOINT 175,3808 172.397012710571,3807.5661687851 180.299916267395,3808.88394880295 PathPoint;PointKind.SMOOTHPOINT 163.828876018524,3802.42768764496 161.303308010101,3799.26577091217 166.266167163849,3805.47914028168 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3792.32730388641 160.264520645142,3775.98640680313 158.454608917236,3795.57631731033 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3758.99570703506 160.019280910492,3742.62577772141 157.490172386169,3775.36540031433 PathPoint;PointKind.SMOOTHPOINT 157.739896774292,3700.41291475296 158.897409439087,3689.25887346268 156.582384109497,3711.56672000885 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3656.98069810867 158.613932132721,3633.61187696457 158.883247375488,3678.27218055725 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3564.05631780624 157.129983901978,3534.96201038361 160.00346660614,3586.41561985016 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3453.96114349365 157.854845523834,3425.27352333069 159.741232395172,3485.40611743927 PathPoint;PointKind.SMOOTHPOINT 159.769556522369,3399.41855192184 159.274120330811,3383.50629329681 160.265228748322,3415.33081054688 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3346.89617872238 159.21062707901,3332.51082658768 158.298826217651,3361.28129482269 PathPoint;PointKind.SMOOTHPOINT 157.739896774292,3283.263194561 158.423452377319,3261.55723571777 157.057285308838,3304.94602203369 PathPoint;PointKind.SMOOTHPOINT 155.710473060608,3204.47939872742 156.602210998535,3176.60444498062 154.818499088287,3232.35435247421 PathPoint;PointKind.SMOOTHPOINT 157.739896774292,3136.80621385574 157.577505111694,3109.1127705574 157.902524471283,3164.49965715408 PathPoint;PointKind.SMOOTHPOINT 156.72518491745,3068.1228017807 156.83210849762,3041.6487121582 156.61826133728,3094.59712743759 PathPoint;PointKind.SMOOTHPOINT 156.72518491745,3013.58021020889 157.280101776123,2975.43516397476 156.170268058777,3051.72549247742 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2948.93723487854 154.558389186859,2922.89579629898 154.828884601593,2974.23020839691 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2885.30425071716 154.577980041504,2858.58822584152 154.909608364105,2933.95613193512 PathPoint;PointKind.SMOOTHPOINT 155.184824466705,2813.60974216461 155.207483768463,2811.33295440674 155.004258155823,2831.79690027237 PathPoint;PointKind.SMOOTHPOINT 155.239584445953,2806.89503574371 156.368300914764,2804.74216604233 153.783252239227,2809.67268848419 PathPoint;PointKind.SMOOTHPOINT 155.262007713318,2799.72690725327 155.260119438171,2790.21802568436 155.262479782104,2802.08040618896 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2778.23928594589 153.320152759552,2748.8294005394 155.116846561432,2787.24777460098 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2698.44549894333 154.271371364594,2676.07439517975 155.119678974152,2720.81636667252 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2642.89268016815 155.194973945618,2613.9683175087 154.196076393127,2671.817278862 PathPoint;PointKind.SMOOTHPOINT 153.680813312531,2544.91810798645 155.488364696503,2514.79020595551 151.873261928558,2575.0460100174 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2459.06413793564 154.89497423172,2438.28461408615 154.488759040833,2480.61667442322 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2418.66213083267 155.258467197418,2407.02681541443 154.132583141327,2430.29744625092 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2393.41093540192 153.125896453857,2372.83133268356 156.265389919281,2413.99077415466 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2300.48655509949 154.112756252289,2279.68980073929 155.278294086456,2321.28330945969 PathPoint;PointKind.SMOOTHPOINT 152.665865421295,2233.82336139679 151.191358566284,2209.00623321533 154.140608310699,2258.64048957825 PathPoint;PointKind.SMOOTHPOINT 153.680813312531,2144.93918180466 154.961063861847,2108.69185209274 152.400326728821,2181.18651151657 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2015.65299510956 154.905595779419,1991.41179084778 154.485454559326,2039.89419937134 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1921.71862363815 155.321960449219,1891.91385269165 154.0629529953,1951.81961774826 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1833.844435215 154.192063808441,1794.16068077087 155.198986530304,1873.52818965912 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1621.73448801041 156.063108444214,1578.85860443115 153.327941894531,1664.61013555527 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1509.61909532547 154.738719463348,1479.99607086182 154.65044260025,1540.65903425217 PathPoint;PointKind.SMOOTHPOINT 155.710473060608,1423.76512527466 157.054216861725,1383.9942741394 154.366493225098,1463.53574037552 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1331.8507361412 154.925422668457,1306.47326231003 154.465627670288,1357.22820997238 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1273.2679438591 155.044384002686,1247.40518331528 154.34666633606,1299.13070440292 PathPoint;PointKind.SMOOTHPOINT 156.72518491745,1217.71536111832 157.728095054626,1199.07666921616 155.722274780273,1236.35381698608 PathPoint;PointKind.SMOOTHPOINT 156.72518491745,1153.07214975357 157.926363945007,1128.43653202057 155.524005889893,1177.70800352097 PathPoint;PointKind.SMOOTHPOINT 156.72518491745,1062.16798782349 158.489305973053,1029.14795637131 154.961063861847,1095.18778324127 PathPoint;PointKind.SMOOTHPOINT 157.739896774292,853.088014125824 159.036197662354,811.376252174377 156.443831920624,894.799776077271 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,732.892220020294 158.782460689545,701.509795188904 158.726992607117,764.274880886078 PathPoint;PointKind.SMOOTHPOINT 160.784504413605,543.003258705139 159.963812828064,511.672053337097 161.604959964752,574.334464073181 PathPoint;PointKind.SMOOTHPOINT 160.784504413605,373.315300941467 163.480017185211,333.639335632324 158.088755607605,412.99126625061 PathPoint;PointKind.SMOOTHPOINT 162.813928127289,295.541496276855 162.655549049377,275.557644367218 162.972543239594,315.525584220886 PathPoint;PointKind.SMOOTHPOINT 162.813928127289,245.039105415344 162.45326757431,224.924962520599 163.174824714661,265.153248310089 PathPoint";
	
	maskSquare[2] = "PointKind.SMOOTHPOINT 162,180 162,180 160.71951341629,186.28134727478 PathPoint;PointKind.SMOOTHPOINT 162.813928127289,161.205117702484 166.210463047028,158.559172153473 161.039185523987,162.587807178497 PathPoint;PointKind.SMOOTHPOINT 180,159 191.907935142517,156.265777587891 168.09182882309,161.734222412109 PathPoint;PointKind.SMOOTHPOINT 204,157 205.757748126984,157.094177722931 189.49521446228,156.222738742828 PathPoint;PointKind.SMOOTHPOINT 213.608057498932,156.373021602631 216.849517822266,151.761381626129 212.653770446777,157.730927467346 PathPoint;PointKind.SMOOTHPOINT 222.886333465576,156.464366912842 226.669964790344,153.349421024323 220.586414337158,158.357598781586 PathPoint;PointKind.SMOOTHPOINT 234.86531496048,155.144934654236 239.029197692871,155.667986869812 231.045806407928,154.665076732635 PathPoint;PointKind.SMOOTHPOINT 252,155 256.623205661774,155.918173789978 246.739973545074,153.955547809601 PathPoint;PointKind.SMOOTHPOINT 272,154 283.004631519318,153.757356643677 265.836669921875,154.135719776154 PathPoint;PointKind.SMOOTHPOINT 291.69460773468,155.144934654236 299.983427524567,155.906381607056 286.381237506866,154.65681552887 PathPoint;PointKind.SMOOTHPOINT 331,156 350.571499824524,155.563572406769 312.395533084869,156.414712429047 PathPoint;PointKind.SMOOTHPOINT 368.819789886475,154.13494348526 378.868718147278,152.903788089752 358.770861625671,155.365862846375 PathPoint;PointKind.SMOOTHPOINT 400,156 421.528933048248,156.848307609558 378.471066951752,155.151692390442 PathPoint;PointKind.SMOOTHPOINT 441.885888576508,155.144934654236 459.355738162994,152.098910808563 424.416275024414,158.190958499908 PathPoint;PointKind.SMOOTHPOINT 476.389396190643,154.13494348526 494.636034965515,154.908192157745 458.142521381378,153.361458778381 PathPoint;PointKind.SMOOTHPOINT 524,152 546.230427265167,152.954759120941 501.769336700439,151.045240879059 PathPoint;PointKind.SMOOTHPOINT 564.677588939667,155.144934654236 574.346029758453,154.466335773468 555.00914812088,155.823533535004 PathPoint;PointKind.SMOOTHPOINT 590.047745704651,151.104733943939 599.215557575226,151.317636966705 566.088838577271,150.548400878906 PathPoint;PointKind.SMOOTHPOINT 615.417902469635,154.13494348526 621.963844299316,153.82904291153 606.155440807343,154.567594528198 PathPoint;PointKind.SMOOTHPOINT 634.699079990387,153.124952316284 637.059423923492,152.101979255676 629.237480163574,155.491669178009 PathPoint;PointKind.SMOOTHPOINT 654,157 663.38708782196,156.814476966858 650.708972454071,157.06490945816 PathPoint;PointKind.SMOOTHPOINT 677.320990562439,155.144934654236 681.133654117584,155.20370721817 661.960344314575,154.908192157745 PathPoint;PointKind.SMOOTHPOINT 687,155 690.914394378662,158.098423480988 682.736746788025,151.624944210052 PathPoint;PointKind.SMOOTHPOINT 706,154 714.889763355255,153.631550312042 700.669163227081,154.220928192139 PathPoint;PointKind.SMOOTHPOINT 730.090963840485,155.144934654236 745.808730125427,154.588601589203 722.704031467438,155.406460762024 PathPoint;PointKind.SMOOTHPOINT 761,152 766.326989274983,153.486835755311 750.148924160004,148.971283245087 PathPoint;PointKind.SMOOTHPOINT 788.445274829865,154.368145465851 792.732603549957,153.694267272949 780.616958141327,155.598828792572 PathPoint;PointKind.SMOOTHPOINT 822.438476085663,158.175144195557 828.920452594757,158.080730438232 810.24069070816,158.352642059326 PathPoint;PointKind.SMOOTHPOINT 839.230906963348,158.044145107269 840.818710327148,157.260038852692 834.352548122406,160.45334815979 PathPoint;PointKind.SMOOTHPOINT 844.418234825134,158.03352355957 855.19816160202,158.010156154633 842.721855640411,158.037300109863 PathPoint;PointKind.SMOOTHPOINT 882.312140464783,157.164916992188 896.375777721405,156.527388095856 865.088710784912,157.945954799652 PathPoint;PointKind.SMOOTHPOINT 920,156 925.134456157684,156.785286426544 909.515824317932,154.396618366241 PathPoint;PointKind.SMOOTHPOINT 947.259600162506,155.144934654236 966.568865776062,158.723452091217 937.82719373703,153.396863937378 PathPoint;PointKind.SMOOTHPOINT 984,154 988.093780517578,153.909126758575 965.674053668976,154.406215190887 PathPoint;PointKind.SMOOTHPOINT 1001.5626168251,154.27538394928 1008.28251600266,153.108901977539 997.957899570465,154.900875091553 PathPoint;PointKind.SMOOTHPOINT 1018.29603910446,155.144934654236 1026.03159427643,155.980968475342 1011.86646223068,154.45004940033 PathPoint;PointKind.SMOOTHPOINT 1041.63677215576,156.154925823212 1053.98089885712,155.748474597931 1036.40152931213,156.327230930328 PathPoint;PointKind.SMOOTHPOINT 1080,152 1086.81407690048,151.17151927948 1073.18568706512,152.828716754913 PathPoint;PointKind.SMOOTHPOINT 1103,153 1117.02894020081,153.560345649719 1088.97105979919,152.439890384674 PathPoint;PointKind.SMOOTHPOINT 1127,152 1139.95474767685,152.291974544525 1114.04548835754,151.708025455475 PathPoint;PointKind.SMOOTHPOINT 1154.28017377853,156.154925823212 1174.37425374985,156.652014255524 1134.18632984161,155.6578373909 PathPoint;PointKind.SMOOTHPOINT 1174.57629919052,153.124952316284 1175.06890296936,153.138406276703 1160.76687097549,152.746117115021 PathPoint;PointKind.SMOOTHPOINT 1180.99997520447,153.999931812286 1183.19415092468,154.00016784668 1179.78675842285,153.999931812286 PathPoint;PointKind.SMOOTHPOINT 1186.75402164459,157.164916992188 1188.37203741074,157.154295444489 1184.78407859802,157.17789888382 PathPoint;PointKind.SMOOTHPOINT 1189.9999666214,155.000009536743 1192.57675409317,155.487184524536 1188.91869306564,154.795603752136 PathPoint;PointKind.SMOOTHPOINT 1198.00011634827,153.999931812286 1198.7894153595,154.048318862915 1194.95952129364,153.813700675964 PathPoint;PointKind.SMOOTHPOINT 1203,155 1207.1001534462,156.263964176178 1201.92651557922,154.668843746185 PathPoint;PointKind.SMOOTHPOINT 1208.92685651779,155.731244087219 1209.96706008911,155.202527046204 1207.0813035965,156.669716835022 PathPoint;PointKind.SMOOTHPOINT 1217.19820976257,158.175144195557 1219.31874275208,158.784112930298 1213.14880371094,157.011966705322 PathPoint;PointKind.SMOOTHPOINT 1221.9181895256,159.21275138855 1226.03911399841,159.640209674835 1220.81850528717,159.098746776581 PathPoint;PointKind.SMOOTHPOINT 1228.9999294281,156.999928951263 1230.65925121307,156.906223297119 1224.5362830162,157.251777648926 PathPoint;PointKind.SMOOTHPOINT 1234.00008201599,155.000009536743 1236.00259780884,155.575225353241 1233.81857156754,154.947845935822 PathPoint;PointKind.SMOOTHPOINT 1241.99999570847,156.999928951263 1243.18890094757,157.199141979218 1238.88080120087,156.47782087326 PathPoint;PointKind.SMOOTHPOINT 1253.73137712479,159.185135364532 1255.78346014023,158.416843414307 1248.93232584,160.981829166412 PathPoint;PointKind.SMOOTHPOINT 1258.99423599243,158.338952064514 1259.83333826065,157.877504825592 1257.75434732437,159.020619392395 PathPoint;PointKind.SMOOTHPOINT 1269,156 1273.14193153381,156.054051876068 1266.09111213684,155.96223449707 PathPoint;PointKind.SMOOTHPOINT 1276.00004196167,159.99992609024 1276.62482500076,160.385370254517 1274.00673151016,158.770186901093 PathPoint;PointKind.SMOOTHPOINT 1285.0000333786,159.99992609024 1289.89892721176,159.502365589142 1280.17454624176,160.489933490753 PathPoint;PointKind.SMOOTHPOINT 1292,162 1293.39968395233,161.602754116058 1289.30897188187,162.76357126236 PathPoint;PointKind.SMOOTHPOINT 1297.38263368607,157.134940624237 1297.43479728699,157.112045288086 1294.58562612534,158.360903263092 PathPoint;PointKind.SMOOTHPOINT 1301.99993848801,158.00000667572 1301.92535161972,158.167119026184 1302.0284986496,157.936041355133 PathPoint;PointKind.SMOOTHPOINT 1306.9998550415,158.00000667572 1308.48639965057,158.080022335052 1304.91331100464,157.887654304504 PathPoint;PointKind.SMOOTHPOINT 1312.00000762939,158.00000667572 1313.30268144608,158.882539272308 1310.53494215012,157.007482051849 PathPoint;PointKind.SMOOTHPOINT 1316.64941310883,159.185135364532 1320.21140813828,159.96994972229 1314.99858856201,158.821406364441 PathPoint;PointKind.SMOOTHPOINT 1324.29621934891,157.285530567169 1326.37851476669,157.390093803406 1321.62265777588,157.151226997375 PathPoint;PointKind.SMOOTHPOINT 1329.84184741974,157.164916992188 1332.75876045227,157.888598442078 1327.37080335617,156.55193567276 PathPoint;PointKind.SMOOTHPOINT 1337.62933015823,159.134624004364 1339.29714918137,159.167432785034 1335.24089813232,159.087653160095 PathPoint;PointKind.SMOOTHPOINT 1348.10831308365,161.205117702484 1350.99147319794,161.507477760315 1344.87723827362,160.866408348083 PathPoint;PointKind.SMOOTHPOINT 1356,157 1358.21990346909,156.906530380249 1353.21030950546,157.117545127869 PathPoint;PointKind.SMOOTHPOINT 1362.999958992,159.000084400177 1370.32316207886,162.344927787781 1360.61813592911,157.912201881409 PathPoint;PointKind.SMOOTHPOINT 1376.52284145355,161.205117702484 1383.78514766693,160.459485054016 1369.26077127457,161.950986385345 PathPoint;PointKind.SMOOTHPOINT 1396.75980567932,159.175221920013 1399.21810388565,157.535254955292 1390.50536632538,163.347365856171 PathPoint;PointKind.SMOOTHPOINT 1402.00000524521,159.000084400177 1402.43714094162,158.030219078064 1401.47199630737,160.172703266144 PathPoint;PointKind.SMOOTHPOINT 1407,160 1408.90031290054,160.079307556152 1404.62809038162,159.900629520416 PathPoint;PointKind.SMOOTHPOINT 1415.01163721085,161.205117702484 1425.19604921341,161.541466712952 1411.77277326584,161.098430156708 PathPoint;PointKind.SMOOTHPOINT 2130.52432537079,162.215344905853 2154.78063583374,162.274353504181 2106.26801490784,162.156100273132 PathPoint;PointKind.SMOOTHPOINT 2273.61215114594,161.205117702484 2304.93249893188,160.573961734772 2242.29180335999,161.83650970459 PathPoint;PointKind.SMOOTHPOINT 2389.30016040802,162.215344905853 2422.88785457611,161.461687088013 2355.71246623993,162.968766689301 PathPoint;PointKind.SMOOTHPOINT 2481.6474366188,165.245318412781 2496.08872890472,165.249330997467 2467.20638036728,165.241541862488 PathPoint;PointKind.SMOOTHPOINT 2521.22497558594,164.235327243805 2531.01237773895,165.166482925415 2511.43757343292,163.304171562195 PathPoint;PointKind.SMOOTHPOINT 2538.47672939301,163.225336074829 2561.58732891083,163.292369842529 2515.36612987518,163.158302307129 PathPoint;PointKind.SMOOTHPOINT 2562,167 2572.75443506241,167.047206878662 2551.2453289032,166.952557086945 PathPoint;PointKind.SMOOTHPOINT 2591,165 2606.8921957016,165.114476680756 2575.10804033279,164.885523319244 PathPoint;PointKind.SMOOTHPOINT 2621.69089078903,164.235327243805 2632.48497962952,164.937765598297 2610.89656591415,163.533124923706 PathPoint;PointKind.SMOOTHPOINT 2644,165 2655.20738506317,161.47435426712 2629.86366415024,169.447360038757 PathPoint;PointKind.SMOOTHPOINT 2668.37188482285,167.265536785126 2671.55905723572,166.324939727783 2665.18494844437,168.206133842468 PathPoint;PointKind.SMOOTHPOINT 2684,166 2691.27269172668,169.662073612213 2677.58458518982,162.769397258759 PathPoint;PointKind.SMOOTHPOINT 2693.74204158783,168.275527954102 2703.08145046234,169.553890228271 2688.66801023483,167.581114768982 PathPoint;PointKind.SMOOTHPOINT 2713,166 2719.68260574341,168.037448883057 2704.66987419128,163.460269927979 PathPoint;PointKind.SMOOTHPOINT 2729.2604970932,166.25554561615 2739.6025800705,164.56294298172 2718.91817808151,167.94814825058 PathPoint;PointKind.CORNERPOINT 2753.61570596695,166.25554561615 2753.61570596695,166.25554561615 2753.61570596695,166.25554561615 PathPoint;PointKind.SMOOTHPOINT 2772,163 2778.16828680038,163.430054664612 2765.83194923401,162.569945335388 PathPoint;PointKind.SMOOTHPOINT 2793.19324493408,165.245318412781 2798.75492334366,165.127065181732 2787.63156652451,165.363807678223 PathPoint;PointKind.SMOOTHPOINT 2811,161 2820.09747362137,162.27836227417 2801.90229034424,159.72163772583 PathPoint;PointKind.SMOOTHPOINT 2852.05196142197,166.25554561615 2869.30371522903,166.882688999176 2834.8002076149,165.62816619873 PathPoint;PointKind.SMOOTHPOINT 2888,163 2896.46324920654,163.094649791718 2879.53675079346,162.905350208282 PathPoint;PointKind.SMOOTHPOINT 2924.10334825516,164.235327243805 2936.15408420563,163.746027946472 2912.05237627029,164.724626541138 PathPoint;PointKind.SMOOTHPOINT 2955.56224822998,164.235327243805 2976.81785345078,164.91014957428 2934.30687904358,163.560740947723 PathPoint;PointKind.SMOOTHPOINT 3004.47429917853,163.203629495405 3016.75940999427,164.637791358203 2994.30806532195,162.016824988382 PathPoint;PointKind.SMOOTHPOINT 3036.74674987793,162.215344905853 3058.30759639817,162.161104682321 3015.09163415656,162.269822280674 PathPoint;PointKind.SMOOTHPOINT 3071.25025749207,164.235327243805 3087.38013982773,164.310386180878 3055.1203751564,164.160504341125 PathPoint;PointKind.SMOOTHPOINT 3102.70939350128,163.225336074829 3125.13006448746,163.607947826385 3080.28848648071,162.842488288879 PathPoint;PointKind.SMOOTHPOINT 3149.3903875351,166.25554561615 3161.13593101501,166.444845199585 3137.64484405518,166.066009998322 PathPoint;PointKind.SMOOTHPOINT 3181.86423540115,164.235327243805 3205.03832817078,164.468057155609 3158.69014263153,164.002597332001 PathPoint;PointKind.SMOOTHPOINT 3230.57488918304,166.25554561615 3248.52837324142,166.243507862091 3212.62164115906,166.267347335815 PathPoint;PointKind.SMOOTHPOINT 3259,165 3271.83555030823,163.883557319641 3246.16421365738,166.116678714752 PathPoint;PointKind.SMOOTHPOINT 3286.38923406601,165.245318412781 3298.6580657959,165.466246604919 3274.12040233612,165.024390220642 PathPoint;PointKind.SMOOTHPOINT 3305.67064762115,165.245318412781 3321.38440132141,164.448466300964 3289.9568939209,166.04240655899 PathPoint;PointKind.SMOOTHPOINT 3330.0260925293,168.275527954102 3340.76070070267,168.662152290344 3319.29124832153,167.888903617859 PathPoint;PointKind.SMOOTHPOINT 3348.29255819321,165.245318412781 3365.38970947266,163.864517211914 3331.19540691376,166.626355648041 PathPoint;PointKind.SMOOTHPOINT 3379,168 3389.73484420776,167.885523319244 3368.26515579224,168.114476680756 PathPoint;PointKind.SMOOTHPOINT 3405.12161493301,166.25554561615 3421.04142665863,164.35759305954 3389.20203924179,168.153262138367 PathPoint;PointKind.SMOOTHPOINT 3441,167 3452.83665275574,167.875923633575 3429.16311120987,166.124076366425 PathPoint;PointKind.SMOOTHPOINT 3462.96561956406,166.25554561615 3472.59039402008,166.25554561615 3453.34084510803,166.25554561615 PathPoint;PointKind.SMOOTHPOINT 3487,167 3500.50966453552,167.599763393402 3473.49033546448,166.400236606598 PathPoint;PointKind.SMOOTHPOINT 3517.76525259018,165.245318412781 3534.46987867355,166.590714454651 3501.06062650681,163.899922370911 PathPoint;PointKind.SMOOTHPOINT 3541.10574960709,169.285519123077 3552.87914514542,169.167265892029 3529.33235406876,169.404008388519 PathPoint;PointKind.SMOOTHPOINT 3557,166 3568.09149217606,166.386624336243 3545.90850782394,165.613139629364 PathPoint;PointKind.SMOOTHPOINT 3599.96470212936,167.265536785126 3619.69387292862,167.356173992157 3580.23529529572,167.174663543701 PathPoint;PointKind.SMOOTHPOINT 3627,165 3640.64373207092,170.030601024628 3622.98529100418,163.519592285156 PathPoint;PointKind.SMOOTHPOINT 3643.60132455826,167.265536785126 3650.75647115707,166.945946216583 3636.44617795944,167.585127353668 PathPoint;PointKind.SMOOTHPOINT 3659,163 3670.67024850845,163.327379703522 3647.32975149155,162.672384262085 PathPoint;PointKind.SMOOTHPOINT 3687,165 3712.34230470657,166.400628089905 3661.65745925903,163.599371910095 PathPoint;PointKind.SMOOTHPOINT 3714.63776350021,162.215344905853 3736.53136968613,161.248548030853 3692.7441573143,163.18190574646 PathPoint;PointKind.SMOOTHPOINT 3743,162 3748.09291410446,161.041936397552 3728.29623746872,164.182610034943 PathPoint;PointKind.SMOOTHPOINT 3759.28933382034,161.205117702484 3765.63582658768,160.384662151337 3752.94284105301,162.025809288025 PathPoint;PointKind.SMOOTHPOINT 3770.45210838318,163.225336074829 3778.07507514954,164.752242565155 3762.82914161682,161.698429584503 PathPoint;PointKind.SMOOTHPOINT 3782.62983083725,163.225336074829 3790.81573963165,163.01219701767 3774.44392204285,163.438475131989 PathPoint;PointKind.SMOOTHPOINT 3795,168 3800.1375246048,170.69079208374 3789.8627114296,165.30920791626 PathPoint;PointKind.SMOOTHPOINT 3800,190 3799.77010250092,204.803605079651 3800.22989749908,175.196630954742 PathPoint;PointKind.SMOOTHPOINT 3802,212 3803.68080091476,222.546252727509 3800.31919908524,201.453511238098 PathPoint;PointKind.SMOOTHPOINT 3801.9112443924,242.009131908417 3800.68622589111,251.146731376648 3803.13602685928,232.871296405792 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,447.048668861389 3804.90014791489,468.981692790985 3805.01108407974,425.115644931793 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,539.973049163818 3803.33830833435,552.334406375885 3804.5432639122,527.611927986145 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,688.450248241425 3804.45616722107,698.60987663269 3803.42540502548,678.290619850159 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,722.791836261749 3804.68205213547,735.208189487457 3805.22917985916,710.375247001648 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,769.254026412964 3806.02579593658,780.431671142578 3803.88520002365,758.07638168335 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,820.766408443451 3807.28645563126,829.000704288483 3804.65420007706,812.532112598419 PathPoint;PointKind.SMOOTHPOINT 3804,841 3803.93674278259,847.865060329437 3804.0634932518,834.134703636169 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,857.128214836121 3806.86631441116,866.21081829071 3805.07457733154,848.045611381531 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,891.469802856445 3805.14987230301,908.964200019836 3804.76135969162,873.975405693054 PathPoint;PointKind.SMOOTHPOINT 3806,927 3806.39653778076,936.054987430573 3805.60369825363,917.945012569427 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,953.082804679871 3803.88921260834,964.185390472412 3803.99235963821,941.979982852936 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,983.384191989899 3803.85758399963,995.994093418121 3806.053647995,970.774290561676 PathPoint;PointKind.SMOOTHPOINT 3804,1007 3803.03296709061,1015.45144748688 3804.96726894379,998.548788547516 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,1044.99719381332 3803.25498819351,1061.17357492447 3804.62658405304,1028.82057666779 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,1081.3587641716 3803.23917388916,1095.65725564957 3804.64239835739,1067.06027269363 PathPoint;PointKind.SMOOTHPOINT 3803,1120 3802.25861597061,1133.51721763611 3803.74138402939,1106.48278236389 PathPoint;PointKind.SMOOTHPOINT 3802.92595624924,1148.0219578743 3803.71077060699,1163.15294265747 3802.14114189148,1132.89097309113 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,1224.78553533554 3804.253885746,1243.16364526749 3805.65711021423,1206.40742540359 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,1289.42874670029 3805.97481250763,1295.35934686661 3805.95852613449,1273.75323057175 PathPoint;PointKind.SMOOTHPOINT 3806,1351 3805.99598741531,1354.53744745255 3806.03658533096,1318.44070768356 PathPoint;PointKind.SMOOTHPOINT 3805.88559150696,1365.96313476562 3807.50053882599,1369.43850517273 3804.34947967529,1362.6577091217 PathPoint;PointKind.SMOOTHPOINT 3805.87874650955,1372.57162570953 3805.82917928696,1422.39990234375 3805.88087081909,1370.35644292831 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,1487.39810943604 3806.26371860504,1504.96732950211 3805.80722808838,1477.63218641281 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,1591.43286466599 3805.25278329849,1616.04487895966 3804.65821266174,1566.82085037231 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,1703.54825735092 3804.44885015488,1721.34194612503 3805.72060346603,1676.68423891068 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,1782.33205318451 3805.74043035507,1799.13982629776 3804.17080163956,1765.52428007126 PathPoint;PointKind.SMOOTHPOINT 3806,1853 3804.83847475052,1875.93121337891 3807.16152524948,1830.06878662109 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,1904.54782962799 3803.5377573967,1932.60854244232 3804.29353952408,1879.97688531876 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,1972.22101449966 3805.53437232971,1991.41179084778 3806.40651941299,1953.03000211716 PathPoint;PointKind.SMOOTHPOINT 3808,2028 3808.43595552444,2048.73373317719 3807.56380844116,2007.26650285721 PathPoint;PointKind.SMOOTHPOINT 3808,2101 3808.04767894745,2113.9847240448 3807.95255708694,2088.0152759552 PathPoint;PointKind.SMOOTHPOINT 3806.98527574539,2176.25056028366 3807.13256120682,2201.26359701157 3806.84979200363,2153.28441381454 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,2248.974173069 3806.44617319107,2276.81348562241 3805.49471855164,2221.1346244812 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2316.64735794067 3803.71879577637,2341.25535964966 3806.19243621826,2292.0391201973 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2379.27035093307 3804.91866455078,2388.86455154419 3805.05693652848,2352.90121293413 PathPoint;PointKind.SMOOTHPOINT 3806,2450 3804.19100484325,2498.77882618129 3807.69750547409,2404.23324012756 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2510.57651996613 3805.03563165665,2519.42568540573 3804.65042352676,2476.85027360916 PathPoint;PointKind.SMOOTHPOINT 3805.04884958267,2535.36390781403 3805.04625320435,2537.86610841751 3805.05687475204,2527.64581918716 PathPoint;PointKind.SMOOTHPOINT 3805.03303527832,2542.71637916565 3802.65097618103,2546.839427948 3806.23539447784,2540.63502788544 PathPoint;PointKind.SMOOTHPOINT 3805.00258684158,2550.27443647385 3804.93083238602,2565.46820640564 3805.01415252686,2547.80716896057 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2591.38029813766 3805.20132780075,2613.86965513229 3804.81753587723,2578.75505447388 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2637.84248828888 3805.49873113632,2653.06434631348 3804.41250085831,2622.62086629868 PathPoint;PointKind.SMOOTHPOINT 3806,2659 3806.05546808243,2679.11815547943 3805.94453191757,2638.88208055496 PathPoint;PointKind.SMOOTHPOINT 3802.92595624924,2698.44549894333 3803.65128993988,2732.71604061127 3802.20062255859,2664.174721241 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,2758.03828239441 3804.65821266174,2785.57783126831 3803.22335958481,2730.49873352051 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,2824.70147609711 3805.46308994293,2844.38934087753 3806.47780179977,2805.01337528229 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,2878.23384046555 3806.54908418655,2906.05757474899 3805.39157152176,2850.41034221649 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,2950.95745325089 3805.68897485733,2987.82012462616 3804.2222571373,2914.09454584122 PathPoint;PointKind.SMOOTHPOINT 3805.97032785416,3026.71103954315 3806.58094882965,3059.45066213608 3805.35994291306,2993.97118091583 PathPoint;PointKind.SMOOTHPOINT 3804.95561599731,3134.7859954834 3804.44035291672,3155.83530664444 3805.47087907791,3113.73692035675 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,3251.95158004761 3804.2222571373,3281.5625667572 3803.65931510925,3222.34059333801 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,3348.91616106033 3803.61564874649,3373.57963085175 3804.26592350006,3324.25292730331 PathPoint;PointKind.SMOOTHPOINT 3802.92595624924,3437.80034065247 3802.89031505585,3466.95365667343 3802.96159744263,3408.6470246315 PathPoint;PointKind.SMOOTHPOINT 3802.92595624924,3506.48375272751 3803.79409074783,3533.75493049622 3802.05782175064,3479.21233892441 PathPoint;PointKind.SMOOTHPOINT 3803.94066810608,3577.18691110611 3802.69605875015,3593.84102582932 3805.1855134964,3560.5330324173 PathPoint;PointKind.SMOOTHPOINT 3801.9112443924,3631.72950267792 3800.63075780869,3655.21327257156 3803.19149494171,3608.24596881866 PathPoint;PointKind.SMOOTHPOINT 3801.9112443924,3693.34250450134 3801.46726369858,3715.20448207855 3802.35522508621,3671.48052692413 PathPoint;PointKind.SMOOTHPOINT 3798.86663675308,3739.80469465256 3797.18607187271,3749.57769870758 3800.54743766785,3730.03169059753 PathPoint;PointKind.SMOOTHPOINT 3798.86663675308,3774.14628267288 3797.9416179657,3789.15334939957 3800.04421234131,3755.04637956619 PathPoint;PointKind.SMOOTHPOINT 3793.79260540009,3804.44766998291 3790.3306607795,3810.25474871875 3798.29899187088,3796.88947553635 PathPoint;PointKind.SMOOTHPOINT 3748.12632322311,3809.49809789658 3741.15339517593,3809.50258255005 3772.34392404556,3809.48228359222 PathPoint;PointKind.SMOOTHPOINT 3654.24907207489,3809.31257486343 3650.43286800385,3809.30384159088 3706.23045444489,3809.43106412888 PathPoint;PointKind.SMOOTHPOINT 3623.52925634384,3809.28590297699 3615.6269449234,3809.90462627411 3627.66060044895,3808.96238463944 PathPoint;PointKind.SMOOTHPOINT 3607.59339427948,3809.24884557724 3383.08007574081,3808.72697353363 3613.04578876495,3809.26159143448 PathPoint;PointKind.SMOOTHPOINT 2905.83688259125,3807.47787952423 2855.25494813919,3807.37142801285 2944.78184938431,3807.5600194931 PathPoint;PointKind.SMOOTHPOINT 2679.53489542007,3807.47787952423 2655.40155887604,3808.34979057312 2703.66823196411,3806.60596847534 PathPoint;PointKind.SMOOTHPOINT 2589.21704292297,3808.48787069321 2582.16315507889,3808.34530591965 2630.74493408203,3809.32838916779 PathPoint;PointKind.SMOOTHPOINT 2561.45869016647,3808.05215120316 2557.95688390732,3808.00683259964 2572.6006937027,3808.19636821747 PathPoint;PointKind.SMOOTHPOINT 2550.51401138306,3807.91761159897 2546.74158871163,3806.91492065676 2556.38321685791,3809.47798910141 PathPoint;PointKind.SMOOTHPOINT 2538.4167766571,3807.78378009796 2484.11895275116,3807.21281290054 2542.56366491318,3807.82721042633 PathPoint;PointKind.SMOOTHPOINT 2393.35924386978,3807.47787952423 2367.49766349792,3808.35781574249 2412.02224731445,3806.84294700623 PathPoint;PointKind.SMOOTHPOINT 2283.76021385193,3807.47787952423 2226.41967058182,3806.92957162857 2341.10075712204,3808.02642345428 PathPoint;PointKind.SMOOTHPOINT 2138.6427283287,3808.48787069321 2085.57960033417,3806.90195560455 2191.70609235764,3810.07402181625 PathPoint;PointKind.SMOOTHPOINT 1785.490193367,3808.48787069321 1744.29133415222,3807.18590497971 1826.68881654739,3809.7900724411 PathPoint;PointKind.SMOOTHPOINT 1572.38064050674,3807.47787952423 1570.1874089241,3807.48637676239 1600.98942518234,3807.36741542816 PathPoint;PointKind.SMOOTHPOINT 1561.84217691422,3807.51894950867 1558.56200695038,3807.53169536591 1566.60346269608,3807.5003027916 PathPoint;PointKind.SMOOTHPOINT 1550.39521694183,3807.563560009 1547.17291021347,3806.50483646393 1554.89134737092,3809.04089975763 PathPoint;PointKind.SMOOTHPOINT 1537.59341955185,3807.6131272316 1457.32591152191,3807.9235124588 1542.22205400467,3807.5954246521 PathPoint;PointKind.SMOOTHPOINT 1249.67205762863,3808.48787069321 1220.75005531311,3808.33421230316 1273.47659826279,3808.61462116241 PathPoint;PointKind.SMOOTHPOINT 1022.35535860062,3808.48787069321 969.141404628754,3808.45246553421 1075.56931257248,3808.5235118866 PathPoint;PointKind.SMOOTHPOINT 778.801853656769,3807.47787952423 740.504801273346,3807.01619625092 817.098906040192,3807.93956279755 PathPoint;PointKind.SMOOTHPOINT 590.047745704651,3808.48787069321 553.938732147217,3808.62996339798 626.156523227692,3808.34601402283 PathPoint;PointKind.SMOOTHPOINT 419.560103416443,3807.47787952423 386.349120140076,3806.99259281158 452.771322727203,3807.96316623688 PathPoint;PointKind.SMOOTHPOINT 258.205811977386,3808.48787069321 231.262013912201,3807.98299312592 285.149846076965,3808.99298429489 PathPoint;PointKind.SMOOTHPOINT 194.273064136505,3807.47787952423 174.690470695496,3807.62398481369 213.855657577515,3807.33201026917 PathPoint;PointKind.SMOOTHPOINT 175,3808 172.397012710571,3807.5661687851 180.299916267395,3808.88394880295 PathPoint;PointKind.SMOOTHPOINT 163.828876018524,3802.42768764496 161.303308010101,3799.26577091217 166.266167163849,3805.47914028168 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3792.32730388641 160.264520645142,3775.98640680313 158.454608917236,3795.57631731033 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3758.99570703506 160.019280910492,3742.62577772141 157.490172386169,3775.36540031433 PathPoint;PointKind.SMOOTHPOINT 157.739896774292,3700.41291475296 158.897409439087,3689.25887346268 156.582384109497,3711.56672000885 PathPoint;PointKind.SMOOTHPOINT 159,3648 158.859087467194,3624.6311788559 159.128402709961,3669.29148244858 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3564.05631780624 157.129983901978,3534.96201038361 160.00346660614,3586.41561985016 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3453.96114349365 157.854845523834,3425.27352333069 159.741232395172,3485.40611743927 PathPoint;PointKind.SMOOTHPOINT 159.769556522369,3399.41855192184 159.274120330811,3383.50629329681 160.265228748322,3415.33081054688 PathPoint;PointKind.SMOOTHPOINT 158.754844665527,3346.89617872238 159.21062707901,3332.51082658768 158.298826217651,3361.28129482269 PathPoint;PointKind.SMOOTHPOINT 157.739896774292,3283.263194561 158.423452377319,3261.55723571777 157.057285308838,3304.94602203369 PathPoint;PointKind.SMOOTHPOINT 155.710473060608,3204.47939872742 156.602210998535,3176.60444498062 154.818499088287,3232.35435247421 PathPoint;PointKind.SMOOTHPOINT 157.739896774292,3136.80621385574 157.577505111694,3109.1127705574 157.902524471283,3164.49965715408 PathPoint;PointKind.SMOOTHPOINT 156.72518491745,3068.1228017807 156.83210849762,3041.6487121582 156.61826133728,3094.59712743759 PathPoint;PointKind.SMOOTHPOINT 157,3017 157.554916858673,2978.85495376587 156.445083141327,3055.14528226852 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2948.93723487854 154.558389186859,2922.89579629898 154.828884601593,2974.23020839691 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2885.30425071716 154.577980041504,2858.58822584152 154.909608364105,2933.95613193512 PathPoint;PointKind.SMOOTHPOINT 155.184824466705,2813.60974216461 155.207483768463,2811.33295440674 155.004258155823,2831.79690027237 PathPoint;PointKind.SMOOTHPOINT 155.239584445953,2806.89503574371 156.368300914764,2804.74216604233 153.783252239227,2809.67268848419 PathPoint;PointKind.SMOOTHPOINT 155.262007713318,2799.72690725327 155.260119438171,2790.21802568436 155.262479782104,2802.08040618896 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2778.23928594589 153.320152759552,2748.8294005394 155.116846561432,2787.24777460098 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2698.44549894333 154.271371364594,2676.07439517975 155.119678974152,2720.81636667252 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2642.89268016815 155.194973945618,2613.9683175087 154.196076393127,2671.817278862 PathPoint;PointKind.SMOOTHPOINT 153.680813312531,2544.91810798645 155.488364696503,2514.79020595551 151.873261928558,2575.0460100174 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2459.06413793564 154.89497423172,2438.28461408615 154.488759040833,2480.61667442322 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2418.66213083267 155.258467197418,2407.02681541443 154.132583141327,2430.29744625092 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2393.41093540192 153.125896453857,2372.83133268356 156.265389919281,2413.99077415466 PathPoint;PointKind.SMOOTHPOINT 156,2296 155.417231082916,2275.2032456398 156.582768917084,2316.7967543602 PathPoint;PointKind.SMOOTHPOINT 154,2235 154.112993144989,2209.63755931854 153.889477970053,2259.86066174995 PathPoint;PointKind.SMOOTHPOINT 153.680813312531,2144.93918180466 154.961063861847,2108.69185209274 152.400326728821,2181.18651151657 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,2015.65299510956 154.905595779419,1991.41179084778 154.485454559326,2039.89419937134 PathPoint;PointKind.SMOOTHPOINT 154,1927 154.626435279846,1897.1952290535 153.367427825928,1957.10099411011 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1833.844435215 154.192063808441,1794.16068077087 155.198986530304,1873.52818965912 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1621.73448801041 156.063108444214,1578.85860443115 153.327941894531,1664.61013555527 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1509.61909532547 154.738719463348,1479.99607086182 154.65044260025,1540.65903425217 PathPoint;PointKind.SMOOTHPOINT 156,1417 157.343743801117,1377.22914886475 154.65602016449,1456.77061510086 PathPoint;PointKind.SMOOTHPOINT 155,1336 155.229897499084,1310.62252616882 154.770102500916,1361.37747383118 PathPoint;PointKind.SMOOTHPOINT 154.695525169373,1273.2679438591 155.044384002686,1247.40518331528 154.34666633606,1299.13070440292 PathPoint;PointKind.SMOOTHPOINT 156.72518491745,1217.71536111832 157.728095054626,1199.07666921616 155.722274780273,1236.35381698608 PathPoint;PointKind.SMOOTHPOINT 157,1149 157.232429027557,1122.178444767 156.78627763542,1173.664193574 PathPoint;PointKind.SMOOTHPOINT 156.72518491745,1062.16798782349 158.489305973053,1029.14795637131 154.961063861847,1095.18778324127 PathPoint;PointKind.SMOOTHPOINT 157.739896774292,853.088014125824 159.036197662354,811.376252174377 156.443831920624,894.799776077271 PathPoint;PointKind.SMOOTHPOINT 159,728 159.027616024017,696.61757516861 158.972147941589,759.382660865784 PathPoint;PointKind.SMOOTHPOINT 160.784504413605,543.003258705139 159.963812828064,511.672053337097 161.604959964752,574.334464073181 PathPoint;PointKind.SMOOTHPOINT 161,366 163.695512771606,326.324034690857 158.304251194,405.675965309143 PathPoint;PointKind.SMOOTHPOINT 162.813928127289,295.541496276855 162.655549049377,275.557644367218 162.972543239594,315.525584220886 PathPoint;PointKind.SMOOTHPOINT 162.813928127289,245.039105415344 162.45326757431,224.924962520599 163.174824714661,265.153248310089 PathPoint";
	
	subshadowSquare[0] = "PointKind.SMOOTHPOINT 164.000000953674,161.000003814697 167.438549995422,159.064521789551 161.562125889337,162.372138699394 PathPoint;PointKind.CORNERPOINT 180.749001502991,157.833602428436 180.749001502991,157.833602428436 180.749001502991,157.833602428436 PathPoint;PointKind.SMOOTHPOINT 203.464715480804,155.784823894501 213.066122531891,154.41299200058 192.533254623413,157.346663475037 PathPoint;PointKind.SMOOTHPOINT 237.995131015778,151.985378265381 675.073707103729,153.187265396118 220.617098808289,151.937463283539 PathPoint;PointKind.SMOOTHPOINT 3763.30829143524,160.889067649841 3765.11655092239,160.895912647247 3487.89014339447,159.8708152771 PathPoint;PointKind.SMOOTHPOINT 3770.00010251999,162.999923229218 3785.19104003906,163.104250431061 3768.4118270874,162.989065647125 PathPoint;PointKind.SMOOTHPOINT 3788.35295677185,163.104958534241 3788.86727571487,163.054919242859 3787.83863782883,163.154997825623 PathPoint;PointKind.SMOOTHPOINT 3800.00007390976,171.000072956085 3802.27143287659,173.374106884003 3798.33957195282,169.264512062073 PathPoint;PointKind.CORNERPOINT 3806.00006246567,186.00005865097 3806.00006246567,186.00005865097 3806.00006246567,186.00005865097 PathPoint;PointKind.SMOOTHPOINT 3805.42413854599,399.3612241745 3806.0024228096,893.49426984787 3805.35403633118,339.52249288559 PathPoint;PointKind.SMOOTHPOINT 3807.92783308029,3392.27371025085 3808.01752614975,3468.80573797226 3807.11634683609,2698.4860162735 PathPoint;PointKind.SMOOTHPOINT 3807.91862773895,3621.31416845322 3807.74139687662,3813.75857723793 3807.98094081879,3553.63508272171 PathPoint;PointKind.SMOOTHPOINT 3786,3808 3787.26663440927,3806.99954737932 3802.2857272104,3795.13669994433 PathPoint;PointKind.SMOOTHPOINT 168.999917507172,3806.00006818771 164.802753925323,3805.29739379883 175.300855636597,3807.05514192581 PathPoint;PointKind.SMOOTHPOINT 157,3790 155.392669662602,3785.71192579698 159.629087236683,3797.01390812976 PathPoint;PointKind.SMOOTHPOINT 154,3764 153.93084192276,3589.04186630249 154.002596378326,3770.86057567596 PathPoint;PointKind.SMOOTHPOINT 155,188 154.993817599737,165.14338521113 155.0670337677,435.988591194153 PathPoint";
	
}


// 67

var negative67 = [];
var mask67 = [];
var shadow67 = [];
var subshadow67 = [];

negative67[0] = "PointKind.SMOOTHPOINT 4337.08844161034,192.592735290527 4347.10239744186,192.997770309448 4312.27866983414,191.588881015778 PathPoint;PointKind.SMOOTHPOINT 4353.0135641098,187.852456569672 4356.97784042358,187.095494270325 4349.04901242256,188.609654903412 PathPoint;PointKind.SMOOTHPOINT 4361.707654953,187.827436923981 4365.001121521,188.438766002655 4358.41363763809,187.215871810913 PathPoint;PointKind.SMOOTHPOINT 4368.95217990875,187.806193828583 4369.67861509323,188.088018894196 4365.19415831566,186.347737312317 PathPoint;PointKind.SMOOTHPOINT 4371.85489153862,189.362368583679 4374.67774486542,190.171022415161 4371.17884969711,189.168820381165 PathPoint;PointKind.SMOOTHPOINT 4380.54870700836,189.337348937988 4383.97187447548,189.231841564178 4377.78698658943,189.42232131958 PathPoint;PointKind.SMOOTHPOINT 4387.78910136223,187.751669883728 4392.90003275871,187.311229705811 4382.67789459229,188.191637992859 PathPoint;PointKind.SMOOTHPOINT 4395.05235171318,193.989114761353 4395.83523845673,196.991472244263 4394.26918959618,190.986757278442 PathPoint;PointKind.SMOOTHPOINT 4397.99113726616,208.062665462494 4398.2472345829,215.14652967453 4397.73503994942,200.978329181671 PathPoint;PointKind.SMOOTHPOINT 4399.6268556118,272.208552360535 4399.74967217445,287.228600978851 4399.50348830223,257.188267707825 PathPoint;PointKind.SMOOTHPOINT 4400.03165459633,411.461527347565 4399.41619491577,427.141528129578 4400.64711427689,395.781290531158 PathPoint;PointKind.SMOOTHPOINT 4402.24951243401,675.881416797638 4402.41749024391,706.97304725647 4402.15753769875,658.891189098358 PathPoint;PointKind.SMOOTHPOINT 4401.15985965729,799.492392539978 4401.44734954834,823.905901908875 4400.87209439278,775.078883171082 PathPoint;PointKind.SMOOTHPOINT 4403.09105372429,965.340306758881 4402.97567224503,975.84808588028 4403.20615983009,954.832055568695 PathPoint;PointKind.SMOOTHPOINT 4403.19569563866,1001.32705450058 4403.14337468147,1015.3061914444 4403.24774122238,987.347445487976 PathPoint;PointKind.SMOOTHPOINT 4403.36863017082,1060.78317403793 4402.85918927193,1074.58858966827 4403.87779569626,1046.97775840759 PathPoint;PointKind.SMOOTHPOINT 4403.96426296234,1265.75119256973 4404.29058051109,1283.98319721222 4403.63822078705,1247.51895189285 PathPoint;PointKind.SMOOTHPOINT 4404.31921935081,1387.79301166534 4404.51253151894,1399.34713125229 4404.12590718269,1376.2388920784 PathPoint;PointKind.SMOOTHPOINT 4405.94557499886,1448.80979061127 4406.28180599213,1462.65367984772 4405.60961937904,1434.96613740921 PathPoint;PointKind.SMOOTHPOINT 4404.80607962608,1555.20961046219 4404.80718111992,1573.31250429153 4404.80470275879,1537.10671663284 PathPoint;PointKind.SMOOTHPOINT 4405.0241754055,1630.3124499321 4405.66028809547,1648.63320350647 4404.38861346245,1611.99146032333 PathPoint;PointKind.SMOOTHPOINT 4405.99789595604,1965.14541149139 4405.69085454941,1981.04468822479 4406.30466198921,1949.246134758 PathPoint;PointKind.SMOOTHPOINT 4407.55595898628,2002.69258260727 4407.1013174057,2010.5529999733 4408.01087594032,1994.83240127563 PathPoint;PointKind.SMOOTHPOINT 4406.19341111183,2032.42512702942 4405.61980819702,2042.24581003189 4406.7672894001,2022.60444402695 PathPoint;PointKind.SMOOTHPOINT 4406.46190023422,2124.73888635635 4406.64116835594,2143.11817646027 4406.2826321125,2106.35983228683 PathPoint;PointKind.SMOOTHPOINT 4406.69404006004,2204.53574180603 4406.87743878365,2230.88898181915 4406.51009058952,2178.18250179291 PathPoint;PointKind.SMOOTHPOINT 4407.23542428017,2390.72769641876 4407.49565219879,2409.67323303223 4406.97492098808,2371.78239583969 PathPoint;PointKind.SMOOTHPOINT 4406.05462288857,2483.04570436478 4406.00230193138,2508.6297082901 4406.10694384575,2457.46193647385 PathPoint;PointKind.SMOOTHPOINT 4406.6414437294,2684.88437891006 4406.13062596321,2694.27288293839 4407.15226149559,2675.49587488174 PathPoint;PointKind.SMOOTHPOINT 4406.80997228622,2742.77606248856 4406.95977544785,2757.46778726578 4406.65989375114,2728.08410167694 PathPoint;PointKind.SMOOTHPOINT 4405.76575613022,2882.03328609467 4405.42594528198,2899.64003562927 4406.105291605,2864.42677259445 PathPoint;PointKind.SMOOTHPOINT 4405.51764464378,3295.10244369507 4405.43007588387,3335.85637807846 4405.6052134037,3254.34898138046 PathPoint;PointKind.SMOOTHPOINT 4402.24455571175,3664.37046289444 4402.34589314461,3696.1878991127 4402.14294290543,3632.55302667618 PathPoint;PointKind.SMOOTHPOINT 4402.4356648922,3730.08527040482 4401.77201485634,3745.43317079544 4403.18743443489,3712.68457889557 PathPoint;PointKind.SMOOTHPOINT 4402.51745080948,3758.24889421463 4401.49994587898,3761.67044878006 4403.53440499306,3754.8273396492 PathPoint;PointKind.CORNERPOINT 4398.20234870911,3769.21410799026 4398.20234870911,3769.21410799026 4398.20234870911,3769.21410799026 PathPoint;PointKind.SMOOTHPOINT 4392.42446279526,3775.48931837082 4388.90766835213,3776.54911279678 4395.94125723839,3774.42928791046 PathPoint;PointKind.SMOOTHPOINT 4369.23608994484,3773.99191617966 4363.07240581512,3773.37020158768 4375.39977407455,3774.61363077164 PathPoint;PointKind.SMOOTHPOINT 4280.84368801117,3772.68381357193 4275.06277298927,3772.81386852264 4318.43023753166,3771.8378663063 PathPoint;PointKind.SMOOTHPOINT 3967.86302661896,3773.591837883 3947.91635012627,3774.32519674301 3987.80970311165,3772.85824298859 PathPoint;PointKind.SMOOTHPOINT 3846.14850854874,3773.94494533539 3832.54010295868,3774.29309606552 3859.75691413879,3773.59655857086 PathPoint;PointKind.SMOOTHPOINT 3753.40878582001,3772.64935255051 3725.21880483627,3772.64463186264 3781.59849143028,3772.65383720398 PathPoint;PointKind.SMOOTHPOINT 3601.2655005455,3773.090736866 3583.20403075218,3773.20733785629 3619.32697033882,3772.97389984131 PathPoint;PointKind.SMOOTHPOINT 3469.40787649155,3773.47311258316 3456.71068167686,3773.08129549026 3482.10507130623,3773.86492967606 PathPoint;PointKind.SMOOTHPOINT 3230.32561039925,3774.1668176651 3215.03660058975,3774.05942201614 3245.61406946182,3774.27397727966 PathPoint;PointKind.SMOOTHPOINT 3092.66751980782,3773.00127983093 3070.21522021294,3773.63597631454 3115.11981940269,3772.36658334732 PathPoint;PointKind.SMOOTHPOINT 2949.21832537651,3773.41764450073 2926.50084114075,3773.78821849823 2971.93553423882,3773.04683446884 PathPoint;PointKind.SMOOTHPOINT 2737.66652083397,3774.03133392334 2719.93990516663,3773.93526792526 2755.39258575439,3774.12739992142 PathPoint;PointKind.SMOOTHPOINT 2304.41567516327,3773.72354507446 2278.13843822479,3773.48113775253 2330.69291210175,3773.96595239639 PathPoint;PointKind.SMOOTHPOINT 2063.88439393044,3774.42126274109 2034.53288769722,3773.28334093094 2093.23590016365,3775.55942058563 PathPoint;PointKind.SMOOTHPOINT 1546.58351039886,3771.22818946838 1506.66840291023,3770.8255147934 1586.49834251404,3771.63039207458 PathPoint;PointKind.SMOOTHPOINT 916.266054868698,3769.92740392685 881.520257949829,3769.37130689621 951.012127161026,3770.48350095749 PathPoint;PointKind.SMOOTHPOINT 697.464768648148,3768.9976644516 641.662264823914,3769.29695606232 753.267823219299,3768.69790077209 PathPoint;PointKind.SMOOTHPOINT 446.781294107437,3766.59530639648 405.384952783585,3766.62504673004 488.178186178207,3766.56580209732 PathPoint;PointKind.SMOOTHPOINT 320.720005989075,3766.96115970612 295.039778709412,3767.13653326035 346.399957895279,3766.78555011749 PathPoint;PointKind.SMOOTHPOINT 274.35262298584,3767.0956993103 265.345432519913,3767.89916038513 283.359813451767,3766.29200220108 PathPoint;PointKind.SMOOTHPOINT 261.32084941864,3770.26280879974 254.293869495392,3770.99286317825 268.34755396843,3769.53275442123 PathPoint;PointKind.SMOOTHPOINT 243.928537130356,3768.74841213226 237.816347837448,3769.57382440567 250.040451049805,3767.92347192764 PathPoint;PointKind.SMOOTHPOINT 230.892082214355,3770.35084962845 225.850820302963,3771.06556177139 235.933344125748,3769.63660955429 PathPoint;PointKind.SMOOTHPOINT 220.731076955795,3764.12190198898 219.40350151062,3762.04857587814 222.058377027512,3766.19522809982 PathPoint;PointKind.SMOOTHPOINT 219.222856521606,3743.78565073013 218.651181221008,3738.50744962692 219.794531822205,3749.06385183334 PathPoint;PointKind.SMOOTHPOINT 215.8792719841,3590.45936107635 215.699453115463,3568.96394491196 216.05854010582,3611.95477724075 PathPoint;PointKind.SMOOTHPOINT 215.415267705917,3430.86612224579 214.941349983215,3418.39666128159 215.889185428619,3443.3353471756 PathPoint;PointKind.SMOOTHPOINT 215.356062412262,3410.52585840225 214.10999751091,3404.15906667709 216.336116552353,3415.53545236588 PathPoint;PointKind.SMOOTHPOINT 215.287769794464,3387.05601453781 215.738831520081,3379.89307880402 214.836983442307,3394.21895027161 PathPoint;PointKind.SMOOTHPOINT 216.131514072418,3178.95463943481 217.437610387802,3144.51556921005 214.783560991287,3214.49976682663 PathPoint;PointKind.SMOOTHPOINT 213.517944574356,2778.41088294983 213.752562761307,2752.65622615814 213.283601760864,2804.16577577591 PathPoint;PointKind.SMOOTHPOINT 213.377228736877,2729.90699529648 213.439187765121,2722.7329659462 213.314994335175,2737.08102464676 PathPoint;PointKind.SMOOTHPOINT 217.69233083725,2718.94225358963 217.148468255997,2713.66452455521 218.235642671585,2724.21951055527 PathPoint;PointKind.SMOOTHPOINT 213.304254770279,2704.87271547318 213.854726314545,2700.82260131836 212.753783226013,2708.92282962799 PathPoint;PointKind.SMOOTHPOINT 214.703151941299,2687.65754699707 215.318886995316,2680.17218828201 214.087416887283,2695.14290571213 PathPoint;PointKind.SMOOTHPOINT 213.204294204712,2670.45087575912 213.978919744492,2664.37889099121 212.429393291473,2676.52238845825 PathPoint;PointKind.SMOOTHPOINT 212.985923051834,2595.34803628922 213.252759933472,2567.77166604996 212.718810796738,2622.92417049408 PathPoint;PointKind.SMOOTHPOINT 212.685765981674,2492.08180904388 213.1635389328,2485.19975423813 212.20744228363,2498.96339178085 PathPoint;PointKind.SMOOTHPOINT 214.089069128036,2476.43107652664 213.622586488724,2470.46459913254 214.555551767349,2482.39755392075 PathPoint;PointKind.SMOOTHPOINT 214.057401180267,2465.47884464264 213.842885255814,2459.35257196426 214.271366357803,2471.60464525223 PathPoint;PointKind.SMOOTHPOINT 214.016370534897,2451.39679670334 213.64296412468,2445.02268791199 214.389501571655,2457.77090549469 PathPoint;PointKind.SMOOTHPOINT 213.957165241241,2431.0565328598 214.249887228012,2413.63412618637 213.664443254471,2448.47893953323 PathPoint;PointKind.SMOOTHPOINT 213.715938091278,2348.13033342361 212.956458091736,2333.46976518631 214.475693464279,2362.79113769531 PathPoint;PointKind.SMOOTHPOINT 214.241626024246,2030.50427913666 214.084112405777,2007.52137422562 214.399139642715,2053.4871840477 PathPoint;PointKind.SMOOTHPOINT 214.530768156052,1631.51669740677 214.954567909241,1602.14740991592 214.106417655945,1660.88622093201 PathPoint;PointKind.SMOOTHPOINT 212.458032131195,1417.1653676033 212.983720064163,1399.24516439438 211.932894945145,1435.08509874344 PathPoint;PointKind.SMOOTHPOINT 213.433955669403,1254.43830013275 213.238440513611,1239.02619838715 213.630021572113,1269.85040187836 PathPoint;PointKind.SMOOTHPOINT 213.120305299759,1146.47829294205 213.148393392563,1116.13677978516 213.089188098907,1179.94560956955 PathPoint;PointKind.SMOOTHPOINT 214.114128112793,990.009913444519 214.000674247742,971.704738140106 214.227857351303,1008.31508874893 PathPoint;PointKind.SMOOTHPOINT 216.480136871338,806.938569545746 216.285447835922,765.921692848206 216.674550533295,847.955446243286 PathPoint;PointKind.SMOOTHPOINT 217.105785369873,523.734354972839 217.234660148621,494.129269123077 216.976635217667,553.339204788208 PathPoint;PointKind.SMOOTHPOINT 218.213337421417,406.382067203522 217.483873128891,365.790288448334 218.942801713943,446.97384595871 PathPoint;PointKind.SMOOTHPOINT 220.669944047928,254.603691101074 220.90896821022,240.722272396088 220.431195259094,268.484873771667 PathPoint;PointKind.SMOOTHPOINT 217.608341932297,198.284704685211 216.902284383774,191.940336227417 218.31439948082,204.629545211792 PathPoint;PointKind.SMOOTHPOINT 220.474428892136,187.323975563049 224.869940042496,181.213989257812 216.078917741776,193.433961868286 PathPoint;PointKind.SMOOTHPOINT 230.612853527069,185.72979927063 233.854825258255,185.488336086273 227.370606422424,185.97149848938 PathPoint;PointKind.SMOOTHPOINT 250.90319609642,187.235698699951 256.083796977997,187.961504459381 245.722319841385,186.509892940521 PathPoint;PointKind.SMOOTHPOINT 282.78538441658,188.707845211029 288.930618524551,190.21799325943 276.640150308609,187.197697162628 PathPoint;PointKind.SMOOTHPOINT 319.010212182999,188.602809906006 333.880103588104,188.256547451019 304.140045404434,188.949072360992 PathPoint;PointKind.SMOOTHPOINT 382.760820150375,186.853322982788 399.02272439003,187.070002555847 366.498915910721,186.636407375336 PathPoint;PointKind.SMOOTHPOINT 492.883492469788,186.533968448639 510.562193155289,186.597461700439 475.205067157745,186.470239162445 PathPoint;PointKind.SMOOTHPOINT 640.680007696152,186.105093955994 658.446001768112,186.69163942337 622.913738250732,185.518548488617 PathPoint;PointKind.SMOOTHPOINT 972.501996517181,186.706981658936 998.858265638351,185.821144580841 946.145452022552,187.592582702637 PathPoint;PointKind.SMOOTHPOINT 1310.11508917809,185.727438926697 1341.61285614967,186.83562040329 1278.6173222065,184.619493484497 PathPoint;PointKind.SMOOTHPOINT 1366.6299841404,187.128303050995 1380.16679263115,187.07448720932 1353.0934510231,187.182354927063 PathPoint;PointKind.SMOOTHPOINT 1434.73231887817,186.930506229401 1458.28446006775,187.185895442963 1411.1801776886,186.675589084625 PathPoint;PointKind.SMOOTHPOINT 1562.24289751053,186.560640335083 1585.49956297874,186.38078212738 1538.98623204231,186.740734577179 PathPoint;PointKind.SMOOTHPOINT 1707.14110708237,186.140263080597 1766.11976838112,186.80210351944 1648.16299653053,185.478894710541 PathPoint;PointKind.SMOOTHPOINT 1873.77454376221,185.656864643097 1922.14526867867,186.198799610138 1825.40326809883,185.115165710449 PathPoint;PointKind.SMOOTHPOINT 2056.35100221634,186.692111492157 2091.31627178192,186.400609016418 2021.38573265076,186.983377933502 PathPoint;PointKind.SMOOTHPOINT 2185.30591464043,184.753324985504 2207.70809626579,185.248053073883 2164.41002583504,184.291641712189 PathPoint;PointKind.SMOOTHPOINT 2285.29043769836,186.027910709381 2320.63875174522,185.038690567017 2249.94267439842,187.016894817352 PathPoint;PointKind.SMOOTHPOINT 2457.71965956688,185.527517795563 2483.67994165421,186.048681735992 2431.75910210609,185.006353855133 PathPoint;PointKind.SMOOTHPOINT 2648.98993349075,186.537272930145 2675.92779135704,185.792820453644 2622.05235099792,187.282197475433 PathPoint;PointKind.SMOOTHPOINT 2789.54577898979,187.69407749176 2808.85000920296,188.132865428925 2770.24209952354,187.255525588989 PathPoint;PointKind.SMOOTHPOINT 2930.09308791161,185.722010135651 2962.44946932793,186.297934055328 2897.73643112183,185.146086215973 PathPoint;PointKind.SMOOTHPOINT 3085.13412809372,185.272128582001 3103.12482690811,184.888808727264 3048.00084328651,186.062607765198 PathPoint;PointKind.SMOOTHPOINT 3190.91443634033,186.529955863953 3229.6685693264,186.300766468048 3152.16057872772,186.758673191071 PathPoint;PointKind.SMOOTHPOINT 3648.80267000198,188.330662250519 3678.18253970146,187.811150550842 3619.42280030251,188.850173950195 PathPoint;PointKind.SMOOTHPOINT 3860.35888051987,189.281408786774 3885.12349104881,189.888017177582 3835.59426999092,188.675508499146 PathPoint;PointKind.SMOOTHPOINT 3979.18032503128,190.501706600189 4003.07365393639,190.014295578003 3955.28672075272,190.988881587982 PathPoint;PointKind.SMOOTHPOINT 4137.11939549446,190.04332780838 4168.98643827438,190.946867465973 4105.252628088,189.140024185181 PathPoint;PointKind.SMOOTHPOINT 4276.23118257523,192.769289016724 4292.76432967186,195.485336780548 4259.69776010513,190.052769184113 PathPoint";

negative67[1] = "PointKind.SMOOTHPOINT 4326.00000500679,192.000052928925 4336.01423621178,191.604931354523 4300.9371650219,192.988328933716 PathPoint;PointKind.SMOOTHPOINT 4351.99994087219,189.999897480011 4357.07479834557,189.030976295471 4348.03538918495,190.757095813751 PathPoint;PointKind.SMOOTHPOINT 4376.00011467934,187.999978065491 4379.42328214645,187.894470691681 4364.90256428719,188.341519832611 PathPoint;PointKind.SMOOTHPOINT 4384.99987006187,186.999900341034 4389.4625723362,186.822166442871 4379.87406849861,187.203834056854 PathPoint;PointKind.SMOOTHPOINT 4397.00009465218,192.999894618988 4397.78298139572,196.002252101898 4396.21693253517,189.997537136078 PathPoint;PointKind.SMOOTHPOINT 4397.99116373062,208.062665462494 4398.24726104736,215.14652967453 4397.73506641388,200.978329181671 PathPoint;PointKind.SMOOTHPOINT 4399.62688207626,272.208552360535 4399.74969863892,287.228600978851 4399.50351476669,257.188267707825 PathPoint;PointKind.SMOOTHPOINT 4400.03168106079,411.461527347565 4399.41622138023,427.141528129578 4400.64714074135,395.781290531158 PathPoint;PointKind.SMOOTHPOINT 4402.24953889847,675.881416797638 4402.41751670837,706.97304725647 4402.15756416321,658.891189098358 PathPoint;PointKind.SMOOTHPOINT 4401.15988612175,799.492392539978 4401.4473760128,823.905901908875 4400.87212085724,775.078883171082 PathPoint;PointKind.SMOOTHPOINT 4403.09108018875,965.340306758881 4402.97569870949,975.84808588028 4403.20618629456,954.832055568695 PathPoint;PointKind.SMOOTHPOINT 4403.19572210312,1001.32705450058 4403.14340114594,1015.3061914444 4403.24776768684,987.347445487976 PathPoint;PointKind.SMOOTHPOINT 4403.36865663528,1060.78317403793 4402.85921573639,1074.58858966827 4403.87782216072,1046.97775840759 PathPoint;PointKind.SMOOTHPOINT 4403.9642894268,1265.75119256973 4404.29060697556,1283.98319721222 4403.63824725151,1247.51895189285 PathPoint;PointKind.SMOOTHPOINT 4404.31924581528,1387.79301166534 4404.5125579834,1399.34713125229 4404.12593364716,1376.2388920784 PathPoint;PointKind.SMOOTHPOINT 4405.94560146332,1448.80979061127 4406.28183245659,1462.65367984772 4405.60964584351,1434.96613740921 PathPoint;PointKind.SMOOTHPOINT 4404.80610609055,1555.20961046219 4404.80720758438,1573.31250429153 4404.80472922325,1537.10671663284 PathPoint;PointKind.SMOOTHPOINT 4405.02420186996,1630.3124499321 4405.3794336319,1640.54005622864 4404.38863992691,1611.99146032333 PathPoint;PointKind.SMOOTHPOINT 4405.93045592308,1826.27504825592 4405.93596339226,1828.87567520142 4405.7368683815,1738.74287366867 PathPoint;PointKind.SMOOTHPOINT 4405.94725370407,1834.04648065567 4405.35740375519,1835.46174287796 4406.93887352943,1831.66536569595 PathPoint;PointKind.SMOOTHPOINT 4405.95937013626,1839.88809585571 4406.08907103539,1903.55837345123 4405.95523953438,1837.94860124588 PathPoint;PointKind.SMOOTHPOINT 4405.9979224205,1965.14541149139 4405.69088101387,1981.04468822479 4406.12459421158,1958.58554363251 PathPoint;PointKind.SMOOTHPOINT 4407.55598545074,2002.69258260727 4407.10134387016,2010.5529999733 4408.01090240479,1994.83240127563 PathPoint;PointKind.SMOOTHPOINT 4406.19343757629,2032.42512702942 4405.61983466148,2042.24581003189 4406.76731586456,2022.60444402695 PathPoint;PointKind.SMOOTHPOINT 4406.46192669868,2124.73888635635 4406.6411948204,2143.11817646027 4406.28265857697,2106.35983228683 PathPoint;PointKind.SMOOTHPOINT 4406.69406652451,2204.53574180603 4406.87746524811,2230.88898181915 4406.51011705399,2178.18250179291 PathPoint;PointKind.SMOOTHPOINT 4407.23545074463,2390.72769641876 4407.49567866325,2409.67323303223 4406.97494745255,2371.78239583969 PathPoint;PointKind.SMOOTHPOINT 4406.05464935303,2483.04570436478 4406.00232839584,2508.6297082901 4406.10697031021,2457.46193647385 PathPoint;PointKind.SMOOTHPOINT 4406.64147019386,2684.88437891006 4406.13065242767,2694.27288293839 4407.15228796005,2675.49587488174 PathPoint;PointKind.SMOOTHPOINT 4406.80999875069,2742.77606248856 4406.95980191231,2757.46778726578 4406.65992021561,2728.08410167694 PathPoint;PointKind.SMOOTHPOINT 4405.76578259468,2882.03328609467 4405.42597174644,2899.64003562927 4406.10531806946,2864.42677259445 PathPoint;PointKind.SMOOTHPOINT 4405.51767110825,3295.10244369507 4405.43010234833,3335.85637807846 4405.60523986816,3254.34898138046 PathPoint;PointKind.SMOOTHPOINT 4402.24458217621,3664.37046289444 4402.26440906525,3670.63505172729 4402.14296936989,3632.55302667618 PathPoint;PointKind.SMOOTHPOINT 4402.37263083458,3681.50632381439 4402.40347266197,3684.19971227646 4402.31315016747,3676.30577802658 PathPoint;PointKind.SMOOTHPOINT 4402.47148990631,3689.22535657883 4403.34277153015,3690.67602396011 4401.22955560684,3687.15769529343 PathPoint;PointKind.SMOOTHPOINT 4402.54198551178,3694.1521024704 4402.75016784668,3708.48694324493 4402.51885414124,3692.55769014359 PathPoint;PointKind.SMOOTHPOINT 4402.43569135666,3730.08527040482 4401.7720413208,3745.43317079544 4402.91015982628,3719.10613059998 PathPoint;PointKind.SMOOTHPOINT 4402.51747727394,3758.24889421463 4401.49997234344,3761.67044878006 4403.53443145752,3754.8273396492 PathPoint;PointKind.CORNERPOINT 4398.20237517357,3769.21410799026 4398.20237517357,3769.21410799026 4398.20237517357,3769.21410799026 PathPoint;PointKind.SMOOTHPOINT 4392.42448925972,3775.48931837082 4388.90769481659,3776.54911279678 4395.94128370285,3774.42928791046 PathPoint;PointKind.SMOOTHPOINT 4369.2361164093,3773.99191617966 4363.07243227959,3773.37020158768 4375.39980053902,3774.61363077164 PathPoint;PointKind.SMOOTHPOINT 4280.84371447563,3772.68381357193 4275.06279945374,3772.81386852264 4318.43026399612,3771.8378663063 PathPoint;PointKind.SMOOTHPOINT 3967.86305308342,3773.591837883 3947.91637659073,3774.32519674301 3987.80972957611,3772.85824298859 PathPoint;PointKind.SMOOTHPOINT 3846.1485350132,3773.94494533539 3832.54012942314,3774.29309606552 3859.75694060326,3773.59655857086 PathPoint;PointKind.SMOOTHPOINT 3753.40881228447,3772.64935255051 3725.21883130074,3772.64463186264 3781.59851789474,3772.65383720398 PathPoint;PointKind.SMOOTHPOINT 3601.26552700996,3773.090736866 3583.20405721664,3773.20733785629 3619.32699680328,3772.97389984131 PathPoint;PointKind.SMOOTHPOINT 3469.40790295601,3773.47311258316 3456.71070814133,3773.08129549026 3482.10509777069,3773.86492967606 PathPoint;PointKind.SMOOTHPOINT 3230.32563686371,3774.1668176651 3222.52650976181,3774.11205768585 3245.61409592628,3774.27397727966 PathPoint;PointKind.SMOOTHPOINT 3162.38054037094,3773.28428506851 3160.08365035057,3773.25690507889 3192.70631790161,3773.6447095871 PathPoint;PointKind.SMOOTHPOINT 3156.0001373291,3773.00009965897 3153.35875511169,3774.49230909348 3157.99687027931,3771.87185525894 PathPoint;PointKind.SMOOTHPOINT 3148.46454262733,3773.12779426575 3124.27711486816,3772.87311315536 3150.79310059547,3773.15210580826 PathPoint;PointKind.SMOOTHPOINT 3092.66754627228,3773.00127983093 3070.2152466774,3773.63597631454 3101.90963029861,3772.73998975754 PathPoint;PointKind.SMOOTHPOINT 2949.21835184097,3773.41764450073 2926.50086760521,3773.78821849823 2971.93556070328,3773.04683446884 PathPoint;PointKind.SMOOTHPOINT 2737.66654729843,3774.03133392334 2719.93993163109,3773.93526792526 2755.39261221886,3774.12739992142 PathPoint;PointKind.SMOOTHPOINT 2304.41570162773,3773.72354507446 2278.13846468925,3773.48113775253 2330.69293856621,3773.96595239639 PathPoint;PointKind.SMOOTHPOINT 2063.8844203949,3774.42126274109 2034.53291416168,3773.28334093094 2093.23592662811,3775.55942058563 PathPoint;PointKind.SMOOTHPOINT 1546.58353686333,3771.22818946838 1510.00210046768,3770.85903167725 1586.4983689785,3771.63039207458 PathPoint;PointKind.SMOOTHPOINT 935.268777608871,3770.06241559982 931.554540395737,3770.0454211235 1040.23067593575,3770.54109334946 PathPoint;PointKind.SMOOTHPOINT 925.5315721035,3770.01096010208 923.175752162933,3771.05635643005 929.253244400024,3768.35966348648 PathPoint;PointKind.SMOOTHPOINT 919.110964536667,3769.96186494827 917.942279577255,3769.95053529739 920.80451130867,3769.9783873558 PathPoint;PointKind.SMOOTHPOINT 916.26608133316,3769.92740392685 881.520284414291,3769.37130689621 916.990864276886,3769.93896961212 PathPoint;PointKind.SMOOTHPOINT 697.46479511261,3768.9976644516 641.662291288376,3769.29695606232 753.267849683762,3768.69790077209 PathPoint;PointKind.SMOOTHPOINT 446.781320571899,3766.59530639648 405.384979248047,3766.62504673004 488.17821264267,3766.56580209732 PathPoint;PointKind.SMOOTHPOINT 320.720032453537,3766.96115970612 295.039805173874,3767.13653326035 346.399984359741,3766.78555011749 PathPoint;PointKind.SMOOTHPOINT 274.352649450302,3767.0956993103 265.345458984375,3767.89916038513 283.359839916229,3766.29200220108 PathPoint;PointKind.SMOOTHPOINT 259.99990940094,3770.00010251999 252.972929477692,3770.7301568985 267.026613950729,3769.27004814148 PathPoint;PointKind.SMOOTHPOINT 243.928563594818,3768.74841213226 237.81637430191,3769.57382440567 250.040477514267,3767.92347192764 PathPoint;PointKind.SMOOTHPOINT 229.000017642975,3770.99994421005 223.958755731583,3771.714656353 234.041279554367,3770.28570413589 PathPoint;PointKind.SMOOTHPOINT 219.999986886978,3764.00010824203 218.672411441803,3761.9267821312 221.327286958694,3766.07343435287 PathPoint;PointKind.SMOOTHPOINT 219.222882986069,3743.78565073013 219.082717895508,3742.49241828918 219.794558286667,3749.06385183334 PathPoint;PointKind.SMOOTHPOINT 218.503882884979,3721.39590024948 218.4408223629,3718.90526533127 218.821388483047,3733.91964912415 PathPoint;PointKind.SMOOTHPOINT 217.999949455261,3713.99999856949 219.304393529892,3710.23194551468 217.091217041016,3716.6247010231 PathPoint;PointKind.SMOOTHPOINT 218.062183856964,3703.03572893143 217.125638723373,3662.46165275574 218.146172761917,3706.67325496674 PathPoint;PointKind.SMOOTHPOINT 215.879298448563,3590.45936107635 215.699479579926,3568.96394491196 215.995506048203,3604.39199924469 PathPoint;PointKind.SMOOTHPOINT 215.41529417038,3430.86612224579 214.941376447678,3418.39666128159 215.889211893082,3443.3353471756 PathPoint;PointKind.SMOOTHPOINT 215.356088876724,3410.52585840225 214.110023975372,3404.15906667709 216.336143016815,3415.53545236588 PathPoint;PointKind.SMOOTHPOINT 215.287796258926,3387.05601453781 215.738857984543,3379.89307880402 214.837009906769,3394.21895027161 PathPoint;PointKind.SMOOTHPOINT 216.13154053688,3178.95463943481 217.437636852264,3144.51556921005 214.78358745575,3214.49976682663 PathPoint;PointKind.SMOOTHPOINT 213.517971038818,2778.41088294983 213.752589225769,2752.65622615814 213.283628225327,2804.16577577591 PathPoint;PointKind.SMOOTHPOINT 213.37725520134,2729.90699529648 213.439214229584,2722.7329659462 213.315020799637,2737.08102464676 PathPoint;PointKind.SMOOTHPOINT 215.999912023544,2719.00008201599 217.357778549194,2713.72848987579 214.676191806793,2724.1373705864 PathPoint;PointKind.SMOOTHPOINT 213.304281234741,2704.87271547318 213.854752779007,2700.82260131836 212.753809690475,2708.92282962799 PathPoint;PointKind.SMOOTHPOINT 214.703178405762,2687.65754699707 217.08763718605,2680.69406032562 212.269978523254,2694.76312637329 PathPoint;PointKind.SMOOTHPOINT 213.204320669174,2670.45087575912 213.978946208954,2664.37889099121 212.429419755936,2676.52238845825 PathPoint;PointKind.SMOOTHPOINT 212.985949516296,2595.34803628922 213.252786397934,2567.77166604996 212.7188372612,2622.92417049408 PathPoint;PointKind.SMOOTHPOINT 212.685792446136,2492.08180904388 213.163565397263,2485.19975423813 212.207468748093,2498.96339178085 PathPoint;PointKind.SMOOTHPOINT 214.089095592499,2476.43107652664 213.622612953186,2470.46459913254 214.555578231812,2482.39755392075 PathPoint;PointKind.SMOOTHPOINT 214.05742764473,2465.47884464264 213.842911720276,2459.35257196426 214.271392822266,2471.60464525223 PathPoint;PointKind.SMOOTHPOINT 214.016396999359,2451.39679670334 213.642990589142,2445.02268791199 214.389528036118,2457.77090549469 PathPoint;PointKind.SMOOTHPOINT 213.957191705704,2431.0565328598 214.249913692474,2413.63412618637 213.664469718933,2448.47893953323 PathPoint;PointKind.SMOOTHPOINT 213.71596455574,2348.13033342361 212.956484556198,2333.46976518631 214.475719928741,2362.79113769531 PathPoint;PointKind.SMOOTHPOINT 214.241652488708,2030.50427913666 214.084138870239,2007.52137422562 214.399166107178,2053.4871840477 PathPoint;PointKind.SMOOTHPOINT 214.530794620514,1631.51669740677 214.889055490494,1606.68705940247 214.106444120407,1660.88622093201 PathPoint;PointKind.SMOOTHPOINT 212.44291305542,1435.10634183884 212.426390647888,1432.74552583694 212.784651517868,1483.44217300415 PathPoint;PointKind.SMOOTHPOINT 212.406013011932,1428.58022689819 210.930837392807,1427.38140821457 215.64027428627,1431.2087059021 PathPoint;PointKind.SMOOTHPOINT 212.39692568779,1423.44388246536 212.399954795837,1420.61737060547 212.395273447037,1424.96134757996 PathPoint;PointKind.SMOOTHPOINT 212.458058595657,1417.1653676033 212.983746528625,1399.24516439438 212.419230937958,1418.48621606827 PathPoint;PointKind.SMOOTHPOINT 213.433982133865,1254.43830013275 213.238466978073,1239.02619838715 213.630048036575,1269.85040187836 PathPoint;PointKind.SMOOTHPOINT 213.120331764221,1146.47829294205 213.148419857025,1116.13677978516 213.08921456337,1179.94560956955 PathPoint;PointKind.SMOOTHPOINT 214.114154577255,990.009913444519 214.000700712204,971.704738140106 214.227883815765,1008.31508874893 PathPoint;PointKind.SMOOTHPOINT 216.4801633358,806.938569545746 216.285474300385,765.921692848206 216.674576997757,847.955446243286 PathPoint;PointKind.SMOOTHPOINT 217.105811834335,523.734354972839 217.234686613083,494.129269123077 216.976661682129,553.339204788208 PathPoint;PointKind.SMOOTHPOINT 218.21336388588,406.382067203522 217.943773269653,391.386330127716 218.942828178406,446.97384595871 PathPoint;PointKind.SMOOTHPOINT 218.58842253685,345.240190029144 218.618438243866,343.526816368103 218.176188468933,368.650553226471 PathPoint;PointKind.SMOOTHPOINT 218.681498765945,340.091807842255 220.464817285538,337.609198093414 217.679414749146,341.487243175507 PathPoint;PointKind.SMOOTHPOINT 218.803213834763,333.751451969147 219.516981840134,297.565019130707 218.761632442474,335.86277961731 PathPoint;PointKind.SMOOTHPOINT 220.66997051239,254.603691101074 220.801599025726,246.953580379486 220.533936023712,262.51957654953 PathPoint;PointKind.SMOOTHPOINT 219.999986886978,220.999946594238 218.625597953796,211.361718177795 221.760449409485,233.34596157074 PathPoint;PointKind.SMOOTHPOINT 217.608368396759,198.284704685211 216.902310848236,191.940336227417 217.92532324791,201.13293170929 PathPoint;PointKind.SMOOTHPOINT 220.474455356598,187.323975563049 222.6231944561,183.654584884644 216.671272516251,193.819169998169 PathPoint;PointKind.SMOOTHPOINT 230.612879991531,185.72979927063 233.854851722717,185.488336086273 227.370632886887,185.97149848938 PathPoint;PointKind.SMOOTHPOINT 250.903222560883,187.235698699951 256.083823442459,187.961504459381 245.722346305847,186.509892940521 PathPoint;PointKind.SMOOTHPOINT 282.000045776367,187.999978065491 288.737332820892,188.629009723663 275.699225664139,187.411780357361 PathPoint;PointKind.SMOOTHPOINT 319.010238647461,188.602809906006 333.880130052567,188.256547451019 304.140071868896,188.949072360992 PathPoint;PointKind.SMOOTHPOINT 382.760846614838,186.853322982788 399.022750854492,187.070002555847 366.498942375183,186.636407375336 PathPoint;PointKind.SMOOTHPOINT 492.88351893425,186.533968448639 510.562219619751,186.597461700439 475.205093622208,186.470239162445 PathPoint;PointKind.SMOOTHPOINT 640.680034160614,186.105093955994 658.446028232574,186.69163942337 622.913764715195,185.518548488617 PathPoint;PointKind.SMOOTHPOINT 972.502022981644,186.706981658936 986.141270399094,186.248602867126 946.145478487015,187.592582702637 PathPoint;PointKind.SMOOTHPOINT 1147.48065233231,185.441837310791 1149.70153927803,185.434520244598 1067.64190077782,185.705487728119 PathPoint;PointKind.SMOOTHPOINT 1154.13753032684,185.420594215393 1156.84803128242,187.062449455261 1152.24158406258,184.272050857544 PathPoint;PointKind.SMOOTHPOINT 1160.4595541954,185.401475429535 1230.22679686546,185.197305679321 1158.3557009697,185.407612323761 PathPoint;PointKind.SMOOTHPOINT 1310.11511564255,185.727438926697 1341.61288261414,186.83562040329 1295.80230474472,185.223977565765 PathPoint;PointKind.SMOOTHPOINT 1366.63001060486,187.128303050995 1380.16681909561,187.07448720932 1353.09347748756,187.182354927063 PathPoint;PointKind.SMOOTHPOINT 1434.73234534264,186.930506229401 1458.28448653221,187.185895442963 1411.18020415306,186.675589084625 PathPoint;PointKind.SMOOTHPOINT 1562.24292397499,186.560640335083 1585.49958944321,186.38078212738 1538.98625850677,186.740734577179 PathPoint;PointKind.SMOOTHPOINT 1707.14113354683,186.140263080597 1766.11979484558,186.80210351944 1648.163022995,185.478894710541 PathPoint;PointKind.SMOOTHPOINT 1873.77457022667,185.656864643097 1922.14529514313,186.198799610138 1825.40329456329,185.115165710449 PathPoint;PointKind.SMOOTHPOINT 2056.3510286808,186.692111492157 2091.31629824638,186.400609016418 2021.38575911522,186.983377933502 PathPoint;PointKind.SMOOTHPOINT 2185.30594110489,184.753324985504 2207.70812273026,185.248053073883 2164.4100522995,184.291641712189 PathPoint;PointKind.SMOOTHPOINT 2285.29046416283,186.027910709381 2320.63877820969,185.038690567017 2249.94270086288,187.016894817352 PathPoint;PointKind.SMOOTHPOINT 2457.71968603134,185.527517795563 2476.38807892799,185.90234041214 2431.75912857056,185.006353855133 PathPoint;PointKind.SMOOTHPOINT 2604.87678408623,186.756312847137 2608.51667046547,186.764101982117 2553.18863511086,186.645376682281 PathPoint;PointKind.SMOOTHPOINT 2615.3938472271,186.770002841949 2623.08420181274,186.04278087616 2612.04695820808,187.086524963379 PathPoint;PointKind.SMOOTHPOINT 2633.30083250999,186.733417510986 2640.08933901787,186.697776317596 2628.08112859726,186.761033535004 PathPoint;PointKind.SMOOTHPOINT 2648.98995995522,186.537272930145 2675.9278178215,185.792820453644 2645.48362970352,186.634283065796 PathPoint;PointKind.SMOOTHPOINT 2789.54580545425,187.69407749176 2808.85003566742,188.132865428925 2770.24212598801,187.255525588989 PathPoint;PointKind.SMOOTHPOINT 2930.09311437607,185.722010135651 2962.44949579239,186.297934055328 2897.73645758629,185.146086215973 PathPoint;PointKind.SMOOTHPOINT 3085.13415455818,185.272128582001 3103.12485337257,184.888808727264 3048.00086975098,186.062607765198 PathPoint;PointKind.SMOOTHPOINT 3190.91446280479,186.529955863953 3229.66859579086,186.300766468048 3152.16060519218,186.758673191071 PathPoint;PointKind.SMOOTHPOINT 3648.80269646645,188.330662250519 3678.18256616592,187.811150550842 3619.42282676697,188.850173950195 PathPoint;PointKind.SMOOTHPOINT 3860.35890698433,189.281408786774 3885.12351751328,189.888017177582 3835.59429645538,188.675508499146 PathPoint;PointKind.SMOOTHPOINT 3979.18035149574,190.501706600189 4003.07368040085,190.014295578003 3955.28674721718,190.988881587982 PathPoint;PointKind.SMOOTHPOINT 4137.11942195892,190.04332780838 4168.98646473885,190.946867465973 4105.25265455246,189.140024185181 PathPoint;PointKind.SMOOTHPOINT 4274.00013327599,192.000052928925 4287.24724888802,192.820744514465 4257.27697849274,190.963389873505 PathPoint";

negative67[2] = "PointKind.SMOOTHPOINT 4328.99992346764,192.999894618988 4340.25746583939,193.455440998077 4304.19015169144,191.996040344238 PathPoint;PointKind.SMOOTHPOINT 4358.00005316734,189.000055789948 4362.03868031502,188.515949249268 4354.39321160316,189.431998729706 PathPoint;PointKind.SMOOTHPOINT 4368.95220637321,187.806193828583 4370.02285838127,187.931528091431 4364.87750530243,187.328932285309 PathPoint;PointKind.SMOOTHPOINT 4372.1118414402,188.236484527588 4373.91140699387,188.101236820221 4371.07285737991,188.314611911774 PathPoint;PointKind.SMOOTHPOINT 4376.86203360558,188.890299797058 4378.00676107407,189.007608890533 4375.39897441864,188.740181922913 PathPoint;PointKind.SMOOTHPOINT 4379.99991416931,189.000055789948 4383.41729879379,188.775351047516 4379.06364440918,189.061424732208 PathPoint;PointKind.SMOOTHPOINT 4387.78912782669,187.751669883728 4392.90005922318,187.311229705811 4382.67792105675,188.191637992859 PathPoint;PointKind.SMOOTHPOINT 4395.05237817764,193.989114761353 4395.83526492119,196.991472244263 4394.26921606064,190.986757278442 PathPoint;PointKind.SMOOTHPOINT 4397.99116373062,208.062665462494 4398.24726104736,215.14652967453 4397.73506641388,200.978329181671 PathPoint;PointKind.SMOOTHPOINT 4399.62688207626,272.208552360535 4399.74969863892,287.228600978851 4399.50351476669,257.188267707825 PathPoint;PointKind.SMOOTHPOINT 4400.03168106079,411.461527347565 4399.41622138023,427.141528129578 4400.64714074135,395.781290531158 PathPoint;PointKind.SMOOTHPOINT 4402.24953889847,675.881416797638 4402.41751670837,706.97304725647 4402.15756416321,658.891189098358 PathPoint;PointKind.SMOOTHPOINT 4401.15988612175,799.492392539978 4401.4473760128,823.905901908875 4400.87212085724,775.078883171082 PathPoint;PointKind.SMOOTHPOINT 4403.09108018875,965.340306758881 4402.97569870949,975.84808588028 4403.20618629456,954.832055568695 PathPoint;PointKind.SMOOTHPOINT 4403.19572210312,1001.32705450058 4403.14340114594,1015.3061914444 4403.24776768684,987.347445487976 PathPoint;PointKind.SMOOTHPOINT 4403.36865663528,1060.78317403793 4402.85921573639,1074.58858966827 4403.87782216072,1046.97775840759 PathPoint;PointKind.SMOOTHPOINT 4403.9642894268,1265.75119256973 4404.29060697556,1283.98319721222 4403.63824725151,1247.51895189285 PathPoint;PointKind.SMOOTHPOINT 4404.31924581528,1387.79301166534 4404.5125579834,1399.34713125229 4404.12593364716,1376.2388920784 PathPoint;PointKind.SMOOTHPOINT 4405.94560146332,1448.80979061127 4406.28183245659,1462.65367984772 4405.60964584351,1434.96613740921 PathPoint;PointKind.SMOOTHPOINT 4404.80610609055,1555.20961046219 4404.80720758438,1573.31250429153 4404.80472922325,1537.10671663284 PathPoint;PointKind.SMOOTHPOINT 4405.02420186996,1630.3124499321 4405.66031455994,1648.63320350647 4404.38863992691,1611.99146032333 PathPoint;PointKind.SMOOTHPOINT 4405.9979224205,1965.14541149139 4405.69088101387,1981.04468822479 4406.30468845367,1949.246134758 PathPoint;PointKind.SMOOTHPOINT 4407.55598545074,2002.69258260727 4407.10134387016,2010.5529999733 4408.01090240479,1994.83240127563 PathPoint;PointKind.SMOOTHPOINT 4406.19343757629,2032.42512702942 4405.61983466148,2042.24581003189 4406.76731586456,2022.60444402695 PathPoint;PointKind.SMOOTHPOINT 4406.46192669868,2124.73888635635 4406.6411948204,2143.11817646027 4406.28265857697,2106.35983228683 PathPoint;PointKind.SMOOTHPOINT 4406.69406652451,2204.53574180603 4406.87746524811,2230.88898181915 4406.51011705399,2178.18250179291 PathPoint;PointKind.SMOOTHPOINT 4407.23545074463,2390.72769641876 4407.49567866325,2409.67323303223 4406.97494745255,2371.78239583969 PathPoint;PointKind.SMOOTHPOINT 4406.05464935303,2483.04570436478 4406.00232839584,2508.6297082901 4406.10697031021,2457.46193647385 PathPoint;PointKind.SMOOTHPOINT 4406.64147019386,2684.88437891006 4406.13065242767,2694.27288293839 4407.15228796005,2675.49587488174 PathPoint;PointKind.SMOOTHPOINT 4406.80999875069,2742.77606248856 4406.95980191231,2757.46778726578 4406.65992021561,2728.08410167694 PathPoint;PointKind.SMOOTHPOINT 4405.76578259468,2882.03328609467 4405.60331225395,2890.44932842255 4406.10531806946,2864.42677259445 PathPoint;PointKind.SMOOTHPOINT 4405.54851293564,3067.24215745926 4405.54823756218,3070.02240657806 4405.55952787399,2975.88716983795 PathPoint;PointKind.SMOOTHPOINT 4405.5474114418,3075.59706687927 4404.33466672897,3078.08439731598 4406.76979422569,3073.08990955353 PathPoint;PointKind.SMOOTHPOINT 4405.54686069489,3083.00004959106 4405.53915023804,3177.98760652542 4405.54713606834,3080.53065776825 PathPoint;PointKind.SMOOTHPOINT 4405.51767110825,3295.10244369507 4405.43010234833,3335.85637807846 4405.56090474129,3274.94581460953 PathPoint;PointKind.SMOOTHPOINT 4402.24458217621,3664.37046289444 4402.34591960907,3696.1878991127 4402.14296936989,3632.55302667618 PathPoint;PointKind.SMOOTHPOINT 4402.43569135666,3730.08527040482 4401.7720413208,3745.43317079544 4403.18746089935,3712.68457889557 PathPoint;PointKind.SMOOTHPOINT 4402.51747727394,3758.24889421463 4401.49997234344,3761.67044878006 4403.53443145752,3754.8273396492 PathPoint;PointKind.SMOOTHPOINT 4400.00001311302,3769.00002479553 4398.65619063377,3772.37342834473 4401.34383559227,3765.62662124634 PathPoint;PointKind.SMOOTHPOINT 4392.42448925972,3775.48931837082 4388.90769481659,3776.54911279678 4395.94128370285,3774.42928791046 PathPoint;PointKind.SMOOTHPOINT 4369.2361164093,3773.99191617966 4363.07243227959,3773.37020158768 4375.39980053902,3774.61363077164 PathPoint;PointKind.SMOOTHPOINT 4280.84371447563,3772.68381357193 4275.06279945374,3772.81386852264 4318.43026399612,3771.8378663063 PathPoint;PointKind.SMOOTHPOINT 3967.86305308342,3773.591837883 3947.91637659073,3774.32519674301 3987.80972957611,3772.85824298859 PathPoint;PointKind.SMOOTHPOINT 3846.1485350132,3773.94494533539 3832.54012942314,3774.29309606552 3859.75694060326,3773.59655857086 PathPoint;PointKind.SMOOTHPOINT 3753.40881228447,3772.64935255051 3725.21883130074,3772.64463186264 3781.59851789474,3772.65383720398 PathPoint;PointKind.SMOOTHPOINT 3601.26552700996,3773.090736866 3583.20405721664,3773.20733785629 3619.32699680328,3772.97389984131 PathPoint;PointKind.SMOOTHPOINT 3469.40790295601,3773.47311258316 3456.71070814133,3773.08129549026 3482.10509777069,3773.86492967606 PathPoint;PointKind.SMOOTHPOINT 3230.32563686371,3774.1668176651 3215.03662705421,3774.05942201614 3245.61409592628,3774.27397727966 PathPoint;PointKind.SMOOTHPOINT 3092.66754627228,3773.00127983093 3070.2152466774,3773.63597631454 3115.11984586716,3772.36658334732 PathPoint;PointKind.SMOOTHPOINT 2949.21835184097,3773.41764450073 2942.99491167068,3773.51913928986 2971.93556070328,3773.04683446884 PathPoint;PointKind.SMOOTHPOINT 2903.34333658218,3773.70678663254 2901.3939678669,3773.71457576752 2925.63509345055,3773.61827373505 PathPoint;PointKind.SMOOTHPOINT 2897.38645792007,3773.72968196869 2895.26057481766,3774.64195489883 2899.85848546028,3772.66917943954 PathPoint;PointKind.SMOOTHPOINT 2890.32092571259,3773.75540971756 2831.40202045441,3773.96288394928 2892.71612405777,3773.7469124794 PathPoint;PointKind.SMOOTHPOINT 2737.66654729843,3774.03133392334 2719.93993163109,3773.93526792526 2749.62574124336,3774.0962433815 PathPoint;PointKind.SMOOTHPOINT 2304.41570162773,3773.72354507446 2278.13846468925,3773.48113775253 2330.69293856621,3773.96595239639 PathPoint;PointKind.SMOOTHPOINT 2063.8844203949,3774.42126274109 2043.73121380806,3773.63998889923 2093.23592662811,3775.55942058563 PathPoint;PointKind.SMOOTHPOINT 1678.90819430351,3771.92047834396 1677.14167356491,3771.9122171402 1826.19499325752,3772.61583566666 PathPoint;PointKind.SMOOTHPOINT 1673.63974928856,3771.89569473267 1672.75084376335,3773.33385229111 1674.97613668442,3769.73361968994 PathPoint;PointKind.SMOOTHPOINT 1668.59738588333,3771.87185525894 1606.34976625443,3771.57775640488 1670.26807665825,3771.87964439392 PathPoint;PointKind.SMOOTHPOINT 1546.58353686333,3771.22818946838 1506.66842937469,3770.8255147934 1558.44524860382,3771.3476228714 PathPoint;PointKind.SMOOTHPOINT 916.26608133316,3769.92740392685 881.520284414291,3769.37130689621 951.012153625488,3770.48350095749 PathPoint;PointKind.SMOOTHPOINT 697.46479511261,3768.9976644516 661.955938339233,3769.188144207 753.267849683762,3768.69790077209 PathPoint;PointKind.SMOOTHPOINT 526.328727006912,3767.37988471985 521.511894464493,3767.31851577759 586.894090175629,3768.15148115158 PathPoint;PointKind.SMOOTHPOINT 512.180314064026,3767.2016787529 507.767454385757,3767.74927854538 516.805211305618,3766.62764310837 PathPoint;PointKind.SMOOTHPOINT 499.198107719421,3767.04329967499 476.480623483658,3766.77233219147 503.398379087448,3767.09333896637 PathPoint;PointKind.SMOOTHPOINT 446.781320571899,3766.59530639648 405.384979248047,3766.62504673004 457.718878984451,3766.58751726151 PathPoint;PointKind.SMOOTHPOINT 320.720032453537,3766.96115970612 295.039805173874,3767.13653326035 346.399984359741,3766.78555011749 PathPoint;PointKind.SMOOTHPOINT 274.352649450302,3767.0956993103 265.345458984375,3767.89916038513 283.359839916229,3766.29200220108 PathPoint;PointKind.SMOOTHPOINT 261.320875883102,3770.26280879974 254.293895959854,3770.99286317825 268.347580432892,3769.53275442123 PathPoint;PointKind.SMOOTHPOINT 243.928563594818,3768.74841213226 237.81637430191,3769.57382440567 250.040477514267,3767.92347192764 PathPoint;PointKind.SMOOTHPOINT 233.000092506409,3770.99994421005 227.958830595016,3771.714656353 238.041354417801,3770.28570413589 PathPoint;PointKind.SMOOTHPOINT 220.731103420258,3764.12190198898 219.403527975082,3762.04857587814 222.058403491974,3766.19522809982 PathPoint;PointKind.SMOOTHPOINT 219.222882986069,3743.78565073013 218.651207685471,3738.50744962692 219.794558286667,3749.06385183334 PathPoint;PointKind.SMOOTHPOINT 215.879298448563,3590.45936107635 215.699479579926,3568.96394491196 216.058566570282,3611.95477724075 PathPoint;PointKind.SMOOTHPOINT 215.41529417038,3430.86612224579 214.941376447678,3418.39666128159 215.889211893082,3443.3353471756 PathPoint;PointKind.SMOOTHPOINT 215.356088876724,3410.52585840225 214.110023975372,3404.15906667709 216.336143016815,3415.53545236588 PathPoint;PointKind.SMOOTHPOINT 215.287796258926,3387.05601453781 215.738857984543,3379.89307880402 214.837009906769,3394.21895027161 PathPoint;PointKind.SMOOTHPOINT 216.13154053688,3178.95463943481 217.437636852264,3144.51556921005 214.78358745575,3214.49976682663 PathPoint;PointKind.SMOOTHPOINT 213.517971038818,2778.41088294983 213.752589225769,2752.65622615814 213.283628225327,2804.16577577591 PathPoint;PointKind.SMOOTHPOINT 213.37725520134,2731.906914711 213.439214229584,2724.73288536072 213.315020799637,2739.08094406128 PathPoint;PointKind.SMOOTHPOINT 217.000068426132,2721.00000143051 216.456205844879,2715.72227239609 217.543380260468,2726.27725839615 PathPoint;PointKind.SMOOTHPOINT 213.304281234741,2704.87271547318 213.854752779007,2700.82260131836 212.753809690475,2708.92282962799 PathPoint;PointKind.SMOOTHPOINT 214.703178405762,2687.65754699707 216.956284046173,2680.84252595901 212.345430850983,2694.78861808777 PathPoint;PointKind.SMOOTHPOINT 213.204320669174,2670.45087575912 213.978946208954,2664.37889099121 212.429419755936,2676.52238845825 PathPoint;PointKind.SMOOTHPOINT 212.985949516296,2595.34803628922 213.252786397934,2567.77166604996 212.7188372612,2622.92417049408 PathPoint;PointKind.SMOOTHPOINT 212.685792446136,2492.08180904388 213.163565397263,2485.19975423813 212.207468748093,2498.96339178085 PathPoint;PointKind.SMOOTHPOINT 214.089095592499,2476.43107652664 213.622612953186,2470.46459913254 214.555578231812,2482.39755392075 PathPoint;PointKind.SMOOTHPOINT 214.05742764473,2465.47884464264 213.842911720276,2459.35257196426 214.271392822266,2471.60464525223 PathPoint;PointKind.SMOOTHPOINT 214.016396999359,2451.39679670334 213.642990589142,2445.02268791199 214.389528036118,2457.77090549469 PathPoint;PointKind.SMOOTHPOINT 213.957191705704,2431.0565328598 214.249913692474,2413.63412618637 213.664469718933,2448.47893953323 PathPoint;PointKind.SMOOTHPOINT 213.71596455574,2348.13033342361 212.956484556198,2333.46976518631 214.475719928741,2362.79113769531 PathPoint;PointKind.SMOOTHPOINT 214.241652488708,2030.50427913666 214.084138870239,2007.52137422562 214.399166107178,2053.4871840477 PathPoint;PointKind.SMOOTHPOINT 214.530794620514,1631.51669740677 214.954594373703,1602.14740991592 214.106444120407,1660.88622093201 PathPoint;PointKind.SMOOTHPOINT 212.458058595657,1417.1653676033 212.983746528625,1399.24516439438 211.932921409607,1435.08509874344 PathPoint;PointKind.SMOOTHPOINT 213.433982133865,1254.43830013275 213.238466978073,1239.02619838715 213.630048036575,1269.85040187836 PathPoint;PointKind.SMOOTHPOINT 213.120331764221,1146.47829294205 213.148419857025,1116.13677978516 213.08921456337,1179.94560956955 PathPoint;PointKind.SMOOTHPOINT 214.114154577255,990.009913444519 214.000700712204,971.704738140106 214.227883815765,1008.31508874893 PathPoint;PointKind.SMOOTHPOINT 216.4801633358,806.938569545746 216.285474300385,765.921692848206 216.674576997757,847.955446243286 PathPoint;PointKind.SMOOTHPOINT 217.105811834335,523.734354972839 217.234686613083,494.129269123077 216.976661682129,553.339204788208 PathPoint;PointKind.SMOOTHPOINT 218.21336388588,406.382067203522 217.968556880951,392.764298915863 218.942828178406,446.97384595871 PathPoint;PointKind.SMOOTHPOINT 218.479650020599,351.670711040497 218.53279709816,348.381571769714 218.137636184692,372.763452529907 PathPoint;PointKind.SMOOTHPOINT 218.651207685471,341.743576526642 219.912968873978,338.607623577118 217.410925626755,344.826421737671 PathPoint;PointKind.SMOOTHPOINT 218.840389251709,331.881115436554 219.55167889595,296.364784240723 218.774574995041,335.161993503571 PathPoint;PointKind.SMOOTHPOINT 220.66997051239,254.603691101074 220.908994674683,240.722272396088 220.536139011383,262.383148670197 PathPoint;PointKind.SMOOTHPOINT 217.608368396759,198.284704685211 216.902310848236,191.940336227417 218.314425945282,204.629545211792 PathPoint;PointKind.SMOOTHPOINT 220.474455356598,187.323975563049 224.869966506958,181.213989257812 216.078944206238,193.433961868286 PathPoint;PointKind.SMOOTHPOINT 233.999973535538,186.00005865097 237.241945266724,185.758595466614 230.757726430893,186.24175786972 PathPoint;PointKind.SMOOTHPOINT 256.000109910965,186.999900341034 261.180710792542,187.725706100464 250.81923365593,186.274094581604 PathPoint;PointKind.SMOOTHPOINT 282.785410881042,188.707845211029 288.930644989014,190.21799325943 276.640176773071,187.197697162628 PathPoint;PointKind.SMOOTHPOINT 319.010238647461,188.602809906006 333.880130052567,188.256547451019 304.140071868896,188.949072360992 PathPoint;PointKind.SMOOTHPOINT 382.760846614838,186.853322982788 399.022750854492,187.070002555847 366.498942375183,186.636407375336 PathPoint;PointKind.SMOOTHPOINT 492.88351893425,186.533968448639 510.562219619751,186.597461700439 475.205093622208,186.470239162445 PathPoint;PointKind.SMOOTHPOINT 640.680034160614,186.105093955994 658.446028232574,186.69163942337 622.913764715195,185.518548488617 PathPoint;PointKind.SMOOTHPOINT 972.502022981644,186.706981658936 998.858292102814,185.821144580841 946.145478487015,187.592582702637 PathPoint;PointKind.SMOOTHPOINT 1310.11511564255,185.727438926697 1341.61288261414,186.83562040329 1278.61734867096,184.619493484497 PathPoint;PointKind.SMOOTHPOINT 1366.63001060486,187.128303050995 1380.16681909561,187.07448720932 1353.09347748756,187.182354927063 PathPoint;PointKind.SMOOTHPOINT 1434.73234534264,186.930506229401 1458.28448653221,187.185895442963 1411.18020415306,186.675589084625 PathPoint;PointKind.SMOOTHPOINT 1562.24292397499,186.560640335083 1585.49958944321,186.38078212738 1538.98625850677,186.740734577179 PathPoint;PointKind.SMOOTHPOINT 1707.14113354683,186.140263080597 1766.11979484558,186.80210351944 1648.163022995,185.478894710541 PathPoint;PointKind.SMOOTHPOINT 1873.77457022667,185.656864643097 1922.14529514313,186.198799610138 1825.40329456329,185.115165710449 PathPoint;PointKind.SMOOTHPOINT 2056.3510286808,186.692111492157 2091.31629824638,186.400609016418 2021.38575911522,186.983377933502 PathPoint;PointKind.SMOOTHPOINT 2185.30594110489,184.753324985504 2207.70812273026,185.248053073883 2164.4100522995,184.291641712189 PathPoint;PointKind.SMOOTHPOINT 2285.29046416283,186.027910709381 2305.41558265686,185.464732646942 2249.94270086288,187.016894817352 PathPoint;PointKind.SMOOTHPOINT 2389.65012073517,185.194473266602 2392.28902459145,185.193293094635 2350.10236144066,185.211703777313 PathPoint;PointKind.SMOOTHPOINT 2397.48890161514,185.194001197815 2402.09314584732,186.628382205963 2395.0218307972,184.425473213196 PathPoint;PointKind.SMOOTHPOINT 2410.02968430519,185.206983089447 2431.33918404579,185.244040489197 2405.96324443817,185.199902057648 PathPoint;PointKind.SMOOTHPOINT 2457.71968603134,185.527517795563 2483.67996811867,186.048681735992 2449.15942668915,185.355684757233 PathPoint;PointKind.SMOOTHPOINT 2648.98995995522,186.537272930145 2675.9278178215,185.792820453644 2622.05237746239,187.282197475433 PathPoint;PointKind.SMOOTHPOINT 2789.54580545425,187.69407749176 2808.85003566742,188.132865428925 2770.24212598801,187.255525588989 PathPoint;PointKind.SMOOTHPOINT 2930.09311437607,185.722010135651 2962.44949579239,186.297934055328 2897.73645758629,185.146086215973 PathPoint;PointKind.SMOOTHPOINT 3085.13415455818,185.272128582001 3103.12485337257,184.888808727264 3048.00086975098,186.062607765198 PathPoint;PointKind.SMOOTHPOINT 3190.91446280479,186.529955863953 3217.29468941689,186.373937129974 3152.16060519218,186.758673191071 PathPoint;PointKind.SMOOTHPOINT 3533.59938383102,188.079993724823 3536.09178900719,188.091323375702 3406.31626367569,187.505486011505 PathPoint;PointKind.SMOOTHPOINT 3541.00390076637,188.113038539886 3543.15401673317,186.888728141785 3537.97451734543,189.838213920593 PathPoint;PointKind.SMOOTHPOINT 3548.34700942039,188.14537525177 3600.79326152802,188.371968269348 3545.926476717,188.134753704071 PathPoint;PointKind.SMOOTHPOINT 3648.80269646645,188.330662250519 3678.18256616592,187.811150550842 3640.21021842957,188.482668399811 PathPoint;PointKind.SMOOTHPOINT 3860.35890698433,189.281408786774 3885.12351751328,189.888017177582 3835.59429645538,188.675508499146 PathPoint;PointKind.SMOOTHPOINT 3979.18035149574,190.501706600189 4003.07368040085,190.014295578003 3955.28674721718,190.988881587982 PathPoint;PointKind.SMOOTHPOINT 4137.11942195892,190.04332780838 4168.98646473885,190.946867465973 4105.25265455246,189.140024185181 PathPoint;PointKind.SMOOTHPOINT 4268.99990200996,190.999975204468 4285.90975999832,191.780776977539 4252.26270318031,190.226726531982 PathPoint";


if (mask_variant_67 == 3) {
	
	mask67[0] = "PointKind.SMOOTHPOINT 150.989745855331,298.574774265289 150.922003984451,289.841737747192 151.172043085098,321.955161094666 PathPoint;PointKind.SMOOTHPOINT 151.984670162201,275.57204246521 151.236480474472,271.35977268219 153.016219139099,281.378016471863 PathPoint;PointKind.SMOOTHPOINT 151.984670162201,262.570323944092 151.780343055725,254.95349407196 152.153474092484,268.853323459625 PathPoint;PointKind.SMOOTHPOINT 150.989745855331,247.568686008453 150.21319270134,242.830059528351 151.766299009323,252.307076454163 PathPoint;PointKind.CORNERPOINT 150.989745855331,234.566967487335 150.989745855331,234.566967487335 150.989745855331,234.566967487335 PathPoint;PointKind.SMOOTHPOINT 153.923202981553,208.804917106732 156.51458486502,202.036143439541 152.533719867647,212.434292141117 PathPoint;PointKind.SMOOTHPOINT 166,201 168.696934757117,200.62255178206 159.19332363042,201.952625145645 PathPoint;PointKind.SMOOTHPOINT 185.211380578265,199.263727423108 187.342630106505,199.09807366351 180.675016761676,199.616321387898 PathPoint;PointKind.SMOOTHPOINT 211.028594970703,199.236631393433 217.113797664642,199.648039340973 202.100161314011,198.633091449738 PathPoint;PointKind.SMOOTHPOINT 235.494149923325,197.345759868622 238.245681524277,195.947256088257 233.767282962799,198.223571777344 PathPoint;PointKind.SMOOTHPOINT 266.40674829483,198.562989234924 289.166915416718,197.925460338593 253.177807331085,198.933327198029 PathPoint;PointKind.SMOOTHPOINT 334.837328195572,197.235059738159 338.206797838211,197.181243896484 295.182173252106,197.869992256165 PathPoint;PointKind.SMOOTHPOINT 389.799116849899,197.345051765442 394.820827245712,197.055909633636 380.67626953125,197.870464324951 PathPoint;PointKind.SMOOTHPOINT 409.576989412308,197.345051765442 422.359274625778,196.645445823669 404.505161046982,197.622392177582 PathPoint;PointKind.SMOOTHPOINT 452.088868618011,198.344185352325 467.501796483994,199.892334938049 442.939585447311,197.425303459167 PathPoint;PointKind.SMOOTHPOINT 486.700283288956,199.344971179962 501.317932605743,199.368574619293 472.083184719086,199.321603775024 PathPoint;PointKind.SMOOTHPOINT 540.10153055191,198.344185352325 569.440369606018,197.74276971817 520.833098888397,198.739070892334 PathPoint;PointKind.SMOOTHPOINT 594.490817785263,198.344185352325 618.081786632538,198.265821933746 580.752160549164,198.389739990234 PathPoint;PointKind.SMOOTHPOINT 641.958317756653,198.344185352325 685.651549100876,198.531596660614 598.26508641243,198.15630197525 PathPoint;PointKind.SMOOTHPOINT 707.225958108902,199.344971179962 721.924016475677,200.693671703339 692.527624368668,197.996270656586 PathPoint;PointKind.SMOOTHPOINT 760.626654624939,198.344185352325 795.099281072617,199.567787647247 726.154028177261,197.12034702301 PathPoint;PointKind.SMOOTHPOINT 857.539111375809,199.344971179962 889.693919420242,199.707047939301 805.799467563629,198.762438297272 PathPoint;PointKind.SMOOTHPOINT 919.839878082275,199.344971179962 929.855486154556,199.729943275452 909.824545383453,198.960471153259 PathPoint;PointKind.SMOOTHPOINT 939.618026018143,199.344971179962 948.274941444397,198.418536186218 936.34135723114,199.695718288422 PathPoint;PointKind.SMOOTHPOINT 955.440434217453,199.344971179962 965.959149599075,200.760233402252 944.921443462372,197.929708957672 PathPoint;PointKind.SMOOTHPOINT 975.21858215332,198.344185352325 991.829109191895,198.347961902618 958.608330488205,198.340408802032 PathPoint;PointKind.SMOOTHPOINT 1003.89680027962,199.344971179962 1007.98389315605,200.812633037567 997.536224126816,197.060866355896 PathPoint;PointKind.SMOOTHPOINT 1023.67467284203,198.344185352325 1040.73323249817,198.590605258942 1006.61611318588,198.098001480103 PathPoint;PointKind.SMOOTHPOINT 1067.18643307686,198.344185352325 1107.02471137047,198.852367401123 1027.34815478325,197.836003303528 PathPoint;PointKind.SMOOTHPOINT 1319.35637354851,200.345757007599 1346.38152480125,200.791625976562 1292.33177304268,199.900360107422 PathPoint;PointKind.SMOOTHPOINT 1392.54650831223,200.346701145172 1421.91618919373,200.174632072449 1363.17710280418,200.518534183502 PathPoint;PointKind.SMOOTHPOINT 1432.1025288105,200.346701145172 1436.2273478508,200.360391139984 1419.19302105904,200.30374288559 PathPoint;PointKind.SMOOTHPOINT 1445.71781873703,200.346229076385 1447.09441065788,200.343396663666 1440.94642281532,200.355906486511 PathPoint;PointKind.SMOOTHPOINT 1449.84814524651,200.337023735046 1450.9185218811,198.946545124054 1448.54232430458,202.033874988556 PathPoint;PointKind.SMOOTHPOINT 1455.00423789024,200.324985980988 1461.77897572517,199.810431003571 1452.85384654999,200.488085746765 PathPoint;PointKind.SMOOTHPOINT 1471.65882468224,200.346701145172 1479.56975340843,200.440406799316 1467.9305434227,200.302562713623 PathPoint;PointKind.SMOOTHPOINT 1496.37001276016,200.345757007599 1519.70571041107,200.737810134888 1462.84412026405,199.782814979553 PathPoint;PointKind.SMOOTHPOINT 1534.92670297623,199.345679283142 1536.63126468658,199.330809116364 1524.94111061096,199.434192180634 PathPoint;PointKind.SMOOTHPOINT 1542.83763170242,199.345679283142 1547.50053048134,198.08501958847 1541.46544575691,199.716725349426 PathPoint;PointKind.SMOOTHPOINT 1555.69344162941,199.345679283142 1574.52513098717,200.139462947845 1551.41909480095,199.165821075439 PathPoint;PointKind.SMOOTHPOINT 1609.09413814545,201.347486972809 1623.45651626587,200.975968837738 1594.73176002502,201.718769073486 PathPoint;PointKind.SMOOTHPOINT 1635.79489946365,200.346701145172 1649.90971684456,198.896269798279 1621.67953133583,201.797132492065 PathPoint;PointKind.SMOOTHPOINT 1663.48397612572,200.346701145172 1677.86921024323,199.885489940643 1649.09846663475,200.808148384094 PathPoint;PointKind.SMOOTHPOINT 2001.69958591461,201.346778869629 2037.00659394264,202.437493801117 1966.39257788658,200.255827903748 PathPoint;PointKind.SMOOTHPOINT 2052.13340878487,203.348586559296 2062.35472083092,203.665108680725 2041.91237211227,203.03159236908 PathPoint;PointKind.SMOOTHPOINT 2071.91183209419,201.346778869629 2084.35788631439,200.299022197723 2059.46522712708,202.394535541534 PathPoint;PointKind.SMOOTHPOINT 2100.58977484703,201.346778869629 2112.72328019142,202.191309928894 2088.4565448761,200.502247810364 PathPoint;PointKind.SMOOTHPOINT 2120.3679227829,201.346778869629 2127.65705823898,201.479902267456 2113.07851195335,201.213891506195 PathPoint;PointKind.SMOOTHPOINT 2139.15692925453,202.347564697266 2142.79213428497,202.420027256012 2127.77299046516,202.120971679688 PathPoint;PointKind.SMOOTHPOINT 2147.22234249115,202.524118423462 2150.91399908066,200.904922485352 2145.39716720581,203.324038982391 PathPoint;PointKind.SMOOTHPOINT 2155.96847891808,203.348586559296 2157.11127877235,203.315777778625 2151.65833353996,203.47156047821 PathPoint;PointKind.SMOOTHPOINT 2160.91280937195,202.347564697266 2171.60170555115,201.984071731567 2159.38806653023,202.399492263794 PathPoint;PointKind.SMOOTHPOINT 2182.66868948936,202.347564697266 2194.04904842377,201.827580928802 2171.28860592842,202.867548465729 PathPoint;PointKind.SMOOTHPOINT 2231.13607048988,200.347645282745 2246.92075252533,200.562672615051 2206.7572581768,200.015308856964 PathPoint;PointKind.SMOOTHPOINT 2263.75873804092,201.141428947449 2268.56593251228,199.818692207336 2255.41079163551,203.43875169754 PathPoint;PointKind.SMOOTHPOINT 2279.59243655205,201.348667144775 2297.4079978466,201.352443695068 2273.31171870232,201.347250938416 PathPoint;PointKind.SMOOTHPOINT 2323.99998664856,201.999886035919 2352.80184745789,202.167706489563 2295.19785046577,201.831593513489 PathPoint;PointKind.SMOOTHPOINT 2388.34953188896,198.348670005798 2410.36040782928,198.313500881195 2366.3389313221,198.383839130402 PathPoint;PointKind.SMOOTHPOINT 2474.38418626785,198.348670005798 2504.46460604668,199.912397861481 2444.30376648903,196.784706115723 PathPoint;PointKind.SMOOTHPOINT 2516.90680503845,199.349219799042 2522.4811899662,199.978959560394 2511.33297085762,198.719952106476 PathPoint;PointKind.SMOOTHPOINT 2539.6518266201,199.349219799042 2543.31456899643,198.557796478271 2534.16969180107,200.534348487854 PathPoint;PointKind.SMOOTHPOINT 2562.39657282829,199.349219799042 2585.84049224854,200.533876419067 2538.95265340805,198.164799213409 PathPoint;PointKind.SMOOTHPOINT 2600.96345186234,199.349219799042 2623.60025167465,200.620265007019 2578.32692742348,198.078646659851 PathPoint;PointKind.SMOOTHPOINT 3078.60367298126,198.351266384125 3091.0835981369,198.384075164795 3049.90700483322,198.275263309479 PathPoint;PointKind.SMOOTHPOINT 3154.5334982872,198.586120605469 3157.50395178795,198.593673706055 3120.07904648781,198.50209236145 PathPoint;PointKind.SMOOTHPOINT 3163.56024026871,198.607127666473 3167.00240850449,197.473926544189 3160.66441297531,199.560470581055 PathPoint;PointKind.SMOOTHPOINT 3174.98658657074,198.630495071411 3179.94523644447,196.792023181915 3171.37065768242,199.970934391022 PathPoint;PointKind.SMOOTHPOINT 3189.18511748314,198.653390407562 3232.04727172852,198.711926937103 3184.4126200676,198.64678144455 PathPoint;PointKind.SMOOTHPOINT 3308.02886724472,198.351266384125 3373.29678297043,197.662990093231 3277.47425436974,198.673453330994 PathPoint;PointKind.SMOOTHPOINT 3423.61963033676,199.445521831512 3437.34066367149,200.524671077728 3409.89887237549,198.36660861969 PathPoint;PointKind.SMOOTHPOINT 3453.39769005775,199.352052211761 3470.61844468117,199.700202941895 3436.1772108078,199.004137516022 PathPoint;PointKind.SMOOTHPOINT 3482.07618355751,201.353623867035 3490.27680516243,201.733167171478 3473.87501120567,200.974552631378 PathPoint;PointKind.SMOOTHPOINT 3499.91432547569,199.379432201385 3513.70475292206,199.160628318787 3486.12334728241,199.598472118378 PathPoint;PointKind.SMOOTHPOINT 3521.66993021965,200.380454063416 3530.3034389019,200.212397575378 3513.0364215374,200.548510551453 PathPoint;PointKind.SMOOTHPOINT 3549.35955762863,200.380454063416 3553.48713040352,201.64559841156 3541.18289351463,197.874476909637 PathPoint;PointKind.SMOOTHPOINT 3577.3518204689,199.407284259796 3599.2082118988,200.02498626709 3555.49597978592,198.789582252502 PathPoint;PointKind.SMOOTHPOINT 3788.98816466331,200.40712594986 3828.13470482826,202.044968605042 3749.84134912491,198.768811225891 PathPoint;PointKind.SMOOTHPOINT 3854.90320801735,199.4353723526 3870.231320858,200.224671363831 3839.5750951767,198.64536523819 PathPoint;PointKind.SMOOTHPOINT 3887.5371658802,200.435922145844 3906.94824099541,204.630961418152 3868.126090765,196.240882873535 PathPoint;PointKind.SMOOTHPOINT 3951.81566476822,201.436944007874 3970.34637093544,201.334977149963 3933.28550934792,201.538438796997 PathPoint;PointKind.SMOOTHPOINT 3992.00008749962,198.999888896942 4003.69299530983,200.352602005005 3980.30690431595,197.647175788879 PathPoint;PointKind.SMOOTHPOINT 4057.99994587898,199.999966621399 4090.23626446724,200.379037857056 4025.76417803764,199.620659351349 PathPoint;PointKind.SMOOTHPOINT 4162.44111299515,199.437732696533 4222.45958447456,200.837180614471 4103.37653517723,198.060235977173 PathPoint;PointKind.SMOOTHPOINT 4250.45349955559,199.437732696533 4283.53906989098,200.30161857605 4217.36765384674,198.573610782623 PathPoint;PointKind.SMOOTHPOINT 4311.76540017128,201.439304351807 4333.98087859154,200.942924022675 4289.54992175102,201.935920715332 PathPoint;PointKind.SMOOTHPOINT 4365.16609668732,201.439304351807 4394.98766541481,200.970540046692 4335.34425258636,201.908540725708 PathPoint;PointKind.SMOOTHPOINT 4408.28847885132,200.564088821411 4424.87229466438,200.403821468353 4391.70521378517,200.724356174469 PathPoint;PointKind.SMOOTHPOINT 4434,201 4432.05408342473,201.012226087479 4422.96904573267,201.069536317955 PathPoint;PointKind.SMOOTHPOINT 4465,204 4467.12899168305,205.597181663325 4462.32471285487,201.993683424872 PathPoint;PointKind.SMOOTHPOINT 4467,213 4467.53564264428,217.997134576521 4466.6057024732,209.321506837326 PathPoint;PointKind.SMOOTHPOINT 4468.0059671402,226.461546421051 4468.67338298393,234.780487261564 4467.84485755351,224.453411413354 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,343.469696044922 4471.21406793594,360.527429580688 4470.76575994492,326.411962509155 PathPoint;PointKind.CORNERPOINT 4470.98963856697,480.588212013245 4470.98963856697,480.588212013245 4470.98963856697,480.588212013245 PathPoint;PointKind.CORNERPOINT 4471.9787800312,1856.77848100662 4471.9787800312,1856.77848100662 4471.9787800312,1856.77848100662 PathPoint;PointKind.SMOOTHPOINT 4470.0007724762,2019.91955280304 4470.60714483261,2041.11732959747 4469.39440011978,1998.72130393982 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,2374.22582387924 4470.61898589134,2387.56932020187 4471.36056661606,2360.88232755661 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3079.83600854874 4470.95494151115,3090.62655687332 4471.02461099625,3069.04546022415 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3181.92442417145 4470.14369130135,3192.96918153763 4471.8355858326,3170.87943077087 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3257.99028396606 4470.812022686,3279.72763538361 4471.1675298214,3236.25246047974 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3331.05331420898 4470.2945959568,3356.46572113037 4471.6849565506,3305.6409072876 PathPoint;PointKind.SMOOTHPOINT 4471.9787800312,3418.12852621078 4472.10985779762,3443.6351108551 4471.84715151787,3392.62194156647 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3504.20318841934 4470.51048874855,3527.86020755768 4471.46878838539,3480.54593324661 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3603.28877449036 4470.68066954613,3621.88686847687 4471.29860758781,3584.69091653824 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3729.3979382515 4470.99239230156,3733.88188362122 4470.98192811012,3716.79724216461 PathPoint;PointKind.SMOOTHPOINT 4470.0007724762,3744.41090583801 4469.04577732086,3747.47911691666 4471.07225060463,3740.96810817719 PathPoint;PointKind.SMOOTHPOINT 4467,3758 4464.57203221321,3759.96475028992 4469.35526919365,3756.09402227402 PathPoint;PointKind.SMOOTHPOINT 4453,3760 4443.79527105741,3760.9005920998 4455.77409260783,3759.72837155058 PathPoint;PointKind.SMOOTHPOINT 4372.09944963455,3761.4254450798 4336.94692611694,3761.58193588257 4407.25197315216,3761.26895427704 PathPoint;PointKind.SMOOTHPOINT 3317.92909383774,3760.42442321777 3256.67529702187,3760.30735015869 3379.18316602707,3760.54196834564 PathPoint;PointKind.SMOOTHPOINT 2003.67731809616,3761.4254450798 1955.545617342,3763.19263458252 2051.80901885033,3759.65825557709 PathPoint;PointKind.SMOOTHPOINT 776.449338197708,3760.42442321777 741.262117624283,3760.54952144623 811.636283397675,3760.29956102371 PathPoint;PointKind.SMOOTHPOINT 610.313501358032,3760.42442321777 597.387746572495,3758.07517290115 623.238705396652,3762.77438163757 PathPoint;PointKind.SMOOTHPOINT 476.81162238121,3760.42442321777 459.065455198288,3761.45660161972 494.557514190674,3759.39248085022 PathPoint;PointKind.SMOOTHPOINT 377.921158075333,3759.42363739014 353.608160018921,3760.08453369141 402.234431505203,3758.76297712326 PathPoint;PointKind.SMOOTHPOINT 238,3761 214.430213395292,3761.1790473323 266.606869026918,3760.78329017278 PathPoint;PointKind.SMOOTHPOINT 181,3760 167.859498508788,3760.20152442157 186.241377644553,3759.92005879517 PathPoint;PointKind.SMOOTHPOINT 154,3756 152.963723498944,3754.8388641514 156.428359686552,3758.72094897691 PathPoint;PointKind.SMOOTHPOINT 151.394553254805,3746.85396774292 150.638697365721,3740.80870775716 151.69446848675,3749.25265984413 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,3709.38033342361 150.1404941082,3694.42849874496 150.765867233276,3722.49416828156 PathPoint;PointKind.SMOOTHPOINT 149.48455452919,3322.04553365707 147.839198112488,3305.08528232574 151.13046169281,3339.00554895401 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,3130.88033437729 150.214844942093,3122.75980710983 150.732547044754,3139.00038957596 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,2641.45711898804 148.264099359512,2629.93155956268 152.683292627335,2652.98267841339 PathPoint;PointKind.SMOOTHPOINT 151.462562084198,2274.13945198059 151.63632273674,2259.76731777191 151.288526058197,2288.51111412048 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,1541.50592565536 150.709140300751,1526.78988933563 150.237976312637,1556.22148990631 PathPoint;PointKind.SMOOTHPOINT 151.462562084198,1280.27958154678 151.219131946564,1267.19430685043 151.705992221832,1293.36532831192 PathPoint;PointKind.SMOOTHPOINT 149.48455452919,1217.22511768341 150.176017284393,1200.16738414764 148.793367147446,1234.28308725357 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,628.716316223145 150.870784521103,615.909090042114 150.073853731155,641.607806682587 PathPoint;PointKind.SMOOTHPOINT 151.462562084198,514.617762565613 151.582349538803,495.190715789795 151.356267929077,531.861255168915 PathPoint;PointKind.SMOOTHPOINT 149.448480606079,418.535242080688 150.93191742897,399.237542152405 147.965043783188,437.833414077759 PathPoint;PointKind.SMOOTHPOINT 150.437346696854,376.49893283844 150.402649641037,375.704205036163 150.974600315094,388.755490779877 PathPoint";
	
	mask67[1] = "PointKind.SMOOTHPOINT 150.989745855331,298.574774265289 150.922003984451,289.841737747192 151.172043085098,321.955161094666 PathPoint;PointKind.SMOOTHPOINT 151.984670162201,275.57204246521 151.984670162201,268.266507722722 151.984670162201,282.877577207698 PathPoint;PointKind.CORNERPOINT 150.989745855331,234.566967487335 150.989745855331,234.566967487335 150.989745855331,234.566967487335 PathPoint;PointKind.SMOOTHPOINT 153.923202981553,208.804917106732 156.51458486502,202.036143439541 152.533719867647,212.434292141117 PathPoint;PointKind.SMOOTHPOINT 166,201 168.696934757117,200.62255178206 159.19332363042,201.952625145645 PathPoint;PointKind.SMOOTHPOINT 185.211380578265,199.263727423108 187.342630106505,199.09807366351 180.675016761676,199.616321387898 PathPoint;PointKind.SMOOTHPOINT 209,198 215.085202693939,198.41140794754 200.071566343307,197.396460056305 PathPoint;PointKind.SMOOTHPOINT 235.494149923325,197.345759868622 238.245681524277,195.947256088257 233.767282962799,198.223571777344 PathPoint;PointKind.SMOOTHPOINT 266.40674829483,198.562989234924 289.166915416718,197.925460338593 253.177807331085,198.933327198029 PathPoint;PointKind.SMOOTHPOINT 334.837328195572,197.235059738159 338.206797838211,197.181243896484 295.182173252106,197.869992256165 PathPoint;PointKind.SMOOTHPOINT 389.799116849899,197.345051765442 394.820827245712,197.055909633636 380.67626953125,197.870464324951 PathPoint;PointKind.SMOOTHPOINT 409.576989412308,197.345051765442 422.359274625778,196.645445823669 404.505161046982,197.622392177582 PathPoint;PointKind.SMOOTHPOINT 452.088868618011,198.344185352325 467.501796483994,199.892334938049 442.939585447311,197.425303459167 PathPoint;PointKind.SMOOTHPOINT 486.700283288956,199.344971179962 501.317932605743,199.368574619293 472.083184719086,199.321603775024 PathPoint;PointKind.SMOOTHPOINT 540.10153055191,198.344185352325 569.440369606018,197.74276971817 520.833098888397,198.739070892334 PathPoint;PointKind.SMOOTHPOINT 594.490817785263,198.344185352325 618.081786632538,198.265821933746 580.752160549164,198.389739990234 PathPoint;PointKind.SMOOTHPOINT 641.958317756653,198.344185352325 685.651549100876,198.531596660614 598.26508641243,198.15630197525 PathPoint;PointKind.SMOOTHPOINT 707.225958108902,199.344971179962 721.924016475677,200.693671703339 692.527624368668,197.996270656586 PathPoint;PointKind.SMOOTHPOINT 760.626654624939,198.344185352325 795.099281072617,199.567787647247 726.154028177261,197.12034702301 PathPoint;PointKind.SMOOTHPOINT 857.539111375809,199.344971179962 889.693919420242,199.707047939301 805.799467563629,198.762438297272 PathPoint;PointKind.SMOOTHPOINT 919.839878082275,199.344971179962 929.855486154556,199.729943275452 909.824545383453,198.960471153259 PathPoint;PointKind.SMOOTHPOINT 933,198 943.406456985881,197.844623449351 929.704980603149,198.049285374963 PathPoint;PointKind.SMOOTHPOINT 955.440434217453,199.344971179962 965.959149599075,200.760233402252 944.921443462372,197.929708957672 PathPoint;PointKind.SMOOTHPOINT 982,199 998.610527038574,199.003776550293 965.389748334885,198.996223449707 PathPoint;PointKind.SMOOTHPOINT 1003.89680027962,199.344971179962 1007.98389315605,200.812633037567 997.536224126816,197.060866355896 PathPoint;PointKind.SMOOTHPOINT 1023.67467284203,198.344185352325 1040.73323249817,198.590605258942 1006.61611318588,198.098001480103 PathPoint;PointKind.SMOOTHPOINT 1067.18643307686,198.344185352325 1107.02471137047,198.852367401123 1027.34815478325,197.836003303528 PathPoint;PointKind.SMOOTHPOINT 1319.35637354851,200.345757007599 1346.38152480125,200.791625976562 1292.33177304268,199.900360107422 PathPoint;PointKind.SMOOTHPOINT 1392.54650831223,200.346701145172 1421.91618919373,200.174632072449 1363.17710280418,200.518534183502 PathPoint;PointKind.SMOOTHPOINT 1432.1025288105,200.346701145172 1436.2273478508,200.360391139984 1419.19302105904,200.30374288559 PathPoint;PointKind.SMOOTHPOINT 1445.71781873703,200.346229076385 1447.09441065788,200.343396663666 1440.94642281532,200.355906486511 PathPoint;PointKind.SMOOTHPOINT 1449.84814524651,200.337023735046 1450.9185218811,198.946545124054 1448.54232430458,202.033874988556 PathPoint;PointKind.SMOOTHPOINT 1455.00423789024,200.324985980988 1461.77897572517,199.810431003571 1452.85384654999,200.488085746765 PathPoint;PointKind.SMOOTHPOINT 1471.65882468224,200.346701145172 1479.56975340843,200.440406799316 1467.9305434227,200.302562713623 PathPoint;PointKind.SMOOTHPOINT 1496.37001276016,200.345757007599 1519.70571041107,200.737810134888 1462.84412026405,199.782814979553 PathPoint;PointKind.SMOOTHPOINT 1534.92670297623,199.345679283142 1536.63126468658,199.330809116364 1524.94111061096,199.434192180634 PathPoint;PointKind.SMOOTHPOINT 1542.83763170242,199.345679283142 1547.50053048134,198.08501958847 1541.46544575691,199.716725349426 PathPoint;PointKind.SMOOTHPOINT 1555.69344162941,199.345679283142 1574.52513098717,200.139462947845 1551.41909480095,199.165821075439 PathPoint;PointKind.SMOOTHPOINT 1609.09413814545,201.347486972809 1623.45651626587,200.975968837738 1594.73176002502,201.718769073486 PathPoint;PointKind.SMOOTHPOINT 1635.79489946365,200.346701145172 1649.90971684456,198.896269798279 1621.67953133583,201.797132492065 PathPoint;PointKind.SMOOTHPOINT 1663.48397612572,200.346701145172 1677.86921024323,199.885489940643 1649.09846663475,200.808148384094 PathPoint;PointKind.SMOOTHPOINT 2001.69958591461,201.346778869629 2037.00659394264,202.437493801117 1966.39257788658,200.255827903748 PathPoint;PointKind.SMOOTHPOINT 2052.13340878487,203.348586559296 2062.35472083092,203.665108680725 2041.91237211227,203.03159236908 PathPoint;PointKind.SMOOTHPOINT 2071.91183209419,201.346778869629 2084.35788631439,200.299022197723 2059.46522712708,202.394535541534 PathPoint;PointKind.SMOOTHPOINT 2100.58977484703,201.346778869629 2112.72328019142,202.191309928894 2088.4565448761,200.502247810364 PathPoint;PointKind.SMOOTHPOINT 2120.3679227829,201.346778869629 2127.65705823898,201.479902267456 2113.07851195335,201.213891506195 PathPoint;PointKind.SMOOTHPOINT 2139.15692925453,202.347564697266 2142.79213428497,202.420027256012 2127.77299046516,202.120971679688 PathPoint;PointKind.SMOOTHPOINT 2147.22234249115,202.524118423462 2150.91399908066,200.904922485352 2145.39716720581,203.324038982391 PathPoint;PointKind.SMOOTHPOINT 2155.96847891808,203.348586559296 2157.11127877235,203.315777778625 2151.65833353996,203.47156047821 PathPoint;PointKind.SMOOTHPOINT 2160.91280937195,202.347564697266 2171.60170555115,201.984071731567 2159.38806653023,202.399492263794 PathPoint;PointKind.SMOOTHPOINT 2182.66868948936,202.347564697266 2194.04904842377,201.827580928802 2171.28860592842,202.867548465729 PathPoint;PointKind.SMOOTHPOINT 2231.13607048988,200.347645282745 2246.92075252533,200.562672615051 2206.7572581768,200.015308856964 PathPoint;PointKind.SMOOTHPOINT 2263.75873804092,201.141428947449 2268.56593251228,199.818692207336 2255.41079163551,203.43875169754 PathPoint;PointKind.SMOOTHPOINT 2279.59243655205,201.348667144775 2297.4079978466,201.352443695068 2273.31171870232,201.347250938416 PathPoint;PointKind.SMOOTHPOINT 2323.99998664856,201.999886035919 2352.80184745789,202.167706489563 2295.19785046577,201.831593513489 PathPoint;PointKind.SMOOTHPOINT 2388.34953188896,198.348670005798 2410.36040782928,198.313500881195 2366.3389313221,198.383839130402 PathPoint;PointKind.SMOOTHPOINT 2474.38418626785,198.348670005798 2504.46460604668,199.912397861481 2444.30376648903,196.784706115723 PathPoint;PointKind.SMOOTHPOINT 2516.90680503845,199.349219799042 2522.4811899662,199.978959560394 2511.33297085762,198.719952106476 PathPoint;PointKind.SMOOTHPOINT 2539.6518266201,199.349219799042 2543.31456899643,198.557796478271 2534.16969180107,200.534348487854 PathPoint;PointKind.SMOOTHPOINT 2562.39657282829,199.349219799042 2585.84049224854,200.533876419067 2538.95265340805,198.164799213409 PathPoint;PointKind.SMOOTHPOINT 2600.96345186234,199.349219799042 2623.60025167465,200.620265007019 2578.32692742348,198.078646659851 PathPoint;PointKind.SMOOTHPOINT 3078.60367298126,198.351266384125 3091.0835981369,198.384075164795 3049.90700483322,198.275263309479 PathPoint;PointKind.SMOOTHPOINT 3147,199 3149.97045350075,199.007553100586 3112.54554820061,198.915971755981 PathPoint;PointKind.SMOOTHPOINT 3163.56024026871,198.607127666473 3167.00240850449,197.473926544189 3160.66441297531,199.560470581055 PathPoint;PointKind.SMOOTHPOINT 3172,199 3177.21369177449,198.113656082922 3166.53204594605,199.929289485239 PathPoint;PointKind.SMOOTHPOINT 3189.18511748314,198.653390407562 3232.04727172852,198.711926937103 3184.4126200676,198.64678144455 PathPoint;PointKind.SMOOTHPOINT 3308.02886724472,198.351266384125 3373.29678297043,197.662990093231 3277.47425436974,198.673453330994 PathPoint;PointKind.SMOOTHPOINT 3423.61963033676,199.445521831512 3437.34066367149,200.524671077728 3409.89887237549,198.36660861969 PathPoint;PointKind.SMOOTHPOINT 3453.39769005775,199.352052211761 3470.61844468117,199.700202941895 3436.1772108078,199.004137516022 PathPoint;PointKind.SMOOTHPOINT 3482.07618355751,201.353623867035 3490.27680516243,201.733167171478 3473.87501120567,200.974552631378 PathPoint;PointKind.SMOOTHPOINT 3499.91432547569,199.379432201385 3513.70475292206,199.160628318787 3486.12334728241,199.598472118378 PathPoint;PointKind.SMOOTHPOINT 3521.66993021965,200.380454063416 3530.3034389019,200.212397575378 3513.0364215374,200.548510551453 PathPoint;PointKind.SMOOTHPOINT 3549.35955762863,200.380454063416 3553.48713040352,201.64559841156 3541.18289351463,197.874476909637 PathPoint;PointKind.SMOOTHPOINT 3577.3518204689,199.407284259796 3599.2082118988,200.02498626709 3555.49597978592,198.789582252502 PathPoint;PointKind.SMOOTHPOINT 3788.98816466331,200.40712594986 3828.13470482826,202.044968605042 3749.84134912491,198.768811225891 PathPoint;PointKind.SMOOTHPOINT 3854.90320801735,199.4353723526 3870.231320858,200.224671363831 3839.5750951767,198.64536523819 PathPoint;PointKind.SMOOTHPOINT 3887.5371658802,200.435922145844 3906.94824099541,204.630961418152 3868.126090765,196.240882873535 PathPoint;PointKind.SMOOTHPOINT 3951.81566476822,201.436944007874 3970.34637093544,201.334977149963 3933.28550934792,201.538438796997 PathPoint;PointKind.SMOOTHPOINT 3992.00008749962,198.999888896942 4003.69299530983,200.352602005005 3980.30690431595,197.647175788879 PathPoint;PointKind.SMOOTHPOINT 4057.99994587898,199.999966621399 4090.23626446724,200.379037857056 4025.76417803764,199.620659351349 PathPoint;PointKind.SMOOTHPOINT 4162.44111299515,199.437732696533 4222.45958447456,200.837180614471 4103.37653517723,198.060235977173 PathPoint;PointKind.SMOOTHPOINT 4250.45349955559,199.437732696533 4283.53906989098,200.30161857605 4217.36765384674,198.573610782623 PathPoint;PointKind.SMOOTHPOINT 4311.76540017128,201.439304351807 4333.98087859154,200.942924022675 4289.54992175102,201.935920715332 PathPoint;PointKind.SMOOTHPOINT 4365.16609668732,201.439304351807 4394.98766541481,200.970540046692 4335.34425258636,201.908540725708 PathPoint;PointKind.SMOOTHPOINT 4408.28847885132,200.564088821411 4424.87229466438,200.403821468353 4391.70521378517,200.724356174469 PathPoint;PointKind.SMOOTHPOINT 4441,200 4439.05408342473,200.012226087479 4429.96904573267,200.069536317955 PathPoint;PointKind.SMOOTHPOINT 4465,204 4467.12899168305,205.597181663325 4462.32471285487,201.993683424872 PathPoint;PointKind.SMOOTHPOINT 4467,213 4467.53564264428,217.997134576521 4466.6057024732,209.321506837326 PathPoint;PointKind.SMOOTHPOINT 4468.0059671402,226.461546421051 4468.67338298393,234.780487261564 4467.84485755351,224.453411413354 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,343.469696044922 4471.21406793594,360.527429580688 4470.76575994492,326.411962509155 PathPoint;PointKind.CORNERPOINT 4470.98963856697,480.588212013245 4470.98963856697,480.588212013245 4470.98963856697,480.588212013245 PathPoint;PointKind.CORNERPOINT 4471.9787800312,1856.77848100662 4471.9787800312,1856.77848100662 4471.9787800312,1856.77848100662 PathPoint;PointKind.SMOOTHPOINT 4470.0007724762,2019.91955280304 4470.60714483261,2041.11732959747 4469.39440011978,1998.72130393982 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,2374.22582387924 4470.61898589134,2387.56932020187 4471.36056661606,2360.88232755661 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3079.83600854874 4470.95494151115,3090.62655687332 4471.02461099625,3069.04546022415 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3181.92442417145 4470.14369130135,3192.96918153763 4471.8355858326,3170.87943077087 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3257.99028396606 4470.812022686,3279.72763538361 4471.1675298214,3236.25246047974 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3331.05331420898 4470.2945959568,3356.46572113037 4471.6849565506,3305.6409072876 PathPoint;PointKind.SMOOTHPOINT 4471.9787800312,3418.12852621078 4472.10985779762,3443.6351108551 4471.84715151787,3392.62194156647 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3504.20318841934 4470.51048874855,3527.86020755768 4471.46878838539,3480.54593324661 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3603.28877449036 4470.68066954613,3621.88686847687 4471.29860758781,3584.69091653824 PathPoint;PointKind.SMOOTHPOINT 4471,3726 4471.01083360409,3743.64051229948 4470.99228954315,3713.39930391312 PathPoint;PointKind.SMOOTHPOINT 4467,3758 4464.54010536863,3759.92462715298 4470.7822957388,3755.04063513689 PathPoint;PointKind.SMOOTHPOINT 4453,3760 4443.79527105741,3760.9005920998 4455.77409260783,3759.72837155058 PathPoint;PointKind.SMOOTHPOINT 4372.09944963455,3761.4254450798 4346.63228435711,3761.53881893578 4407.25197315216,3761.26895427704 PathPoint;PointKind.SMOOTHPOINT 3534.68258539742,3760.68733689911 3531.87613261179,3760.68420878771 3836.91811970169,3761.02421283886 PathPoint;PointKind.SMOOTHPOINT 3526.31744931388,3760.67799918342 3524.44099654683,3759.57218121572 3529.03451070143,3762.27919872038 PathPoint;PointKind.SMOOTHPOINT 3519.81777378998,3760.6707243516 3412.46096945776,3760.55042056951 3521.9727509265,3760.6731392139 PathPoint;PointKind.SMOOTHPOINT 3317.92909383774,3760.42442321777 3256.67529702187,3760.30735015869 3334.06998401905,3760.45539720746 PathPoint;PointKind.SMOOTHPOINT 2003.67731809616,3761.4254450798 1989.32925307895,3761.95224445496 2051.80901885033,3759.65825557709 PathPoint;PointKind.SMOOTHPOINT 1726.90645051209,3761.96685649732 1723.95607631599,3761.96493671212 1877.60636364908,3762.06491574101 PathPoint;PointKind.SMOOTHPOINT 1718.01094755687,3761.96085635491 1715.85239503017,3763.13794206991 1721.52387527625,3760.04521289238 PathPoint;PointKind.SMOOTHPOINT 1710.60567758325,3761.95554726109 1354.86968077616,3761.69384469815 1713.08380905633,3761.95737033597 PathPoint;PointKind.SMOOTHPOINT 776.449338197708,3760.42442321777 741.262117624283,3760.54952144623 800.77225663002,3760.33811242995 PathPoint;PointKind.SMOOTHPOINT 610.313501358032,3760.42442321777 597.387746572495,3758.07517290115 623.238705396652,3762.77438163757 PathPoint;PointKind.SMOOTHPOINT 476.81162238121,3760.42442321777 459.065455198288,3761.45660161972 494.557514190674,3759.39248085022 PathPoint;PointKind.SMOOTHPOINT 377.921158075333,3759.42363739014 353.608160018921,3760.08453369141 402.234431505203,3758.76297712326 PathPoint;PointKind.SMOOTHPOINT 238,3761 214.430213395292,3761.1790473323 266.606869026918,3760.78329017278 PathPoint;PointKind.SMOOTHPOINT 181,3760 167.859498508788,3760.20152442157 186.241377644553,3759.92005879517 PathPoint;PointKind.SMOOTHPOINT 154,3756 152.963723498944,3754.8388641514 156.428359686552,3758.72094897691 PathPoint;PointKind.SMOOTHPOINT 151.394553254805,3746.85396774292 150.638697365721,3740.80870775716 151.69446848675,3749.25265984413 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,3709.38033342361 150.1404941082,3694.42849874496 150.765867233276,3722.49416828156 PathPoint;PointKind.SMOOTHPOINT 149.48455452919,3322.04553365707 147.839198112488,3305.08528232574 151.13046169281,3339.00554895401 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,3130.88033437729 150.214844942093,3122.75980710983 150.732547044754,3139.00038957596 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,2641.45711898804 148.264099359512,2629.93155956268 152.683292627335,2652.98267841339 PathPoint;PointKind.SMOOTHPOINT 151.462562084198,2274.13945198059 151.63632273674,2259.76731777191 151.288526058197,2288.51111412048 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,1541.50592565536 150.709140300751,1526.78988933563 150.237976312637,1556.22148990631 PathPoint;PointKind.SMOOTHPOINT 151.462562084198,1280.27958154678 151.219131946564,1267.19430685043 151.705992221832,1293.36532831192 PathPoint;PointKind.SMOOTHPOINT 149.48455452919,1217.22511768341 150.176017284393,1200.16738414764 148.793367147446,1234.28308725357 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,628.716316223145 150.870784521103,615.909090042114 150.073853731155,641.607806682587 PathPoint;PointKind.SMOOTHPOINT 151.462562084198,514.617762565613 151.582349538803,495.190715789795 151.356267929077,531.861255168915 PathPoint;PointKind.SMOOTHPOINT 149.448480606079,418.535242080688 150.93191742897,399.237542152405 147.965043783188,437.833414077759 PathPoint;PointKind.SMOOTHPOINT 150.437346696854,376.49893283844 150.402649641037,375.704205036163 150.974600315094,388.755490779877 PathPoint";
	
	mask67[2] = "PointKind.SMOOTHPOINT 150.989745855331,298.574774265289 150.922003984451,289.841737747192 151.172043085098,321.955161094666 PathPoint;PointKind.SMOOTHPOINT 151.984670162201,275.57204246521 151.236480474472,271.35977268219 153.016219139099,281.378016471863 PathPoint;PointKind.SMOOTHPOINT 151.984670162201,262.570323944092 151.780343055725,254.95349407196 152.153474092484,268.853323459625 PathPoint;PointKind.SMOOTHPOINT 150.989745855331,247.568686008453 150.21319270134,242.830059528351 151.766299009323,252.307076454163 PathPoint;PointKind.CORNERPOINT 150.989745855331,234.566967487335 150.989745855331,234.566967487335 150.989745855331,234.566967487335 PathPoint;PointKind.SMOOTHPOINT 153,213 153.210950519174,211.748601862742 151.813529081266,220.03836853981 PathPoint;PointKind.SMOOTHPOINT 153.923202981553,208.804917106732 155.757436400841,204.013839825852 153.713450807791,209.352796598926 PathPoint;PointKind.SMOOTHPOINT 160.990094851219,201.800857071729 162.31640375031,201.291121086941 157.510121328042,203.138303975754 PathPoint;PointKind.SMOOTHPOINT 166,201 168.696934757117,200.62255178206 164.011229223964,201.278337465645 PathPoint;PointKind.SMOOTHPOINT 185.211380578265,199.263727423108 187.342630106505,199.09807366351 180.675016761676,199.616321387898 PathPoint;PointKind.SMOOTHPOINT 211.028594970703,199.236631393433 217.113797664642,199.648039340973 202.100161314011,198.633091449738 PathPoint;PointKind.SMOOTHPOINT 235.494149923325,197.345759868622 238.245681524277,195.947256088257 233.767282962799,198.223571777344 PathPoint;PointKind.SMOOTHPOINT 266.40674829483,198.562989234924 289.166915416718,197.925460338593 253.177807331085,198.933327198029 PathPoint;PointKind.SMOOTHPOINT 334.837328195572,197.235059738159 338.206797838211,197.181243896484 295.182173252106,197.869992256165 PathPoint;PointKind.SMOOTHPOINT 389.799116849899,197.345051765442 394.820827245712,197.055909633636 380.67626953125,197.870464324951 PathPoint;PointKind.SMOOTHPOINT 409.576989412308,197.345051765442 422.359274625778,196.645445823669 404.505161046982,197.622392177582 PathPoint;PointKind.SMOOTHPOINT 452.088868618011,198.344185352325 467.501796483994,199.892334938049 442.939585447311,197.425303459167 PathPoint;PointKind.SMOOTHPOINT 486.700283288956,199.344971179962 501.317932605743,199.368574619293 472.083184719086,199.321603775024 PathPoint;PointKind.SMOOTHPOINT 540.10153055191,198.344185352325 569.440369606018,197.74276971817 520.833098888397,198.739070892334 PathPoint;PointKind.SMOOTHPOINT 594.490817785263,198.344185352325 618.081786632538,198.265821933746 580.752160549164,198.389739990234 PathPoint;PointKind.SMOOTHPOINT 641.958317756653,198.344185352325 685.651549100876,198.531596660614 598.26508641243,198.15630197525 PathPoint;PointKind.SMOOTHPOINT 707.225958108902,199.344971179962 721.924016475677,200.693671703339 692.527624368668,197.996270656586 PathPoint;PointKind.SMOOTHPOINT 760.626654624939,198.344185352325 795.099281072617,199.567787647247 726.154028177261,197.12034702301 PathPoint;PointKind.SMOOTHPOINT 857.539111375809,199.344971179962 889.693919420242,199.707047939301 805.799467563629,198.762438297272 PathPoint;PointKind.SMOOTHPOINT 919.839878082275,199.344971179962 929.855486154556,199.729943275452 909.824545383453,198.960471153259 PathPoint;PointKind.SMOOTHPOINT 939.618026018143,199.344971179962 948.274941444397,198.418536186218 936.34135723114,199.695718288422 PathPoint;PointKind.SMOOTHPOINT 955.440434217453,199.344971179962 965.959149599075,200.760233402252 944.921443462372,197.929708957672 PathPoint;PointKind.SMOOTHPOINT 975.21858215332,198.344185352325 991.829109191895,198.347961902618 958.608330488205,198.340408802032 PathPoint;PointKind.SMOOTHPOINT 1003.89680027962,199.344971179962 1007.98389315605,200.812633037567 997.536224126816,197.060866355896 PathPoint;PointKind.SMOOTHPOINT 1023.67467284203,198.344185352325 1040.73323249817,198.590605258942 1006.61611318588,198.098001480103 PathPoint;PointKind.SMOOTHPOINT 1067.18643307686,198.344185352325 1107.02471137047,198.852367401123 1027.34815478325,197.836003303528 PathPoint;PointKind.SMOOTHPOINT 1319.35637354851,200.345757007599 1346.38152480125,200.791625976562 1292.33177304268,199.900360107422 PathPoint;PointKind.SMOOTHPOINT 1392.54650831223,200.346701145172 1421.91618919373,200.174632072449 1363.17710280418,200.518534183502 PathPoint;PointKind.SMOOTHPOINT 1432.1025288105,200.346701145172 1436.2273478508,200.360391139984 1419.19302105904,200.30374288559 PathPoint;PointKind.SMOOTHPOINT 1445.71781873703,200.346229076385 1447.09441065788,200.343396663666 1440.94642281532,200.355906486511 PathPoint;PointKind.SMOOTHPOINT 1449.84814524651,200.337023735046 1450.9185218811,198.946545124054 1448.54232430458,202.033874988556 PathPoint;PointKind.SMOOTHPOINT 1455.00423789024,200.324985980988 1461.77897572517,199.810431003571 1452.85384654999,200.488085746765 PathPoint;PointKind.SMOOTHPOINT 1471.65882468224,200.346701145172 1479.56975340843,200.440406799316 1467.9305434227,200.302562713623 PathPoint;PointKind.SMOOTHPOINT 1496.37001276016,200.345757007599 1519.70571041107,200.737810134888 1462.84412026405,199.782814979553 PathPoint;PointKind.SMOOTHPOINT 1534.92670297623,199.345679283142 1536.63126468658,199.330809116364 1524.94111061096,199.434192180634 PathPoint;PointKind.SMOOTHPOINT 1542.83763170242,199.345679283142 1547.50053048134,198.08501958847 1541.46544575691,199.716725349426 PathPoint;PointKind.SMOOTHPOINT 1555.69344162941,199.345679283142 1574.52513098717,200.139462947845 1551.41909480095,199.165821075439 PathPoint;PointKind.SMOOTHPOINT 1609.09413814545,201.347486972809 1623.45651626587,200.975968837738 1594.73176002502,201.718769073486 PathPoint;PointKind.SMOOTHPOINT 1635.79489946365,200.346701145172 1649.90971684456,198.896269798279 1621.67953133583,201.797132492065 PathPoint;PointKind.SMOOTHPOINT 1663.48397612572,200.346701145172 1677.86921024323,199.885489940643 1649.09846663475,200.808148384094 PathPoint;PointKind.SMOOTHPOINT 2001.69958591461,201.346778869629 2037.00659394264,202.437493801117 1966.39257788658,200.255827903748 PathPoint;PointKind.SMOOTHPOINT 2052.13340878487,203.348586559296 2062.35472083092,203.665108680725 2041.91237211227,203.03159236908 PathPoint;PointKind.SMOOTHPOINT 2071.91183209419,201.346778869629 2084.35788631439,200.299022197723 2059.46522712708,202.394535541534 PathPoint;PointKind.SMOOTHPOINT 2100.58977484703,201.346778869629 2112.72328019142,202.191309928894 2088.4565448761,200.502247810364 PathPoint;PointKind.SMOOTHPOINT 2120.3679227829,201.346778869629 2127.65705823898,201.479902267456 2113.07851195335,201.213891506195 PathPoint;PointKind.SMOOTHPOINT 2139.15692925453,202.347564697266 2142.79213428497,202.420027256012 2127.77299046516,202.120971679688 PathPoint;PointKind.SMOOTHPOINT 2147.22234249115,202.524118423462 2150.91399908066,200.904922485352 2145.39716720581,203.324038982391 PathPoint;PointKind.SMOOTHPOINT 2155.96847891808,203.348586559296 2157.11127877235,203.315777778625 2151.65833353996,203.47156047821 PathPoint;PointKind.SMOOTHPOINT 2160.91280937195,202.347564697266 2171.60170555115,201.984071731567 2159.38806653023,202.399492263794 PathPoint;PointKind.SMOOTHPOINT 2182.66868948936,202.347564697266 2194.04904842377,201.827580928802 2171.28860592842,202.867548465729 PathPoint;PointKind.SMOOTHPOINT 2231.13607048988,200.347645282745 2246.92075252533,200.562672615051 2206.7572581768,200.015308856964 PathPoint;PointKind.SMOOTHPOINT 2263.75873804092,201.141428947449 2268.56593251228,199.818692207336 2255.41079163551,203.43875169754 PathPoint;PointKind.SMOOTHPOINT 2279.59243655205,201.348667144775 2297.4079978466,201.352443695068 2273.31171870232,201.347250938416 PathPoint;PointKind.SMOOTHPOINT 2323.99998664856,201.999886035919 2352.80184745789,202.167706489563 2295.19785046577,201.831593513489 PathPoint;PointKind.SMOOTHPOINT 2388.34953188896,198.348670005798 2410.36040782928,198.313500881195 2366.3389313221,198.383839130402 PathPoint;PointKind.SMOOTHPOINT 2474.38418626785,198.348670005798 2504.46460604668,199.912397861481 2444.30376648903,196.784706115723 PathPoint;PointKind.SMOOTHPOINT 2516.90680503845,199.349219799042 2522.4811899662,199.978959560394 2511.33297085762,198.719952106476 PathPoint;PointKind.SMOOTHPOINT 2539.6518266201,199.349219799042 2543.31456899643,198.557796478271 2534.16969180107,200.534348487854 PathPoint;PointKind.SMOOTHPOINT 2562.39657282829,199.349219799042 2585.84049224854,200.533876419067 2538.95265340805,198.164799213409 PathPoint;PointKind.SMOOTHPOINT 2600.96345186234,199.349219799042 2623.60025167465,200.620265007019 2578.32692742348,198.078646659851 PathPoint;PointKind.SMOOTHPOINT 3078.60367298126,198.351266384125 3091.0835981369,198.384075164795 3049.90700483322,198.275263309479 PathPoint;PointKind.SMOOTHPOINT 3154.5334982872,198.586120605469 3157.50395178795,198.593673706055 3120.07904648781,198.50209236145 PathPoint;PointKind.SMOOTHPOINT 3163.56024026871,198.607127666473 3167.00240850449,197.473926544189 3160.66441297531,199.560470581055 PathPoint;PointKind.SMOOTHPOINT 3174.98658657074,198.630495071411 3179.94523644447,196.792023181915 3171.37065768242,199.970934391022 PathPoint;PointKind.SMOOTHPOINT 3189.18511748314,198.653390407562 3232.04727172852,198.711926937103 3184.4126200676,198.64678144455 PathPoint;PointKind.SMOOTHPOINT 3308.02886724472,198.351266384125 3373.29678297043,197.662990093231 3277.47425436974,198.673453330994 PathPoint;PointKind.SMOOTHPOINT 3423.61963033676,199.445521831512 3437.34066367149,200.524671077728 3409.89887237549,198.36660861969 PathPoint;PointKind.SMOOTHPOINT 3453.39769005775,199.352052211761 3470.61844468117,199.700202941895 3436.1772108078,199.004137516022 PathPoint;PointKind.SMOOTHPOINT 3482.07618355751,201.353623867035 3490.27680516243,201.733167171478 3473.87501120567,200.974552631378 PathPoint;PointKind.SMOOTHPOINT 3499.91432547569,199.379432201385 3513.70475292206,199.160628318787 3486.12334728241,199.598472118378 PathPoint;PointKind.SMOOTHPOINT 3521.66993021965,200.380454063416 3530.3034389019,200.212397575378 3513.0364215374,200.548510551453 PathPoint;PointKind.SMOOTHPOINT 3549.35955762863,200.380454063416 3553.48713040352,201.64559841156 3541.18289351463,197.874476909637 PathPoint;PointKind.SMOOTHPOINT 3577.3518204689,199.407284259796 3599.2082118988,200.02498626709 3555.49597978592,198.789582252502 PathPoint;PointKind.SMOOTHPOINT 3788.98816466331,200.40712594986 3828.13470482826,202.044968605042 3749.84134912491,198.768811225891 PathPoint;PointKind.SMOOTHPOINT 3854.90320801735,199.4353723526 3870.231320858,200.224671363831 3839.5750951767,198.64536523819 PathPoint;PointKind.SMOOTHPOINT 3887.5371658802,200.435922145844 3906.94824099541,204.630961418152 3868.126090765,196.240882873535 PathPoint;PointKind.SMOOTHPOINT 3951.81566476822,201.436944007874 3970.34637093544,201.334977149963 3933.28550934792,201.538438796997 PathPoint;PointKind.SMOOTHPOINT 3992.00008749962,198.999888896942 4003.69299530983,200.352602005005 3980.30690431595,197.647175788879 PathPoint;PointKind.SMOOTHPOINT 4057.99994587898,199.999966621399 4090.23626446724,200.379037857056 4025.76417803764,199.620659351349 PathPoint;PointKind.SMOOTHPOINT 4162.44111299515,199.437732696533 4222.45958447456,200.837180614471 4103.37653517723,198.060235977173 PathPoint;PointKind.SMOOTHPOINT 4250.45349955559,199.437732696533 4283.53906989098,200.30161857605 4217.36765384674,198.573610782623 PathPoint;PointKind.SMOOTHPOINT 4311.76540017128,201.439304351807 4333.98087859154,200.942924022675 4289.54992175102,201.935920715332 PathPoint;PointKind.SMOOTHPOINT 4365.16609668732,201.439304351807 4394.98766541481,200.970540046692 4335.34425258636,201.908540725708 PathPoint;PointKind.SMOOTHPOINT 4408.28847885132,200.564088821411 4424.87229466438,200.403821468353 4391.70521378517,200.724356174469 PathPoint;PointKind.SMOOTHPOINT 4434,201 4432.90389435328,201.006886771866 4422.96904573267,201.069536317955 PathPoint;PointKind.SMOOTHPOINT 4449.60255453646,201.139326713767 4456.26436957443,201.094342058629 4441.19016610635,201.196132312581 PathPoint;PointKind.SMOOTHPOINT 4465,204 4467.12899392713,205.597178672044 4462.69155810888,202.268802031158 PathPoint;PointKind.SMOOTHPOINT 4467,213 4467.53564264428,217.997134576521 4466.6057024732,209.321506837326 PathPoint;PointKind.SMOOTHPOINT 4468.0059671402,226.461546421051 4468.67338298393,234.780487261564 4467.84485755351,224.453411413354 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,343.469696044922 4471.21406793594,360.527429580688 4470.76575994492,326.411962509155 PathPoint;PointKind.CORNERPOINT 4470.98963856697,480.588212013245 4470.98963856697,480.588212013245 4470.98963856697,480.588212013245 PathPoint;PointKind.CORNERPOINT 4471.9787800312,1856.77848100662 4471.9787800312,1856.77848100662 4471.9787800312,1856.77848100662 PathPoint;PointKind.SMOOTHPOINT 4470.0007724762,2019.91955280304 4470.60714483261,2041.11732959747 4469.39440011978,1998.72130393982 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,2374.22582387924 4470.61898589134,2387.56932020187 4471.36056661606,2360.88232755661 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3079.83600854874 4470.95494151115,3090.62655687332 4471.02461099625,3069.04546022415 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3181.92442417145 4470.14369130135,3192.96918153763 4471.8355858326,3170.87943077087 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3257.99028396606 4470.812022686,3279.72763538361 4471.1675298214,3236.25246047974 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3331.05331420898 4470.2945959568,3356.46572113037 4471.6849565506,3305.6409072876 PathPoint;PointKind.SMOOTHPOINT 4471.9787800312,3418.12852621078 4472.10985779762,3443.6351108551 4471.84715151787,3392.62194156647 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3504.20318841934 4470.51048874855,3527.86020755768 4471.46878838539,3480.54593324661 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3603.28877449036 4470.68066954613,3621.88686847687 4471.29860758781,3584.69091653824 PathPoint;PointKind.SMOOTHPOINT 4470.98963856697,3729.3979382515 4470.99239230156,3733.88188362122 4470.98192811012,3716.79724216461 PathPoint;PointKind.SMOOTHPOINT 4470.0007724762,3744.41090583801 4469.04577732086,3747.47911691666 4471.07225060463,3740.96810817719 PathPoint;PointKind.SMOOTHPOINT 4467,3758 4464.57203221321,3759.96475028992 4469.35526919365,3756.09402227402 PathPoint;PointKind.SMOOTHPOINT 4453,3760 4443.79527105741,3760.9005920998 4455.77409260783,3759.72837155058 PathPoint;PointKind.SMOOTHPOINT 4372.09944963455,3761.4254450798 4336.94692611694,3761.58193588257 4407.25197315216,3761.26895427704 PathPoint;PointKind.SMOOTHPOINT 3317.92909383774,3760.42442321777 3292.33378581415,3760.37550345828 3379.18316602707,3760.54196834564 PathPoint;PointKind.SMOOTHPOINT 2749.39681096868,3760.21514322282 2742.35868331658,3760.21306353723 2826.32047393879,3760.23787327856 PathPoint;PointKind.SMOOTHPOINT 2738.68936780931,3760.21194571828 2737.67476997034,3759.09559129438 2738.76443726245,3760.29454407685 PathPoint;PointKind.SMOOTHPOINT 2733.84081477673,3760.21204661436 2731.90880239492,3761.53695658608 2734.90107342509,3759.48495642123 PathPoint;PointKind.SMOOTHPOINT 2726.8092394573,3760.21225106404 2724.62602870951,3761.64078218101 2729.45863199217,3758.47868517673 PathPoint;PointKind.SMOOTHPOINT 2718.97812265543,3760.21256056304 2384.17244713987,3760.227649517 2721.589768002,3760.21244286194 PathPoint;PointKind.SMOOTHPOINT 2003.67731809616,3761.4254450798 1955.545617342,3763.19263458252 2029.35218718914,3760.48277406603 PathPoint;PointKind.SMOOTHPOINT 776.449338197708,3760.42442321777 741.262117624283,3760.54952144623 811.636283397675,3760.29956102371 PathPoint;PointKind.SMOOTHPOINT 610.313501358032,3760.42442321777 597.387746572495,3758.07517290115 623.238705396652,3762.77438163757 PathPoint;PointKind.SMOOTHPOINT 476.81162238121,3760.42442321777 459.065455198288,3761.45660161972 494.557514190674,3759.39248085022 PathPoint;PointKind.SMOOTHPOINT 377.921158075333,3759.42363739014 370.203615261713,3759.63342211058 402.234431505203,3758.76297712326 PathPoint;PointKind.SMOOTHPOINT 339.692031857905,3760.04780746766 338.064668535957,3760.06763743109 356.169703237581,3759.84702156045 PathPoint;PointKind.SMOOTHPOINT 334.742164015174,3760.10690639454 331.668045012,3761.47131290593 336.269870962566,3759.42885414465 PathPoint;PointKind.SMOOTHPOINT 326.16695010996,3760.20423117811 293.167489350731,3760.56786411995 329.070301910054,3760.17223809907 PathPoint;PointKind.SMOOTHPOINT 238,3761 214.430213395292,3761.1790473323 255.123023587172,3760.87028543811 PathPoint;PointKind.SMOOTHPOINT 181,3760 172.070730549264,3760.13694042517 186.241377644553,3759.92005879517 PathPoint;PointKind.SMOOTHPOINT 158.8685503093,3758.2192873248 156.55932690015,3757.57773161079 163.899029631035,3759.61687091949 PathPoint;PointKind.SMOOTHPOINT 154,3756 153.611808054675,3755.56503540957 154.778234082211,3756.87200229913 PathPoint;PointKind.SMOOTHPOINT 152.800546705514,3753.23240433425 152.676005278819,3750.78898223719 152.868506502766,3754.56573152283 PathPoint;PointKind.SMOOTHPOINT 151.394553254805,3746.85396774292 150.638697365721,3740.80870775716 151.58211943975,3748.3541033758 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,3709.38033342361 150.1404941082,3694.42849874496 150.765867233276,3722.49416828156 PathPoint;PointKind.SMOOTHPOINT 149.48455452919,3322.04553365707 147.839198112488,3305.08528232574 151.13046169281,3339.00554895401 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,3130.88033437729 150.214844942093,3122.75980710983 150.732547044754,3139.00038957596 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,2641.45711898804 148.264099359512,2629.93155956268 152.683292627335,2652.98267841339 PathPoint;PointKind.SMOOTHPOINT 151.462562084198,2274.13945198059 151.63632273674,2259.76731777191 151.288526058197,2288.51111412048 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,1541.50592565536 150.709140300751,1526.78988933563 150.237976312637,1556.22148990631 PathPoint;PointKind.SMOOTHPOINT 151.462562084198,1280.27958154678 151.219131946564,1267.19430685043 151.705992221832,1293.36532831192 PathPoint;PointKind.SMOOTHPOINT 149.48455452919,1217.22511768341 149.874690229529,1207.60083818449 148.793367147446,1234.28308725357 PathPoint;PointKind.SMOOTHPOINT 150.129742058992,866.475277044057 150.130822256598,865.01322740411 150.01218142412,1025.59383363493 PathPoint;PointKind.SMOOTHPOINT 150.132977784293,862.095076831797 150.536535667461,859.864729300873 149.87337726224,863.529813724658 PathPoint;PointKind.SMOOTHPOINT 150.137022248624,856.620798342769 150.224841880589,737.793978377736 150.135676218156,858.442082678844 PathPoint;PointKind.SMOOTHPOINT 150.473695993423,628.716316223145 150.870784521103,615.909090042114 150.304123875387,634.183565556556 PathPoint;PointKind.SMOOTHPOINT 151.462562084198,514.617762565613 151.582349538803,495.190715789795 151.356267929077,531.861255168915 PathPoint;PointKind.SMOOTHPOINT 149.448480606079,418.535242080688 150.93191742897,399.237542152405 147.965043783188,437.833414077759 PathPoint;PointKind.SMOOTHPOINT 150.437346696854,376.49893283844 150.402649641037,375.704205036163 150.974600315094,388.755490779877 PathPoint";
	
	subshadow67[0] = "PointKind.SMOOTHPOINT 149.59375,212.65625 152.63635134697,207.772226333618 147.689817905426,215.712659358978 PathPoint;PointKind.SMOOTHPOINT 154.59375,201.65625 157.585958003998,199.862624645233 151.889031887054,203.277334213257 PathPoint;PointKind.SMOOTHPOINT 168.59375,199.65625 175.504879744525,200.97490412396 163.435913218038,198.672190748966 PathPoint;PointKind.CORNERPOINT 208.59375,229.65625 208.59375,229.65625 208.59375,229.65625 PathPoint;PointKind.CORNERPOINT 4433.984375,227 4433.984375,227 4433.984375,227 PathPoint;PointKind.SMOOTHPOINT 4443.97595203253,203.518148460668 4449.27366113717,204.569479096354 4443.97595203253,203.518148460668 PathPoint;PointKind.SMOOTHPOINT 4457.984375,201 4460.95463896911,200.672151009263 4451.37353520828,201.729685030078 PathPoint;PointKind.SMOOTHPOINT 4467.59375,204.65625 4468.26801568105,206.397541045449 4466.63618942234,202.18293896528 PathPoint;PointKind.CORNERPOINT 4469.59200668335,223.656349182129 4469.59200668335,223.656349182129 4469.59200668335,223.656349182129 PathPoint;PointKind.SMOOTHPOINT 4471.59375,339.65625 4472.15633797646,803.214344501495 4471.50563049316,267.21989107132 PathPoint;PointKind.SMOOTHPOINT 4473.37595081329,3348.65620326996 4473.51473903656,3462.10542631149 4472.43720269203,2581.17762756348 PathPoint;PointKind.SMOOTHPOINT 4472.38047575951,3621.65617895126 4472.41985416412,3678.3853931427 4472.33724212646,3559.54065990448 PathPoint;PointKind.SMOOTHPOINT 4471.37595081329,3754.65622282028 4468.10671710968,3759.52986097336 4472.18472266197,3753.45032310486 PathPoint;PointKind.SMOOTHPOINT 4461.59375,3760.65625 4457.62311329669,3761.44557953168 4465.27052799068,3759.92500153448 PathPoint;PointKind.CORNERPOINT 4450.59375,3743.65625 4450.59375,3743.65625 4450.59375,3743.65625 PathPoint;PointKind.CORNERPOINT 185.482622619994,3738.13449997249 185.482622619994,3738.13449997249 185.482622619994,3738.13449997249 PathPoint;PointKind.SMOOTHPOINT 167.59375,3759.65625 164.037148596618,3760.7233460969 171.35787412604,3758.52689033678 PathPoint;PointKind.SMOOTHPOINT 151.59375,3756.65625 148.031518936157,3754.11085510254 156.156688213348,3759.91635704041 PathPoint;PointKind.SMOOTHPOINT 147.59375,3744.65625 147.338478803635,3739.28528738022 147.848470449448,3750.02721261978 PathPoint;PointKind.SMOOTHPOINT 148.989358901978,3558.65623903275 148.863237857819,3364.3739695549 149.064260482788,3674.30459451675 PathPoint;PointKind.SMOOTHPOINT 151.393919944763,2653.97134256363 151.406311750412,2648.25482559204 150.562842845917,3034.04926490784 PathPoint;PointKind.SMOOTHPOINT 147.993608474731,2637.65617322922 148.184166908264,2547.28332471848 147.981492042542,2643.39487743378 PathPoint;PointKind.SMOOTHPOINT 148.989358901978,2369.6563501358 149.008359670639,2363.54943227768 148.691955566406,2464.38096475601 PathPoint;PointKind.SMOOTHPOINT 149.984558582306,2336.65614557266 150.923031330109,2036.64722633362 149.965282440186,2342.77604532242 PathPoint;PointKind.SMOOTHPOINT 148.368116378784,1432.04182338715 147.974056959152,1387.43344736099 150.953047037125,1724.7995300293 PathPoint;PointKind.SMOOTHPOINT 148.989358901978,1301.65618848801 148.880861759186,1292.60379743576 149.510365486145,1345.26849937439 PathPoint;PointKind.SMOOTHPOINT 148.989358901978,1274.65621423721 148.943646907806,1270.40051412582 149.086014986038,1283.66352272034 PathPoint;PointKind.SMOOTHPOINT 147.993608474731,1248.65631771088 147.803325414658,1229.93997049332 148.036842107773,1252.90139627457 PathPoint;PointKind.SMOOTHPOINT 147.473978757858,1192.97273588181 147.360249519348,1179.56102561951 147.630115509033,1211.37657356262 PathPoint;PointKind.SMOOTHPOINT 146.998133420944,1143.65618181229 147.63810133934,902.108733177185 146.963160991669,1156.89629507065 PathPoint;PointKind.SMOOTHPOINT 147.993608474731,529.656137943268 148.117251157761,516.06409740448 146.462807416916,697.919864177704 PathPoint;PointKind.SMOOTHPOINT 146.609306097031,482.055553913116 147.278188228607,417.136182308197 146.476025342941,494.959554195404 PathPoint;PointKind.SMOOTHPOINT 148.989083528519,315.65626335144 149.435739278793,293.664702892303 148.066031694412,361.0971326828 PathPoint";
	
} else if (mask_variant_67 == 2) {
	
	mask67[0] = "PointKind.SMOOTHPOINT 210.904025041467,302.229280778217 212.121640378432,281.326434841048 209.686680105421,323.132356907729 PathPoint;PointKind.SMOOTHPOINT 211.869085920354,274.797949789135 211.802837695269,265.932782259101 211.938308555544,284.067795458912 PathPoint;PointKind.SMOOTHPOINT 211.869085920354,255.494480254092 209.863792707178,249.886764575883 213.874379133529,261.1021959323 PathPoint;PointKind.SMOOTHPOINT 210.904025041467,240.254826349897 212.675691860874,234.190869447018 209.132358222059,246.319013445119 PathPoint;PointKind.SMOOTHPOINT 212.83414679924,226.031241449585 212.076483425006,221.221142241349 213.591810173474,230.841340657821 PathPoint;PointKind.CORNERPOINT 210.904025041467,213.839564364697 210.904025041467,213.839564364697 210.904025041467,213.839564364697 PathPoint;PointKind.CORNERPOINT 215.729059034982,206.727771914542 215.729059034982,206.727771914542 215.729059034982,206.727771914542 PathPoint;PointKind.SMOOTHPOINT 217.58903214961,192.535864637312 221.336788882972,186.147336530201 213.442434061146,199.604150734559 PathPoint;PointKind.SMOOTHPOINT 227.23882973572,183.392164371731 228.003793934759,183.080253746389 220.045354095198,186.325505404014 PathPoint;PointKind.SMOOTHPOINT 229.168681092575,180.344187552424 232.478658738541,179.200822182626 228.17793212641,180.686483567099 PathPoint;PointKind.SMOOTHPOINT 237.923566442944,179.29644092546 241.235977697178,178.535194845749 236.356593119002,179.656461750578 PathPoint;PointKind.SMOOTHPOINT 249.503485786828,176.248464106152 259.628107386199,171.367005271454 242.630435234981,179.562082889774 PathPoint;PointKind.SMOOTHPOINT 265.908168723308,173.200487286844 272.018418283466,172.402870816873 259.797919163151,173.998103756816 PathPoint;PointKind.SMOOTHPOINT 279.417939424047,173.200487286844 282.457245750381,173.52666983748 271.098784758923,172.307571186695 PathPoint;PointKind.SMOOTHPOINT 290.032797889044,173.200487286844 292.729398020278,171.805069319291 288.604727729831,173.939388767885 PathPoint;PointKind.SMOOTHPOINT 316.017855079905,172.072848740308 340.268678301507,171.28469076391 303.110092092915,172.492023062057 PathPoint;PointKind.SMOOTHPOINT 381.147926160886,172.072848740308 388.343835409676,172.814988855514 349.437802267703,168.802469114098 PathPoint;PointKind.SMOOTHPOINT 404.865848845323,171.16857947142 413.73905499289,172.966381673579 395.992372296838,169.370777269261 PathPoint;PointKind.SMOOTHPOINT 434.780302482542,172.184418282961 439.680507931459,171.890923045093 429.879826632706,172.478143713173 PathPoint;PointKind.SMOOTHPOINT 454.079897654763,172.184418282961 459.029316070886,171.902662854607 449.130479238641,172.466173711314 PathPoint;PointKind.SMOOTHPOINT 464.694756119761,172.184418282961 469.753416507043,174.760270605901 459.636095732478,169.608796152364 PathPoint;PointKind.SMOOTHPOINT 478.204526820499,171.16857947142 490.71165091465,170.751931329819 465.697402726348,171.585227613023 PathPoint;PointKind.SMOOTHPOINT 496.539061113834,171.16857947142 511.579301014488,172.740102599992 481.499091614098,169.597056342849 PathPoint;PointKind.SMOOTHPOINT 530.313487865681,172.184418282961 544.57740672871,172.208358286677 516.04983940357,172.160708471588 PathPoint;PointKind.SMOOTHPOINT 582.422719311781,171.16857947142 601.22477679357,170.767584409172 563.620661829991,171.569344341326 PathPoint;PointKind.SMOOTHPOINT 617.162206942514,173.200487286844 623.596667204209,176.625519164684 610.72774668082,169.775455409004 PathPoint;PointKind.SMOOTHPOINT 635.496741235849,171.16857947142 658.517053049561,171.089163112939 612.476699823055,171.247995829903 PathPoint;PointKind.SMOOTHPOINT 681.816148210466,171.16857947142 724.452424271294,171.358948539434 639.17960174872,170.977980211063 PathPoint;PointKind.SMOOTHPOINT 745.505028599532,172.184418282961 759.847634129906,173.553602341661 731.162152668238,170.81523422426 PathPoint;PointKind.SMOOTHPOINT 797.613989644713,171.16857947142 831.252675135366,172.410697356549 763.97530415406,169.926231393949 PathPoint;PointKind.SMOOTHPOINT 892.182384549884,172.184418282961 923.55970715734,172.552035455413 841.694206611468,171.593284345042 PathPoint;PointKind.SMOOTHPOINT 952.976352703208,172.184418282961 962.74972350917,172.575054689755 943.202981897245,171.79401206851 PathPoint;PointKind.SMOOTHPOINT 972.275947875429,172.184418282961 980.723542976942,171.243852367721 969.078457011648,172.540525838241 PathPoint;PointKind.SMOOTHPOINT 987.715840333941,172.184418282961 997.979988807368,173.621048698285 977.451421459596,170.747787867637 PathPoint;PointKind.SMOOTHPOINT 1007.01543550616,171.16857947142 1023.22407777658,171.172492741259 990.80679323575,171.164666201583 PathPoint;PointKind.SMOOTHPOINT 1035.00003778653,172.184418282961 1038.98818093662,173.67445332196 1028.79325509839,169.865920999971 PathPoint;PointKind.SMOOTHPOINT 1054.29963295875,171.16857947142 1070.94551351472,171.418568356382 1037.65375240278,170.918590586459 PathPoint;PointKind.SMOOTHPOINT 1096.75879641782,171.16857947142 1135.63352529843,171.684440513039 1057.88433793813,170.652718429802 PathPoint;PointKind.SMOOTHPOINT 1342.82958126686,173.200487286844 1369.20097166618,173.652815241677 1316.45846126845,172.748159332012 PathPoint;PointKind.SMOOTHPOINT 1413.27361740721,174.216556290728 1441.93286997976,174.041840302067 1384.61436483466,174.391042087045 PathPoint;PointKind.SMOOTHPOINT 1451.87280775165,174.216556290728 1455.8977254267,174.230367831334 1439.27536975065,174.172819745478 PathPoint;PointKind.SMOOTHPOINT 1465.1586864917,174.216095906042 1466.50230865678,174.213103405576 1460.5029234733,174.225763984466 PathPoint;PointKind.SMOOTHPOINT 1469.18928258603,174.206658019962 1470.23384133502,172.79511857007 1467.91488305614,175.92918732582 PathPoint;PointKind.SMOOTHPOINT 1474.22063248053,174.194227633416 1480.83139414122,173.671921206182 1472.12232135131,174.359966120683 PathPoint;PointKind.SMOOTHPOINT 1490.47226849701,174.216556290728 1498.19194432535,174.311625728564 1486.83402413573,174.17166878376 PathPoint;PointKind.SMOOTHPOINT 1515.56168814072,173.200487286844 1538.33269030738,173.598259656284 1482.84642178747,172.628919698117 PathPoint;PointKind.SMOOTHPOINT 1554.16114888608,173.200487286844 1555.824655338,173.185294592178 1544.41725178026,173.290032108438 PathPoint;PointKind.SMOOTHPOINT 1561.88082471442,173.200487286844 1566.43113137452,171.920617857394 1560.54206976587,173.577081960691 PathPoint;PointKind.SMOOTHPOINT 1574.42580493719,173.200487286844 1592.801980972,174.006160488837 1570.25460036512,173.017714566165 PathPoint;PointKind.SMOOTHPOINT 1626.53476598237,175.232395102269 1640.54964559926,174.855340043736 1612.51988636547,175.609450160801 PathPoint;PointKind.SMOOTHPOINT 1652.58951690588,174.216556290728 1666.36292850236,172.74401586983 1638.81583490848,175.688866519283 PathPoint;PointKind.SMOOTHPOINT 1679.60905830736,174.216556290728 1693.6463812005,173.748114871855 1665.57146501329,174.684767517258 PathPoint;PointKind.SMOOTHPOINT 2008.66831871768,174.216556290728 2043.12118137458,175.323781462608 1974.21545606078,173.109100926505 PathPoint;PointKind.SMOOTHPOINT 2057.88236752712,176.248464106152 2067.85637581477,176.569812617576 2047.90835923947,175.926885402386 PathPoint;PointKind.SMOOTHPOINT 2077.18223310026,174.216556290728 2089.32729036425,173.152837471755 2065.03690543535,175.280044917357 PathPoint;PointKind.SMOOTHPOINT 2105.16656497971,174.216556290728 2117.00661000739,175.073792577648 2093.32679035294,173.359320003809 PathPoint;PointKind.SMOOTHPOINT 2124.46643055284,174.216556290728 2131.57932671959,174.351449003976 2117.35326398518,174.081433385137 PathPoint;PointKind.SMOOTHPOINT 2142.80096484618,175.232395102269 2146.34808409786,175.305826459821 2131.69235430361,175.002202758843 PathPoint;PointKind.SMOOTHPOINT 2150.67098358532,175.411484745454 2154.27353502533,173.768141605734 2148.8903935356,176.223603333062 PathPoint;PointKind.SMOOTHPOINT 2159.20564778266,176.248464106152 2160.32105157235,176.215316408699 2155.00010229392,176.373458548633 PathPoint;PointKind.SMOOTHPOINT 2164.03068177617,175.232395102269 2174.46085641369,174.863396775757 2162.5426655205,175.285109148913 PathPoint;PointKind.SMOOTHPOINT 2185.26012830525,175.232395102269 2196.36522363587,174.704564058792 2174.15530337555,175.760226145745 PathPoint;PointKind.SMOOTHPOINT 2231.57953527987,175.232395102269 2246.98238281252,175.45084763618 2207.79047365425,174.895163319149 PathPoint;PointKind.SMOOTHPOINT 2263.41302423719,176.038298496605 2268.10420977594,174.695356365055 2255.26692616004,178.370146935513 PathPoint;PointKind.SMOOTHPOINT 2278.86373273245,176.248464106152 2296.24834859835,176.25237737599 2272.73509590982,176.247082952093 PathPoint;PointKind.SMOOTHPOINT 2325.18286930615,176.248464106152 2353.28807039626,176.419036632632 2297.07766821604,176.07766138733 PathPoint;PointKind.SMOOTHPOINT 2386.94189833836,176.248464106152 2408.42011371265,176.212784292921 2365.46341256315,176.284143919383 PathPoint;PointKind.SMOOTHPOINT 2470.89543477854,176.248464106152 2500.24826570759,177.83587050642 2441.54260384948,174.661057705884 PathPoint;PointKind.SMOOTHPOINT 2512.38953735872,177.264302917692 2517.82892223955,177.903316863044 2506.95042287881,176.625519164684 PathPoint;PointKind.SMOOTHPOINT 2534.5843151676,177.264302917692 2538.15847451115,176.460701446791 2529.2349737927,178.467288104439 PathPoint;PointKind.SMOOTHPOINT 2556.77882257556,177.264302917692 2579.65582190236,178.466827719752 2533.90209364969,176.061778115632 PathPoint;PointKind.SMOOTHPOINT 2594.41322244204,177.264302917692 2616.5022734917,178.554300810254 2572.32417139237,175.974535217475 PathPoint;PointKind.SMOOTHPOINT 3060.50031161752,179.29644092546 3072.67808739268,179.329818815258 3032.49759247561,179.219326490412 PathPoint;PointKind.SMOOTHPOINT 3134.59340815591,179.53492019325 3137.49210600451,179.54228634824 3100.97256912589,179.449518833839 PathPoint;PointKind.SMOOTHPOINT 3143.40171808298,179.556097888844 3146.76090869616,178.405826748743 3140.57629888335,180.523826500609 PathPoint;PointKind.SMOOTHPOINT 3154.55197036703,179.579807700217 3159.39052440648,177.713638372061 3151.02323837783,180.940474642211 PathPoint;PointKind.SMOOTHPOINT 3168.40704304097,179.603057126904 3210.23238674658,179.662446751508 3163.74992801798,179.596381548944 PathPoint;PointKind.SMOOTHPOINT 3284.37631865768,179.29644092546 3348.06546944766,178.597807163162 3254.56083175671,179.623314053125 PathPoint;PointKind.SMOOTHPOINT 3397.17121775706,180.4072045 3410.56038964805,181.502689862366 3383.78204586606,179.311949329977 PathPoint;PointKind.SMOOTHPOINT 3426.22891101544,180.312279737001 3443.03324650977,180.66562498416 3409.42484592202,179.959164682184 PathPoint;PointKind.SMOOTHPOINT 3454.2135132958,182.344187552424 3462.21602848511,182.729299342976 3446.21099810649,181.959305954216 PathPoint;PointKind.SMOOTHPOINT 3471.62019732583,180.340185552423 3485.07723984742,180.118049941017 3458.16315480424,180.562551356174 PathPoint;PointKind.SMOOTHPOINT 3492.84991425583,181.356254556307 3501.27452527925,181.185682029829 3484.42503283149,181.526827082786 PathPoint;PointKind.SMOOTHPOINT 3519.86945565731,181.356254556307 3523.89734774245,182.640497640283 3511.89073574884,178.812398969104 PathPoint;PointKind.SMOOTHPOINT 3547.18505957796,180.368321560191 3568.51266164052,180.995365503685 3525.85745751539,179.741277616698 PathPoint;PointKind.SMOOTHPOINT 3752.72653232478,180.368321560191 3790.92634051228,182.031000856759 3714.52672413727,178.70541207128 PathPoint;PointKind.SMOOTHPOINT 3817.04720045797,179.3817944778 3832.00442727658,180.18332421761 3802.08997363936,178.580034545646 PathPoint;PointKind.SMOOTHPOINT 3848.89177585296,180.397633289341 3867.83336020881,184.655961450384 3829.95019149712,176.139305128298 PathPoint;PointKind.SMOOTHPOINT 3911.61559536314,181.413702293224 3929.69784559932,181.310345931025 3893.53361552789,181.516828463079 PathPoint;PointKind.SMOOTHPOINT 3951.18011698739,182.429541104764 3962.59022455432,183.802868625646 3939.76973901954,181.056443776226 PathPoint;PointKind.SMOOTHPOINT 4013.90393649757,182.429541104764 4045.36021617329,182.814652895317 3982.44765682185,182.044659506555 PathPoint;PointKind.SMOOTHPOINT 4118.12212898885,182.429541104764 4176.68891289676,183.850298774974 4060.48622597347,181.03136545255 PathPoint;PointKind.SMOOTHPOINT 4204.0057871868,182.429541104764 4236.29111607929,183.306573933219 4171.72018789338,181.552508276311 PathPoint;PointKind.SMOOTHPOINT 4263.83469446123,184.461448920188 4285.51273611446,183.957557880428 4242.1563824071,184.965570152292 PathPoint;PointKind.SMOOTHPOINT 4315.94365550642,184.461448920188 4345.04393197739,183.985411153983 4286.84337903544,184.937716878737 PathPoint;PointKind.SMOOTHPOINT 4363.227852959,185.477517924071 4379.4102663403,185.314771937269 4347.04570997862,185.640263910874 PathPoint;PointKind.SMOOTHPOINT 4384.457569889,187.509425739496 4389.2347429199,188.531019359621 4375.47485136935,185.588700825947 PathPoint;PointKind.SMOOTHPOINT 4392.17751611825,186.493586927956 4393.72502057605,186.408185568544 4389.96076938664,186.615588869971 PathPoint;PointKind.SMOOTHPOINT 4402.79237458325,188.52549474338 4404.25335074706,188.834412868257 4397.19291235854,187.341385328795 PathPoint;PointKind.SMOOTHPOINT 4406.65207729696,189.541333554919 4409.51724543164,190.003099395833 4404.67977299587,189.223668120992 PathPoint;PointKind.SMOOTHPOINT 4412.36802133911,190.557402558804 4413.84819596814,191.66439753834 4410.75994707552,189.354647564401 PathPoint;PointKind.SMOOTHPOINT 4416.22799445374,195.637287193535 4417.38666239042,201.17157151419 4415.76236407171,193.412938579007 PathPoint;PointKind.SMOOTHPOINT 4417.26693576196,210.87694109773 4417.9423972569,219.319475485234 4417.10334320613,208.830991549357 PathPoint;PointKind.SMOOTHPOINT 4418.23199664084,318.485003686296 4418.45075098408,335.800301951165 4418.01351269852,301.169705421426 PathPoint;PointKind.CORNERPOINT 4418.23199664084,457.673566447131 4418.23199664084,457.673566447131 4418.23199664084,457.673566447131 PathPoint;PointKind.CORNERPOINT 4419.19705751973,1854.64022965194 4419.19705751973,1854.64022965194 4419.19705751973,1854.64022965194 PathPoint;PointKind.SMOOTHPOINT 4417.26693576196,2020.24428459031 4417.85884337302,2041.76220446912 4416.67529855181,1998.72613451917 PathPoint;PointKind.SMOOTHPOINT 4418.23199664084,2379.89956426769 4417.8702002116,2393.44454213958 4418.59379307008,2366.3545863958 PathPoint;PointKind.SMOOTHPOINT 4418.23199664084,3096.16237699548 4418.198196526,3107.11584946508 4418.2660671566,3085.20890452589 PathPoint;PointKind.SMOOTHPOINT 4418.23199664084,3199.79197750554 4417.40646263601,3211.00349559212 4419.05753064567,3188.58045941896 PathPoint;PointKind.SMOOTHPOINT 4418.23199664084,3277.00608583806 4418.05866965195,3299.07186349421 4418.40532362974,3254.9403081819 PathPoint;PointKind.SMOOTHPOINT 4418.23199664084,3351.17221735126 4417.55356073579,3376.96849212499 4418.91043254589,3325.37617276988 PathPoint;PointKind.SMOOTHPOINT 4419.19705751973,3439.56216395713 4419.3252275552,3465.45373836103 4419.06888748426,3413.67058955322 PathPoint;PointKind.SMOOTHPOINT 4418.23199664084,3526.9360415591 4417.76447345239,3550.95039740237 4418.6995198293,3502.92168571584 PathPoint;PointKind.SMOOTHPOINT 4418.23199664084,3627.51766524985 4417.93049961648,3646.39666010362 4418.53349366521,3608.63890058843 PathPoint;PointKind.SMOOTHPOINT 4418.23199664084,3755.53061992969 4418.23470065003,3760.0824433286 4418.22442541512,3742.73975217486 PathPoint;PointKind.SMOOTHPOINT 4417.26693576196,3770.77027383388 4416.33513419607,3773.88500643278 4418.31257611462,3767.27549367598 PathPoint;PointKind.SMOOTHPOINT 4411.47711129047,3775.85015846861 4409.10758803979,3777.8447751244 4413.77524869862,3773.91562201446 PathPoint;PointKind.SMOOTHPOINT 4400.86225282548,3783.97801992265 4391.05048508905,3787.79575993838 4404.07055972601,3782.72945665191 PathPoint;PointKind.SMOOTHPOINT 4321.73375037882,3788.0418355535 4287.43150103364,3788.20066827046 4356.03572932307,3787.88300283654 PathPoint;PointKind.SMOOTHPOINT 3293.06132576582,3787.02576654962 3233.2889322834,3786.90675710806 3352.83371924825,3787.14500618351 PathPoint;PointKind.SMOOTHPOINT 2010.59817007453,3788.0418355535 1963.63061209776,3789.83572448582 2057.56572805131,3786.24794662118 PathPoint;PointKind.SMOOTHPOINT 813.053882103225,3787.02576654962 778.717832643211,3787.15283272319 847.389931563239,3786.89893056839 PathPoint;PointKind.SMOOTHPOINT 650.936633694361,3787.02576654962 638.323782840993,3784.64074367938 663.54921414681,3789.4110196122 PathPoint;PointKind.SMOOTHPOINT 520.66369027957,3787.02576654962 503.346945044271,3788.07360209689 537.980705915788,3785.97816119468 PathPoint;PointKind.SMOOTHPOINT 424.165444017545,3786.00992773808 400.440467409666,3786.68070822682 447.890420625423,3785.33914724933 PathPoint;PointKind.SMOOTHPOINT 270.732932315904,3787.02576654962 247.754262243674,3788.06968882705 293.711602388135,3785.98207446452 PathPoint;PointKind.SMOOTHPOINT 230.203620213688,3784.99385873419 228.14641002412,3784.75399831234 234.828287126437,3785.53342958718 PathPoint;PointKind.SMOOTHPOINT 225.378856621092,3781.94588191489 223.530666341689,3780.86489867016 227.126457758734,3782.96839630438 PathPoint;PointKind.SMOOTHPOINT 218.623971270723,3780.93004310334 217.061053960562,3780.05945566051 220.677666248348,3782.07409905017 PathPoint;PointKind.SMOOTHPOINT 214.763998156095,3775.85015846861 212.400423725625,3774.29037514956 216.313125019402,3776.87244266577 PathPoint;PointKind.SMOOTHPOINT 206.079261448871,3771.78634283777 198.93608037923,3766.24607351618 208.223270333346,3773.44925232668 PathPoint;PointKind.SMOOTHPOINT 202.219288334243,3735.21108139076 201.89426642995,3720.03334922695 202.504290902566,3748.52287441876 PathPoint;PointKind.SMOOTHPOINT 201.254227455356,3342.02851708568 199.648586800038,3324.81243172083 202.860138511593,3359.24460245054 PathPoint;PointKind.SMOOTHPOINT 202.219288334243,3147.97729234668 201.966733876165,3139.73433472093 202.471842792321,3156.22001978009 PathPoint;PointKind.SMOOTHPOINT 202.219288334243,2651.16512753155 200.063111408425,2639.46560167691 204.37546526006,2662.86465338619 PathPoint;PointKind.SMOOTHPOINT 203.18434921313,2278.3021017654 203.353890589163,2263.71320161607 203.014537436178,2292.89077172239 PathPoint;PointKind.SMOOTHPOINT 202.219288334243,1534.60795804853 202.449129115149,1519.66985611422 201.989177152418,1549.54582979049 PathPoint;PointKind.SMOOTHPOINT 203.18434921313,1269.43811823094 202.946666805581,1256.15509924587 203.42176121976,1282.72136740836 PathPoint;PointKind.SMOOTHPOINT 201.254227455356,1205.4317559872 201.928877747545,1188.11645772233 200.579577163167,1222.74705425207 PathPoint;PointKind.SMOOTHPOINT 202.219288334243,608.037967481315 202.606772850759,595.03762469397 201.82909980854,621.123941820412 PathPoint;PointKind.SMOOTHPOINT 203.18434921313,492.216920078713 203.301162410014,472.496572209725 203.080515260344,509.720745872849 PathPoint;PointKind.SMOOTHPOINT 207.044051926839,395.699112018811 208.49150804471,376.109973785577 205.596595808968,415.288480444388 PathPoint;PointKind.SMOOTHPOINT 208.009112805726,353.028127125534 207.48507582526,340.586461155685 208.533149786191,365.469793095382 PathPoint;PointKind.SMOOTHPOINT 210.904025041467,325.596796136451 212.7208488143,315.25839760849 209.087201268634,335.935194664414 PathPoint";
	
	mask67[1] = "PointKind.SMOOTHPOINT 211.121946573258,302.935509681701 212.33909726143,282.034428119659 209.904520511628,323.836591243743 PathPoint;PointKind.SMOOTHPOINT 212.086579799653,275.506660938262 212.020765542985,266.642625331878 212.155973911286,284.775731563568 PathPoint;PointKind.SMOOTHPOINT 212.086579799653,256.205184459686 210.081585645677,250.5979514122 214.091849327088,261.812417507171 PathPoint;PointKind.SMOOTHPOINT 211.121946573258,240.96704006195 212.893148660661,234.903552532196 209.350193738938,247.030763626098 PathPoint;PointKind.SMOOTHPOINT 211.217776536942,227.713236808776 210.459948778153,222.903563976287 211.975328922273,232.522909641265 PathPoint;PointKind.CORNERPOINT 211.121946573258,214.554319381713 211.121946573258,214.554319381713 211.121946573258,214.554319381713 PathPoint;PointKind.CORNERPOINT 215.946214199067,207.44283914566 215.946214199067,207.44283914566 215.946214199067,207.44283914566 PathPoint;PointKind.SMOOTHPOINT 217.806086540223,193.25245141983 219.127328395844,189.874327182769 214.822139739991,200.883679389953 PathPoint;PointKind.SMOOTHPOINT 227.454897165299,184.109659194946 228.239986896516,183.852617740631 221.389521360398,186.097304821014 PathPoint;PointKind.SMOOTHPOINT 229.384438991548,181.06198310852 232.694152593614,179.918868541717 228.394196033479,181.40423297882 PathPoint;PointKind.SMOOTHPOINT 238.13856124878,180.014226436615 241.450753211976,179.253251552581 236.571961641313,180.374178886413 PathPoint;PointKind.SMOOTHPOINT 249.717464447022,176.966786384582 259.841294288636,172.085831165313 242.845244407655,180.279765129089 PathPoint;PointKind.SMOOTHPOINT 266.120635271073,173.918874263763 272.230070829392,173.121314048767 260.010924339295,174.716670513153 PathPoint;PointKind.SMOOTHPOINT 279.629080295564,173.918874263763 282.668101787568,174.245073795318 271.31087422371,173.025956153869 PathPoint;PointKind.SMOOTHPOINT 290.242799520493,173.918874263763 292.939256429673,172.523674964904 288.814988136292,174.657897949218 PathPoint;PointKind.SMOOTHPOINT 316.225386857987,172.791337966918 340.474222898484,172.003455162048 303.319183588029,173.210535049438 PathPoint;PointKind.SMOOTHPOINT 381.34928226471,172.791337966918 388.544515371324,173.533430099487 349.642231464387,169.521317481994 PathPoint;PointKind.SMOOTHPOINT 405.06499528885,171.887326240539 413.937252759934,173.684964179992 396.192187070847,170.089452266693 PathPoint;PointKind.SMOOTHPOINT 434.976611137391,172.902982234954 439.876331090928,172.609355449676 430.076340436936,173.196609020233 PathPoint;PointKind.SMOOTHPOINT 452.194612026216,172.718403339386 457.143623828889,172.436814308166 447.245600223542,172.999992370605 PathPoint;PointKind.SMOOTHPOINT 464.887951612473,172.902982234954 469.946286678315,175.478589534759 459.829891920091,170.327610969543 PathPoint;PointKind.SMOOTHPOINT 478.396396636964,171.887326240539 490.902482271195,171.470725536346 465.890586376191,172.303926944732 PathPoint;PointKind.SMOOTHPOINT 499.190121889115,171.718797683715 514.228817224503,173.290078639984 484.151426553727,170.147280693054 PathPoint;PointKind.SMOOTHPOINT 530.500359535218,172.902982234954 544.763052463532,172.926821708679 516.238217353822,172.87914276123 PathPoint;PointKind.SMOOTHPOINT 582.60487318039,171.887326240539 601.404894590379,171.486303806304 563.804301023484,172.28811264038 PathPoint;PointKind.SMOOTHPOINT 614.178918600083,173.718481063842 620.612744092942,177.143340110778 607.744817733766,170.2938580513 PathPoint;PointKind.SMOOTHPOINT 635.673469305039,171.887326240539 658.691661357881,171.807782649993 612.655827999116,171.966633796691 PathPoint;PointKind.SMOOTHPOINT 681.98853135109,171.887326240539 724.620748758317,172.077569961547 639.356038570405,171.696610450744 PathPoint;PointKind.SMOOTHPOINT 745.671397447587,172.902982234954 760.012571811677,174.271981716156 731.329947710038,171.533982753753 PathPoint;PointKind.SMOOTHPOINT 797.775360345841,171.887326240539 831.410851478578,173.129103183746 764.139593839646,170.644841194152 PathPoint;PointKind.SMOOTHPOINT 892.334750890733,172.902982234954 923.708875179292,173.270487785339 841.851085424424,172.311952114105 PathPoint;PointKind.SMOOTHPOINT 953.12261581421,172.902982234954 962.895069122315,173.293619155883 943.350437879563,172.512581348419 PathPoint;PointKind.SMOOTHPOINT 972.420512437821,172.902982234954 980.867317914964,171.962621212005 969.22342658043,173.258922100067 PathPoint;PointKind.SMOOTHPOINT 987.858774662019,172.902982234954 998.122218847276,174.339487552642 977.595330476762,171.466476917266 PathPoint;PointKind.SMOOTHPOINT 1007.15639591217,171.887326240539 1023.36377620697,171.891102790832 990.949566364289,171.883313655853 PathPoint;PointKind.SMOOTHPOINT 1035.13846993446,172.902982234954 1039.12615299225,174.392831325531 1028.93237829208,170.584652423858 PathPoint;PointKind.SMOOTHPOINT 1054.43609118462,171.887326240539 1071.08048915863,172.137286663055 1037.79196858406,171.637365818023 PathPoint;PointKind.SMOOTHPOINT 1096.8912434578,171.887326240539 1135.76213479042,172.403061389923 1058.02062749863,171.371355056762 PathPoint;PointKind.SMOOTHPOINT 1342.93825507164,173.918874263763 1369.30719137192,174.371352195739 1316.56959414482,173.46663236618 PathPoint;PointKind.SMOOTHPOINT 1413.37548136711,174.935002326965 1442.03194499016,174.760336875915 1384.71901774407,175.109195709228 PathPoint;PointKind.SMOOTHPOINT 1451.97099924088,174.935002326965 1455.99558234215,174.94892835617 1439.3748664856,174.891335964202 PathPoint;PointKind.SMOOTHPOINT 1465.25556564331,174.934530258178 1466.5991127491,174.931697845459 1460.60037732124,174.944207668304 PathPoint;PointKind.SMOOTHPOINT 1469.28593158722,174.925088882446 1470.33014774323,173.513603210449 1468.01150321961,176.647431850433 PathPoint;PointKind.SMOOTHPOINT 1474.31672930718,174.912815093994 1480.92706918717,174.390470981597 1472.2186589241,175.078275203704 PathPoint;PointKind.SMOOTHPOINT 1490.5667924881,174.935002326965 1498.28578591347,175.029888153076 1486.92910909653,174.890155792236 PathPoint;PointKind.SMOOTHPOINT 1515.65386533737,173.918874263763 1538.42284440994,174.316828250885 1482.9417014122,173.347434997558 PathPoint;PointKind.SMOOTHPOINT 1554.2496585846,173.918874263763 1555.91263890266,173.903768062591 1544.50639486313,174.008567333221 PathPoint;PointKind.SMOOTHPOINT 1561.96837663651,173.918874263763 1566.51837229729,172.639095783233 1560.62978625298,174.295585155487 PathPoint;PointKind.SMOOTHPOINT 1574.5121884346,173.918874263763 1592.88675785065,174.724695682525 1570.34138202667,173.736183643341 PathPoint;PointKind.SMOOTHPOINT 1626.61615133286,175.95065832138 1640.62990665436,175.57347536087 1612.60267138481,176.327605247497 PathPoint;PointKind.SMOOTHPOINT 1652.6686835289,174.935002326965 1666.44066095352,173.462619781494 1638.8958799839,176.407148838043 PathPoint;PointKind.SMOOTHPOINT 1679.68529820442,174.935002326965 1693.72135877609,174.466710090637 1665.64923763275,175.4030585289 PathPoint;PointKind.SMOOTHPOINT 2008.71279716492,174.935002326965 2043.16256761551,176.042003631591 1974.26330208778,173.827528953552 PathPoint;PointKind.SMOOTHPOINT 2053.04048895836,176.718242168426 2063.01341414452,177.039484977722 2043.06728839874,176.396527290344 PathPoint;PointKind.SMOOTHPOINT 2077.22020626068,174.935002326965 2089.36417579651,173.871431350708 2065.0759613514,175.998337268829 PathPoint;PointKind.SMOOTHPOINT 2105.20172953606,174.935002326965 2117.04086065292,175.792043209075 2093.36342453957,174.077725410461 PathPoint;PointKind.SMOOTHPOINT 2124.49990153313,174.935002326965 2131.61197185516,175.069777965545 2117.38728046417,174.799990653991 PathPoint;PointKind.SMOOTHPOINT 2142.83261418343,175.95065832138 2146.37942433357,176.0240650177 2131.72515034676,175.720524787902 PathPoint;PointKind.SMOOTHPOINT 2150.70196151733,176.129808425903 2154.30412173271,174.486536979675 2148.92139673233,176.941766738891 PathPoint;PointKind.SMOOTHPOINT 2159.23578500748,176.966786384582 2160.35104751587,176.933505535125 2155.03055691719,177.091648578643 PathPoint;PointKind.SMOOTHPOINT 2166.02952361107,175.718164443969 2176.45874261856,175.349242687225 2164.5419561863,175.770800113678 PathPoint;PointKind.SMOOTHPOINT 2185.2877664566,175.95065832138 2196.39165043831,175.422885417938 2174.1838824749,176.478431224823 PathPoint;PointKind.SMOOTHPOINT 2231.6025531292,175.95065832138 2247.00419068337,176.168990135192 2207.81579375267,175.613365173339 PathPoint;PointKind.SMOOTHPOINT 2263.43324661255,176.756479740142 2268.12368273735,175.413680076599 2255.28797507286,179.088263511657 PathPoint;PointKind.SMOOTHPOINT 2278.8825237751,176.966786384582 2296.26547336578,176.970562934875 2272.75436282158,176.965370178222 PathPoint;PointKind.SMOOTHPOINT 2325.19703507423,176.966786384582 2353.29972267151,177.137203216552 2297.09434747696,176.795897483825 PathPoint;PointKind.SMOOTHPOINT 2386.95008397102,176.966786384582 2408.42618465424,176.931145191192 2365.47370791435,177.002427577972 PathPoint;PointKind.SMOOTHPOINT 2470.89547991753,176.966786384582 2500.24560928345,178.553881645202 2441.54562592506,175.379219055175 PathPoint;PointKind.SMOOTHPOINT 2512.38572359085,177.982206344604 2517.82462477684,178.621387481689 2506.94709777832,177.343733310699 PathPoint;PointKind.SMOOTHPOINT 2534.57834601402,177.982206344604 2538.15214276314,177.178981304168 2529.22949194908,179.185273647307 PathPoint;PointKind.SMOOTHPOINT 2556.77069306374,177.982206344604 2579.64541554451,179.184801578521 2533.89597058296,176.780083179473 PathPoint;PointKind.SMOOTHPOINT 2594.40130233765,177.982206344604 2616.48845672607,179.272370338439 2572.31442332268,176.692750453948 PathPoint;PointKind.SMOOTHPOINT 3060.44361948967,180.014226436614 3072.6203584671,180.047507286071 3032.44364619255,179.937279224395 PathPoint;PointKind.SMOOTHPOINT 3134.52954411507,180.252621173858 3137.42784976959,180.260174274444 3100.91195225716,180.167412757873 PathPoint;PointKind.SMOOTHPOINT 3143.33708882332,180.273864269256 3146.69581890106,179.123904705047 3140.51175713539,181.241605281829 PathPoint;PointKind.SMOOTHPOINT 3154.48613405228,180.29770374298 3159.32444572449,178.431615829467 3150.95804929733,181.658205986022 PathPoint;PointKind.SMOOTHPOINT 3168.34017276764,180.320835113524 3210.16141533852,180.380315780639 3163.68333220482,180.314226150512 PathPoint;PointKind.SMOOTHPOINT 3284.29800868034,180.014226436614 3347.9811501503,179.315800666808 3254.48525190353,180.341134071349 PathPoint;PointKind.SMOOTHPOINT 3397.08216547966,181.125004291534 3410.46999692917,182.220439910888 3383.69433403015,180.029804706573 PathPoint;PointKind.SMOOTHPOINT 3426.13681912422,181.030118465423 3442.93955683708,181.383461952209 3409.33463215828,180.67701101303 PathPoint;PointKind.SMOOTHPOINT 3454.11916851997,183.061666488647 3462.12069511414,183.446874618529 3446.11709117889,182.67693042755 PathPoint;PointKind.SMOOTHPOINT 3471.52387261391,181.057970523833 3484.97972130775,180.835862159728 3458.06802392006,181.280314922332 PathPoint;PointKind.SMOOTHPOINT 3492.75158643723,182.074098587035 3501.17526054382,181.903445720672 3484.32763695717,182.244515419005 PathPoint;PointKind.SMOOTHPOINT 3519.76875185966,182.074098587035 3523.79608869553,183.358125686645 3511.79063200951,179.530355930327 PathPoint;PointKind.SMOOTHPOINT 3547.08139300346,181.086058616637 3568.40713977814,181.713201999663 3525.75619697571,180.459151268004 PathPoint;PointKind.SMOOTHPOINT 3752.60306954384,181.086058616637 3790.79929590225,182.748448848723 3714.40711855888,179.423432350158 PathPoint;PointKind.SMOOTHPOINT 3816.91764235497,180.099670886992 3831.87345027924,180.901007652282 3801.96183443069,179.29809808731 PathPoint;PointKind.SMOOTHPOINT 3848.75935077667,181.115326881408 3867.6989865303,185.37338733673 3829.81943964958,176.857502460479 PathPoint;PointKind.SMOOTHPOINT 3911.47703289986,182.13145494461 3929.55750346184,182.02807188034 3893.39683771133,182.234601974486 PathPoint;PointKind.SMOOTHPOINT 3951.03773474693,183.147110939025 3962.44673252106,184.520359039306 3939.62846159935,181.774334907531 PathPoint;PointKind.SMOOTHPOINT 4013.75541687012,183.147110939025 4045.20884871483,183.532083034514 3982.30226039886,182.762138843535 PathPoint;PointKind.SMOOTHPOINT 4117.96361804008,183.147110939025 4176.5248131752,184.567801952361 4060.33346056938,181.749079227447 PathPoint;PointKind.SMOOTHPOINT 4203.83883118629,183.147110939025 4236.12113714218,184.024214744567 4171.55652523041,182.270243167876 PathPoint;PointKind.SMOOTHPOINT 4263.66206288338,185.178658962249 4285.33808469772,184.675197601317 4241.98604106903,185.68282842636 PathPoint;PointKind.SMOOTHPOINT 4315.76602578163,185.178658962249 4344.86363768578,184.703049659728 4286.66841387749,185.65497636795 PathPoint;PointKind.SMOOTHPOINT 4363.04572105408,186.194787025451 4379.22666549683,186.03215932846 4346.86505198479,186.357650756835 PathPoint;PointKind.SMOOTHPOINT 4384.2734348774,188.226571083068 4389.05033826828,189.248127937316 4375.29157876968,186.3059592247 PathPoint;PointKind.SMOOTHPOINT 4391.99270367622,187.210915088653 4393.54002714157,187.125470638274 4389.77594733238,187.332944869994 PathPoint;PointKind.SMOOTHPOINT 4403.81393551826,188.717050552367 4405.27506709099,189.026019573211 4398.21504235268,187.533102035522 PathPoint;PointKind.SMOOTHPOINT 4406.46578192711,190.258119106292 4409.33049201965,190.720038414001 4404.49355721474,189.940416812896 PathPoint;PointKind.SMOOTHPOINT 4412.1811580658,191.274247169494 4413.66129040718,192.38124847412 4410.5732524395,190.071415901183 PathPoint;PointKind.SMOOTHPOINT 4416.04079246521,196.353707313537 4417.19928860664,201.887533664702 4415.57513594627,194.129555225371 PathPoint;PointKind.SMOOTHPOINT 4417.0797765255,211.591851711272 4417.75526762009,220.033385753631 4416.91620469093,209.54614162445 PathPoint;PointKind.SMOOTHPOINT 4418.04440975189,319.189546108245 4418.26333165169,336.50314092636 4417.82631397247,301.87595129013 PathPoint;PointKind.CORNERPOINT 4418.04440975189,458.364865779876 4418.04440975189,458.364865779876 4418.04440975189,458.364865779876 PathPoint;PointKind.CORNERPOINT 4419.0095937252,1855.19893884659 4419.0095937252,1855.19893884659 4419.0095937252,1855.19893884659 PathPoint;PointKind.SMOOTHPOINT 4417.0797765255,2020.78745126724 4417.67155408859,2042.30316638946 4416.4879989624,1999.27102804184 PathPoint;PointKind.SMOOTHPOINT 4418.04440975189,2380.40850877762 4417.68284440041,2393.95192623138 4418.40625047684,2366.86461925507 PathPoint;PointKind.SMOOTHPOINT 4418.04440975189,3096.60294771194 4418.01053881645,3107.55565166473 4418.07855606079,3085.65071582794 PathPoint;PointKind.SMOOTHPOINT 4418.04440975189,3200.22299051285 4417.21911549568,3211.43320798874 4418.86997938156,3189.01230096817 PathPoint;PointKind.SMOOTHPOINT 4418.04440975189,3277.42984056473 4417.87147521973,3299.49339151382 4418.21789503098,3255.36605358124 PathPoint;PointKind.SMOOTHPOINT 4418.04440975189,3351.58877849579 4417.36644029617,3377.38238096237 4418.72292995453,3325.79517602921 PathPoint;PointKind.SMOOTHPOINT 4419.0095937252,3439.97020483017 4419.13764238358,3465.85940122604 4418.88126969337,3414.08124446869 PathPoint;PointKind.SMOOTHPOINT 4418.04440975189,3527.33597517014 4417.5771009922,3551.34799003601 4418.51199388504,3503.32396030426 PathPoint;PointKind.SMOOTHPOINT 4418.04440975189,3627.90810585022 4417.7431511879,3646.78519248962 4418.34594368935,3609.03101921082 PathPoint;PointKind.SMOOTHPOINT 4418.04440975189,3755.90884923935 4418.04716348648,3760.46006441116 4418.0369746685,3743.11908960342 PathPoint;PointKind.SMOOTHPOINT 4417.0797765255,3771.14699363708 4416.14791274071,3774.26146745682 4418.12509417534,3767.65250444412 PathPoint;PointKind.SMOOTHPOINT 4411.29032492638,3776.22645378113 4408.92128705978,3778.22070837021 4413.58831644058,3774.29215192795 PathPoint;PointKind.SMOOTHPOINT 4400.67660570145,3784.3535900116 4390.8656001091,3788.17073822021 4403.88443112373,3783.10496807098 PathPoint;PointKind.SMOOTHPOINT 4321.55547738075,3788.41692209244 4287.25661158562,3788.57577323914 4355.85434317589,3788.25807094574 PathPoint;PointKind.SMOOTHPOINT 3292.98218607903,3787.40079402924 3233.21568131447,3787.28183269501 3352.74896621704,3787.51999139786 PathPoint;PointKind.SMOOTHPOINT 2010.64261436462,3788.41692209244 1963.67959856987,3790.21054744721 2057.60563015938,3786.62329673767 PathPoint;PointKind.SMOOTHPOINT 813.213622570039,3787.40079402924 778.880885839463,3787.52778053284 847.546359300614,3787.27404356003 PathPoint;PointKind.SMOOTHPOINT 651.112006902696,3787.40079402924 638.500177860261,3785.01613855362 663.723560571671,3789.78592157364 PathPoint;PointKind.SMOOTHPOINT 520.851824283601,3787.40079402924 503.536616563798,3788.44855070114 538.166756629945,3786.35350942612 PathPoint;PointKind.SMOOTHPOINT 424.362616539002,3786.38513803482 400.640019178391,3787.05594778061 448.085489273072,3785.71432828903 PathPoint;PointKind.SMOOTHPOINT 270.944902896882,3787.40079402924 247.968567609788,3788.44477415085 293.921513557435,3786.35728597641 PathPoint;PointKind.SMOOTHPOINT 230.419567823411,3785.36924600601 228.36252808571,3785.12919902802 235.043638944627,3785.90882062912 PathPoint;PointKind.SMOOTHPOINT 225.595300197602,3782.32133388519 223.746993541718,3781.24076843262 227.342544794084,3783.34383487701 PathPoint;PointKind.SMOOTHPOINT 218.840939998628,3781.30591392517 217.278195619584,3780.43518304825 220.894399881364,3782.44973659515 PathPoint;PointKind.SMOOTHPOINT 214.21741962433,3776.37633562088 211.854164600373,3774.81638431549 215.766119956971,3777.39836454392 PathPoint;PointKind.SMOOTHPOINT 206.29767894745,3772.16312170029 204.461213350297,3770.73889017105 208.441461324693,3773.82574796677 PathPoint;PointKind.SMOOTHPOINT 203.21872830391,3765.37713289261 201.288084983827,3757.42300987244 203.886233568192,3768.129529953 PathPoint;PointKind.SMOOTHPOINT 202.438044548036,3735.59100866318 202.112828493119,3720.41470527649 202.649806737901,3745.47966957092 PathPoint;PointKind.SMOOTHPOINT 201.472860574723,3342.4459862709 199.867433309556,3325.23128986359 203.078838586808,3359.66044664383 PathPoint;PointKind.SMOOTHPOINT 202.438044548036,3148.41320514679 202.1852517128,3140.17088413239 202.690562009812,3156.65505409241 PathPoint;PointKind.SMOOTHPOINT 202.438044548036,2651.64837598801 200.282145738603,2639.94980335236 204.593943357469,2663.34671258926 PathPoint;PointKind.SMOOTHPOINT 203.402953147889,2278.82072210312 203.572307825089,2264.23308849335 203.233047723771,2293.4078836441 PathPoint;PointKind.SMOOTHPOINT 202.438044548036,1535.19719839096 202.667706012727,1520.26046991348 202.207832336427,1550.13345479965 PathPoint;PointKind.SMOOTHPOINT 202.218571901322,1277.61357307434 201.980924606324,1264.33191776276 202.455943822862,1290.89546442032 PathPoint;PointKind.SMOOTHPOINT 201.472860574723,1206.05195760727 202.147525548936,1188.73836278915 200.798195600511,1223.36578845978 PathPoint;PointKind.SMOOTHPOINT 202.438044548036,608.715233802795 202.825495004655,595.71587562561 202.047840356828,621.800036430358 PathPoint;PointKind.SMOOTHPOINT 203.402953147889,492.905194759368 203.519436120988,473.186409473419 203.299137353898,510.407145023345 PathPoint;PointKind.SMOOTHPOINT 207.262036800385,396.396396160125 208.709675073625,376.80908203125 205.814949274064,415.983946323394 PathPoint;PointKind.SMOOTHPOINT 208.227220773698,353.729639053344 207.703185081483,341.289210319519 208.751256465913,366.17006778717 PathPoint;PointKind.SMOOTHPOINT 209.218014478684,327.703778743743 211.03437781334,317.366416454315 207.401100397111,338.041377067565 PathPoint";
	
	mask67[2] = "PointKind.SMOOTHPOINT 210.904126167297,302.229294776917 212.121552228928,281.326324939728 209.686700105667,323.132264614105 PathPoint;PointKind.SMOOTHPOINT 211.869034767151,274.797849655151 211.802945137024,265.932869911194 211.938428878784,284.06786441803 PathPoint;PointKind.SMOOTHPOINT 211,257 208.994730472565,251.392294883728 213.005269527435,262.607705116272 PathPoint;PointKind.SMOOTHPOINT 211,239 212.771477460861,232.936040401459 209.22824716568,245.064195632935 PathPoint;PointKind.SMOOTHPOINT 212.834218740463,226.031255722046 211.174669807308,221.704111101564 214.577652407285,230.577882893607 PathPoint;PointKind.CORNERPOINT 210.904126167297,213.83960723877 210.904126167297,213.83960723877 210.904126167297,213.83960723877 PathPoint;PointKind.CORNERPOINT 215.728944540024,206.727654933929 215.728944540024,206.727654933929 215.728944540024,206.727654933929 PathPoint;PointKind.SMOOTHPOINT 217.589092254639,192.53585100174 218.403573517007,190.735721560659 214.211029396414,200.002003266254 PathPoint;PointKind.SMOOTHPOINT 221,187 222.498302015976,185.342468849542 219.555021377759,188.598540916699 PathPoint;PointKind.SMOOTHPOINT 226,185 226.793104906724,184.768892734428 223.087734053912,185.84919177762 PathPoint;PointKind.SMOOTHPOINT 229.168546199799,180.344202518463 232.478535175323,179.200851917267 228.178027868271,180.686452388763 PathPoint;PointKind.SMOOTHPOINT 237.923494577408,179.296445846558 241.235961914062,178.535234928131 236.356619596481,179.656398296356 PathPoint;PointKind.SMOOTHPOINT 249.503499269485,176.248533725739 259.628155231476,171.367106437683 242.630453109741,179.561984539032 PathPoint;PointKind.SMOOTHPOINT 265.908046960831,173.200385570526 272.018308639526,172.40282535553 259.797785282135,173.998181819916 PathPoint;PointKind.SMOOTHPOINT 279.417868852615,173.200385570526 282.457165718079,173.526585102081 271.098836660385,172.307467460632 PathPoint;PointKind.SMOOTHPOINT 290.032689571381,173.200385570526 292.729421854019,171.805186271667 288.604602813721,173.939409255981 PathPoint;PointKind.SMOOTHPOINT 316.017755270004,172.072849273682 340.268794298172,171.284730434418 303.110175132751,172.492046356201 PathPoint;PointKind.SMOOTHPOINT 381.147984266281,172.072849273682 388.343768119812,172.81494140625 349.43790435791,168.802356719971 PathPoint;PointKind.SMOOTHPOINT 404.865900278091,171.168601512909 413.738983869553,172.966475486755 395.992265939713,169.370727539062 PathPoint;PointKind.SMOOTHPOINT 434.780269861221,172.184493541718 439.680540561676,171.890866756439 429.879723787308,172.478120326996 PathPoint;PointKind.SMOOTHPOINT 454.079818725586,172.184493541718 459.029381275177,171.902668476105 449.130531549454,172.466082572937 PathPoint;PointKind.SMOOTHPOINT 464.694639444351,172.184493541718 469.753525257111,174.760336875916 459.636029005051,169.608886241913 PathPoint;PointKind.SMOOTHPOINT 478.204461336136,171.168601512909 490.711648464203,170.752000808716 465.697274208069,171.585202217102 PathPoint;PointKind.SMOOTHPOINT 496.539101600647,171.168601512909 511.579173803329,172.740118503571 481.499029397964,169.597084522247 PathPoint;PointKind.SMOOTHPOINT 530.31338095665,172.184493541718 544.577450752258,172.208333015442 516.049861907959,172.160654067993 PathPoint;PointKind.SMOOTHPOINT 582.422851324081,171.168601512909 601.224800348282,170.767579078674 563.620626926422,171.56938791275 PathPoint;PointKind.SMOOTHPOINT 617.162314653397,173.200385570526 623.596690893173,176.625480651855 610.727663040161,169.77552652359 PathPoint;PointKind.SMOOTHPOINT 635.496679544449,171.168601512909 658.517074584961,171.089057922363 612.476835250854,171.247909069061 PathPoint;PointKind.SMOOTHPOINT 681.816147565842,171.168601512909 724.452495574951,171.358845233917 639.179524183273,170.977885723114 PathPoint;PointKind.SMOOTHPOINT 745.505071878433,172.184493541718 759.847623109818,173.553493022919 731.16224527359,170.815258026123 PathPoint;PointKind.SMOOTHPOINT 797.613991498947,171.168601512909 831.25278711319,172.410614490509 763.975195884705,169.926116466522 PathPoint;PointKind.SMOOTHPOINT 892.182469367981,172.184493541718 923.559622764587,172.551999092102 841.694122552872,171.593227386475 PathPoint;PointKind.SMOOTHPOINT 952.976392507553,172.184493541718 962.749671936035,172.575130462646 943.203113079071,171.794092655182 PathPoint;PointKind.SMOOTHPOINT 972.275941371918,172.184493541718 980.723572969437,171.243896484375 969.078580141068,172.54043340683 PathPoint;PointKind.SMOOTHPOINT 987.715855836868,172.184493541718 997.980126142502,173.620998859406 977.451310157776,170.747752189636 PathPoint;PointKind.SMOOTHPOINT 1007.01540470123,171.168601512909 1023.22416186333,171.172378063202 990.806922912598,171.164588928223 PathPoint;PointKind.SMOOTHPOINT 1034.99995708466,172.184493541718 1038.98819088936,173.674342632294 1028.79331469536,169.865927696228 PathPoint;PointKind.SMOOTHPOINT 1054.29950594902,171.168601512909 1070.94555616379,171.418561935425 1037.65373110771,170.918641090393 PathPoint;PointKind.SMOOTHPOINT 1096.75878882408,171.168601512909 1135.63353538513,171.684336662292 1057.88431763649,170.652630329132 PathPoint;PointKind.SMOOTHPOINT 1342.82948255539,173.200385570526 1369.2008972168,173.652863502502 1316.45834326744,172.748143672943 PathPoint;PointKind.SMOOTHPOINT 1413.27359318733,174.216513633728 1441.93281054497,174.041848182678 1384.6143758297,174.390943050385 PathPoint;PointKind.SMOOTHPOINT 1451.87269091606,174.216513633728 1455.89782476425,174.230439662933 1439.27545666695,174.172847270966 PathPoint;PointKind.SMOOTHPOINT 1465.15863418579,174.216041564941 1466.50218129158,174.213209152222 1460.50289511681,174.225718975067 PathPoint;PointKind.SMOOTHPOINT 1469.18927550316,174.206600189209 1470.23376703262,172.795114517212 1467.91484713554,175.929179191589 PathPoint;PointKind.SMOOTHPOINT 1474.22062397003,174.194326400757 1480.83151459694,173.671982288361 1472.1222782135,174.360022544861 PathPoint;PointKind.SMOOTHPOINT 1490.47233939171,174.216513633728 1498.191883564,174.311635494232 1486.83410525322,174.171667098999 PathPoint;PointKind.SMOOTHPOINT 1515.56161522865,173.200385570526 1538.33279728889,173.598339557648 1482.84642219543,172.628946304321 PathPoint;PointKind.SMOOTHPOINT 1554.1612637043,173.200385570526 1555.82451939583,173.185279369354 1544.41717386246,173.290078639984 PathPoint;PointKind.SMOOTHPOINT 1561.88080787659,173.200385570526 1566.43107891083,171.920607089996 1560.5419421196,173.57709646225 PathPoint;PointKind.SMOOTHPOINT 1574.42572116852,173.200385570526 1592.80194282532,174.006206989288 1570.25463938713,173.017694950104 PathPoint;PointKind.SMOOTHPOINT 1626.53464078903,175.232405662537 1640.54977297783,174.855222702026 1612.51978397369,175.609352588654 PathPoint;PointKind.SMOOTHPOINT 1652.58965134621,174.216513633728 1666.36300563812,172.744131088257 1638.81574630737,175.688896179199 PathPoint;PointKind.SMOOTHPOINT 1679.60901975632,174.216513633728 1693.64645719528,173.7482213974 1665.57158231735,174.684805870056 PathPoint;PointKind.SMOOTHPOINT 2008.66818666458,174.216513633728 2043.12126159668,175.323750972748 1974.21538710594,173.109040260315 PathPoint;PointKind.SMOOTHPOINT 2057.88238048553,176.248533725739 2067.85640716553,176.569776535034 2047.90835380554,175.926818847656 PathPoint;PointKind.SMOOTHPOINT 2077.18220472336,174.216513633728 2089.32727575302,173.152942657471 2065.03685832024,175.280084609985 PathPoint;PointKind.SMOOTHPOINT 2105.16648173332,174.216513633728 2117.00671434402,175.073790550232 2093.32679986954,173.359236717224 PathPoint;PointKind.SMOOTHPOINT 2124.46630597115,174.216513633728 2131.57920241356,174.351525306702 2117.35313415527,174.081501960754 PathPoint;PointKind.SMOOTHPOINT 2142.80094623566,175.232405662537 2146.34803175926,175.305812358856 2131.69238090515,175.002272129059 PathPoint;PointKind.SMOOTHPOINT 2150.67111968994,175.411555767059 2154.27355527878,173.768048286438 2148.89027953148,176.223514080048 PathPoint;PointKind.SMOOTHPOINT 2159.20576930046,176.248533725739 2160.32103180885,176.215252876282 2154.99999046326,176.3733959198 PathPoint;PointKind.SMOOTHPOINT 2164.03058767319,175.232405662537 2174.46090817451,174.863483905792 2162.54274487495,175.285041332245 PathPoint;PointKind.SMOOTHPOINT 2185.26022911072,175.232405662537 2196.36521458626,174.704632759094 2174.15524363518,175.760178565979 PathPoint;PointKind.SMOOTHPOINT 2231.57942175865,175.232405662537 2246.98243618011,175.450737476349 2207.79045939445,174.895112514496 PathPoint;PointKind.SMOOTHPOINT 2263.41314435005,176.038227081299 2268.10413122177,174.695427417755 2255.26704668999,178.370246887207 PathPoint;PointKind.SMOOTHPOINT 2278.8637983799,176.248533725739 2296.24840021133,176.252310276031 2272.73508667946,176.247117519379 PathPoint;PointKind.SMOOTHPOINT 2325.18299102783,176.248533725739 2330.0407558758,176.277988983077 2297.07754969597,176.077644824982 PathPoint;PointKind.SMOOTHPOINT 2338.45889205051,176.311634853787 2339.07225981421,176.313657205776 2334.42262577437,176.298326767488 PathPoint;PointKind.SMOOTHPOINT 2340,176 2340.93219017668,176.00265844838 2339.40213712137,175.998294996406 PathPoint;PointKind.SMOOTHPOINT 2343.01893922329,176.324094792899 2359.66996939885,176.359954614193 2342.12159845025,176.322162271042 PathPoint;PointKind.SMOOTHPOINT 2386.94182276726,176.248533725739 2408.42012643814,176.212892532349 2370.61964551763,176.275618819832 PathPoint;PointKind.SMOOTHPOINT 2470.89547991753,176.248533725739 2500.24836301804,177.835865020752 2441.54259681702,174.660966396332 PathPoint;PointKind.SMOOTHPOINT 2512.38957881927,177.264189720154 2517.82903075218,177.903370857239 2506.95040225983,176.625480651855 PathPoint;PointKind.SMOOTHPOINT 2534.58440423012,177.264189720154 2538.15847635269,176.460728645325 2529.23499941826,178.467257022858 PathPoint;PointKind.SMOOTHPOINT 2556.7789542675,177.264189720154 2579.65587973595,178.466784954071 2533.90202879906,176.06183052063 PathPoint;PointKind.SMOOTHPOINT 2594.41314339638,177.264189720154 2616.50222539902,178.554353713989 2572.32406139374,175.974497795105 PathPoint;PointKind.SMOOTHPOINT 3060.5003464222,179.296445846558 3072.67818689346,179.329726696014 3032.49761939049,179.219262599945 PathPoint;PointKind.SMOOTHPOINT 3134.59343075752,179.534840583801 3137.49201178551,179.542393684387 3100.97253441811,179.449632167816 PathPoint;PointKind.SMOOTHPOINT 3143.40180158615,179.556083679199 3146.76080703735,178.405888080597 3140.57619452477,180.523824691772 PathPoint;PointKind.SMOOTHPOINT 3154.55194830894,179.579923152924 3159.39053535461,177.713599205017 3151.02331280708,180.940425395966 PathPoint;PointKind.SMOOTHPOINT 3168.40708851814,179.603054523468 3210.2324616909,179.662535190582 3163.74997258186,179.596445560455 PathPoint;PointKind.SMOOTHPOINT 3284.37621474266,179.296445846558 3348.06541442871,178.597784042358 3254.56070423126,179.623353481293 PathPoint;PointKind.SMOOTHPOINT 3397.17111110687,180.407223701477 3410.56031942368,181.502659320831 3383.78217816353,179.312024116516 PathPoint;PointKind.SMOOTHPOINT 3426.22879385948,180.312337875366 3435.28339815613,180.502727735544 3409.42495465279,179.959230422974 PathPoint;PointKind.SMOOTHPOINT 3444.4104357393,181.413251380869 3445.1031660757,181.490133683712 3440.3817834284,180.966133576527 PathPoint;PointKind.SMOOTHPOINT 3447,182 3449.56213079638,182.296121876235 3446.3558523264,181.925551725171 PathPoint;PointKind.SMOOTHPOINT 3454.21362161636,182.344121932983 3462.2159743309,182.729330062866 3451.26445280818,182.202337062027 PathPoint;PointKind.SMOOTHPOINT 3471.62025332451,180.340189933777 3485.07720351219,180.118081569672 3458.16302776337,180.562534332275 PathPoint;PointKind.SMOOTHPOINT 3492.84989476204,181.356317996979 3501.27439498901,181.185665130615 3484.42511916161,181.526734828949 PathPoint;PointKind.SMOOTHPOINT 3519.86953854561,181.356317996979 3523.89742612839,182.640581130981 3511.89086794853,178.812339305878 PathPoint;PointKind.SMOOTHPOINT 3547.184933424,180.368278026581 3568.51260781288,180.995421409607 3525.85753440857,179.741370677948 PathPoint;PointKind.SMOOTHPOINT 3752.72643685341,180.368278026581 3757.01301795397,180.554849191141 3714.52663064003,178.705415725708 PathPoint;PointKind.SMOOTHPOINT 3764.60841318617,180.748058119204 3766.07324063075,180.776568684078 3760.95915568715,180.677031055194 PathPoint;PointKind.SMOOTHPOINT 3769,180 3770.77821069068,180.199670813435 3767.63653314473,179.846899730437 PathPoint;PointKind.SMOOTHPOINT 3772.67906858836,180.827158686511 3795.5519004927,180.818835999578 3771.44634660034,180.827607234344 PathPoint;PointKind.SMOOTHPOINT 3817.04706788063,179.381890296936 3832.00452804565,180.183227062225 3805.0866262606,178.740727679503 PathPoint;PointKind.SMOOTHPOINT 3848.89180541039,180.397546291351 3850.70540340963,180.805288034494 3829.95024204254,176.139249801636 PathPoint;PointKind.SMOOTHPOINT 3854.50586239001,181.426472496047 3872.68498568679,184.082763319117 3852.58096232572,181.145210617098 PathPoint;PointKind.SMOOTHPOINT 3911.61554574966,181.413674354553 3929.69794392586,181.310291290283 3895.2649810917,181.506945365044 PathPoint;PointKind.SMOOTHPOINT 3951.18010282516,182.429566383362 3962.59020209312,183.802814483643 3939.76972818375,181.056554317474 PathPoint;PointKind.SMOOTHPOINT 4013.90384316444,182.429566383362 4045.3603041172,182.814538478851 3982.44765758514,182.044594287872 PathPoint;PointKind.SMOOTHPOINT 4118.12223315239,182.429566383362 4176.68893575668,183.850257396698 4060.48629283905,181.03129863739 PathPoint;PointKind.SMOOTHPOINT 4204.00570750237,182.429566383362 4236.2910425663,183.306670188904 4171.72009706497,181.55246257782 PathPoint;PointKind.SMOOTHPOINT 4263.83472204208,184.461350440979 4285.51267147064,183.957653045654 4242.15649724007,184.96551990509 PathPoint;PointKind.SMOOTHPOINT 4315.9436416626,184.461350440979 4345.04400730133,183.985505104065 4286.84327602386,184.93766784668 PathPoint;PointKind.SMOOTHPOINT 4363.22774291039,185.477478504181 4379.41033959389,185.31485080719 4347.0456969738,185.640342235565 PathPoint;PointKind.SMOOTHPOINT 4384.45765972137,187.509498596191 4389.23483848572,188.531055450439 4375.47497749329,185.58865070343 PathPoint;PointKind.SMOOTHPOINT 4392.17747926712,186.493606567383 4393.72507810593,186.408162117004 4389.96072292328,186.615636348724 PathPoint;PointKind.SMOOTHPOINT 4403,188 4404.46113157272,188.308969020844 4397.40055608749,186.816051483154 PathPoint;PointKind.SMOOTHPOINT 4406.65220975876,189.541282653809 4408.00367728054,189.759178677875 4404.67970967293,189.223580360413 PathPoint;PointKind.SMOOTHPOINT 4409.83232208663,189.764531478712 4410.77097503364,189.803250049173 4408.99416950513,189.729958455864 PathPoint;PointKind.SMOOTHPOINT 4412.36813664436,190.55741071701 4413.84826898575,191.664412021637 4411.51856486483,189.921977577797 PathPoint;PointKind.SMOOTHPOINT 4416.22804641724,195.63734292984 4417.38654255867,201.171641349792 4415.7623898983,193.412954807281 PathPoint;PointKind.SMOOTHPOINT 4417.26703047752,210.876903533936 4417.94252157211,219.319381713867 4417.10345864296,208.83095741272 PathPoint;PointKind.SMOOTHPOINT 4418.23193907738,318.484983444214 4418.45086097717,335.800230503082 4418.0135679245,301.169736385345 PathPoint;PointKind.CORNERPOINT 4418.23193907738,457.67352104187 4418.23193907738,457.67352104187 4418.23193907738,457.67352104187 PathPoint;PointKind.CORNERPOINT 4419.19712305069,1854.64024543762 4419.19712305069,1854.64024543762 4419.19712305069,1854.64024543762 PathPoint;PointKind.SMOOTHPOINT 4417.26703047752,2020.24433612823 4417.85880804062,2041.76217556 4416.67525291443,1998.72602462769 PathPoint;PointKind.SMOOTHPOINT 4418.23193907738,2379.89961862564 4417.91711065266,2391.68463438061 4418.59377980232,2366.35454893112 PathPoint;PointKind.SMOOTHPOINT 4418.22607121717,3060.39603229129 4418.22652915316,3061.70787130888 4418.1759804344,2916.90208697511 PathPoint;PointKind.SMOOTHPOINT 4417,3065 4418.1986402775,3066.77123400833 4416.22248057502,3063.85105742439 PathPoint;PointKind.SMOOTHPOINT 4418.22940283192,3070.3603776115 4418.23428936894,3085.7990766867 4418.22878764602,3068.41673737278 PathPoint;PointKind.SMOOTHPOINT 4418.23193907738,3096.16227149963 4418.19806814194,3107.11591959 4418.23563823707,3094.9756594862 PathPoint;PointKind.SMOOTHPOINT 4418.23193907738,3199.79199171066 4417.40636944771,3211.00338935852 4419.05750870705,3188.58035802841 PathPoint;PointKind.SMOOTHPOINT 4418.23193907738,3277.00615882874 4418.05872917175,3299.07183408737 4418.40542435646,3254.94024753571 PathPoint;PointKind.SMOOTHPOINT 4418.23193907738,3351.1721777916 4417.5536942482,3376.96837663651 4418.91045928001,3325.37621498108 PathPoint;PointKind.SMOOTHPOINT 4419.19712305069,3439.56210136414 4419.32517170906,3465.45365810394 4419.06879901886,3413.67054462433 PathPoint;PointKind.SMOOTHPOINT 4418.23193907738,3526.93613290787 4417.76435494423,3550.95050811768 4418.69952321053,3502.92175769806 PathPoint;PointKind.SMOOTHPOINT 4418.23193907738,3627.51770496368 4417.93040513992,3646.39667987823 4418.53347301483,3608.63896608353 PathPoint;PointKind.SMOOTHPOINT 4418.23193907738,3755.53072214127 4418.23469281197,3760.08240938187 4418.22450399399,3742.73978233337 PathPoint;PointKind.SMOOTHPOINT 4417.26703047752,3770.77028274536 4416.33516669273,3773.88499259949 4418.31262350082,3767.27555751801 PathPoint;PointKind.SMOOTHPOINT 4411,3778 4408.99502478472,3779.68779045319 4413.29826688766,3776.06546211243 PathPoint;PointKind.SMOOTHPOINT 4402.45567863356,3783.16783259869 4401.89217843365,3783.50806819073 4405.55665590686,3781.29549459658 PathPoint;PointKind.SMOOTHPOINT 4396,3785 4386.18816828728,3788.8176202774 4396.49336382225,3784.80799480464 PathPoint;PointKind.SMOOTHPOINT 4321.73364400864,3788.04186344147 4287.43147373199,3788.20071458817 4356.03581428528,3787.88301229477 PathPoint;PointKind.SMOOTHPOINT 3293.06121826172,3787.02573537827 3233.28893065453,3786.90677404404 3352.83378124237,3787.14493274689 PathPoint;PointKind.SMOOTHPOINT 2010.59827923775,3788.04186344147 1963.63058209419,3789.83572483063 2057.56570100784,3786.24800205231 PathPoint;PointKind.SMOOTHPOINT 813.053905963898,3787.02573537827 778.717864751816,3787.15272188187 847.38994717598,3786.89898490906 PathPoint;PointKind.SMOOTHPOINT 650.936594009399,3787.02573537827 638.323663473129,3784.64084386826 663.549249172211,3789.41109895706 PathPoint;PointKind.SMOOTHPOINT 520.663744211197,3787.02573537827 503.346884250641,3788.07349205017 537.980604171753,3785.97821474075 PathPoint;PointKind.SMOOTHPOINT 424.165449142456,3786.00984334946 400.440373420715,3786.68065309525 447.890524864197,3785.33903360367 PathPoint;PointKind.SMOOTHPOINT 270.732865333557,3787.02573537827 247.754327058792,3788.06971549988 293.711678981781,3785.98199129105 PathPoint;PointKind.SMOOTHPOINT 230.203675031662,3784.99395132065 228.146359920502,3784.75390434265 234.828296899796,3785.53352594376 PathPoint;PointKind.SMOOTHPOINT 225.378856658936,3781.94580316544 223.530550003052,3780.86500167847 227.126376628876,3782.96830415726 PathPoint;PointKind.SMOOTHPOINT 217,3780 215.524961702601,3778.98734752854 220.687969426189,3782.53180471122 PathPoint;PointKind.SMOOTHPOINT 214.76403594017,3775.85021495819 212.400505542755,3774.2902636528 216.313011646271,3776.87247991562 PathPoint;PointKind.SMOOTHPOINT 208,3771 200.856812477112,3765.45956468582 210.144057750702,3772.66286230087 PathPoint;PointKind.SMOOTHPOINT 202.06463680403,3737.35369040277 201.454859591821,3738.19309227842 209.890244353797,3726.58118279858 PathPoint;PointKind.SMOOTHPOINT 201.537916135428,3611.74897650752 201.539918164066,3610.44871999046 201.429711900105,3682.02432598281 PathPoint;PointKind.SMOOTHPOINT 203,3609 202.884266046472,3608.50055641553 203.373818683267,3610.61319420467 PathPoint;PointKind.SMOOTHPOINT 201.546530845927,3606.29388163728 201.725888072056,3495.38158840516 201.545699559329,3606.80793900167 PathPoint;PointKind.SMOOTHPOINT 201.254214048386,3342.02844142914 199.726048000859,3324.80527322402 202.2025353761,3352.71648005305 PathPoint;PointKind.SMOOTHPOINT 202.219398021698,3147.97724962234 201.966605186462,3139.73422050476 202.471915483475,3156.22004270554 PathPoint;PointKind.SMOOTHPOINT 202.219398021698,2651.1652135849 200.063223838806,2639.46569681168 204.37557220459,2662.86473035812 PathPoint;PointKind.SMOOTHPOINT 203.184306621552,2278.30215454102 203.353936672211,2263.71310472488 203.014401197433,2292.89073228836 PathPoint;PointKind.SMOOTHPOINT 202.219398021698,1534.60805654526 202.449059486389,1519.66991186142 201.989185810089,1549.54572916031 PathPoint;PointKind.SMOOTHPOINT 203.184306621552,1269.43804979324 202.946659326553,1256.15521430969 203.421678543091,1282.72135734558 PathPoint;PointKind.SMOOTHPOINT 201.254214048386,1205.43165922165 201.421756576927,1201.13168755358 200.579549074173,1222.74714231491 PathPoint;PointKind.SMOOTHPOINT 201.632940705688,1107.73714889301 201.635203913179,1106.37034611506 201.541544946698,1162.93313855471 PathPoint;PointKind.SMOOTHPOINT 203,1103 201.518913635827,1101.52308852187 203.982418878391,1103.97964963619 PathPoint;PointKind.SMOOTHPOINT 201.648972427967,1097.69793190659 201.910337034912,928.086713604933 201.645907664959,1099.68679410852 PathPoint;PointKind.SMOOTHPOINT 202.219398021698,608.038051128387 202.606848478317,595.037512779236 201.931866094777,617.680791864605 PathPoint;PointKind.SMOOTHPOINT 203.184306621552,492.216918468475 203.301064968109,472.496480941772 203.08049082756,509.720757007599 PathPoint;PointKind.SMOOTHPOINT 207.043941020966,395.699150562286 208.491579294205,376.109948158264 205.596578121185,415.288589000702 PathPoint;PointKind.SMOOTHPOINT 208.009124994278,353.028144836426 207.485089302063,340.586535930634 208.533160686493,365.469753742218 PathPoint;PointKind.SMOOTHPOINT 210.904126167297,325.596699714661 212.720764875412,315.258393287659 209.087212085724,335.935242176056 PathPoint";
	
	subshadow67[0] = "PointKind.SMOOTHPOINT 209.015625,212.953125 212.037297964096,210.268705844879 206.319994211197,215.347929954529 PathPoint;PointKind.SMOOTHPOINT 218.015625,189.953125 220.816723823547,188.482158660889 215.214526176453,191.423855304718 PathPoint;PointKind.SMOOTHPOINT 228.015625,181.953125 233.28021478653,181.29718542099 222.75103521347,182.609300613403 PathPoint;PointKind.SMOOTHPOINT 281.015625,171.953125 673.572298130915,172.903506948387 259.276543221131,171.900494558815 PathPoint;PointKind.SMOOTHPOINT 4382.015625,185.953125 4382.015625,185.953125 4388.24138198957,184.1516114929 PathPoint;PointKind.SMOOTHPOINT 4413.015625,191.953125 4419.80422037453,195.930435895276 4410.73925992941,190.619393618699 PathPoint;PointKind.CORNERPOINT 4419.015625,202.953125 4419.015625,202.953125 4419.015625,202.953125 PathPoint;PointKind.SMOOTHPOINT 4421.015625,3655.953125 4421.05527877808,3712.68233919144 4420.6320297718,3107.9662361145 PathPoint;PointKind.SMOOTHPOINT 4420.015625,3749.953125 4419.43489255575,3757.60677590558 4420.36669615344,3745.32732978677 PathPoint;PointKind.SMOOTHPOINT 4417.015625,3771.953125 4413.94934153557,3774.61228847504 4419.26102018356,3770.00560522079 PathPoint;PointKind.SMOOTHPOINT 4398.015625,3785.953125 4394.60264635086,3786.88074016571 4401.42860364914,3785.02550983429 PathPoint;PointKind.SMOOTHPOINT 4351.715741977,3786.84235941444 3964.72641134944,3788.6251896041 4377.15091899039,3786.72518150314 PathPoint;PointKind.SMOOTHPOINT 251.015625,3787.953125 238.753168012829,3787.9549387615 632.541548630952,3787.89669283198 PathPoint;PointKind.SMOOTHPOINT 216.499918937683,3779.95321893692 213.698544740677,3777.49562883377 222.102391958237,3784.86769104004 PathPoint;PointKind.SMOOTHPOINT 203.81759428978,3770.99476957321 201.489587068558,3767.27132701874 206.14587688446,3774.71821212769 PathPoint;PointKind.SMOOTHPOINT 200.015625,3747.953125 199.759527683258,3742.58216238022 200.271722316742,3753.32408761978 PathPoint;PointKind.SMOOTHPOINT 199.015625,3565.953125 200.134906454539,2936.96580863224 198.810034068535,3681.60132235551 PathPoint;PointKind.SMOOTHPOINT 203.015625,330.953125 203.058801667616,308.957026678482 201.952089829235,874.744943818901 PathPoint";
	
} else {

	mask67[0] = "PointKind.SMOOTHPOINT 172.334279923939,263.650767236547 173.57420758035,242.217367266326 171.094352267528,285.084167206768 PathPoint;PointKind.SMOOTHPOINT 173.317008964314,235.523244815022 173.249446342788,226.433074157441 173.387655683209,245.028363424153 PathPoint;PointKind.SMOOTHPOINT 173.317008964314,215.729803110987 171.274775177285,209.979775740961 175.359242751344,221.479830481012 PathPoint;PointKind.SMOOTHPOINT 172.334279923939,200.103401765695 174.138509021503,193.885396230381 170.530050826375,206.321407301009 PathPoint;PointKind.SMOOTHPOINT 174.299738004689,185.51876051009 173.528142156582,180.586677585482 175.071333852797,190.450843434697 PathPoint;PointKind.CORNERPOINT 172.334279923939,173.017639433856 172.334279923939,173.017639433856 172.334279923939,173.017639433856 PathPoint;PointKind.CORNERPOINT 177.247925125815,165.725318806054 177.247925125815,165.725318806054 177.247925125815,165.725318806054 PathPoint;PointKind.SMOOTHPOINT 181.178841287316,153.224197729821 184.995546066746,146.673406959247 176.956177441954,160.47175522877 PathPoint;PointKind.SMOOTHPOINT 191.006131691067,143.848356922646 191.785323484333,143.528433630146 183.680405303794,146.856179291955 PathPoint;PointKind.SMOOTHPOINT 192.971589771817,140.723076653587 196.342399175569,139.550713784513 191.962596966128,141.074002962039 PathPoint;PointKind.SMOOTHPOINT 199.850693054444,137.597796384529 203.223894607233,136.81737149703 198.254716943785,137.967041879386 PathPoint;PointKind.SMOOTHPOINT 211.643441538945,134.472516115471 221.954418892257,129.467184434557 204.644093321873,137.870259915714 PathPoint;PointKind.SMOOTHPOINT 228.349835225323,131.347235846413 234.572506219261,130.529291400995 222.127164231385,132.16518029183 PathPoint;PointKind.SMOOTHPOINT 242.108041790575,131.347235846413 245.203277962463,131.681744919906 233.635842602654,130.431626392587 PathPoint;PointKind.SMOOTHPOINT 252.918061234702,131.347235846413 246.540571065385,127.035322330436 254.2769669192,132.266011670813 PathPoint;PointKind.SMOOTHPOINT 255.866248355828,127.180195487668 264.132677426829,126.140583313665 252.449062888546,127.609951502278 PathPoint;PointKind.SMOOTHPOINT 269.62445492108,127.180195487668 271.825089577776,126.985175262271 261.175288445042,127.92896055213 PathPoint;PointKind.SMOOTHPOINT 273.55537108258,124.05491521861 278.353725981946,124.51003923765 272.219427728947,123.928200975694 PathPoint;PointKind.SMOOTHPOINT 288.296306688208,121.971395039238 300.119765455221,121.442376243694 279.552336672955,122.362627805968 PathPoint;PointKind.SMOOTHPOINT 355.121881433718,121.971395039238 362.450122598078,122.732368229751 347.793640269358,121.210421848725 PathPoint;PointKind.SMOOTHPOINT 369.862817039346,129.26371566704 378.89931766842,131.107142700743 360.826316410271,127.420288633338 PathPoint;PointKind.SMOOTHPOINT 400.327417290976,130.305475756726 405.317838199131,130.004341980802 395.336996382821,130.606609532651 PathPoint;PointKind.SMOOTHPOINT 419.981998098479,130.305475756726 425.022323215715,130.016550106853 414.941672981242,130.5944014066 PathPoint;PointKind.SMOOTHPOINT 430.792017542605,130.305475756726 435.943667433947,132.946500359095 425.640367651264,127.664451154358 PathPoint;PointKind.SMOOTHPOINT 444.550224107858,129.26371566704 457.287313779595,128.836431255255 431.81313443612,129.691000078826 PathPoint;PointKind.SMOOTHPOINT 463.222075874986,129.26371566704 478.538829277708,130.875188305774 447.905322472263,127.652243028307 PathPoint;PointKind.SMOOTHPOINT 497.617592288116,130.305475756726 512.143555916162,130.329892008828 483.091628660071,130.281059504624 PathPoint;PointKind.SMOOTHPOINT 550.684960468375,129.26371566704 569.832821614434,128.852708756656 531.537099322315,129.674722577424 PathPoint;PointKind.SMOOTHPOINT 586.06320592188,131.347235846413 592.616012452819,134.859106773753 579.510399390941,127.835364919072 PathPoint;PointKind.SMOOTHPOINT 604.735057689008,129.26371566704 628.178519601395,129.182328160034 581.291595776621,129.345103174047 PathPoint;PointKind.SMOOTHPOINT 651.906051627016,129.26371566704 695.326552313279,129.459045683856 608.485550940753,129.068385650224 PathPoint;PointKind.SMOOTHPOINT 716.766168291776,130.305475756726 731.372746411415,131.709410252592 702.159590172138,128.90154126086 PathPoint;PointKind.SMOOTHPOINT 769.833536472035,129.26371566704 804.090856613862,130.537430151696 735.576216330207,127.990001182385 PathPoint;PointKind.SMOOTHPOINT 866.1409824288,130.305475756726 898.095242631694,130.682299853255 814.724291933547,129.699138829526 PathPoint;PointKind.SMOOTHPOINT 928.052911972435,130.305475756726 938.006114534485,130.7059022912 918.099709410385,129.905049222253 PathPoint;PointKind.SMOOTHPOINT 947.707492779938,130.305475756726 956.310210668535,129.341033798697 944.451161117613,130.670539789405 PathPoint;PointKind.SMOOTHPOINT 963.431157425941,130.305475756726 973.884169835869,131.778589633548 952.978145016013,128.832361879905 PathPoint;PointKind.SMOOTHPOINT 983.085738233444,129.26371566704 999.592515083495,129.267785042391 966.578961383392,129.25964629169 PathPoint;PointKind.SMOOTHPOINT 1011.58488040432,130.305475756726 1015.6463152665,131.833119263243 1005.26392352732,127.927949326829 PathPoint;PointKind.SMOOTHPOINT 1031.23946121183,129.26371566704 1048.1915371583,129.520086314112 1014.28738526536,129.007345019969 PathPoint;PointKind.SMOOTHPOINT 1074.47953898833,129.26371566704 1114.06893193126,129.792734462584 1034.89014604541,128.734696871497 PathPoint;PointKind.SMOOTHPOINT 1325.075444284,131.347235846413 1351.9315863405,131.811144636351 1298.2193022275,130.883327056474 PathPoint;PointKind.SMOOTHPOINT 1396.81466423138,132.388995936099 1426.00094897346,132.209943420684 1367.62837948931,132.568048451513 PathPoint;PointKind.SMOOTHPOINT 1436.12382584639,132.388995936099 1440.22280939004,132.403297921808 1423.29460532712,132.344232807245 PathPoint;PointKind.SMOOTHPOINT 1449.65397773837,132.388511181009 1451.02232235745,132.385630976762 1444.91273781507,132.398490932581 PathPoint;PointKind.SMOOTHPOINT 1453.75886114463,132.378913015925 1454.82243571426,130.931529237201 1452.46096795886,134.145173320768 PathPoint;PointKind.SMOOTHPOINT 1458.8825100339,132.36616512834 1465.61487755387,131.830635303856 1456.74564851592,132.536142936337 PathPoint;PointKind.SMOOTHPOINT 1475.4329874614,132.388995936099 1483.2948197844,132.486660944507 1471.72788457962,132.34296863747 PathPoint;PointKind.SMOOTHPOINT 1500.98394251115,131.347235846413 1524.17353690904,131.755104079723 1467.66712477125,130.761245795964 PathPoint;PointKind.SMOOTHPOINT 1540.29310412616,131.347235846413 1541.98715443112,131.331579570949 1530.37003550694,131.438944041434 PathPoint;PointKind.SMOOTHPOINT 1548.15493644916,131.347235846413 1552.78877945593,130.034831583149 1546.79141763094,131.733413778521 PathPoint;PointKind.SMOOTHPOINT 1560.93041397404,131.347235846413 1579.64449237962,132.173319042531 1556.68260713177,131.159727716079 PathPoint;PointKind.SMOOTHPOINT 1613.99778215429,133.430756025785 1628.27038595162,133.044165367503 1599.72517835697,133.817346684067 PathPoint;PointKind.SMOOTHPOINT 1640.53146624442,132.388995936099 1654.55838778165,130.879257681124 1626.50454470719,133.898734191073 PathPoint;PointKind.SMOOTHPOINT 1668.04787937493,132.388995936099 1682.34351588414,131.908809644759 1653.75224286572,132.869182227438 PathPoint;PointKind.SMOOTHPOINT 2003.15848214286,132.388995936099 2038.2449799125,133.524351658842 1968.07198437321,131.253640213355 PathPoint;PointKind.SMOOTHPOINT 2053.27766320199,134.472516115471 2063.43508914274,134.802135518848 2043.12023726124,134.142896712094 PathPoint;PointKind.SMOOTHPOINT 2072.93224400949,132.388995936099 2085.30081029109,131.298403342209 2060.5636777279,133.479588529989 PathPoint;PointKind.SMOOTHPOINT 2101.43138618037,132.388995936099 2113.48901085154,133.267981011771 2089.37376150921,131.510010860426 PathPoint;PointKind.SMOOTHPOINT 2121.08596698788,132.388995936099 2128.32975487533,132.52735469801 2113.84217910042,132.250637174187 PathPoint;PointKind.SMOOTHPOINT 2139.757818755,133.430756025785 2143.37001358762,133.506118118563 2128.44491843475,133.194732255465 PathPoint;PointKind.SMOOTHPOINT 2147.77255756805,133.614306197572 2151.44121830655,131.929355765738 2145.95921992503,134.447139828819 PathPoint;PointKind.SMOOTHPOINT 2156.46421244138,134.472516115471 2157.59994986132,134.438486135846 2152.18121993996,134.600846964661 PathPoint;PointKind.SMOOTHPOINT 2161.37785764326,133.430756025785 2171.999776607,133.052304118203 2159.86241338385,133.48475029676 PathPoint;PointKind.SMOOTHPOINT 2182.99789653151,133.430756025785 2194.30695806645,132.88952910419 2171.68883499657,133.971982947379 PathPoint;PointKind.SMOOTHPOINT 2230.16889046952,133.430756025785 2245.85508778994,133.654716998343 2205.94231635308,133.084859121006 PathPoint;PointKind.SMOOTHPOINT 2262.58786580326,134.257100786868 2267.36534137927,132.880141650689 2254.29187065021,136.648164045682 PathPoint;PointKind.SMOOTHPOINT 2278.3226134479,134.472516115471 2296.02709131591,134.476585490821 2272.08141272167,134.471081575092 PathPoint;PointKind.SMOOTHPOINT 2325.49360738591,134.472516115471 2354.11559068684,134.647499255535 2296.87162408498,134.297532975406 PathPoint;PointKind.SMOOTHPOINT 2388.38826596992,134.472516115471 2410.26166468889,134.435891737318 2366.51486725094,134.509140493624 PathPoint;PointKind.SMOOTHPOINT 2473.88569248256,134.472516115471 2503.77831372241,136.100266255605 2443.99307124271,132.844765975336 PathPoint;PointKind.SMOOTHPOINT 2516.14304121869,135.514276205157 2521.68240842674,136.169445636561 2510.60367401064,134.859106773753 PathPoint;PointKind.SMOOTHPOINT 2538.74580914732,135.514276205157 2542.3856720889,134.690144131031 2533.2982149887,136.747711953972 PathPoint;PointKind.SMOOTHPOINT 2561.34857707595,135.514276205157 2584.6461651464,136.747296936309 2538.05098900549,134.281255474005 PathPoint;PointKind.SMOOTHPOINT 2599.67500965058,135.514276205157 2622.17029159042,136.836823194016 2577.17972771074,134.191729216298 PathPoint;PointKind.SMOOTHPOINT 3074.33313615178,137.597796384529 3086.73480400926,137.632167053774 3045.81538944664,137.518760721675 PathPoint;PointKind.SMOOTHPOINT 3149.78868127905,137.842423436715 3152.74083903951,137.849983070666 3115.54964660225,137.754747035251 PathPoint;PointKind.SMOOTHPOINT 3158.75908478989,137.864244979991 3162.17998354475,136.684589593581 3155.88172595089,138.856467228092 PathPoint;PointKind.SMOOTHPOINT 3170.11448630916,137.888352757201 3175.0419839485,135.975006397935 3166.52088882354,139.28374595047 PathPoint;PointKind.SMOOTHPOINT 3184.22429536713,137.912209565941 3226.81864092713,137.973176593142 3179.48144239729,137.905420926693 PathPoint;PointKind.SMOOTHPOINT 3302.32627351882,137.597796384529 3367.18639018358,136.88158632287 3271.96233229387,137.933086564924 PathPoint;PointKind.SMOOTHPOINT 3416.32284220233,140.723076653587 3429.95820763754,141.84622425028 3402.68747676713,139.599929056895 PathPoint;PointKind.SMOOTHPOINT 3446.78744245396,138.639556474215 3463.90074738362,139.001730880395 3429.67413752431,138.277382068035 PathPoint;PointKind.SMOOTHPOINT 3475.28658462484,140.723076653587 3483.43632584639,141.11780606257 3467.13684340329,140.328347244605 PathPoint;PointKind.SMOOTHPOINT 3491.99297831122,140.723076653587 3505.69744188208,140.495191633969 3478.28851474036,140.950961673206 PathPoint;PointKind.SMOOTHPOINT 3513.61301719947,141.764836743274 3522.19270237619,141.589853603209 3505.03333202276,141.939819883338 PathPoint;PointKind.SMOOTHPOINT 3541.12943032998,141.764836743274 3545.23142896884,143.081667606766 3533.00415405473,139.156446171834 PathPoint;PointKind.SMOOTHPOINT 3560.78401113748,142.80659683296 3582.5038584439,143.449558138313 3539.06416383106,142.163635527606 PathPoint;PointKind.SMOOTHPOINT 3770.10529673739,142.80659683296 3809.00754710912,144.511665104751 3731.20304636566,141.101528561169 PathPoint;PointKind.SMOOTHPOINT 3844.7927038059,142.80659683296 3860.02500393172,143.628610653728 3829.56040368009,141.984583012192 PathPoint;PointKind.SMOOTHPOINT 3877.22276213828,143.848356922646 3896.51265834096,148.214796673557 3857.93286593561,139.481917171735 PathPoint;PointKind.SMOOTHPOINT 3941.10014976267,144.890117012332 3959.51480291376,144.784313253223 3922.68549661157,144.995920771441 PathPoint;PointKind.SMOOTHPOINT 3981.39204041805,145.931877102018 3993.01204356342,147.339880973234 3969.77203727268,144.523873230802 PathPoint;PointKind.SMOOTHPOINT 4045.26942804243,145.931877102018 4077.30409148748,146.326606511001 4013.23476459739,145.537147693035 PathPoint;PointKind.SMOOTHPOINT 4151.40416440295,145.931877102018 4209.95331801155,150.347149357133 4092.85501079435,141.516604846903 PathPoint;PointKind.SMOOTHPOINT 4238.86704899634,145.931877102018 4271.74624521045,146.831209054442 4205.98785278223,145.032545149594 PathPoint;PointKind.SMOOTHPOINT 4299.7962494996,148.01539728139 4321.87310384021,147.498586611897 4277.71939515898,148.532207950883 PathPoint;PointKind.SMOOTHPOINT 4352.86361767986,148.01539728139 4382.49904030367,147.52707223935 4323.22819505604,148.50372232343 PathPoint;PointKind.SMOOTHPOINT 4401.01734065824,149.057157371076 4417.49724601109,148.890312981712 4384.53743530539,149.22400176044 PathPoint;PointKind.SMOOTHPOINT 4422.63737954649,151.140677550448 4427.50237394625,152.188137893206 4413.48955414331,149.171099880886 PathPoint;PointKind.SMOOTHPOINT 4430.4992118695,150.098917460762 4432.0752963975,150.011530223144 4428.24176028856,150.224083626796 PathPoint;PointKind.SMOOTHPOINT 4441.30923131362,152.182437640135 4442.79711841369,152.499229978555 4435.60676646404,150.968301719215 PathPoint;PointKind.SMOOTHPOINT 4445.24014747512,153.224197729821 4448.15774251219,153.697630349838 4443.23152236623,152.898261938233 PathPoint;PointKind.SMOOTHPOINT 4453.10197979812,154.265957819507 4454.60930127138,155.401102807502 4451.46432519373,153.03266057719 PathPoint;PointKind.SMOOTHPOINT 4457.03289595962,159.474758267937 4458.21283929367,165.149528413337 4456.55865104221,157.193944587052 PathPoint;PointKind.SMOOTHPOINT 4456.05016691925,175.101159613229 4456.73788549203,183.75788916191 4455.8834977462,173.003193944826 PathPoint;PointKind.SMOOTHPOINT 4457.03289595962,280.318928671525 4457.25554550783,298.073613325042 4456.81024641141,262.564244018007 PathPoint;PointKind.CORNERPOINT 4457.03289595962,423.04006095852 4457.03289595962,423.04006095852 4457.03289595962,423.04006095852 PathPoint;PointKind.CORNERPOINT 4458.015625,1855.46018427691 4458.015625,1855.46018427691 4458.015625,1855.46018427691 PathPoint;PointKind.SMOOTHPOINT 4456.05016691925,2025.26707889574 4456.65285621354,2047.33123204526 4455.44747762496,2003.20292574622 PathPoint;PointKind.SMOOTHPOINT 4457.03289595962,2394.05015064462 4456.66437256948,2407.93892871532 4457.40141934977,2380.16137257392 PathPoint;PointKind.SMOOTHPOINT 4457.03289595962,3128.49101387332 4456.9983468918,3139.72248984025 4457.06744502745,3117.25953790639 PathPoint;PointKind.SMOOTHPOINT 4457.03289595962,3234.7505430213 4456.19220197587,3246.246528386 4457.87358994338,3223.2545576566 PathPoint;PointKind.SMOOTHPOINT 4457.03289595962,3313.92430983744 4456.85631183518,3336.55003678531 4457.20948008407,3291.29858288957 PathPoint;PointKind.SMOOTHPOINT 4457.03289595962,3389.97279638453 4456.34191460311,3416.42373616171 4457.72387731614,3363.52185660734 PathPoint;PointKind.SMOOTHPOINT 4458.015625,3480.60592418722 4458.14614370067,3507.15452897281 4457.88510629933,3454.05731940163 PathPoint;PointKind.SMOOTHPOINT 4457.03289595962,3570.19729190022 4456.55688658069,3594.82108214511 4457.50890533856,3545.57350165534 PathPoint;PointKind.SMOOTHPOINT 4457.03289595962,3673.33154077915 4456.72579313451,3692.6895593207 4457.33999878474,3653.9735222376 PathPoint;PointKind.SMOOTHPOINT 4457.03289595962,3804.5933120796 4457.03562808696,3809.26060622109 4457.025218389,3791.47771532546 PathPoint;PointKind.SMOOTHPOINT 4456.05016691925,3820.21971342489 4455.10119289802,3823.4134298239 4457.11495097029,3816.63624516427 PathPoint;PointKind.SMOOTHPOINT 4450.153792677,3825.42851387332 4447.74071892044,3827.47372696942 4452.49429360738,3823.44481024998 PathPoint;PointKind.SMOOTHPOINT 4439.34377323287,3833.76259459081 4429.35141506062,3837.67733367783 4442.61115343677,3832.48252228196 PathPoint;PointKind.SMOOTHPOINT 4358.75999192211,3837.92963494955 4323.82704556502,3838.09240996356 4393.6929382792,3837.76685993554 PathPoint;PointKind.SMOOTHPOINT 3311.17083488219,3836.88787485986 3250.29921615864,3836.76579359936 3372.04245360574,3837.00995612038 PathPoint;PointKind.SMOOTHPOINT 2005.12394022361,3837.92963494955 1957.2926752116,3839.7689926079 2052.95520523562,3836.0902772912 PathPoint;PointKind.SMOOTHPOINT 785.557201118037,3836.88787485986 750.589705693126,3837.01809487108 820.524696542949,3836.75765484865 PathPoint;PointKind.SMOOTHPOINT 620.458722335011,3836.88787485986 607.614146674482,3834.44218027431 633.303297995539,3839.33356944542 PathPoint;PointKind.SMOOTHPOINT 487.790301884365,3836.88787485986 470.154922152007,3837.96218995235 505.425681616722,3835.81355976738 PathPoint;PointKind.SMOOTHPOINT 389.517397846849,3835.84611477018 365.35608308075,3836.53383920439 413.678712612947,3835.15839033597 PathPoint;PointKind.SMOOTHPOINT 233.263480427199,3836.88787485986 209.862245153265,3837.958120577 256.664715701132,3835.81762914273 PathPoint;PointKind.SMOOTHPOINT 191.988860731442,3834.80435468049 189.893587704593,3834.5582334824 196.698406484269,3835.35756136445 PathPoint;PointKind.SMOOTHPOINT 187.075215529566,3831.67907441143 185.192991927238,3830.57049583302 188.855099984578,3832.72737801173 PathPoint;PointKind.SMOOTHPOINT 180.19611224694,3830.63731432175 178.604519885902,3829.74460695149 182.287661248662,3831.81044209918 PathPoint;PointKind.SMOOTHPOINT 176.26519608544,3825.42851387332 173.858222545278,3823.82919052358 177.842875541356,3826.47680939886 PathPoint;PointKind.SMOOTHPOINT 167.420634722063,3821.26147351457 160.146136552099,3815.5806255255 169.604287047628,3822.9667453605 PathPoint;PointKind.SMOOTHPOINT 163.489718560563,3783.75811028587 163.158815266499,3768.19519119605 163.77994269208,3797.40782232484 PathPoint;PointKind.SMOOTHPOINT 162.506989520188,3380.59695557735 160.871666976438,3362.9440053076 164.142312063937,3398.24990584711 PathPoint;PointKind.SMOOTHPOINT 163.489718560563,3181.62077844731 163.232519944527,3173.16868584466 163.746917176598,3190.07287104996 PathPoint;PointKind.SMOOTHPOINT 163.489718560563,2672.20009459081 161.293933360975,2660.20357605802 165.685503760151,2684.1966131236 PathPoint;PointKind.SMOOTHPOINT 164.472447600938,2289.87414167601 164.645192940066,2274.91511788817 164.299702261809,2304.83316546385 PathPoint;PointKind.SMOOTHPOINT 163.489718560563,1527.30575602578 163.723884464715,1511.98862720712 163.255552656411,1542.62288484445 PathPoint;PointKind.SMOOTHPOINT 164.472447600938,1255.40637261771 164.230604126158,1241.78617332014 164.714291075718,1269.02657191529 PathPoint;PointKind.SMOOTHPOINT 162.506989520188,1189.77548696749 163.194132091387,1172.02080231397 161.819846948988,1207.53017162101 PathPoint;PointKind.SMOOTHPOINT 163.489718560563,577.220554232063 163.884345690838,563.890094459431 163.092498484929,590.638603405254 PathPoint;PointKind.SMOOTHPOINT 164.472447600938,458.459904007848 164.591449945671,438.239177892026 164.366820163437,476.407983004186 PathPoint;PointKind.SMOOTHPOINT 168.403363762439,359.492695487668 169.877457323001,339.406258758408 166.929270201876,379.579132216928 PathPoint;PointKind.SMOOTHPOINT 169.386092802814,315.738771720852 168.852501644172,302.981279997548 169.919683961455,328.496263444156 PathPoint;PointKind.SMOOTHPOINT 172.334279923939,287.611249299327 174.18457444527,277.010526511701 170.483985402608,298.211972086953 PathPoint";
	
	mask67[1] = "PointKind.SMOOTHPOINT 172.334218025208,263.650653362274 173.574224710464,242.217314243317 171.094486713409,285.084228515625 PathPoint;PointKind.SMOOTHPOINT 173.317025899887,235.523142814636 173.249559402466,226.43298625946 173.387521505356,245.028247833252 PathPoint;PointKind.SMOOTHPOINT 173.317025899887,215.7297706604 171.274856328964,209.979736804962 175.35919547081,221.479804515839 PathPoint;PointKind.SMOOTHPOINT 172.334218025208,200.103349685669 173.323084115982,193.704929351807 171.330757141113,206.596419811249 PathPoint;PointKind.SMOOTHPOINT 174.299833774567,185.51878452301 173.528237342834,180.586609840393 175.071430206299,190.450959205627 PathPoint;PointKind.CORNERPOINT 173.000071048737,171.999914646149 173.000071048737,171.999914646149 173.000071048737,171.999914646149 PathPoint;PointKind.CORNERPOINT 175.999989509583,165.999920368195 175.999989509583,165.999920368195 175.999989509583,165.999920368195 PathPoint;PointKind.SMOOTHPOINT 181.178938150406,153.224086761475 184.995614290237,146.673424243927 176.956086158752,160.471758842468 PathPoint;PointKind.SMOOTHPOINT 189.999976158142,144.999940395355 190.779007673264,144.680113792419 182.674216032028,148.007726669312 PathPoint;PointKind.SMOOTHPOINT 192.971531152725,140.722997188568 196.342377662659,139.550614356995 191.962562799454,141.073980331421 PathPoint;PointKind.SMOOTHPOINT 199.850635528564,137.597901821136 203.056808710098,136.133780479431 198.360589742661,138.278152942657 PathPoint;PointKind.SMOOTHPOINT 211.643503904343,134.472570419312 221.954312324524,129.467225074768 204.644061326981,137.870285511017 PathPoint;PointKind.SMOOTHPOINT 228.349860906601,131.347239017487 234.572474956512,130.529379844666 222.127246856689,132.165098190308 PathPoint;PointKind.SMOOTHPOINT 242.108069658279,131.347239017487 245.100277662277,131.670606136322 233.635929822922,130.431661605835 PathPoint;PointKind.SMOOTHPOINT 254.551920890808,130.5881524086 255.501133203506,130.465886592865 249.779148101807,131.202313899994 PathPoint;PointKind.SMOOTHPOINT 257.398456335068,130.209317207336 258.941649198532,128.783433437347 256.645585298538,130.904674530029 PathPoint;PointKind.SMOOTHPOINT 266.99990272522,129.000113010406 267.794630527496,128.929538726807 264.366781711578,129.233314990997 PathPoint;PointKind.SMOOTHPOINT 277.999970912933,126.000115871429 279.118813276291,125.607354640961 272.041164636612,128.090908527374 PathPoint;PointKind.SMOOTHPOINT 289.000039100647,125.000038146973 292.232372760773,124.855349063873 285.600278377533,125.152044296265 PathPoint;PointKind.SMOOTHPOINT 305.027049779892,124.830329418182 306.084208488464,124.833633899689 298.082406520844,124.807670116425 PathPoint;PointKind.SMOOTHPOINT 308.269296884537,124.845435619354 308.675472736359,125.194058418274 307.432987689972,124.126946926117 PathPoint;PointKind.SMOOTHPOINT 309.585031270981,125.478007793427 310.263551473618,125.539376735687 309.11083817482,125.435285568237 PathPoint;PointKind.SMOOTHPOINT 314.833924770355,124.899959564209 321.455554962158,124.969589710236 313.100173473358,124.881784915924 PathPoint;PointKind.SMOOTHPOINT 334.640160799026,125.223562717438 335.775250196457,125.249054431915 328.390835523605,125.083358287811 PathPoint;PointKind.SMOOTHPOINT 337.971628904343,125.302634239197 339.004554748535,124.787843227386 336.937601566315,125.8176612854 PathPoint;PointKind.SMOOTHPOINT 341.328431367874,125.391855239868 347.872130870819,125.576434135437 340.246764421463,125.361170768738 PathPoint;PointKind.SMOOTHPOINT 354.999897480011,126.000115871429 362.328135967255,126.761090755463 352.962960004807,125.78839302063 PathPoint;PointKind.SMOOTHPOINT 369.862904548645,129.263763427734 378.899284601212,131.10719203949 360.82624912262,127.420334815979 PathPoint;PointKind.SMOOTHPOINT 400.327470302582,130.305383205414 405.317788124084,130.004439353943 395.33687710762,130.606563091278 PathPoint;PointKind.SMOOTHPOINT 419.98197555542,130.305383205414 425.022411346436,130.016477108002 414.941539764404,130.594289302826 PathPoint;PointKind.SMOOTHPOINT 430.792036056519,130.305383205414 435.943722724915,132.946608066559 425.640349388123,127.664394378662 PathPoint;PointKind.SMOOTHPOINT 444.550244808197,129.263763427734 457.287368774414,128.836541175842 431.81312084198,129.690985679626 PathPoint;PointKind.SMOOTHPOINT 463.221942186356,129.263763427734 478.538764715195,130.875170230865 447.905395030975,127.652356624603 PathPoint;PointKind.SMOOTHPOINT 497.617464065552,130.305383205414 512.143689393997,130.329930782318 483.091514110565,130.281071662903 PathPoint;PointKind.SMOOTHPOINT 550.684958696365,129.263763427734 569.832776784897,128.852591514587 531.537140607834,129.674699306488 PathPoint;PointKind.SMOOTHPOINT 586.063288450241,131.347239017487 592.616075277328,134.859194755554 579.510501623154,127.835283279419 PathPoint;PointKind.SMOOTHPOINT 604.7349858284,129.263763427734 628.178629875183,129.182331562042 581.291617155075,129.345195293427 PathPoint;PointKind.SMOOTHPOINT 651.906183958054,129.263763427734 695.326520204544,129.458963871002 608.485572338104,129.068326950073 PathPoint;PointKind.SMOOTHPOINT 716.766271591187,130.305383205414 731.372630596161,131.709315776825 702.159637212753,128.901450634003 PathPoint;PointKind.SMOOTHPOINT 769.833490848541,129.263763427734 804.090775251389,130.537405014038 735.576206445694,127.989885807037 PathPoint;PointKind.SMOOTHPOINT 866.140952110291,130.305383205414 898.095288276672,130.682330131531 814.724321365356,129.699246883392 PathPoint;PointKind.SMOOTHPOINT 928.052891492844,130.305383205414 938.005989789963,130.705933570862 918.099793195724,129.905068874359 PathPoint;PointKind.SMOOTHPOINT 947.707396745682,130.305383205414 956.310338973999,129.340946674347 944.451105594635,130.670528411865 PathPoint;PointKind.SMOOTHPOINT 963.431221246719,130.305383205414 973.884122371674,131.778473854065 952.978044748306,128.832292556763 PathPoint;PointKind.SMOOTHPOINT 983.085726499557,129.263763427734 999.592437744141,129.267776012421 966.579015254974,129.259750843048 PathPoint;PointKind.SMOOTHPOINT 1011.58495187759,130.305383205414 1015.64643502235,131.833233833313 1005.26402950287,127.92804479599 PathPoint;PointKind.SMOOTHPOINT 1031.23945713043,129.263763427734 1048.191447258,129.52009677887 1014.28746700287,129.007430076599 PathPoint;PointKind.SMOOTHPOINT 1074.47942376137,129.263763427734 1114.06903982162,129.792716503143 1034.89008307457,128.734810352325 PathPoint;PointKind.SMOOTHPOINT 1325.07532954216,131.347239017487 1351.93167686462,131.811046600342 1298.21925759315,130.883431434631 PathPoint;PointKind.SMOOTHPOINT 1396.81479692459,132.389094829559 1426.00107908249,132.209944725037 1367.62851476669,132.568008899689 PathPoint;PointKind.SMOOTHPOINT 1436.12380743027,132.389094829559 1440.22274136543,132.403256893158 1423.29470872879,132.34424829483 PathPoint;PointKind.SMOOTHPOINT 1449.65400695801,132.388622760773 1451.02233767509,132.38555431366 1444.91262674332,132.398536205292 PathPoint;PointKind.SMOOTHPOINT 1453.75872373581,132.378945350647 1454.82249140739,130.931582450867 1452.46088862419,134.14519071579 PathPoint;PointKind.SMOOTHPOINT 1458.88259768486,132.366199493408 1465.61492800713,131.830637454987 1456.74569964409,132.536144256592 PathPoint;PointKind.SMOOTHPOINT 1475.4330933094,132.389094829559 1483.29473018646,132.486577033997 1471.72794342041,132.343068122864 PathPoint;PointKind.SMOOTHPOINT 1500.9838950634,131.347239017487 1524.17364478111,131.755106449127 1467.66701102257,130.761165618896 PathPoint;PointKind.SMOOTHPOINT 1540.29318094254,131.347239017487 1541.98727846146,131.331660747528 1530.37009835243,131.439056396484 PathPoint;PointKind.SMOOTHPOINT 1548.1548178196,131.347239017487 1552.78880238533,130.03488779068 1546.79144382477,131.733391284943 PathPoint;PointKind.SMOOTHPOINT 1560.93049407005,131.347239017487 1579.64459896088,132.173359394073 1556.68258309364,131.159827709198 PathPoint;PointKind.SMOOTHPOINT 1613.99771332741,133.430714607239 1628.27031970024,133.044090270996 1599.72510695457,133.817338943481 PathPoint;PointKind.SMOOTHPOINT 1640.53159832954,132.389094829559 1654.55829620361,130.879182815552 1626.50462508202,133.898770809174 PathPoint;PointKind.SMOOTHPOINT 1668.0480158329,132.389094829559 1682.34347820282,131.908764839172 1653.75227808952,132.869188785553 PathPoint;PointKind.SMOOTHPOINT 2003.15851449966,132.389094829559 2038.24494838715,133.524420261383 1968.07208061218,131.253533363342 PathPoint;PointKind.SMOOTHPOINT 2053.27758550644,134.472570419312 2063.43501091003,134.802074432373 2043.12016010284,134.142830371857 PathPoint;PointKind.SMOOTHPOINT 2072.93236613274,132.389094829559 2085.30076503754,131.298379898071 2060.56369185448,133.479573726654 PathPoint;PointKind.SMOOTHPOINT 2101.43131613731,132.389094829559 2113.48909378052,133.268086910248 2089.37381386757,131.510102748871 PathPoint;PointKind.SMOOTHPOINT 2121.08609676361,132.389094829559 2128.32979559898,132.527410984039 2113.84212255478,132.250542640686 PathPoint;PointKind.SMOOTHPOINT 2139.75779414177,133.430714607239 2143.37014317513,133.506009578705 2128.44490170479,133.194680213928 PathPoint;PointKind.SMOOTHPOINT 2147.77253866196,133.614349365234 2151.44133925438,131.92929983139 2145.95920443535,134.447078704834 PathPoint;PointKind.SMOOTHPOINT 2156.46415114403,134.472570419312 2157.60006666183,134.438581466675 2152.18126773834,134.600737094879 PathPoint;PointKind.SMOOTHPOINT 2161.37791514397,133.430714607239 2171.99989557266,133.052351474762 2159.86253499985,133.484766483307 PathPoint;PointKind.SMOOTHPOINT 2182.99776077271,133.430714607239 2194.30707335472,132.889487743378 2171.68872356415,133.9719414711 PathPoint;PointKind.SMOOTHPOINT 2230.16895890236,133.430714607239 2245.85505723953,133.65471124649 2205.94242811203,133.084924221039 PathPoint;PointKind.SMOOTHPOINT 2262.58785009384,134.257071018219 2267.36530423164,132.880046367645 2254.29194927216,136.648099422455 PathPoint;PointKind.SMOOTHPOINT 2278.32268953323,134.472570419312 2296.02699995041,134.476583003998 2272.08135008812,134.471154212952 PathPoint;PointKind.SMOOTHPOINT 2325.49361228943,134.472570419312 2354.11565423012,134.647471904755 2296.87157034874,134.297432899475 PathPoint;PointKind.SMOOTHPOINT 2388.38835954666,134.472570419312 2410.26154875755,134.435985088348 2366.51489496231,134.509155750275 PathPoint;PointKind.SMOOTHPOINT 2473.88576030731,134.472570419312 2503.77837538719,136.100263595581 2443.99314522743,132.844877243042 PathPoint;PointKind.SMOOTHPOINT 2516.14291906357,135.514190196991 2521.68233156204,136.169421672821 2510.60378193855,134.859194755554 PathPoint;PointKind.SMOOTHPOINT 2538.74584794044,135.514190196991 2542.38573431969,134.690194129944 2533.29813480377,136.747705936432 PathPoint;PointKind.SMOOTHPOINT 2561.34850144386,135.514190196991 2584.64619755745,136.747233867645 2538.05108070374,134.281146526337 PathPoint;PointKind.SMOOTHPOINT 2599.67497944832,135.514190196991 2622.17023730278,136.836926937103 2577.17972159386,134.191689491272 PathPoint;PointKind.SMOOTHPOINT 3074.33318138123,137.597901821136 3086.73490047455,137.632126808167 3045.81550598145,137.518830299377 PathPoint;PointKind.SMOOTHPOINT 3149.788813591,137.842433452606 3152.74081707001,137.849986553192 3115.54970383644,137.754864692688 PathPoint;PointKind.SMOOTHPOINT 3158.75910401344,137.864148616791 3162.18006849289,136.684684753418 3155.88172674179,138.856437206268 PathPoint;PointKind.SMOOTHPOINT 3170.11440396309,137.888460159302 3175.04193663597,135.974929332733 3166.52078032494,139.28365945816 PathPoint;PointKind.SMOOTHPOINT 3184.22426462173,137.912299633026 3226.8187558651,137.9731965065 3179.48150753975,137.90545463562 PathPoint;PointKind.SMOOTHPOINT 3302.32615828514,137.597901821136 3367.18652129173,136.881537437439 3271.96237921715,137.933070659637 PathPoint;PointKind.SMOOTHPOINT 3416.32278442383,140.722997188568 3429.95817661285,141.846284866333 3402.6873922348,139.599945545197 PathPoint;PointKind.SMOOTHPOINT 3446.78735017776,138.639521598816 3463.90070915222,139.001834392548 3429.67426657677,138.277444839478 PathPoint;PointKind.SMOOTHPOINT 3475.2865755558,140.722997188568 3483.43625307083,141.117882728577 3467.13689804077,140.328347682953 PathPoint;PointKind.SMOOTHPOINT 3491.99293255806,140.722997188568 3505.69744348526,140.495223999023 3478.28842163086,140.951006412506 PathPoint;PointKind.SMOOTHPOINT 3513.61305356026,141.764853000641 3522.19258904457,141.589951515198 3505.03324270248,141.939754486084 PathPoint;PointKind.SMOOTHPOINT 3541.12947106361,141.764853000641 3545.23143410683,143.08168888092 3533.00402641296,139.156436920166 PathPoint;PointKind.SMOOTHPOINT 3560.78397631645,142.806708812714 3582.50378251076,143.449666500092 3539.06417012215,142.163751125336 PathPoint;PointKind.SMOOTHPOINT 3770.10525584221,142.806708812714 3809.00753974915,144.511585235596 3731.20297193527,141.101596355438 PathPoint;PointKind.SMOOTHPOINT 3844.79259610176,142.806708812714 3860.02487897873,143.628580570221 3829.56031322479,141.984601020813 PathPoint;PointKind.SMOOTHPOINT 3877.22277760506,143.848328590393 3896.51268839836,148.214728832245 3857.93286681175,139.481928348541 PathPoint;PointKind.SMOOTHPOINT 3941.10005736351,144.890184402466 3959.51483130455,144.784204959869 3922.68555879593,144.995927810669 PathPoint;PointKind.SMOOTHPOINT 3981.39215111732,145.931804180145 3993.01208496094,147.339985370636 3969.77194190025,144.523859024048 PathPoint;PointKind.SMOOTHPOINT 4045.26943087578,145.931804180145 4077.30417609215,146.326689720154 4013.23468565941,145.53715467453 PathPoint;PointKind.SMOOTHPOINT 4151.40414476395,145.931804180145 4209.95322346687,150.347063541412 4092.85506606102,141.516544818878 PathPoint;PointKind.SMOOTHPOINT 4238.86716127396,145.931804180145 4271.7462015152,146.831095218658 4205.98784565926,145.032513141632 PathPoint;PointKind.SMOOTHPOINT 4299.79629278183,148.015279769897 4321.87298297882,147.498600482941 4277.71932721138,148.532195091248 PathPoint;PointKind.SMOOTHPOINT 4352.86351203918,148.015279769897 4382.49892830849,147.527160644531 4323.22809576988,148.503634929657 PathPoint;PointKind.SMOOTHPOINT 4398.01732420921,149.05713558197 4414.49732422829,148.8902592659 4381.5375995636,149.224011898041 PathPoint;PointKind.SMOOTHPOINT 4419.63744521141,151.140611171722 4424.50246810913,152.188131809235 4410.489538908,149.171140193939 PathPoint;PointKind.SMOOTHPOINT 4430.49927592278,150.098991394043 4432.07523822784,150.011422634125 4428.24176430702,150.224089622498 PathPoint;PointKind.SMOOTHPOINT 4441.30933642387,152.182466983795 4442.79717922211,152.499225139618 4435.60690283775,150.968306064606 PathPoint;PointKind.SMOOTHPOINT 4445.24001717567,153.224086761475 4448.15787434578,153.697571754456 4443.23144316673,152.898359298706 PathPoint;PointKind.SMOOTHPOINT 4453.10192942619,154.265942573547 4454.60932374001,155.401031970978 4451.46428346634,153.0326628685 PathPoint;PointKind.SMOOTHPOINT 4457.00011610985,162.999923229218 4458.18009138107,168.67466211319 4456.52592301369,160.719122886658 PathPoint;PointKind.SMOOTHPOINT 4455.99995970726,180.000064373016 4456.6878426075,188.656861782074 4455.83335876465,177.902190685272 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,280.318930149078 4457.25566267967,298.073673248291 4456.81038379669,262.564187049866 PathPoint;PointKind.CORNERPOINT 4457.03288555145,423.03995847702 4457.03288555145,423.03995847702 4457.03288555145,423.03995847702 PathPoint;PointKind.CORNERPOINT 4458.01569342613,1855.46022891998 4458.01569342613,1855.46022891998 4458.01569342613,1855.46022891998 PathPoint;PointKind.SMOOTHPOINT 4456.05007767677,2025.26714801788 4456.65287017822,2047.33117103577 4455.44756054878,2003.20288896561 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,2394.050116539 4456.78560018539,2403.37371110916 4457.40133523941,2380.16138076782 PathPoint;PointKind.SMOOTHPOINT 4456.96817278862,2940.63425302505 4456.96927428246,2943.8646197319 4456.88583612442,2726.09079122543 PathPoint;PointKind.SMOOTHPOINT 4456.97175264359,2950.25029420853 4456.05778813362,2952.49946594238 4458.19716453552,2947.2344827652 PathPoint;PointKind.SMOOTHPOINT 4456.97450637817,2957.48781681061 4457.01223254204,3054.04287815094 4456.9736802578,2955.09088754654 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3128.49095821381 4456.99846386909,3139.7224187851 4457.04362511635,3124.99930143356 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3234.7505736351 4456.19217038155,3246.24662876129 4457.87360072136,3223.25451850891 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3313.92429828644 4456.85637116432,3336.5500831604 4457.20939993858,3291.29851341248 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3389.97269153595 4456.34197354317,3416.4236497879 4457.72379755974,3363.52196931839 PathPoint;PointKind.SMOOTHPOINT 4458.01569342613,3480.60588598251 4458.14622044563,3507.1545624733 4457.88516640663,3454.05720949173 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3570.197224617 4456.55676484108,3594.82104063034 4457.50900626183,3545.57340860367 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3673.33150863647 4456.8759226799,3683.22843074799 4457.33992695808,3653.9736199379 PathPoint;PointKind.SMOOTHPOINT 4456.91750407219,3743.24465990067 4456.92135930061,3746.02325677872 4456.8772995472,3713.88764619827 PathPoint;PointKind.SMOOTHPOINT 4456.92962050438,3751.52663469315 4455.57368159294,3754.24669504166 4458.28776240349,3748.80256175995 PathPoint;PointKind.SMOOTHPOINT 4456.94504141808,3760.50656318665 4456.98331832886,3781.6469836235 4456.93980932236,3757.56769895554 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3804.59330320358 4457.03563928604,3809.26064729691 4457.02985644341,3799.52281236649 PathPoint;PointKind.SMOOTHPOINT 4457.00011610985,3818.00005674362 4456.05117917061,3821.19383811951 4458.06498527527,3814.41658258438 PathPoint;PointKind.SMOOTHPOINT 4450.15378117561,3825.42853116989 4447.7406835556,3827.47376918793 4452.49418020248,3823.44489812851 PathPoint;PointKind.SMOOTHPOINT 4439.34372067451,3833.76266956329 4429.35151934624,3837.67729997635 4442.61102676392,3832.48241901398 PathPoint;PointKind.SMOOTHPOINT 4358.7600839138,3837.9296207428 4323.82703304291,3838.09248447418 4393.69285941124,3837.76675701141 PathPoint;PointKind.SMOOTHPOINT 3311.17087841034,3836.88776493073 3272.21765041351,3836.80963754654 3372.04245686531,3837.01003074646 PathPoint;PointKind.SMOOTHPOINT 2397.1892952919,3836.77753686905 2394.88083958626,3836.7791891098 2767.875841856,3836.50491714478 PathPoint;PointKind.SMOOTHPOINT 2390.27962446213,3836.7827296257 2387.57242798805,3838.31860542297 2392.86345362663,3835.31695604324 PathPoint;PointKind.SMOOTHPOINT 2380.97172617912,3836.79004669189 2180.04548192024,3836.94889783859 2384.06444549561,3836.78745031357 PathPoint;PointKind.SMOOTHPOINT 2005.12385487556,3837.9296207428 1957.29258656502,3839.76903676987 2021.8979537487,3837.28453874588 PathPoint;PointKind.SMOOTHPOINT 785.557315349579,3836.88776493073 750.589842796326,3837.01805591583 820.524787902832,3836.75770998001 PathPoint;PointKind.SMOOTHPOINT 620.458810329437,3836.88776493073 607.614015340805,3834.44221258163 633.303329944611,3839.33355331421 PathPoint;PointKind.SMOOTHPOINT 487.790211439133,3836.88776493073 470.155019760132,3837.96219348907 505.425678491592,3835.81357240677 PathPoint;PointKind.SMOOTHPOINT 389.517409801483,3835.84614515305 375.587918758392,3836.24268293381 413.678677082062,3835.15834093094 PathPoint;PointKind.SMOOTHPOINT 299.504435062408,3836.31585359573 297.429220676422,3836.32199048996 335.469310283661,3836.20987415314 PathPoint;PointKind.SMOOTHPOINT 293.000113964081,3837.00011730194 291.461327075958,3838.04150104523 296.05731010437,3834.930331707 PathPoint;PointKind.SMOOTHPOINT 287.805469036102,3836.35692358017 266.153129339218,3836.44661664963 289.626513719559,3836.34937047958 PathPoint;PointKind.SMOOTHPOINT 238.999929428101,3837.00011730194 215.598692893982,3838.0705332756 247.423052787781,3836.61490917206 PathPoint;PointKind.SMOOTHPOINT 194.999932050705,3836.00003957748 192.904890775681,3835.75409173965 199.709644317627,3836.5533041954 PathPoint;PointKind.SMOOTHPOINT 187.075234651566,3831.67895793915 185.193057060242,3830.57054042816 188.854973316193,3832.72742271423 PathPoint;PointKind.SMOOTHPOINT 180.196130275726,3830.63733816147 178.604471683502,3829.74465608597 182.287591695786,3831.81042909622 PathPoint;PointKind.SMOOTHPOINT 176.265174150467,3825.42853116989 173.858134746552,3823.82916212082 177.842788696289,3826.47675991058 PathPoint;PointKind.SMOOTHPOINT 167.420729398727,3821.26157999039 162.8382396698,3816.85269355774 169.41691160202,3823.18242788315 PathPoint;PointKind.SMOOTHPOINT 162.999883890152,3779.00009393692 162.668884992599,3763.43716621399 163.290127515793,3792.64972686768 PathPoint;PointKind.SMOOTHPOINT 162.506965398788,3380.59693336487 160.871797800064,3362.94392108917 164.142408370972,3398.24994564056 PathPoint;PointKind.SMOOTHPOINT 163.489773273468,3181.62088394165 163.383754491806,3178.13961267471 163.746972084045,3190.07280349731 PathPoint;PointKind.SMOOTHPOINT 164.037215709686,2993.5243678093 164.043273925781,2991.45741462708 163.737609386444,3093.13890695572 PathPoint;PointKind.SMOOTHPOINT 164.05566573143,2987.30533361435 163.667939901352,2985.2289390564 164.486900568008,2989.61540222168 PathPoint;PointKind.SMOOTHPOINT 164.074391126633,2980.95152378082 164.48166847229,2841.34945392609 164.068057537079,2983.07488918304 PathPoint;PointKind.SMOOTHPOINT 163.489773273468,2672.20012664795 161.2939453125,2660.20367860794 164.743273258209,2679.04866456985 PathPoint;PointKind.SMOOTHPOINT 164.472581148148,2289.87421274185 164.645240306854,2274.91506099701 164.299646615982,2304.8331284523 PathPoint;PointKind.SMOOTHPOINT 163.489773273468,1527.30586051941 163.723840713501,1511.98864459991 163.255430459976,1542.62284040451 PathPoint;PointKind.SMOOTHPOINT 164.00004029274,1261.00005626678 163.275532722473,1247.39692211151 164.855901002884,1277.07352638245 PathPoint;PointKind.SMOOTHPOINT 162.506965398788,1189.77549791336 162.815108299255,1181.81264162064 161.819908618927,1207.53024101257 PathPoint;PointKind.SMOOTHPOINT 163.071756362915,927.857809066772 163.073408603668,925.572052001953 162.964636087418,1060.47916173935 PathPoint;PointKind.SMOOTHPOINT 163.077263832092,920.990624427795 164.376751184464,919.720759391785 160.943945646286,923.074808120728 PathPoint;PointKind.SMOOTHPOINT 163.081394433975,915.534217357635 163.206689357758,755.828862190247 163.080017566681,917.35475063324 PathPoint;PointKind.SMOOTHPOINT 163.489773273468,577.220456600189 163.884383440018,563.890178203583 163.276083469391,584.434611797333 PathPoint;PointKind.SMOOTHPOINT 164.472581148148,458.459987640381 164.591542482376,438.23915719986 164.366837739944,476.408042907715 PathPoint;PointKind.SMOOTHPOINT 168.403261899948,359.492654800415 169.877336025238,339.406363964081 166.929187774658,379.579181671143 PathPoint;PointKind.SMOOTHPOINT 169.999877214432,317.999932765961 169.466203451157,305.242509841919 170.533550977707,330.757355690002 PathPoint;PointKind.SMOOTHPOINT 172.334218025208,287.611212730408 174.184452295303,277.010436058044 170.483983755112,298.211989402771 PathPoint";
	
	mask67[2] = "PointKind.SMOOTHPOINT 172.334218025208,263.650653362274 173.574224710464,242.217314243317 171.094486713409,285.084228515625 PathPoint;PointKind.SMOOTHPOINT 173.317025899887,235.523142814636 173.249559402466,226.43298625946 173.387521505356,245.028247833252 PathPoint;PointKind.SMOOTHPOINT 173.317025899887,215.7297706604 171.274856328964,209.979736804962 175.35919547081,221.479804515839 PathPoint;PointKind.SMOOTHPOINT 172.334218025208,200.103349685669 173.323084115982,193.704929351807 171.330757141113,206.596419811249 PathPoint;PointKind.SMOOTHPOINT 174.299833774567,185.51878452301 173.528237342834,180.586609840393 175.071430206299,190.450959205627 PathPoint;PointKind.CORNERPOINT 173.000071048737,174.999911785126 173.000071048737,174.999911785126 173.000071048737,174.999911785126 PathPoint;PointKind.CORNERPOINT 175.999989509583,165.999920368195 175.999989509583,165.999920368195 175.999989509583,165.999920368195 PathPoint;PointKind.SMOOTHPOINT 180.999945402145,153.000090122223 184.816621541977,146.449427604675 176.777093410492,160.247762203217 PathPoint;PointKind.SMOOTHPOINT 189.999976158142,144.999940395355 190.779007673264,144.680113792419 182.674216032028,148.007726669312 PathPoint;PointKind.SMOOTHPOINT 192.971531152725,140.722997188568 196.342377662659,139.550614356995 191.962562799454,141.073980331421 PathPoint;PointKind.SMOOTHPOINT 199.850635528564,137.597901821136 203.056808710098,136.133780479431 198.360589742661,138.278152942657 PathPoint;PointKind.SMOOTHPOINT 211.643503904343,134.472570419312 221.954312324524,129.467225074768 204.644061326981,137.870285511017 PathPoint;PointKind.SMOOTHPOINT 228.349860906601,131.347239017487 234.572474956512,130.529379844666 222.127246856689,132.165098190308 PathPoint;PointKind.SMOOTHPOINT 242.108069658279,131.347239017487 245.100277662277,131.670606136322 233.635929822922,130.431661605835 PathPoint;PointKind.SMOOTHPOINT 254.551920890808,130.5881524086 255.501133203506,130.465886592865 249.779148101807,131.202313899994 PathPoint;PointKind.SMOOTHPOINT 257.398456335068,130.209317207336 258.941649198532,128.783433437347 256.645585298538,130.904674530029 PathPoint;PointKind.SMOOTHPOINT 266.99990272522,129.000113010406 267.794630527496,128.929538726807 264.366781711578,129.233314990997 PathPoint;PointKind.SMOOTHPOINT 277.999970912933,123.999960422516 279.118813276291,123.60743522644 272.041164636612,126.090989112854 PathPoint;PointKind.SMOOTHPOINT 291.999957561493,122.999882698059 295.232291221619,122.855429649353 288.600196838379,123.152124881744 PathPoint;PointKind.SMOOTHPOINT 305.000063180923,122.999882698059 306.057221889496,123.003423213959 298.055419921875,122.977459430695 PathPoint;PointKind.SMOOTHPOINT 308.269296884537,124.845435619354 308.675472736359,125.194058418274 307.432987689972,124.126946926117 PathPoint;PointKind.SMOOTHPOINT 309.585031270981,125.478007793427 310.263551473618,125.539376735687 309.11083817482,125.435285568237 PathPoint;PointKind.SMOOTHPOINT 314.833924770355,124.899959564209 321.455554962158,124.969589710236 313.100173473358,124.881784915924 PathPoint;PointKind.SMOOTHPOINT 334.640160799026,125.223562717438 335.775250196457,125.249054431915 328.390835523605,125.083358287811 PathPoint;PointKind.SMOOTHPOINT 337.971628904343,125.302634239197 339.004554748535,124.787843227386 336.937601566315,125.8176612854 PathPoint;PointKind.SMOOTHPOINT 341.328431367874,125.391855239868 347.872130870819,125.576434135437 340.246764421463,125.361170768738 PathPoint;PointKind.SMOOTHPOINT 354.999897480011,126.000115871429 362.328135967255,126.761090755463 352.962960004807,125.78839302063 PathPoint;PointKind.SMOOTHPOINT 369.862904548645,129.263763427734 378.899284601212,131.10719203949 360.82624912262,127.420334815979 PathPoint;PointKind.SMOOTHPOINT 400.327470302582,130.305383205414 405.317788124084,130.004439353943 395.33687710762,130.606563091278 PathPoint;PointKind.SMOOTHPOINT 419.98197555542,130.305383205414 425.022411346436,130.016477108002 414.941539764404,130.594289302826 PathPoint;PointKind.SMOOTHPOINT 430.792036056519,130.305383205414 435.943722724915,132.946608066559 425.640349388123,127.664394378662 PathPoint;PointKind.SMOOTHPOINT 444.550244808197,129.263763427734 457.287368774414,128.836541175842 431.81312084198,129.690985679626 PathPoint;PointKind.SMOOTHPOINT 463.221942186356,129.263763427734 478.538764715195,130.875170230865 447.905395030975,127.652356624603 PathPoint;PointKind.SMOOTHPOINT 497.617464065552,130.305383205414 512.143689393997,130.329930782318 483.091514110565,130.281071662903 PathPoint;PointKind.SMOOTHPOINT 550.684958696365,129.263763427734 569.832776784897,128.852591514587 531.537140607834,129.674699306488 PathPoint;PointKind.SMOOTHPOINT 585.999952554703,132.999951839447 592.55273938179,136.511907577515 579.447165727615,129.487996101379 PathPoint;PointKind.SMOOTHPOINT 604.7349858284,129.263763427734 628.178629875183,129.182331562042 581.291617155075,129.345195293427 PathPoint;PointKind.SMOOTHPOINT 651.906183958054,129.263763427734 695.326520204544,129.458963871002 608.485572338104,129.068326950073 PathPoint;PointKind.SMOOTHPOINT 716.766271591187,130.305383205414 731.372630596161,131.709315776825 702.159637212753,128.901450634003 PathPoint;PointKind.SMOOTHPOINT 769.833490848541,129.263763427734 804.090775251389,130.537405014038 735.576206445694,127.989885807037 PathPoint;PointKind.SMOOTHPOINT 866.140952110291,130.305383205414 898.095288276672,130.682330131531 814.724321365356,129.699246883392 PathPoint;PointKind.SMOOTHPOINT 928.052891492844,130.305383205414 938.005989789963,130.705933570862 918.099793195724,129.905068874359 PathPoint;PointKind.SMOOTHPOINT 947.707396745682,130.305383205414 956.310338973999,129.340946674347 944.451105594635,130.670528411865 PathPoint;PointKind.SMOOTHPOINT 963.431221246719,130.305383205414 974.066970348358,133.740863800049 953.385872840881,127.060618400574 PathPoint;PointKind.SMOOTHPOINT 983.085726499557,129.263763427734 999.592437744141,129.267776012421 966.579015254974,129.259750843048 PathPoint;PointKind.SMOOTHPOINT 1011.58495187759,130.305383205414 1015.64643502235,131.833233833313 1005.26402950287,127.92804479599 PathPoint;PointKind.SMOOTHPOINT 1043.00010681152,129.000113010406 1059.95209693909,129.256446361542 1026.04811668396,128.743779659271 PathPoint;PointKind.SMOOTHPOINT 1074.47942376137,129.263763427734 1114.06903982162,129.792716503143 1034.89008307457,128.734810352325 PathPoint;PointKind.SMOOTHPOINT 1325.07532954216,131.347239017487 1351.93167686462,131.811046600342 1298.21925759315,130.883431434631 PathPoint;PointKind.SMOOTHPOINT 1396.81479692459,132.389094829559 1426.00107908249,132.209944725037 1367.62851476669,132.568008899689 PathPoint;PointKind.SMOOTHPOINT 1436.12380743027,132.389094829559 1440.22274136543,132.403256893158 1423.29470872879,132.34424829483 PathPoint;PointKind.SMOOTHPOINT 1444.65405106544,132.388622760773 1446.02238178253,132.38555431366 1439.91267085075,132.398536205292 PathPoint;PointKind.SMOOTHPOINT 1448.75876784325,132.378945350647 1449.82253551483,130.931582450867 1447.46093273163,134.14519071579 PathPoint;PointKind.SMOOTHPOINT 1453.8826417923,132.366199493408 1460.61497211456,131.830637454987 1451.74574375153,132.536144256592 PathPoint;PointKind.SMOOTHPOINT 1475.4330933094,132.389094829559 1483.29473018646,132.486577033997 1471.72794342041,132.343068122864 PathPoint;PointKind.SMOOTHPOINT 1500.9838950634,131.347239017487 1524.17364478111,131.755106449127 1467.66701102257,130.761165618896 PathPoint;PointKind.SMOOTHPOINT 1540.29318094254,131.347239017487 1541.98727846146,131.331660747528 1530.37009835243,131.439056396484 PathPoint;PointKind.SMOOTHPOINT 1548.1548178196,131.347239017487 1552.78880238533,130.03488779068 1546.79144382477,131.733391284943 PathPoint;PointKind.SMOOTHPOINT 1560.93049407005,131.347239017487 1579.64459896088,132.173359394073 1556.68258309364,131.159827709198 PathPoint;PointKind.SMOOTHPOINT 1613.99771332741,133.430714607239 1628.27031970024,133.044090270996 1599.72510695457,133.817338943481 PathPoint;PointKind.SMOOTHPOINT 1640.53159832954,132.389094829559 1654.55829620361,130.879182815552 1626.50462508202,133.898770809174 PathPoint;PointKind.SMOOTHPOINT 1668.0480158329,132.389094829559 1682.34347820282,131.908764839172 1653.75227808952,132.869188785553 PathPoint;PointKind.SMOOTHPOINT 2003.15851449966,132.389094829559 2038.24494838715,133.524420261383 1968.07208061218,131.253533363342 PathPoint;PointKind.SMOOTHPOINT 2053.27758550644,134.472570419312 2063.43501091003,134.802074432373 2043.12016010284,134.142830371857 PathPoint;PointKind.SMOOTHPOINT 2072.93236613274,132.389094829559 2085.30076503754,131.298379898071 2060.56369185448,133.479573726654 PathPoint;PointKind.SMOOTHPOINT 2101.43131613731,132.389094829559 2113.48909378052,133.268086910248 2089.37381386757,131.510102748871 PathPoint;PointKind.SMOOTHPOINT 2121.08609676361,132.389094829559 2128.32979559898,132.527410984039 2113.84212255478,132.250542640686 PathPoint;PointKind.SMOOTHPOINT 2139.75779414177,133.430714607239 2143.37014317513,133.506009578705 2128.44490170479,133.194680213928 PathPoint;PointKind.SMOOTHPOINT 2153.77265095711,133.614349365234 2157.44145154953,131.92929983139 2151.9593167305,134.447078704834 PathPoint;PointKind.SMOOTHPOINT 2162.46426343918,134.472570419312 2163.60017895699,134.438581466675 2158.18138003349,134.600737094879 PathPoint;PointKind.SMOOTHPOINT 2167.37802743912,133.430714607239 2178.00000786781,133.052351474762 2165.862647295,133.484766483307 PathPoint;PointKind.SMOOTHPOINT 2188.99787306786,133.430714607239 2200.30718564987,132.889487743378 2177.6888358593,133.9719414711 PathPoint;PointKind.SMOOTHPOINT 2230.16895890236,133.430714607239 2245.85505723953,133.65471124649 2205.94242811203,133.084924221039 PathPoint;PointKind.SMOOTHPOINT 2262.58785009384,134.257071018219 2267.36530423164,132.880046367645 2254.29194927216,136.648099422455 PathPoint;PointKind.SMOOTHPOINT 2278.32268953323,134.472570419312 2296.02699995041,134.476583003998 2272.08135008812,134.471154212952 PathPoint;PointKind.SMOOTHPOINT 2325.49361228943,134.472570419312 2354.11565423012,134.647471904755 2296.87157034874,134.297432899475 PathPoint;PointKind.SMOOTHPOINT 2388.38835954666,134.472570419312 2410.26154875755,134.435985088348 2366.51489496231,134.509155750275 PathPoint;PointKind.SMOOTHPOINT 2473.88576030731,134.472570419312 2503.77837538719,136.100263595581 2443.99314522743,132.844877243042 PathPoint;PointKind.SMOOTHPOINT 2516.14291906357,135.514190196991 2521.68233156204,136.169421672821 2510.60378193855,134.859194755554 PathPoint;PointKind.SMOOTHPOINT 2544.7459602356,135.514190196991 2548.38584661484,134.690194129944 2539.29824709892,136.747705936432 PathPoint;PointKind.SMOOTHPOINT 2567.34861373901,135.514190196991 2590.6463098526,136.747233867645 2544.05119299889,134.281146526337 PathPoint;PointKind.SMOOTHPOINT 2599.67497944832,135.514190196991 2622.17023730278,136.836926937103 2577.17972159386,134.191689491272 PathPoint;PointKind.SMOOTHPOINT 3074.33318138123,137.597901821136 3086.73490047455,137.632126808167 3045.81550598145,137.518830299377 PathPoint;PointKind.SMOOTHPOINT 3149.788813591,137.842433452606 3152.74081707001,137.849986553192 3115.54970383644,137.754864692688 PathPoint;PointKind.SMOOTHPOINT 3158.75910401344,137.864148616791 3162.18006849289,136.684684753418 3155.88172674179,138.856437206268 PathPoint;PointKind.SMOOTHPOINT 3170.11440396309,137.888460159302 3175.04193663597,135.974929332733 3166.52078032494,139.28365945816 PathPoint;PointKind.SMOOTHPOINT 3184.22426462173,137.912299633026 3226.8187558651,137.9731965065 3179.48150753975,137.90545463562 PathPoint;PointKind.SMOOTHPOINT 3302.32615828514,137.597901821136 3367.18652129173,136.881537437439 3271.96237921715,137.933070659637 PathPoint;PointKind.SMOOTHPOINT 3416.32278442383,140.722997188568 3429.95817661285,141.846284866333 3402.6873922348,139.599945545197 PathPoint;PointKind.SMOOTHPOINT 3446.78735017776,138.639521598816 3463.90070915222,139.001834392548 3429.67426657677,138.277444839478 PathPoint;PointKind.SMOOTHPOINT 3475.2865755558,140.722997188568 3483.43625307083,141.117882728577 3467.13689804077,140.328347682953 PathPoint;PointKind.SMOOTHPOINT 3491.99293255806,140.722997188568 3505.69744348526,140.495223999023 3478.28842163086,140.951006412506 PathPoint;PointKind.SMOOTHPOINT 3513.61305356026,141.764853000641 3522.19258904457,141.589951515198 3505.03324270248,141.939754486084 PathPoint;PointKind.SMOOTHPOINT 3541.12947106361,141.764853000641 3545.23143410683,143.08168888092 3533.00402641296,139.156436920166 PathPoint;PointKind.SMOOTHPOINT 3560.78397631645,142.806708812714 3582.50378251076,143.449666500092 3539.06417012215,142.163751125336 PathPoint;PointKind.SMOOTHPOINT 3770.10525584221,142.806708812714 3809.00753974915,144.511585235596 3731.20297193527,141.101596355438 PathPoint;PointKind.SMOOTHPOINT 3844.79259610176,142.806708812714 3860.02487897873,143.628580570221 3829.56031322479,141.984601020813 PathPoint;PointKind.SMOOTHPOINT 3877.22277760506,143.848328590393 3896.86268806458,146.181764602661 3858.33133220673,141.603877544403 PathPoint;PointKind.SMOOTHPOINT 3941.10005736351,144.890184402466 3959.51483130455,144.784204959869 3922.68555879593,144.995927810669 PathPoint;PointKind.SMOOTHPOINT 3981.39215111732,145.931804180145 3993.01208496094,147.339985370636 3969.77194190025,144.523859024048 PathPoint;PointKind.SMOOTHPOINT 4045.26943087578,145.931804180145 4077.30417609215,146.326689720154 4013.23468565941,145.53715467453 PathPoint;PointKind.SMOOTHPOINT 4151.40414476395,145.931804180145 4209.95322346687,150.347063541412 4092.85506606102,141.516544818878 PathPoint;PointKind.SMOOTHPOINT 4238.86716127396,145.931804180145 4271.7462015152,146.831095218658 4205.98784565926,145.032513141632 PathPoint;PointKind.SMOOTHPOINT 4299.79629278183,148.015279769897 4321.87298297882,147.498600482941 4277.71932721138,148.532195091248 PathPoint;PointKind.SMOOTHPOINT 4352.86351203918,148.015279769897 4382.49892830849,147.527160644531 4323.22809576988,148.503634929657 PathPoint;PointKind.SMOOTHPOINT 4398.01732420921,149.05713558197 4414.49732422829,148.8902592659 4381.5375995636,149.224011898041 PathPoint;PointKind.SMOOTHPOINT 4419.63744521141,151.140611171722 4424.50246810913,152.188131809235 4410.489538908,149.171140193939 PathPoint;PointKind.SMOOTHPOINT 4430.49927592278,150.098991394043 4432.07523822784,150.011422634125 4428.24176430702,150.224089622498 PathPoint;PointKind.SMOOTHPOINT 4441.30933642387,151.182389259338 4442.79717922211,151.499147415161 4435.60690283775,149.968228340149 PathPoint;PointKind.SMOOTHPOINT 4445.24001717567,152.224009037018 4448.15787434578,152.697494029999 4443.23144316673,151.898281574249 PathPoint;PointKind.SMOOTHPOINT 4452.10204839706,154.265942573547 4453.60944271088,155.401031970978 4450.46440243721,153.0326628685 PathPoint;PointKind.SMOOTHPOINT 4455.99995970726,162.999923229218 4457.17993497849,168.67466211319 4455.5257666111,160.719122886658 PathPoint;PointKind.SMOOTHPOINT 4455.99995970726,180.000064373016 4456.6878426075,188.656861782074 4455.83335876465,177.902190685272 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,280.318930149078 4457.25566267967,298.073673248291 4456.81038379669,262.564187049866 PathPoint;PointKind.CORNERPOINT 4457.03288555145,423.03995847702 4457.03288555145,423.03995847702 4457.03288555145,423.03995847702 PathPoint;PointKind.CORNERPOINT 4458.01569342613,1855.46022891998 4458.01569342613,1855.46022891998 4458.01569342613,1855.46022891998 PathPoint;PointKind.SMOOTHPOINT 4456.05007767677,2025.26714801788 4456.65287017822,2047.33117103577 4455.44756054878,2003.20288896561 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,2394.050116539 4456.78560018539,2403.37371110916 4457.40133523941,2380.16138076782 PathPoint;PointKind.SMOOTHPOINT 4456.96817278862,2940.63425302505 4456.96927428246,2943.8646197319 4456.88583612442,2726.09079122543 PathPoint;PointKind.SMOOTHPOINT 4456.97175264359,2950.25029420853 4456.05778813362,2952.49946594238 4458.19716453552,2947.2344827652 PathPoint;PointKind.SMOOTHPOINT 4456.97450637817,2957.48781681061 4457.01223254204,3054.04287815094 4456.9736802578,2955.09088754654 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3128.49095821381 4456.99846386909,3139.7224187851 4457.04362511635,3124.99930143356 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3234.7505736351 4456.19217038155,3246.24662876129 4457.87360072136,3223.25451850891 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3313.92429828644 4456.85637116432,3336.5500831604 4457.20939993858,3291.29851341248 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3389.97269153595 4456.34197354317,3416.4236497879 4457.72379755974,3363.52196931839 PathPoint;PointKind.SMOOTHPOINT 4458.01569342613,3480.60588598251 4458.14622044563,3507.1545624733 4457.88516640663,3454.05720949173 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3570.197224617 4456.55676484108,3594.82104063034 4457.50900626183,3545.57340860367 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3673.33150863647 4456.8759226799,3683.22843074799 4457.33992695808,3653.9736199379 PathPoint;PointKind.SMOOTHPOINT 4456.91750407219,3743.24465990067 4456.92135930061,3746.02325677872 4456.8772995472,3713.88764619827 PathPoint;PointKind.SMOOTHPOINT 4456.92962050438,3751.52663469315 4455.57368159294,3754.24669504166 4458.28776240349,3748.80256175995 PathPoint;PointKind.SMOOTHPOINT 4456.94504141808,3760.50656318665 4456.98331832886,3781.6469836235 4456.93980932236,3757.56769895554 PathPoint;PointKind.SMOOTHPOINT 4457.03288555145,3804.59330320358 4457.03563928604,3809.26064729691 4457.02985644341,3799.52281236649 PathPoint;PointKind.SMOOTHPOINT 4457.00011610985,3818.00005674362 4456.05117917061,3821.19383811951 4458.06498527527,3814.41658258438 PathPoint;PointKind.SMOOTHPOINT 4450.15378117561,3825.42853116989 4447.7406835556,3827.47376918793 4452.49418020248,3823.44489812851 PathPoint;PointKind.SMOOTHPOINT 4439.34372067451,3833.76266956329 4429.35151934624,3837.67729997635 4442.61102676392,3832.48241901398 PathPoint;PointKind.SMOOTHPOINT 4358.7600839138,3837.9296207428 4323.82703304291,3838.09248447418 4393.69285941124,3837.76675701141 PathPoint;PointKind.SMOOTHPOINT 3311.17087841034,3836.88776493073 3272.21765041351,3836.80963754654 3372.04245686531,3837.01003074646 PathPoint;PointKind.SMOOTHPOINT 2397.1892952919,3836.77753686905 2394.88083958626,3836.7791891098 2767.875841856,3836.50491714478 PathPoint;PointKind.SMOOTHPOINT 2390.27962446213,3836.7827296257 2387.57242798805,3838.31860542297 2392.86345362663,3835.31695604324 PathPoint;PointKind.SMOOTHPOINT 2380.97172617912,3836.79004669189 2359.19546842575,3836.80727720261 2384.06444549561,3836.78745031357 PathPoint;PointKind.SMOOTHPOINT 2330.99997997284,3837.00011730194 2329.29266452789,3837.00176954269 2351.64582967758,3836.97840213776 PathPoint;PointKind.SMOOTHPOINT 2319.99991178513,3837.999958992 2317.39735722542,3838.84401798248 2324.31776762009,3836.60003900528 PathPoint;PointKind.SMOOTHPOINT 2305.99992513657,3839.00003671646 2304.05193328857,3838.03300380707 2306.40692710876,3839.20208215714 PathPoint;PointKind.SMOOTHPOINT 2299.15964841843,3836.86770200729 2138.43214631081,3837.04921245575 2301.31967782974,3836.86534166336 PathPoint;PointKind.SMOOTHPOINT 2005.12385487556,3837.9296207428 1957.29258656502,3839.76903676987 2019.54323530197,3837.37517595291 PathPoint;PointKind.SMOOTHPOINT 785.557315349579,3836.88776493073 750.589842796326,3837.01805591583 820.524787902832,3836.75770998001 PathPoint;PointKind.SMOOTHPOINT 620.458810329437,3836.88776493073 607.614015340805,3834.44221258163 633.303329944611,3839.33355331421 PathPoint;PointKind.SMOOTHPOINT 487.790211439133,3836.88776493073 470.155019760132,3837.96219348907 505.425678491592,3835.81357240677 PathPoint;PointKind.SMOOTHPOINT 389.517409801483,3835.84614515305 375.587918758392,3836.24268293381 413.678677082062,3835.15834093094 PathPoint;PointKind.SMOOTHPOINT 299.504435062408,3836.31585359573 297.429220676422,3836.32199048996 335.469310283661,3836.20987415314 PathPoint;PointKind.SMOOTHPOINT 293.000113964081,3837.00011730194 291.461327075958,3838.04150104523 296.05731010437,3834.930331707 PathPoint;PointKind.SMOOTHPOINT 287.805469036102,3836.35692358017 266.153129339218,3836.44661664963 289.626513719559,3836.34937047958 PathPoint;PointKind.SMOOTHPOINT 238.999929428101,3837.00011730194 215.598692893982,3838.0705332756 247.423052787781,3836.61490917206 PathPoint;PointKind.SMOOTHPOINT 194.999932050705,3836.00003957748 192.904890775681,3835.75409173965 199.709644317627,3836.5533041954 PathPoint;PointKind.SMOOTHPOINT 187.075234651566,3831.67895793915 185.193057060242,3830.57054042816 188.854973316193,3832.72742271423 PathPoint;PointKind.SMOOTHPOINT 180.196130275726,3830.63733816147 178.604471683502,3829.74465608597 182.287591695786,3831.81042909622 PathPoint;PointKind.SMOOTHPOINT 176.265174150467,3825.42853116989 173.858134746552,3823.82916212082 177.842788696289,3826.47675991058 PathPoint;PointKind.SMOOTHPOINT 166.999958753586,3818.99989843369 162.417744398117,3814.59101200104 168.996416330338,3820.92074632645 PathPoint;PointKind.SMOOTHPOINT 162.999883890152,3779.00009393692 162.668884992599,3763.43716621399 163.290127515793,3792.64972686768 PathPoint;PointKind.SMOOTHPOINT 162.506965398788,3380.59693336487 160.871797800064,3362.94392108917 164.142408370972,3398.24994564056 PathPoint;PointKind.SMOOTHPOINT 163.489773273468,3181.62088394165 163.383754491806,3178.13961267471 163.746972084045,3190.07280349731 PathPoint;PointKind.SMOOTHPOINT 164.037215709686,2993.5243678093 164.043273925781,2991.45741462708 163.737609386444,3093.13890695572 PathPoint;PointKind.SMOOTHPOINT 164.05566573143,2987.30533361435 163.667939901352,2985.2289390564 164.486900568008,2989.61540222168 PathPoint;PointKind.SMOOTHPOINT 164.074391126633,2980.95152378082 164.48166847229,2841.34945392609 164.068057537079,2983.07488918304 PathPoint;PointKind.SMOOTHPOINT 163.489773273468,2672.20012664795 161.2939453125,2660.20367860794 164.743273258209,2679.04866456985 PathPoint;PointKind.SMOOTHPOINT 164.472581148148,2289.87421274185 164.645240306854,2274.91506099701 164.299646615982,2304.8331284523 PathPoint;PointKind.SMOOTHPOINT 163.489773273468,1527.30586051941 163.723840713501,1511.98864459991 163.255430459976,1542.62284040451 PathPoint;PointKind.SMOOTHPOINT 164.00004029274,1261.00005626678 163.275532722473,1247.39692211151 164.855901002884,1277.07352638245 PathPoint;PointKind.SMOOTHPOINT 162.506965398788,1189.77549791336 162.815108299255,1181.81264162064 161.819908618927,1207.53024101257 PathPoint;PointKind.SMOOTHPOINT 163.071756362915,927.857809066772 163.073408603668,925.572052001953 162.964636087418,1060.47916173935 PathPoint;PointKind.SMOOTHPOINT 163.077263832092,920.990624427795 164.376751184464,919.720759391785 160.943945646286,923.074808120728 PathPoint;PointKind.SMOOTHPOINT 163.081394433975,915.534217357635 163.206689357758,755.828862190247 163.080017566681,917.35475063324 PathPoint;PointKind.SMOOTHPOINT 163.489773273468,577.220456600189 163.884383440018,563.890178203583 163.276083469391,584.434611797333 PathPoint;PointKind.SMOOTHPOINT 164.472581148148,458.459987640381 164.591542482376,438.23915719986 164.366837739944,476.408042907715 PathPoint;PointKind.SMOOTHPOINT 168.403261899948,359.492654800415 169.877336025238,339.406363964081 166.929187774658,379.579181671143 PathPoint;PointKind.SMOOTHPOINT 169.999877214432,317.999932765961 169.466203451157,305.242509841919 170.533550977707,330.757355690002 PathPoint;PointKind.SMOOTHPOINT 172.334218025208,287.611212730408 174.184452295303,277.010436058044 170.483983755112,298.211989402771 PathPoint";
	
	subshadow67[0] = "PointKind.SMOOTHPOINT 176.000108480453,164.000000953674 180.382952451706,157.330849170685 172.02178812027,170.053102970123 PathPoint;PointKind.SMOOTHPOINT 192.00013256073,141.999943256378 197.766177415848,136.511907577515 185.478462934494,148.206703662872 PathPoint;PointKind.SMOOTHPOINT 234.999973535538,129.000113010406 243.067314386368,128.368484973907 227.063159704208,129.621119499207 PathPoint;PointKind.SMOOTHPOINT 284.394261598587,128.501136302948 790.665336608887,129.610261917114 268.679799795151,128.466675281525 PathPoint;PointKind.CORNERPOINT 4430.14911985397,154.168932437897 4430.14911985397,154.168932437897 4430.14911985397,154.168932437897 PathPoint;PointKind.SMOOTHPOINT 4455,157 4457.11461017232,158.600480921306 4449.60857760263,152.919404532042 PathPoint;PointKind.SMOOTHPOINT 4458,165 4458.33982795861,166.932242078735 4457.66396429048,163.089320429789 PathPoint;PointKind.CORNERPOINT 4460,187 4460,187 4460,187 PathPoint;PointKind.CORNERPOINT 4460,3793 4460,3793 4460,3793 PathPoint;PointKind.SMOOTHPOINT 4456.99995970726,3819.99997615814 4446.91609352546,3832.85988816097 4458.84214397194,3817.65060785985 PathPoint;PointKind.CORNERPOINT 4421.18461227417,3831.03198766708 4421.18461227417,3831.03198766708 4421.18461227417,3831.03198766708 PathPoint;PointKind.SMOOTHPOINT 187.811702251434,3831.03198766708 183.958676815033,3829.93277549744 191.664452314377,3832.13143587112 PathPoint;PointKind.SMOOTHPOINT 167.999958753586,3819.99997615814 162.55775308609,3815.58424472809 176.608683824539,3826.98517799377 PathPoint;PointKind.SMOOTHPOINT 161,3773 159.80867991838,3743.89749084207 161,3773 PathPoint;PointKind.SMOOTHPOINT 159,3663 159.734982554106,3169.62303568248 158.898854287541,3730.89680147936 PathPoint;PointKind.SMOOTHPOINT 164,428 163.894256591797,476.168482780457 162.425689935684,1144.15454912186 PathPoint;PointKind.SMOOTHPOINT 171,187 171.386899709702,181.71542596817 170.44815158844,199.758131027222 PathPoint";
	
}


// 4x5

var negative45 = [];
var mask45 = [];
var shadow45 = [];
var subshadow45 = [];


negative45[0] = "PointKind.CORNERPOINT 227.399591803551,3780.51556634903 227.399591803551,3780.51556634903 227.399591803551,3780.51556634903 PathPoint;PointKind.SMOOTHPOINT 228.003544807434,3776.23815107346 233.22049498558,3775.89000034332 226.09373152256,3776.36560964584 PathPoint;PointKind.SMOOTHPOINT 241.823653578758,3775.08559513092 243.232778906822,3773.63516378403 239.983175396919,3776.97929906845 PathPoint;PointKind.SMOOTHPOINT 242.442358732224,3760.64029026031 242.658625245094,3754.80245161057 242.245270013809,3765.95035600662 PathPoint;PointKind.SMOOTHPOINT 242.442358732224,3745.58648872375 241.122041344643,3737.41214561462 243.003825545311,3749.06492757797 PathPoint;PointKind.SMOOTHPOINT 238.780875205994,3727.52584505081 238.891221284866,3714.6402554512 238.670234084129,3740.41143465042 PathPoint;PointKind.CORNERPOINT 238.17692220211,3571.55880260468 238.17692220211,3571.55880260468 238.17692220211,3571.55880260468 PathPoint;PointKind.SMOOTHPOINT 242.881382703781,3553.70610523224 243.767986893654,3542.9986410141 241.994483470917,3564.41356945038 PathPoint;PointKind.SMOOTHPOINT 242.277429699898,3324.49664640427 242.332307696342,3287.41965579987 242.22196161747,3361.57363700867 PathPoint;PointKind.SMOOTHPOINT 239.177117943764,2858.21329879761 239.382762908936,2819.35377645493 238.976193666458,2896.24056386948 PathPoint;PointKind.SMOOTHPOINT 239.257369637489,2461.6608839035 238.940198421478,2399.4544916153 239.574835896492,2523.86680412292 PathPoint;PointKind.SMOOTHPOINT 239.177117943764,1983.05040407181 238.87204349041,1920.71985769272 239.482487440109,2045.38142251968 PathPoint;PointKind.SMOOTHPOINT 239.177117943764,1584.97297096252 239.403710961342,1527.11126375198 238.950524926186,1642.83444213867 PathPoint;PointKind.SMOOTHPOINT 239.451507925987,1162.93332624435 239.173577427864,1227.5305109024 239.255599379539,1208.46200037003 PathPoint;PointKind.SMOOTHPOINT 241.069523692131,407.175274372101 240.918756723404,402.718236923218 244.419146776199,506.271009922028 PathPoint;PointKind.SMOOTHPOINT 237.54287481308,386.84327173233 238.471965193748,342.490048885345 237.224818468094,402.037985801697 PathPoint;PointKind.SMOOTHPOINT 238.033826351166,230.167654037476 238.126764893532,218.713849067688 237.716065049171,269.400818824768 PathPoint;PointKind.SMOOTHPOINT 241.673181653023,215.167196273804 241.713307499886,204.380424499512 241.643677353859,223.17725944519 PathPoint;PointKind.SMOOTHPOINT 241.069523692131,186.365807533264 241.215865015984,184.017029285431 240.706325769424,192.188067913055 PathPoint;PointKind.SMOOTHPOINT 227.178309559822,183.965809822083 226.929883360863,183.33748626709 227.841566205025,185.639293670654 PathPoint;PointKind.SMOOTHPOINT 226.883856654167,181.096103668213 230.165029764175,179.802635192871 226.360155344009,181.30263376236 PathPoint;PointKind.SMOOTHPOINT 551.868696212769,179.915695667267 553.294343948364,180.135679721832 545.967836380005,179.004602909088 PathPoint;PointKind.SMOOTHPOINT 555.879510641098,222.786858558655 557.157931923866,230.347748279572 553.642789721489,209.556186676025 PathPoint;PointKind.SMOOTHPOINT 566.833571791649,236.461275100708 575.911454558372,238.698173046112 557.755689024925,234.224377155304 PathPoint;PointKind.SMOOTHPOINT 845.375989079475,236.461275100708 858.83053958416,235.766389846802 831.921438574791,237.156160354614 PathPoint;PointKind.SMOOTHPOINT 1166.16915285587,236.461275100708 1203.98245275021,236.110764026642 1128.35555791855,236.812022209167 PathPoint;PointKind.SMOOTHPOINT 1414.97949779034,239.500217914581 1462.87884235382,241.232474327087 1367.07985818386,237.767489433289 PathPoint;PointKind.SMOOTHPOINT 1651.27057850361,239.500217914581 1688.81538927555,240.27087020874 1613.72635781765,238.729093551636 PathPoint;PointKind.SMOOTHPOINT 2087.86251068115,241.019335269928 2135.32784700394,241.766856193542 2040.39717435837,240.272050380707 PathPoint;PointKind.SMOOTHPOINT 2325.71908950806,241.019335269928 2369.8654872179,241.725078105927 2281.57269179821,240.313592433929 PathPoint;PointKind.SMOOTHPOINT 2806.12608611584,241.019335269928 2883.08539509773,240.621145248413 2729.16707217693,241.417525291443 PathPoint;PointKind.SMOOTHPOINT 3248.97735536098,237.980864524841 3336.5599822998,237.718866348267 3161.39472842216,238.242390632629 PathPoint;PointKind.SMOOTHPOINT 4014.18640136719,233.422332286835 4128.97671282291,233.843417644501 3899.39608991146,233.001718997955 PathPoint;PointKind.SMOOTHPOINT 4460.16660153866,234.941921710968 4570.26071369648,235.018632888794 4351.51259422302,234.866154670715 PathPoint;PointKind.CORNERPOINT 4723.06082367897,233.422332286835 4723.06082367897,233.422332286835 4723.06082367897,233.422332286835 PathPoint;PointKind.SMOOTHPOINT 4723.06082367897,236.461275100708 4722.90415585041,237.020440578461 4723.71847450733,234.114149093628 PathPoint;PointKind.SMOOTHPOINT 4715.63370645046,237.225790500641 4715.11413574219,237.271109104156 4719.31525290012,236.904547691345 PathPoint;PointKind.SMOOTHPOINT 4715.23657858372,241.019335269928 4715.50093710423,259.09555721283 4715.18465101719,237.469850063324 PathPoint;PointKind.CORNERPOINT 4715.23657858372,292.678530693054 4715.23657858372,292.678530693054 4715.23657858372,292.678530693054 PathPoint;PointKind.SMOOTHPOINT 4715.23657858372,567.307851791382 4715.65878510475,626.462319374084 4714.81437206268,508.153384208679 PathPoint;PointKind.SMOOTHPOINT 4718.36639463902,1197.85060214996 4718.51362109184,1267.90159749985 4718.21916818619,1127.79937076569 PathPoint;PointKind.SMOOTHPOINT 4716.80178165436,1749.38532400131 4718.07961285114,1828.1374912262 4715.52336037159,1670.63315677643 PathPoint;PointKind.SMOOTHPOINT 4719.93130266666,2414.87391042709 4720.09062588215,2489.5957903862 4719.77197945118,2340.1515583992 PathPoint;PointKind.SMOOTHPOINT 4715.8334505558,3441.05515050888 4714.41576898098,3521.84287834167 4717.25113213062,3360.26742267609 PathPoint;PointKind.SMOOTHPOINT 4714.26854252815,3723.26070356369 4714.2632317543,3723.96054553986 4714.33994293213,3714.08911514282 PathPoint;PointKind.SMOOTHPOINT 4720.52817463875,3723.26070356369 4721.08433067799,3722.80256080627 4720.3358066082,3723.41931867599 PathPoint;PointKind.CORNERPOINT 4720.52817463875,3726.29964637756 4720.52817463875,3726.29964637756 4720.52817463875,3726.29964637756 PathPoint;PointKind.SMOOTHPOINT 4436.69416129589,3722.66070413589 4429.3971580267,3722.63308811188 4453.96243751049,3722.72679376602 PathPoint;PointKind.SMOOTHPOINT 4248.49361300468,3720.18611955643 4290.58946192265,3719.96047067642 4206.39805912971,3720.41153240204 PathPoint;PointKind.SMOOTHPOINT 3935.94395041466,3716.58329057693 3923.35594117641,3716.69894742966 3957.95415759087,3716.38171720505 PathPoint;PointKind.SMOOTHPOINT 3089.16702389717,3717.62373018265 3112.5633430481,3717.5618891716 3032.17681467533,3717.77408409119 PathPoint;PointKind.SMOOTHPOINT 2225.80779612064,3718.59760808945 2246.50594711304,3718.32262802124 2173.68284583092,3719.29013299942 PathPoint;PointKind.SMOOTHPOINT 1704.97990965843,3719.03993654251 1734.32429552078,3718.72247028351 1657.36970722675,3719.55401945114 PathPoint;PointKind.SMOOTHPOINT 1014.4306075573,3720.17856645584 1084.85264897346,3719.96519136429 944.008566141129,3720.39241361618 PathPoint;PointKind.SMOOTHPOINT 651.335064768791,3721.14135074615 613.834215402603,3722.41097974777 654.759923815727,3721.02522182465 PathPoint;PointKind.SMOOTHPOINT 583.068607449532,3728.31561613083 566.727356314659,3733.95424175262 603.18050801754,3721.37644100189 PathPoint;PointKind.SMOOTHPOINT 566.833571791649,3746.97083044052 566.793445944786,3757.35138702393 566.848028898239,3743.20915031433 PathPoint;PointKind.CORNERPOINT 566.268564462662,3779.31580352783 566.268564462662,3779.31580352783 566.268564462662,3779.31580352783 PathPoint";

negative45[1] = "PointKind.CORNERPOINT 227.399665117264,3780.51567077637 227.399665117264,3780.51567077637 227.399665117264,3780.51567077637 PathPoint;PointKind.SMOOTHPOINT 226.999881863594,3776.00009679794 233.482271432877,3776.05650901794 226.38678252697,3775.9946680069 PathPoint;PointKind.SMOOTHPOINT 241.999867558479,3776.00009679794 242.508521676064,3773.57224702835 241.954135894775,3776.21937274933 PathPoint;PointKind.SMOOTHPOINT 242.442432045937,3760.64039468765 242.658698558807,3754.8025560379 242.245343327522,3765.95046043396 PathPoint;PointKind.SMOOTHPOINT 242.442432045937,3745.58659315109 241.122114658356,3737.41225004196 243.003898859024,3749.06503200531 PathPoint;PointKind.SMOOTHPOINT 238.780948519707,3727.52594947815 238.891294598579,3714.64035987854 238.670307397842,3740.41153907776 PathPoint;PointKind.CORNERPOINT 238.176995515823,3571.55890703201 238.176995515823,3571.55890703201 238.176995515823,3571.55890703201 PathPoint;PointKind.SMOOTHPOINT 242.881456017494,3553.70620965958 243.768060207367,3542.99874544144 241.99455678463,3564.41367387772 PathPoint;PointKind.SMOOTHPOINT 242.277503013611,3324.4967508316 242.332381010056,3287.4197602272 242.222034931183,3361.573741436 PathPoint;PointKind.SMOOTHPOINT 239.177191257477,2858.21340322495 239.247706532478,2844.9057841301 238.976266980171,2896.24066829681 PathPoint;PointKind.SMOOTHPOINT 239.363658428192,2747.6792049408 239.36513364315,2746.26583099365 239.31645154953,2801.50283575058 PathPoint;PointKind.SMOOTHPOINT 239.367493987083,2743.41760396957 240.341430902481,2742.22987890244 238.462302088737,2744.52153682709 PathPoint;PointKind.SMOOTHPOINT 239.371624588966,2738.43538999557 239.4551217556,2636.05429172516 239.370149374008,2740.10486125946 PathPoint;PointKind.SMOOTHPOINT 239.257442951202,2461.66098833084 238.940271735191,2399.45459604263 239.460137486458,2501.3577246666 PathPoint;PointKind.SMOOTHPOINT 239.177191257477,1983.05050849915 238.872116804123,1920.71996212006 239.482560753822,2045.38152694702 PathPoint;PointKind.SMOOTHPOINT 239.177191257477,1584.97307538986 239.403784275055,1527.11136817932 238.950598239899,1642.83454656601 PathPoint;PointKind.SMOOTHPOINT 239.4515812397,1162.93343067169 239.173650741577,1227.53061532974 239.255672693253,1208.46210479736 PathPoint;PointKind.SMOOTHPOINT 241.069597005844,407.175378799438 240.918830037117,402.718341350555 244.419220089912,506.271114349365 PathPoint;PointKind.SMOOTHPOINT 237.542948126793,386.843376159668 238.472038507462,342.490153312683 237.224891781807,402.038090229034 PathPoint;PointKind.SMOOTHPOINT 238.033899664879,230.167758464813 238.126838207245,218.713953495026 237.716138362885,269.400923252106 PathPoint;PointKind.SMOOTHPOINT 241.673254966736,215.167300701141 241.713380813599,204.380528926849 241.643750667572,223.177363872528 PathPoint;PointKind.SMOOTHPOINT 240.999966859818,184.999980926514 240.983149409294,184.051122665405 241.103821992874,190.832626819611 PathPoint;PointKind.SMOOTHPOINT 226.999881863594,183.999903202057 226.709559559822,183.389990329742 227.288138866425,184.603915214539 PathPoint;PointKind.SMOOTHPOINT 226.88392996788,181.096208095551 228.203067183495,180.576224327087 226.360228657722,181.302738189697 PathPoint;PointKind.SMOOTHPOINT 341.927388310432,179.855375289917 343.698826432228,179.847350120544 280.031204223633,180.136256217957 PathPoint;PointKind.SMOOTHPOINT 347.265896201134,179.831535816193 350.266483426094,181.123824119568 345.624276995659,179.124848842621 PathPoint;PointKind.SMOOTHPOINT 355.950781702995,179.794950485229 445.201286673546,179.432165622711 353.03929746151,179.806752204895 PathPoint;PointKind.SMOOTHPOINT 551.868769526482,179.915800094604 553.294417262077,180.13578414917 548.517376184464,179.398412704468 PathPoint;PointKind.SMOOTHPOINT 555.879583954811,222.786962985992 557.158005237579,230.347852706909 553.642863035202,209.556291103363 PathPoint;PointKind.SMOOTHPOINT 566.833645105362,236.461379528046 575.911527872086,238.69827747345 557.755762338638,234.224481582642 PathPoint;PointKind.SMOOTHPOINT 845.376062393188,236.461379528046 858.830612897873,235.766494274139 831.921511888504,237.156264781952 PathPoint;PointKind.SMOOTHPOINT 1166.16922616959,236.461379528046 1203.98252606392,236.110868453979 1128.35563123226,236.812126636505 PathPoint;PointKind.SMOOTHPOINT 1414.97957110405,239.500322341919 1462.87891566753,241.232578754425 1367.07993149757,237.767593860626 PathPoint;PointKind.SMOOTHPOINT 1651.27065181732,239.500322341919 1688.81546258926,240.270974636078 1613.72643113136,238.729197978973 PathPoint;PointKind.SMOOTHPOINT 2087.86258399487,241.019439697266 2112.97457814217,241.415033340454 2040.39724767208,240.272154808044 PathPoint;PointKind.SMOOTHPOINT 2216.39717817307,241.003389358521 2218.26480031013,240.996544361115 2165.73505103588,241.194341182709 PathPoint;PointKind.SMOOTHPOINT 2221.98971807957,240.982618331909 2224.18188750744,241.645874977112 2220.20913362503,240.443751811981 PathPoint;PointKind.SMOOTHPOINT 2227.66014933586,240.961611270905 2268.59824955463,240.812437534332 2225.77570974827,240.968456268311 PathPoint;PointKind.SMOOTHPOINT 2325.71916282177,241.019439697266 2369.86556053162,241.725182533264 2306.66676163673,240.714955329895 PathPoint;PointKind.SMOOTHPOINT 2806.12615942955,241.019439697266 2883.08546841145,240.621249675751 2729.16714549065,241.417629718781 PathPoint;PointKind.SMOOTHPOINT 3248.9774286747,237.980968952179 3336.56005561352,237.718970775604 3161.39480173588,238.242495059967 PathPoint;PointKind.SMOOTHPOINT 4014.1864746809,233.422436714172 4128.97678613663,233.843522071838 3899.39616322517,233.001823425293 PathPoint;PointKind.SMOOTHPOINT 4460.16667485237,234.942026138306 4570.26078701019,235.018737316132 4351.51266753674,234.866259098053 PathPoint;PointKind.CORNERPOINT 4723.06089699268,233.422436714172 4723.06089699268,233.422436714172 4723.06089699268,233.422436714172 PathPoint;PointKind.SMOOTHPOINT 4723.06089699268,236.461379528046 4722.90688455105,237.021253108978 4723.09659719467,236.331324577332 PathPoint;PointKind.SMOOTHPOINT 4715.63377976418,237.225894927979 4715.1142090559,237.271213531494 4719.31532621384,236.904652118683 PathPoint;PointKind.SMOOTHPOINT 4715.23665189743,241.019439697266 4715.50101041794,259.095661640167 4715.1847243309,237.469954490662 PathPoint;PointKind.CORNERPOINT 4715.23665189743,292.678635120392 4715.23665189743,292.678635120392 4715.23665189743,292.678635120392 PathPoint;PointKind.SMOOTHPOINT 4715.23665189743,567.307956218719 4715.5092716217,605.506346225739 4714.8144453764,508.153488636017 PathPoint;PointKind.SMOOTHPOINT 4717.50376224518,999.855144023895 4717.51231849194,1001.61666870117 4716.67351126671,828.084890842438 PathPoint;PointKind.SMOOTHPOINT 4717.52913594246,1005.12343168259 4717.01192557812,1007.20501899719 4717.95134246349,1003.42445611954 PathPoint;PointKind.SMOOTHPOINT 4717.55214929581,1009.91020917892 4717.98438727856,1099.67102050781 4717.54477322102,1008.31933736801 PathPoint;PointKind.SMOOTHPOINT 4718.36646795273,1197.8507065773 4718.51369440556,1267.90170192719 4718.31631064415,1173.92224788666 PathPoint;PointKind.SMOOTHPOINT 4716.80185496807,1749.38542842865 4717.23763346672,1776.24330997467 4715.5234336853,1670.63326120377 PathPoint;PointKind.SMOOTHPOINT 4718.1767553091,1946.60443782806 4718.18472146988,1948.25856685638 4717.721799016,1853.49335432053 PathPoint;PointKind.SMOOTHPOINT 4718.20094883442,1951.5816950798 4717.7607446909,1953.47280263901 4718.57801377773,1949.96108293533 PathPoint;PointKind.SMOOTHPOINT 4718.23015809059,1957.66028881073 4719.08666789532,2136.16719961166 4718.22042167187,1955.62732458115 PathPoint;PointKind.SMOOTHPOINT 4719.93137598038,2414.87401485443 4720.09069919586,2489.59589481354 4719.8284059763,2366.63708209991 PathPoint;PointKind.SMOOTHPOINT 4715.83352386951,3441.05525493622 4714.41584229469,3521.84298276901 4717.25120544434,3360.26752710342 PathPoint;PointKind.SMOOTHPOINT 4714.00012671947,3722.99998998642 4713.99334073067,3723.12225580215 4714.44092094898,3715.02226352692 PathPoint;PointKind.SMOOTHPOINT 4720.52824795246,3723.26080799103 4720.71796059608,3723.67056369781 4720.42350769043,3723.03468704224 PathPoint;PointKind.CORNERPOINT 4720.52824795246,3726.2997508049 4720.52824795246,3726.2997508049 4720.52824795246,3726.2997508049 PathPoint;PointKind.SMOOTHPOINT 4436.6942346096,3722.66080856323 4429.39723134041,3722.63319253922 4453.9625108242,3722.72689819336 PathPoint;PointKind.SMOOTHPOINT 4248.4936863184,3720.18622398376 4290.58953523636,3719.96057510376 4206.39813244343,3720.41163682938 PathPoint;PointKind.SMOOTHPOINT 3935.94402372837,3716.58339500427 3923.35601449013,3716.69905185699 3957.95423090458,3716.38182163239 PathPoint;PointKind.SMOOTHPOINT 3089.16709721088,3717.62383460999 3108.91963541508,3717.57167100906 3032.17688798904,3717.77418851852 PathPoint;PointKind.SMOOTHPOINT 2266.19069874287,3718.76104831696 2263.63267600536,3718.76057624817 2442.79753267765,3718.79527330399 PathPoint;PointKind.SMOOTHPOINT 2258.82849097252,3718.75868797302 2256.78590834141,3719.2959022522 2262.17604875565,3717.87851572037 PathPoint;PointKind.SMOOTHPOINT 2252.75237560272,3718.75538349152 2229.39706742764,3718.73886108398 2254.6902179718,3718.75656366348 PathPoint;PointKind.SMOOTHPOINT 2225.80786943436,3718.59771251678 2246.50602042675,3718.32273244858 2218.90002787113,3718.68952989578 PathPoint;PointKind.SMOOTHPOINT 1704.97998297215,3719.04004096985 1734.3243688345,3718.72257471085 1657.36978054047,3719.55412387848 PathPoint;PointKind.SMOOTHPOINT 1014.43068087101,3720.17867088318 1084.85272228718,3719.96529579163 944.008639454842,3720.39251804352 PathPoint;PointKind.SMOOTHPOINT 651.335138082504,3721.14145517349 613.834288716316,3722.41108417511 654.75999712944,3721.02532625198 PathPoint;PointKind.SMOOTHPOINT 583.068680763245,3728.31572055817 566.727429628372,3733.95434617996 603.180581331253,3721.37654542923 PathPoint;PointKind.SMOOTHPOINT 566.833645105362,3746.97093486786 566.793519258499,3757.35149145126 566.848102211952,3743.20925474167 PathPoint;PointKind.CORNERPOINT 566.268637776375,3779.31590795517 566.268637776375,3779.31590795517 566.268637776375,3779.31590795517 PathPoint";

negative45[2] = "PointKind.CORNERPOINT 227.399665117264,3780.51567077637 227.399665117264,3780.51567077637 227.399665117264,3780.51567077637 PathPoint;PointKind.SMOOTHPOINT 226.999881863594,3776.00009679794 233.482271432877,3776.05650901794 226.38678252697,3775.9946680069 PathPoint;PointKind.SMOOTHPOINT 241.999867558479,3776.00009679794 242.508521676064,3773.57224702835 241.954135894775,3776.21937274933 PathPoint;PointKind.SMOOTHPOINT 242.442432045937,3760.64039468765 242.658698558807,3754.8025560379 242.245343327522,3765.95046043396 PathPoint;PointKind.SMOOTHPOINT 242.442432045937,3745.58659315109 241.122114658356,3737.41225004196 243.003898859024,3749.06503200531 PathPoint;PointKind.SMOOTHPOINT 238.780948519707,3727.52594947815 238.891294598579,3714.64035987854 238.670307397842,3740.41153907776 PathPoint;PointKind.CORNERPOINT 238.176995515823,3571.55890703201 238.176995515823,3571.55890703201 238.176995515823,3571.55890703201 PathPoint;PointKind.SMOOTHPOINT 242.881456017494,3553.70620965958 243.768060207367,3542.99874544144 241.99455678463,3564.41367387772 PathPoint;PointKind.SMOOTHPOINT 242.277503013611,3324.4967508316 242.332381010056,3287.4197602272 242.222034931183,3361.573741436 PathPoint;PointKind.SMOOTHPOINT 239.177191257477,2858.21340322495 239.247706532478,2844.9057841301 238.976266980171,2896.24066829681 PathPoint;PointKind.SMOOTHPOINT 239.363658428192,2747.6792049408 239.36513364315,2746.26583099365 239.31645154953,2801.50283575058 PathPoint;PointKind.SMOOTHPOINT 239.367493987083,2743.41760396957 240.341430902481,2742.22987890244 238.462302088737,2744.52153682709 PathPoint;PointKind.SMOOTHPOINT 239.371624588966,2738.43538999557 239.4551217556,2636.05429172516 239.370149374008,2740.10486125946 PathPoint;PointKind.SMOOTHPOINT 239.257442951202,2461.66098833084 238.940271735191,2399.45459604263 239.460137486458,2501.3577246666 PathPoint;PointKind.SMOOTHPOINT 239.177191257477,1983.05050849915 238.872116804123,1920.71996212006 239.482560753822,2045.38152694702 PathPoint;PointKind.SMOOTHPOINT 239.177191257477,1584.97307538986 239.403784275055,1527.11136817932 238.950598239899,1642.83454656601 PathPoint;PointKind.SMOOTHPOINT 239.4515812397,1162.93343067169 239.173650741577,1227.53061532974 239.255672693253,1208.46210479736 PathPoint;PointKind.SMOOTHPOINT 241.069597005844,407.175378799438 240.918830037117,402.718341350555 244.419220089912,506.271114349365 PathPoint;PointKind.SMOOTHPOINT 237.542948126793,386.843376159668 238.472038507462,342.490153312683 237.224891781807,402.038090229034 PathPoint;PointKind.SMOOTHPOINT 238.033899664879,230.167758464813 238.126838207245,218.713953495026 237.716138362885,269.400923252106 PathPoint;PointKind.SMOOTHPOINT 241.673254966736,215.167300701141 241.713380813599,204.380528926849 241.643750667572,223.177363872528 PathPoint;PointKind.SMOOTHPOINT 240.999966859818,184.999980926514 240.983149409294,184.051122665405 241.103821992874,190.832626819611 PathPoint;PointKind.SMOOTHPOINT 226.999881863594,183.999903202057 226.709559559822,183.389990329742 227.288138866425,184.603915214539 PathPoint;PointKind.SMOOTHPOINT 226.88392996788,181.096208095551 228.203067183495,180.576224327087 226.360228657722,181.302738189697 PathPoint;PointKind.SMOOTHPOINT 393.927535414696,180.85521697998 395.698973536491,180.847191810608 332.031056284904,181.136333942413 PathPoint;PointKind.SMOOTHPOINT 399.265748262405,180.831613540649 402.266630530357,182.123665809631 397.624424099922,180.124690532684 PathPoint;PointKind.SMOOTHPOINT 407.950633764267,180.795028209686 497.201433777809,180.432243347168 405.039444565773,180.806829929352 PathPoint;PointKind.SMOOTHPOINT 551.868769526482,179.915800094604 553.294417262077,180.13578414917 548.517376184464,179.398412704468 PathPoint;PointKind.SMOOTHPOINT 555.879583954811,222.786962985992 557.158005237579,230.347852706909 553.642863035202,209.556291103363 PathPoint;PointKind.SMOOTHPOINT 572.000142931938,237.00001001358 581.078025698662,239.236907958984 562.922260165215,234.763112068176 PathPoint;PointKind.SMOOTHPOINT 845.376062393188,236.461379528046 858.830612897873,235.766494274139 831.921511888504,237.156264781952 PathPoint;PointKind.SMOOTHPOINT 1166.16922616959,236.461379528046 1203.98252606392,236.110868453979 1128.35563123226,236.812126636505 PathPoint;PointKind.SMOOTHPOINT 1414.97957110405,239.500322341919 1462.87891566753,241.232578754425 1367.07993149757,237.767593860626 PathPoint;PointKind.SMOOTHPOINT 1651.27065181732,239.500322341919 1688.81546258926,240.270974636078 1613.72643113136,238.729197978973 PathPoint;PointKind.SMOOTHPOINT 2087.86258399487,241.019439697266 2112.97457814217,241.415033340454 2040.39724767208,240.272154808044 PathPoint;PointKind.SMOOTHPOINT 2216.39717817307,241.003389358521 2218.26480031013,240.996544361115 2165.73505103588,241.194341182709 PathPoint;PointKind.SMOOTHPOINT 2221.98971807957,240.982618331909 2224.18188750744,241.645874977112 2220.20913362503,240.443751811981 PathPoint;PointKind.SMOOTHPOINT 2227.66014933586,240.961611270905 2268.59824955463,240.812437534332 2225.77570974827,240.968456268311 PathPoint;PointKind.SMOOTHPOINT 2325.71916282177,241.019439697266 2369.86556053162,241.725182533264 2306.66676163673,240.714955329895 PathPoint;PointKind.SMOOTHPOINT 2806.12615942955,241.019439697266 2883.08546841145,240.621249675751 2729.16714549065,241.417629718781 PathPoint;PointKind.SMOOTHPOINT 3248.9774286747,237.980968952179 3276.70969963074,237.898120880127 3161.39480173588,238.242495059967 PathPoint;PointKind.SMOOTHPOINT 3445.8121150732,236.696705818176 3450.65229535103,236.66200876236 3352.09200382233,237.368459701538 PathPoint;PointKind.SMOOTHPOINT 3460.47575175762,236.59143447876 3462.64490783215,236.244699954987 3456.20736479759,237.273809909821 PathPoint;PointKind.SMOOTHPOINT 3467.0923858881,236.543991565704 3667.72132515907,235.103709697723 3464.87808823586,236.559805870056 PathPoint;PointKind.SMOOTHPOINT 4014.1864746809,233.422436714172 4128.97678613663,233.843522071838 3938.45660984516,233.144860267639 PathPoint;PointKind.SMOOTHPOINT 4460.16667485237,234.942026138306 4570.26078701019,235.018737316132 4351.51266753674,234.866259098053 PathPoint;PointKind.CORNERPOINT 4723.06089699268,233.422436714172 4723.06089699268,233.422436714172 4723.06089699268,233.422436714172 PathPoint;PointKind.SMOOTHPOINT 4723.06089699268,236.461379528046 4722.90688455105,237.021253108978 4723.09659719467,236.331324577332 PathPoint;PointKind.SMOOTHPOINT 4715.63377976418,237.225894927979 4715.1142090559,237.271213531494 4719.31532621384,236.904652118683 PathPoint;PointKind.SMOOTHPOINT 4715.23665189743,241.019439697266 4715.50101041794,259.095661640167 4715.1847243309,237.469954490662 PathPoint;PointKind.CORNERPOINT 4715.23665189743,292.678635120392 4715.23665189743,292.678635120392 4715.23665189743,292.678635120392 PathPoint;PointKind.SMOOTHPOINT 4715.23665189743,567.307956218719 4715.5092716217,605.506346225739 4714.8144453764,508.153488636017 PathPoint;PointKind.SMOOTHPOINT 4717.50376224518,999.855144023895 4717.51231849194,1001.61666870117 4716.67351126671,828.084890842438 PathPoint;PointKind.SMOOTHPOINT 4717.52913594246,1005.12343168259 4717.01192557812,1007.20501899719 4717.95134246349,1003.42445611954 PathPoint;PointKind.SMOOTHPOINT 4717.55214929581,1009.91020917892 4717.98438727856,1099.67102050781 4717.54477322102,1008.31933736801 PathPoint;PointKind.SMOOTHPOINT 4718.36646795273,1197.8507065773 4718.51369440556,1267.90170192719 4718.31631064415,1173.92224788666 PathPoint;PointKind.SMOOTHPOINT 4716.80185496807,1749.38542842865 4717.23763346672,1776.24330997467 4715.5234336853,1670.63326120377 PathPoint;PointKind.SMOOTHPOINT 4718.1767553091,1946.60443782806 4718.18472146988,1948.25856685638 4717.721799016,1853.49335432053 PathPoint;PointKind.SMOOTHPOINT 4718.20094883442,1951.5816950798 4717.7607446909,1953.47280263901 4718.57801377773,1949.96108293533 PathPoint;PointKind.SMOOTHPOINT 4718.23015809059,1957.66028881073 4719.08666789532,2136.16719961166 4718.22042167187,1955.62732458115 PathPoint;PointKind.SMOOTHPOINT 4719.93137598038,2414.87401485443 4719.94701325893,2422.23639965057 4719.8284059763,2366.63708209991 PathPoint;PointKind.SMOOTHPOINT 4719.8953807354,2458.62582206726 4719.89006996155,2461.58852577209 4719.93373632431,2437.32584238052 PathPoint;PointKind.SMOOTHPOINT 4718.99992525578,2467.99992799759 4718.33519339561,2470.84414243698 4719.72809135914,2464.88498210907 PathPoint;PointKind.SMOOTHPOINT 4719.86056566238,2476.45090341568 4719.40767467022,2693.56100320816 4719.86676156521,2473.50519418716 PathPoint;PointKind.SMOOTHPOINT 4715.83352386951,3441.05525493622 4714.41584229469,3521.84298276901 4717.07535982132,3370.29474020004 PathPoint;PointKind.SMOOTHPOINT 4714.00012671947,3722.99998998642 4713.99334073067,3723.12225580215 4714.44092094898,3715.02226352692 PathPoint;PointKind.SMOOTHPOINT 4720.52824795246,3723.26080799103 4720.71796059608,3723.67056369781 4720.42350769043,3723.03468704224 PathPoint;PointKind.CORNERPOINT 4720.52824795246,3726.2997508049 4720.52824795246,3726.2997508049 4720.52824795246,3726.2997508049 PathPoint;PointKind.SMOOTHPOINT 4436.6942346096,3722.66080856323 4429.39723134041,3722.63319253922 4453.9625108242,3722.72689819336 PathPoint;PointKind.SMOOTHPOINT 4248.4936863184,3720.18622398376 4290.58953523636,3719.96057510376 4206.39813244343,3720.41163682938 PathPoint;PointKind.SMOOTHPOINT 3935.94402372837,3716.58339500427 3923.35601449013,3716.69905185699 3957.95423090458,3716.38182163239 PathPoint;PointKind.SMOOTHPOINT 3089.16709721088,3717.62383460999 3108.91963541508,3717.57167100906 3032.17688798904,3717.77418851852 PathPoint;PointKind.SMOOTHPOINT 2266.19069874287,3718.76104831696 2263.63267600536,3718.76057624817 2442.79753267765,3718.79527330399 PathPoint;PointKind.SMOOTHPOINT 2258.82849097252,3718.75868797302 2256.78590834141,3719.2959022522 2262.17604875565,3717.87851572037 PathPoint;PointKind.SMOOTHPOINT 2252.75237560272,3718.75538349152 2229.39706742764,3718.73886108398 2254.6902179718,3718.75656366348 PathPoint;PointKind.SMOOTHPOINT 2225.80786943436,3718.59771251678 2246.50602042675,3718.32273244858 2218.90002787113,3718.68952989578 PathPoint;PointKind.SMOOTHPOINT 1704.97998297215,3719.04004096985 1734.3243688345,3718.72257471085 1657.36978054047,3719.55412387848 PathPoint;PointKind.SMOOTHPOINT 1014.43068087101,3720.17867088318 1084.85272228718,3719.96529579163 944.008639454842,3720.39251804352 PathPoint;PointKind.SMOOTHPOINT 651.335138082504,3721.14145517349 613.834288716316,3722.41108417511 654.75999712944,3721.02532625198 PathPoint;PointKind.SMOOTHPOINT 585.000032186508,3727.99990653992 568.658781051636,3733.63853216171 605.111932754517,3721.06073141098 PathPoint;PointKind.SMOOTHPOINT 566.833645105362,3746.97093486786 566.793519258499,3757.35149145126 566.848102211952,3743.20925474167 PathPoint;PointKind.CORNERPOINT 566.268637776375,3779.31590795517 566.268637776375,3779.31590795517 566.268637776375,3779.31590795517 PathPoint;PointKind.SMOOTHPOINT 403.845110535622,3779.89088773727 401.72139108181,3779.89844083786 486.162105202675,3779.59962129593 PathPoint;PointKind.SMOOTHPOINT 397.47100174427,3779.91354703903 394.725331664085,3781.07743263245 399.427726864815,3779.08412218094 PathPoint;PointKind.SMOOTHPOINT 388.34148645401,3779.94588375092 306.547603011131,3780.23549795151 391.382494568825,3779.93502616882 PathPoint";

if (mask_variant_45 == 2) {
	
	mask45[0] = "PointKind.SMOOTHPOINT 217.830511187396,256.832538989897 217.607960813365,253.656465966435 217.936361892305,258.341860867293 PathPoint;PointKind.SMOOTHPOINT 225.367022733819,244.805215468391 228.727269487972,241.676621113258 220.562984093326,249.278432971072 PathPoint;PointKind.SMOOTHPOINT 234.585128626675,231.385825952809 243.624661539746,225.935547433468 229.870227421894,234.228639615323 PathPoint;PointKind.SMOOTHPOINT 259.570288320662,226.996625773215 262.086954803289,227.04728483081 252.887912794733,226.862367912056 PathPoint;PointKind.SMOOTHPOINT 428.51710302706,225.071808755277 450.999968678736,224.510242879159 352.515124041891,226.970273976439 PathPoint;PointKind.SMOOTHPOINT 495.012457207416,223.897563604123 498.893454243889,223.854628349032 473.614194761989,224.134048263119 PathPoint;PointKind.SMOOTHPOINT 508.021538162173,226.034330849577 508.87156916918,226.05545772113 500.99961937784,225.858273586635 PathPoint;PointKind.SMOOTHPOINT 513.243994963065,225.210155688349 516.807733100062,224.589071098825 510.627635295761,225.666087206702 PathPoint;PointKind.SMOOTHPOINT 528.608767228719,223.845087181234 557.378754250601,223.847813229176 521.967735052906,223.844405669248 PathPoint;PointKind.SMOOTHPOINT 614.358687168672,224.109286660977 630.037199750813,224.629053135312 604.617783379865,223.786477150474 PathPoint;PointKind.SMOOTHPOINT 1061.49464227559,224.617240260895 1106.80284898984,224.597249242652 812.125335489291,224.727190861235 PathPoint;PointKind.SMOOTHPOINT 1203.48735199749,224.537957699906 1207.97852996725,224.535004481302 1154.33186800041,224.570443104552 PathPoint;PointKind.SMOOTHPOINT 1217.00105639587,224.528870873432 1219.01515194162,223.71514556265 1212.88372786866,226.192214459569 PathPoint;PointKind.SMOOTHPOINT 1223.55676293421,224.524327460195 1246.31143912176,224.508879855188 1221.36849753052,224.525917654828 PathPoint;PointKind.SMOOTHPOINT 1292.74031451789,224.474349914585 1373.16984376377,224.413241006545 1269.39187745101,224.492069226211 PathPoint;PointKind.SMOOTHPOINT 1541.22499089779,228.275880790735 1579.85140851661,228.239079143514 1456.78105167712,228.356072034372 PathPoint;PointKind.SMOOTHPOINT 1657.40244366253,228.161841118482 1661.86869833611,228.157297705245 1618.65228920861,228.200914472322 PathPoint;PointKind.SMOOTHPOINT 1670.79856874603,228.14821087877 1671.30788363364,227.75361543912 1667.7582198286,230.504652154242 PathPoint;PointKind.SMOOTHPOINT 1692.67653133891,228.126629665894 1724.34407145194,228.093917090586 1679.86654353826,228.139805564281 PathPoint;PointKind.SMOOTHPOINT 1817.34021984175,227.994870682015 1929.75689382213,227.874243060567 1782.86660979528,228.031899499898 PathPoint;PointKind.SMOOTHPOINT 2139.448899537,227.637076889586 2165.96757987665,227.606863191558 2039.03909679012,227.750889391177 PathPoint;PointKind.SMOOTHPOINT 2217.04274410928,227.549161843446 2223.41225896447,227.541892382266 2191.8675760408,227.577558176178 PathPoint;PointKind.SMOOTHPOINT 2236.01054535531,227.527580630569 2239.69626103591,229.24135610364 2230.35383677057,224.897398707556 PathPoint;PointKind.SMOOTHPOINT 2245.67814533185,227.5166764388 2335.53366518905,227.41535832361 2242.46861121571,227.52031116939 PathPoint;PointKind.SMOOTHPOINT 2479.48241383739,227.262699638841 2566.98605418193,227.175466104687 2415.18470794869,227.326988936147 PathPoint;PointKind.SMOOTHPOINT 2643.70904946452,227.162971718284 2667.76765386461,227.203862437419 2626.05426610376,227.132758020257 PathPoint;PointKind.SMOOTHPOINT 2915.35391872142,227.784964990456 2985.79067227955,227.950118061628 2769.38872880534,227.442618803034 PathPoint;PointKind.SMOOTHPOINT 3153.90974033787,228.342214623998 3197.53371866156,228.443305568526 3066.55329404835,228.139351222958 PathPoint;PointKind.SMOOTHPOINT 3317.41384159098,225.780680550463 3321.29689113419,225.836791703943 3261.02004595576,224.966500898358 PathPoint;PointKind.SMOOTHPOINT 3328.92341976208,225.937655477808 3335.92276097223,224.306570125655 3325.24151587971,226.795679067653 PathPoint;PointKind.SMOOTHPOINT 3342.886329922,226.098719477067 3386.93781607881,226.545336998283 3338.32888530597,226.05260383271 PathPoint;PointKind.SMOOTHPOINT 3428.07063764653,223.955818623743 3435.12246438627,221.558713799799 3421.31935653708,226.250696649851 PathPoint;PointKind.SMOOTHPOINT 3934.95301154634,222.710923396752 3962.98321649486,222.81087848797 3670.53003387364,221.768846662019 PathPoint;PointKind.SMOOTHPOINT 4019.78370168051,223.033051395269 4023.815411355,223.049407682923 3991.33918358508,222.919011723015 PathPoint;PointKind.SMOOTHPOINT 4031.8832289327,223.081893087569 4036.28908126498,222.244769198615 4027.92423663998,223.834282319648 PathPoint;PointKind.SMOOTHPOINT 4041.02157538471,223.119376246776 4073.16089883346,223.251362401316 4037.97506894704,223.106881860373 PathPoint;PointKind.SMOOTHPOINT 4143.2345146991,221.524836860888 4310.15726454128,222.272001167745 4111.36172391173,221.382400855902 PathPoint;PointKind.SMOOTHPOINT 4569.95829024315,223.610490707423 4635.35203473281,223.926712268732 4468.74713022061,223.120937931115 PathPoint;PointKind.SMOOTHPOINT 4681.0502177283,223.984640787506 4686.87259292876,223.461921094566 4676.80885915074,224.365378816783 PathPoint;PointKind.SMOOTHPOINT 4714.83975659873,224.947162881806 4716.36535553956,225.641850765773 4712.8347507257,224.034391162453 PathPoint;PointKind.SMOOTHPOINT 4728.75282016632,235.533997236458 4729.59053613287,237.654408194258 4726.80616412785,230.606211239395 PathPoint;PointKind.SMOOTHPOINT 4730.62030808754,280.504019946241 4730.66634288164,283.335020734338 4730.18869524094,253.847814483611 PathPoint;PointKind.SMOOTHPOINT 4730.75225494962,289.346865129796 4729.77115672628,293.499317657931 4731.45802405409,286.36093395031 PathPoint;PointKind.SMOOTHPOINT 4730.89915578939,301.059102943302 4731.41169604474,346.085009635901 4730.85282778004,296.990930730716 PathPoint;PointKind.SMOOTHPOINT 4727.71825276694,491.835875120558 4727.7789483235,530.300638757323 4727.60184631307,417.914314580714 PathPoint;PointKind.SMOOTHPOINT 4728.71225246123,623.691179359876 4728.61754393579,673.198708869646 4728.79757809871,578.851552610001 PathPoint;PointKind.SMOOTHPOINT 4729.49089118296,772.322737427724 4729.38304427128,867.95638084574 4729.55298748809,717.258611707944 PathPoint;PointKind.SMOOTHPOINT 4731.25936880184,1072.32801357693 4730.78775619218,1142.44100153257 4731.95195576387,969.363545849854 PathPoint;PointKind.SMOOTHPOINT 4732.72672708625,1283.13739704087 4732.73435068272,1287.61447644481 4732.60973420187,1214.28742152705 PathPoint;PointKind.SMOOTHPOINT 4732.69154125636,1296.53183360545 4731.42924960918,1299.14088865691 4733.95412611878,1293.92255138333 PathPoint;PointKind.SMOOTHPOINT 4730.68976075107,1302.21655224783 4730.6648374549,1305.15500475899 4730.6947454103,1301.60500882611 PathPoint;PointKind.SMOOTHPOINT 4732.60592240363,1307.16432926314 4731.94472201702,1392.80857746693 4732.62849997781,1304.2376896264 PathPoint;PointKind.SMOOTHPOINT 4731.25936880184,1549.68550237073 4729.47515401135,1730.35478408916 4732.00882697842,1473.77324532101 PathPoint;PointKind.SMOOTHPOINT 4731.18708842784,1922.85929483523 4731.14809079971,1925.18007031679 4732.0482616143,1871.66161560123 PathPoint;PointKind.SMOOTHPOINT 4732.71767202789,1929.73211603914 4730.15673004266,1936.72601920582 4733.38854851773,1927.89998465124 PathPoint;PointKind.SMOOTHPOINT 4730.72996585456,1943.20628950603 4730.4684178524,1947.03729554764 4730.81235933954,1942.00069480354 PathPoint;PointKind.SMOOTHPOINT 4731.25936880184,2049.17851987876 4731.52707432423,2142.26215291714 4731.07816177793,1986.09299990963 PathPoint;PointKind.SMOOTHPOINT 4732.26327316438,2454.35493677834 4732.77552020448,2554.81048496473 4731.41529466412,2287.92562082793 PathPoint;PointKind.SMOOTHPOINT 4732.17548699654,2771.58774270842 4732.17900557953,2772.3746618811 4731.68493788488,2663.77913453894 PathPoint;PointKind.SMOOTHPOINT 4732.18721560651,2773.94804588514 4732.20363566045,2776.94056501382 4732.18281737777,2773.16135388312 PathPoint;PointKind.SMOOTHPOINT 4732.23647576835,2782.92537610051 4735.02817815459,2786.04874553043 4730.21417019563,2780.66298347905 PathPoint;PointKind.SMOOTHPOINT 4732.28251056245,2791.32955473602 4732.80150155327,2885.90433599885 4732.2672633695,2788.52854047529 PathPoint;PointKind.SMOOTHPOINT 4730.2554644393,3069.33766931713 4731.13716269321,3225.74898625018 4729.75406636342,2980.34537989884 PathPoint;PointKind.SMOOTHPOINT 4727.71825276694,3437.88701774574 4728.16247386926,3518.02896534863 4727.17990956968,3340.71908337778 PathPoint;PointKind.SMOOTHPOINT 4726.7245462879,3603.42786923762 4726.6157634305,3642.58754792901 4726.74301884859,3596.81470410021 PathPoint;PointKind.SMOOTHPOINT 4726.7348348218,3722.01681885605 4720.6462201752,3737.78064542382 4728.63692214241,3717.09175890693 PathPoint;PointKind.SMOOTHPOINT 4692.94529595137,3735.49099232294 4683.92863382772,3736.32220977468 4723.71237203455,3732.65453943896 PathPoint;PointKind.SMOOTHPOINT 4660.57491888636,3737.24088793124 4657.39734523236,3737.33539092658 4672.83718060178,3736.87650618962 PathPoint;PointKind.SMOOTHPOINT 4650.82140684184,3737.48736809936 4645.63354944034,3739.38424312589 4655.85034157836,3735.64842159161 PathPoint;PointKind.SMOOTHPOINT 4633.73663392524,3737.75293060308 4584.19938367389,3738.27928502661 4639.55812947995,3737.69114018305 PathPoint;PointKind.SMOOTHPOINT 4508.09771150405,3738.37833143518 4498.27001600152,3739.06347815135 4527.26519233467,3737.04211360212 PathPoint;PointKind.SMOOTHPOINT 4279.82023122773,3735.21774832632 4178.42874382702,3734.76590587988 4417.20183794302,3735.82974608937 PathPoint;PointKind.SMOOTHPOINT 3913.83218272688,3733.22955069372 3769.275305652,3732.36312178939 4051.77177806112,3734.05645190289 PathPoint;PointKind.SMOOTHPOINT 3459.08201403254,3730.4058193668 3342.85559432121,3729.67637437157 3612.32744536737,3731.36788711978 PathPoint;PointKind.SMOOTHPOINT 3077.85087759439,3728.00303527631 3074.46424146782,3727.98599747667 3144.82505227645,3728.34061087983 PathPoint;PointKind.SMOOTHPOINT 3068.72367332185,3727.9596456799 3060.04303587362,3725.05367857339 3072.90961421734,3729.36106149291 PathPoint;PointKind.SMOOTHPOINT 3054.95926988553,3727.94397090423 3057.60846966073,3728.17409478469 3054.58512722774,3727.91148549958 PathPoint;PointKind.SMOOTHPOINT 2952.32689555082,3731.38884384126 2761.54932590664,3730.36657586289 2984.97905247017,3731.56376525089 PathPoint;PointKind.SMOOTHPOINT 2612.90092324647,3730.63713612116 2599.85343109409,3731.28820723805 2627.55142316543,3729.9061009313 PathPoint;PointKind.SMOOTHPOINT 2274.1006722836,3732.32887604003 2175.76566063902,3732.56536069903 2468.47452695742,3731.86113164726 PathPoint;PointKind.SMOOTHPOINT 1937.89127126137,3732.9545040428 1790.78576724172,3733.16804446494 2061.30732887949,3732.77503921993 PathPoint;PointKind.SMOOTHPOINT 1470.52756898325,3733.4601859361 1373.68385009536,3733.53333488921 1630.9532553369,3733.338649632 PathPoint;PointKind.SMOOTHPOINT 1183.02095361374,3734.62910683184 1179.5932673523,3734.63046985581 1277.62802658185,3734.59275952594 PathPoint;PointKind.SMOOTHPOINT 1172.74757093265,3734.63296873309 1170.59771672659,3735.62138828285 1177.78061068265,3732.31878120073 PathPoint;PointKind.SMOOTHPOINT 1165.61247106218,3734.63546761037 1124.74559572535,3734.65023370339 1167.98927387101,3734.63478609839 PathPoint;PointKind.SMOOTHPOINT 1044.70340382347,3734.66863452701 914.527561853671,3734.69271461716 1084.36985593068,3734.66136506583 PathPoint;PointKind.SMOOTHPOINT 684.757348744609,3734.6168396161 617.382642032341,3734.57912928623 791.98587210823,3734.67658550017 PathPoint;PointKind.SMOOTHPOINT 477.438040825075,3734.32288077965 469.229186712573,3733.77449080193 515.880026052237,3736.89059077066 PathPoint;PointKind.SMOOTHPOINT 461.857755351368,3734.38876027159 459.799677518261,3733.70747545668 468.368306741352,3736.54392834066 PathPoint;PointKind.SMOOTHPOINT 450.451095732688,3734.36899642401 411.22446649906,3734.29834634817 454.200439122335,3734.37558437321 PathPoint;PointKind.SMOOTHPOINT 351.308569292215,3734.11888152531 309.643268832209,3733.96758586451 377.823144618378,3734.21520188593 PathPoint;PointKind.SMOOTHPOINT 258.586577160268,3732.6036532107 251.855821118244,3732.75631189547 262.131549521325,3732.5232347964 PathPoint;PointKind.SMOOTHPOINT 234.585128626675,3728.30039436118 230.183674523132,3725.38079701496 244.396697290504,3734.80906099412 PathPoint;PointKind.SMOOTHPOINT 222.850123650493,3715.2795223008 221.445915822776,3713.05552152119 225.696950503554,3719.7884055974 PathPoint;PointKind.SMOOTHPOINT 220.381518468532,3631.05422436058 220.360993401098,3628.78183622999 220.815477037131,3679.44929913922 PathPoint;PointKind.SMOOTHPOINT 220.852422158512,3623.63914678681 220.818702404871,3620.36266433081 220.876465808934,3625.99831411023 PathPoint;PointKind.SMOOTHPOINT 220.201191090364,3614.03028213147 220.063379923309,3602.81123182486 220.243414086228,3617.471008976 PathPoint;PointKind.SMOOTHPOINT 219.614174161759,3577.84790213441 219.222145373775,3558.56724655038 219.876015379164,3590.72938734451 PathPoint;PointKind.SMOOTHPOINT 218.913976147019,3514.70967857173 218.924825111234,3514.2476134455 218.85797203445,3517.1083735903 PathPoint;PointKind.SMOOTHPOINT 219.858422464221,3505.25824318505 218.660051741339,3500.89747515999 221.359098108877,3510.71897155483 PathPoint;PointKind.SMOOTHPOINT 218.935087644951,3489.64548510741 218.932741922959,3460.5810434584 218.935674075449,3495.75115098622 PathPoint;PointKind.SMOOTHPOINT 218.948575546408,3379.60765123311 218.97584456457,3355.85968458361 218.91075077928,3412.51014121423 PathPoint;PointKind.SMOOTHPOINT 219.108084641893,3305.80399226677 219.120692897602,3301.68016324203 219.030089385644,3331.21303079579 PathPoint;PointKind.SMOOTHPOINT 219.147961915764,3293.37275930848 218.805779720119,3289.83730229795 219.674283287815,3298.81281514803 PathPoint;PointKind.SMOOTHPOINT 219.184907037145,3282.67779171878 219.22654360251,3271.02984320258 219.172005566186,3286.25663832572 PathPoint;PointKind.SMOOTHPOINT 219.323597849947,3247.30709249654 219.298967769027,3246.77687617176 219.48985089616,3250.8679926212 PathPoint;PointKind.SMOOTHPOINT 219.327409648185,3235.53260992169 219.546734654477,3235.06986328348 217.990348112501,3238.35225217669 PathPoint;PointKind.SMOOTHPOINT 219.863700338704,3221.68405920405 220.248105530213,3198.9733537966 219.721784158162,3230.06779247999 PathPoint;PointKind.SMOOTHPOINT 220.513172115357,3102.11437152877 220.521382142331,3098.80790254541 220.389435280257,3151.44697962891 PathPoint;PointKind.SMOOTHPOINT 220.537802196278,3092.1774724377 220.82515314035,3091.57319847716 218.775285334217,3095.88444329793 PathPoint;PointKind.SMOOTHPOINT 220.572401595666,3079.95637234163 220.637202165707,3056.34766130785 220.553049389228,3086.94482341242 PathPoint;PointKind.SMOOTHPOINT 216.936791108281,2980.45867190211 217.018598162767,2969.84185102009 216.769071985823,3002.22162130828 PathPoint;PointKind.SMOOTHPOINT 217.201564478177,2948.52279308719 217.232938509825,2944.96030276791 217.107442383231,2959.19436209872 PathPoint;PointKind.SMOOTHPOINT 217.297445864617,2937.82737115617 216.758516236857,2935.13267276519 218.510184134703,2943.8912376332 PathPoint;PointKind.SMOOTHPOINT 217.373388614122,2929.58948144515 217.82640617391,2881.04470120034 217.347878887454,2932.33665625902 PathPoint;PointKind.SMOOTHPOINT 218.846502025367,2783.30497827648 218.873771043529,2780.50396401575 218.369147599908,2832.08124542573 PathPoint;PointKind.SMOOTHPOINT 218.928015864604,2774.90398003024 218.785806468813,2774.58957583423 220.786707328354,2779.01099842601 PathPoint;PointKind.SMOOTHPOINT 219.120365067983,2764.25626393821 219.373409827916,2741.3595057587 219.04999340821,2770.62204022485 PathPoint;PointKind.SMOOTHPOINT 219.842261011153,2656.53352627892 219.963358909012,2632.76420558721 219.686270498656,2687.12069287438 PathPoint;PointKind.SMOOTHPOINT 219.871289320809,2585.48681046492 219.853989621115,2580.89500987675 219.96071997177,2609.04645263574 PathPoint;PointKind.SMOOTHPOINT 219.809714118508,2571.73003669467 218.705172275323,2568.35564368341 222.120543496298,2578.79027369461 PathPoint;PointKind.SMOOTHPOINT 219.749311777203,2561.1236656631 219.241756181091,2478.99874535284 219.771009705633,2564.65480643105 PathPoint;PointKind.SMOOTHPOINT 217.104803445989,2326.48817585458 217.075481921084,2323.54040934629 217.827285819657,2399.263887576 PathPoint;PointKind.SMOOTHPOINT 217.020650669511,2317.67917909964 218.479396533552,2314.28933848337 215.858638637512,2320.37887524518 PathPoint;PointKind.SMOOTHPOINT 216.930633588051,2307.36949295246 216.619532208805,2269.51922595602 216.95878225196,2310.78954726676 PathPoint;PointKind.SMOOTHPOINT 216.934738601538,2200.68401653522 218.607824812637,2059.94429488123 216.541830167806,2233.73166856927 PathPoint;PointKind.SMOOTHPOINT 219.81821736073,1953.79335103135 219.820269867474,1946.97346059165 219.814698777742,1964.81067379022 PathPoint;PointKind.SMOOTHPOINT 220.026400187558,1896.30849655971 220.048098115988,1895.96887642023 219.868063953069,1898.78965452854 PathPoint;PointKind.SMOOTHPOINT 218.824217666439,1888.34684637351 217.310640550825,1884.01288448654 219.935796675601,1891.52950734616 PathPoint;PointKind.SMOOTHPOINT 220.190307511779,1869.71067395717 220.375326333932,1826.55642634764 220.143979502429,1880.44585075402 PathPoint;PointKind.SMOOTHPOINT 221.153812820169,1645.76220076518 221.479281746618,1573.38630940864 220.839779288433,1715.6146804098 PathPoint;PointKind.SMOOTHPOINT 221.616799698425,1426.09248698932 221.618558989919,1423.08406591432 221.571058119572,1497.17918483982 PathPoint;PointKind.SMOOTHPOINT 221.622370788157,1417.09539292637 220.135476260206,1412.75416157823 222.719875465364,1420.29986228256 PathPoint;PointKind.SMOOTHPOINT 221.629994384632,1403.44561653786 221.664300568771,1340.87213924056 221.62764866264,1407.97085612211 PathPoint;PointKind.SMOOTHPOINT 221.805630318815,1236.77004758999 221.966312275296,1178.55211339253 221.677788470228,1283.17192698148 PathPoint;PointKind.SMOOTHPOINT 221.805630318815,1130.90079536082 221.552878774131,1121.00819454881 221.991528786715,1138.16639463908 PathPoint;PointKind.SMOOTHPOINT 221.269046413047,941.076990310762 221.38574608217,940.767129527985 220.433382953244,943.290541239924 PathPoint;PointKind.SMOOTHPOINT 219.81821736073,929.749352427784 219.828773109696,926.223436585058 219.796226217051,937.07151720085 PathPoint;PointKind.SMOOTHPOINT 221.47576316363,916.579133306462 221.374017472208,859.281467460195 221.484559621101,921.45376136865 PathPoint;PointKind.SMOOTHPOINT 218.824217666439,630.428379678652 217.895018542188,563.754926276108 220.003822613381,715.054448975992 PathPoint;PointKind.SMOOTHPOINT 216.719811823982,449.82838501209 216.703978200533,445.817686976955 216.931220018549,503.937937789816 PathPoint;PointKind.SMOOTHPOINT 218.824217666439,438.901249005971 218.795775787281,423.029516373812 218.831254832416,442.849702279756 PathPoint;PointKind.SMOOTHPOINT 216.836804708354,391.74130111586 217.231179218331,348.598412039416 216.700459617544,406.645286728497 PathPoint;PointKind.SMOOTHPOINT 218.824217666439,293.571771299762 218.804865460001,288.259612542832 218.908370442917,316.637090110374 PathPoint;PointKind.SMOOTHPOINT 216.836804708354,272.231756645388 216.86290086552,264.947756543515 216.82243716115,276.184526161748 PathPoint";
	
	mask45[1] = "PointKind.SMOOTHPOINT 217.814910769463,256.832563877106 217.592448353767,253.656485080719 217.920831203461,258.341767787933 PathPoint;PointKind.SMOOTHPOINT 226.984375,240 230.236369416692,236.758991084617 221.377928547079,245.587847324851 PathPoint;PointKind.SMOOTHPOINT 234.56951713562,231.385931968689 243.609044313431,225.935661792755 229.854730129242,234.228730201721 PathPoint;PointKind.SMOOTHPOINT 259.554642796516,226.996636390686 262.07135951519,227.047383785248 252.872214078903,226.862332820892 PathPoint;PointKind.SMOOTHPOINT 428.50157058239,225.071775913239 450.984436631203,224.510250091553 352.499381065369,226.970200538635 PathPoint;PointKind.SMOOTHPOINT 494.996884822845,223.897504806519 498.877880334854,223.854546546936 473.598596811295,224.134011268616 PathPoint;PointKind.SMOOTHPOINT 508.005920410156,226.034324169159 508.855939269066,226.055567264557 500.983897209167,225.858242511749 PathPoint;PointKind.SMOOTHPOINT 513.228476405144,225.210092067719 516.79200565815,224.589085578918 510.612035155296,225.666110515594 PathPoint;PointKind.SMOOTHPOINT 528.593135237694,223.845105171204 557.363072395325,223.84770154953 521.95201253891,223.844397068024 PathPoint;PointKind.SMOOTHPOINT 614.342955112457,224.109227657318 630.02153968811,224.628975391388 604.602110743523,223.786568641663 PathPoint;PointKind.SMOOTHPOINT 1061.47913372517,224.617173671722 1106.78711569309,224.597346782684 812.109682321548,224.727165699005 PathPoint;PointKind.SMOOTHPOINT 1203.47181892395,224.53786611557 1207.96296334267,224.53503370285 1154.31618130207,224.570438861847 PathPoint;PointKind.SMOOTHPOINT 1216.98537802696,224.528896808624 1218.99963653088,223.71505022049 1212.86805307865,226.192231178284 PathPoint;PointKind.SMOOTHPOINT 1223.54123330116,224.524412155151 1246.29583394527,224.508833885193 1221.35289943218,224.525828361511 PathPoint;PointKind.SMOOTHPOINT 1292.72468423843,224.47437286377 1373.15428888798,224.413239955902 1269.37616205215,224.492075443268 PathPoint;PointKind.SMOOTHPOINT 1541.20930171013,228.275942802429 1579.83574008942,228.239121437073 1456.76534211636,228.355958461761 PathPoint;PointKind.SMOOTHPOINT 1657.38690531254,228.16193819046 1661.85297107697,228.157217502594 1618.63654887676,228.200883865356 PathPoint;PointKind.SMOOTHPOINT 1670.78303730488,228.148248195648 1671.29228150845,227.753598690033 1667.74261927605,230.504579544067 PathPoint;PointKind.SMOOTHPOINT 1692.66077017784,228.126533031464 1724.32832455635,228.093960285187 1679.85088860989,228.139750957489 PathPoint;PointKind.SMOOTHPOINT 1817.32469534874,227.994825839996 1929.74138593674,227.874212265015 1782.85098707676,228.031883239746 PathPoint;PointKind.SMOOTHPOINT 2139.43316078186,227.636997699738 2165.95191991329,227.606785297394 2039.02353978157,227.751002311707 PathPoint;PointKind.SMOOTHPOINT 2217.02710723877,227.549192905426 2223.39649534225,227.541875839233 2191.85197389126,227.577517032623 PathPoint;PointKind.SMOOTHPOINT 2235.99483108521,227.527477741241 2239.68050813675,229.241323471069 2230.33826684952,224.897346496582 PathPoint;PointKind.SMOOTHPOINT 2245.66250479221,227.516620159149 2335.51814293861,227.415361404419 2242.45302712917,227.520396709442 PathPoint;PointKind.SMOOTHPOINT 2479.46666812897,227.262647151947 2566.97051858902,227.175550460815 2415.16912913322,227.327084541321 PathPoint;PointKind.SMOOTHPOINT 2643.69349813461,227.16304063797 2667.75189375877,227.203874588013 2626.03871560097,227.132828235626 PathPoint;PointKind.SMOOTHPOINT 2915.33840036392,227.784991264343 2985.77519392967,227.950215339661 2769.37296128273,227.44250535965 PathPoint;PointKind.SMOOTHPOINT 3147.984375,227 3191.60825157166,227.101022720337 3060.62775099277,226.797010421753 PathPoint;PointKind.SMOOTHPOINT 3317.39820575714,225.78058719635 3321.28126657009,225.836763381958 3261.0042784214,224.966504573822 PathPoint;PointKind.SMOOTHPOINT 3328.90783286095,225.937550067902 3335.90713775158,224.306552410126 3325.22599136829,226.795771121979 PathPoint;PointKind.SMOOTHPOINT 3342.87074244022,226.098761558533 3386.92213630676,226.545338630676 3338.31321334839,226.052498817444 PathPoint;PointKind.SMOOTHPOINT 3428.05496490002,223.955805301666 3435.10678744316,221.558640003204 3421.30379116535,226.250767707825 PathPoint;PointKind.SMOOTHPOINT 3934.93734931946,222.710959911346 3962.96761369705,222.810802459717 3670.51450943947,221.768946647644 PathPoint;PointKind.SMOOTHPOINT 4019.76811027527,223.033146858215 4023.799872756,223.049433231354 3991.32360553741,222.918906211853 PathPoint;PointKind.SMOOTHPOINT 4031.86752831936,223.082005977631 4036.27340531349,222.244791984558 4027.90864145756,223.834247589111 PathPoint;PointKind.SMOOTHPOINT 4041.00589489937,223.119299411774 4073.14522302151,223.251478672028 4037.9595760107,223.106789588928 PathPoint;PointKind.SMOOTHPOINT 4143.21881866455,221.524887084961 4310.14175152779,222.271935939789 4111.34620940685,221.382322311401 PathPoint;PointKind.SMOOTHPOINT 4569.94274294376,223.610486984253 4635.33636665344,223.926773071289 4468.73149013519,223.120951652527 PathPoint;PointKind.SMOOTHPOINT 4681.03469049931,223.98460149765 4686.85706889629,223.462021350861 4676.79315245152,224.36532497406 PathPoint;PointKind.SMOOTHPOINT 4714.82419407368,224.947149753571 4716.34986138344,225.641798973083 4712.8190819025,224.034404754639 PathPoint;PointKind.SMOOTHPOINT 4728.73724138737,235.534000396729 4729.57486844063,237.654297351837 4726.79054772854,230.606310367584 PathPoint;PointKind.SMOOTHPOINT 4730.60456848145,280.503981113434 4730.65059518814,283.334977626801 4730.17321562767,253.847908973694 PathPoint;PointKind.SMOOTHPOINT 4730.7367477417,289.34677362442 4729.75543475151,293.499326705933 4731.4424905777,286.360938549042 PathPoint;PointKind.SMOOTHPOINT 4730.88338410854,301.059036254883 4731.39616882801,346.084957122803 4730.83706235886,296.990983486176 PathPoint;PointKind.SMOOTHPOINT 4727.70252561569,491.835958957672 4727.76330447197,530.300595760345 4727.58627867699,417.914235591888 PathPoint;PointKind.SMOOTHPOINT 4728.69652545452,623.691143989563 4728.60181665421,673.19864988327 4728.7820879221,578.851454257965 PathPoint;PointKind.SMOOTHPOINT 4729.47514390945,772.322709560394 4729.36745321751,867.956292629242 4729.53739798069,717.258718013763 PathPoint;PointKind.SMOOTHPOINT 4731.24363160133,1072.32808828354 4730.7721529007,1142.44092464447 4731.9363925457,969.363512992859 PathPoint;PointKind.SMOOTHPOINT 4732.71117544174,1283.13748598099 4732.71884655952,1287.6145863533 4732.59404337406,1214.28743362427 PathPoint;PointKind.SMOOTHPOINT 4732.67577028275,1296.53172969818 4731.41357636452,1299.14085388184 4733.93855428696,1293.92260551453 PathPoint;PointKind.SMOOTHPOINT 4730.67419862747,1302.21661806107 4730.64911997318,1305.15501022339 4730.67921435833,1301.605052948 PathPoint;PointKind.SMOOTHPOINT 4732.59020781517,1307.16437101364 4731.92901647091,1392.8085064888 4732.61292612553,1304.23778057098 PathPoint;PointKind.SMOOTHPOINT 4731.24363160133,1549.68546152115 4729.4595066309,1730.3546833992 4731.99333584309,1473.77326011658 PathPoint;PointKind.SMOOTHPOINT 4731.17134606838,1922.85937786102 4731.13240039349,1925.18006801605 4732.03257656097,1871.66162967682 PathPoint;PointKind.SMOOTHPOINT 4732.702029109,1929.73222732544 4730.14105594158,1936.72592639923 4733.37295687199,1927.89989233017 PathPoint;PointKind.SMOOTHPOINT 4730.71432447433,1943.20625066757 4730.45291638374,1947.0373249054 4730.796641469,1942.00058698654 PathPoint;PointKind.SMOOTHPOINT 4731.24363160133,2049.17861223221 4731.51153063774,2142.26207971573 4731.06247520447,1986.09299182892 PathPoint;PointKind.SMOOTHPOINT 4732.24766290188,2454.3550157547 4732.75985753536,2554.81054544449 4731.39970934391,2287.92551279068 PathPoint;PointKind.SMOOTHPOINT 4732.15974009037,2771.5878367424 4732.16328060627,2772.3747754097 4731.66937863827,2663.77912759781 PathPoint;PointKind.SMOOTHPOINT 4732.17154181004,2773.94794464111 4732.18806421757,2776.9406247139 4732.16711616516,2773.16124200821 PathPoint;PointKind.SMOOTHPOINT 4732.22081398964,2782.92527675629 4735.01251077652,2786.04871988297 4730.19858932495,2780.66288709641 PathPoint;PointKind.SMOOTHPOINT 4732.26684069633,2791.3295173645 4732.78582131863,2885.90425014496 4732.25149846077,2788.52849721909 PathPoint;PointKind.SMOOTHPOINT 4730.23989534378,3069.33767080307 4731.1214838028,3225.74892997742 4729.738322258,2980.3453874588 PathPoint;PointKind.SMOOTHPOINT 4727.70252561569,3437.88696527481 4728.1468603611,3518.02890300751 4727.16436719894,3340.71915864944 PathPoint;PointKind.SMOOTHPOINT 4726.70882081985,3603.42779874802 4726.60024499893,3642.58755683899 4726.72740852833,3596.81458711624 PathPoint;PointKind.SMOOTHPOINT 4726.71914732456,3722.01690673828 4725.4540061997,3727.67662502914 4727.87081916645,3716.8643981976 PathPoint;PointKind.SMOOTHPOINT 4718.984375,3734 4712.0636125118,3736.79694800634 4724.16096609356,3731.90793916661 PathPoint;PointKind.SMOOTHPOINT 4690.984375,3737 4681.94640695097,3737.55112305064 4700.16529799783,3736.44023920784 PathPoint;PointKind.SMOOTHPOINT 4660.5592969656,3737.24088907242 4657.38168394566,3737.33530282974 4672.82157874107,3736.87645196915 PathPoint;PointKind.SMOOTHPOINT 4650.80576574802,3737.48730897903 4645.61802482605,3739.38431739807 4655.8347735405,3735.64836502075 PathPoint;PointKind.SMOOTHPOINT 4633.72100627422,3737.75284767151 4584.18387806416,3738.27920436859 4639.54249954224,3737.69124269485 PathPoint;PointKind.SMOOTHPOINT 4508.08196401596,3738.37833881378 4498.25437700748,3739.06354665756 4527.24943196774,3737.04214811325 PathPoint;PointKind.SMOOTHPOINT 4279.80454599857,3735.21783828735 4178.41302192211,3734.76583242416 4417.18629932404,3735.82963943481 PathPoint;PointKind.SMOOTHPOINT 3913.81669676304,3733.22948455811 3769.25979292393,3732.36323833466 4051.7560813427,3734.05654907227 PathPoint;PointKind.SMOOTHPOINT 3459.06634366512,3730.40580511093 3342.84005796909,3729.6764588356 3612.311673522,3731.36788129807 PathPoint;PointKind.SMOOTHPOINT 3077.83539330959,3728.00297498703 3074.44859480858,3727.98598051071 3144.80956232548,3728.34050416946 PathPoint;PointKind.SMOOTHPOINT 3068.70794332027,3727.95954465866 3057.50833033966,3725.9500477783 3073.0529852383,3728.73941464423 PathPoint;PointKind.SMOOTHPOINT 3046.984375,3729 3049.60953457028,3728.57607577985 3040.83502355381,3729.99179586594 PathPoint;PointKind.SMOOTHPOINT 2952.31141781807,3731.38888835907 2761.5336689949,3730.36662340164 2984.96353065968,3731.56378984451 PathPoint;PointKind.SMOOTHPOINT 2612.88540399075,3730.63711881638 2599.83771777153,3731.28810167313 2627.53576374054,3729.90612030029 PathPoint;PointKind.SMOOTHPOINT 2274.08517634869,3732.32877731323 2175.7500026226,3732.56528377533 2468.45890915394,3731.86119318008 PathPoint;PointKind.SMOOTHPOINT 1937.8757212162,3732.9545044899 1790.77023601532,3733.16811561584 2061.29161453247,3732.77511835098 PathPoint;PointKind.SMOOTHPOINT 1470.51198518276,3733.46009016037 1373.66825377941,3733.5332608223 1630.93777632713,3733.33853244781 PathPoint;PointKind.SMOOTHPOINT 1183.00527667999,3734.62916851044 1179.57776224613,3734.6305847168 1277.61228716373,3734.59281921387 PathPoint;PointKind.SMOOTHPOINT 1172.73187971115,3734.63294506073 1170.58219647408,3735.62145709991 1177.76501810551,3732.31886386871 PathPoint;PointKind.SMOOTHPOINT 1165.59685504436,3734.63554143906 1124.72986018658,3734.65017557144 1167.973721385,3734.63483333588 PathPoint;PointKind.SMOOTHPOINT 1044.68764698505,3734.66858625412 914.512023687363,3734.69266176224 1084.35411190987,3734.66126918793 PathPoint;PointKind.SMOOTHPOINT 684.741688132286,3734.61689472198 617.367145776749,3734.57912921906 791.970342755318,3734.67661142349 PathPoint;PointKind.SMOOTHPOINT 477.422353982925,3734.32279586792 469.213667869568,3733.77448797226 515.864390492439,3736.89061403275 PathPoint;PointKind.SMOOTHPOINT 461.842018723488,3734.38864946365 459.784093856812,3733.70745420456 468.352732419968,3736.54387950897 PathPoint;PointKind.SMOOTHPOINT 450.435361623764,3734.36905860901 411.208805799484,3734.29824829102 454.184767961502,3734.37566757202 PathPoint;PointKind.SMOOTHPOINT 351.29295027256,3734.1188621521 309.627569079399,3733.96756410599 377.807578802109,3734.21516418457 PathPoint;PointKind.SMOOTHPOINT 258.570969462395,3732.60375738144 251.840153694153,3732.75623559952 262.115911006927,3732.52326965332 PathPoint;PointKind.SMOOTHPOINT 234.56951713562,3728.3003783226 232.40229563295,3726.86284713791 244.381171822548,3734.80902671814 PathPoint;PointKind.SMOOTHPOINT 228.211774363073,3722.49212950412 226.147228085006,3720.13631032559 230.214401395345,3724.77729366837 PathPoint;PointKind.SMOOTHPOINT 222.984375,3719 221.580265402794,3716.77608394623 224.429480496027,3721.28880508161 PathPoint;PointKind.SMOOTHPOINT 220.365852475166,3631.05420827866 220.345494508743,3628.78190517426 220.799860715866,3679.44928407669 PathPoint;PointKind.SMOOTHPOINT 220.836741089821,3623.63918781281 220.803106188774,3620.36255836487 220.860934615135,3625.99835157394 PathPoint;PointKind.SMOOTHPOINT 220.185581207275,3614.03022766113 220.04779613018,3602.81127691269 220.22777235508,3617.47090101242 PathPoint;PointKind.SMOOTHPOINT 219.598445653915,3577.84780740738 219.20662856102,3558.56733798981 219.86044383049,3590.7293844223 PathPoint;PointKind.SMOOTHPOINT 218.898308634758,3514.70978736877 218.909225225449,3514.24763202667 218.842250466347,3517.1083688736 PathPoint;PointKind.SMOOTHPOINT 219.842741250992,3505.25826215744 218.644571661949,3500.89752674103 221.343329906464,3510.71891784668 PathPoint;PointKind.SMOOTHPOINT 218.919551730156,3489.64553117752 218.917191386223,3460.58096408844 218.920141816139,3495.75126886368 PathPoint;PointKind.SMOOTHPOINT 218.93282866478,3379.6077132225 218.960267663002,3355.85958480835 218.89506316185,3412.51019954681 PathPoint;PointKind.SMOOTHPOINT 219.092446923256,3305.80400705338 219.105133771896,3301.68025016785 219.014555573463,3331.21310949326 PathPoint;PointKind.SMOOTHPOINT 219.132277727127,3293.37278366089 218.790027856827,3289.83722448349 219.65863442421,3298.81290435791 PathPoint;PointKind.SMOOTHPOINT 219.169158101082,3282.67782926559 219.211054205894,3271.02976799011 219.156471252441,3286.25658273697 PathPoint;PointKind.SMOOTHPOINT 219.307828307152,3247.30713129044 219.283339738846,3246.77676200867 219.474232554436,3250.86794614792 PathPoint;PointKind.SMOOTHPOINT 219.311663866043,3235.53255558014 219.531175851822,3235.06992816925 217.97482407093,3238.35222244263 PathPoint;PointKind.SMOOTHPOINT 219.848052024841,3221.68394565582 220.232493042946,3198.97342443466 219.706136345863,3230.06788730621 PathPoint;PointKind.SMOOTHPOINT 220.497441649437,3102.11435079575 220.505702853203,3098.80798101425 220.373818635941,3151.44695520401 PathPoint;PointKind.SMOOTHPOINT 220.522225260735,3092.17753887177 220.80959713459,3091.57329082489 218.759638428688,3095.88445901871 PathPoint;PointKind.SMOOTHPOINT 220.556745290756,3079.95638608932 220.621654748917,3056.34775400162 220.5375674963,3086.94489240646 PathPoint;PointKind.SMOOTHPOINT 216.921225547791,2980.45868396759 217.002952456474,2969.84185695648 216.753346085548,3002.22152709961 PathPoint;PointKind.SMOOTHPOINT 217.18587911129,2948.52275848389 217.217448711395,2944.96029138565 217.091760396957,2959.19434547424 PathPoint;PointKind.SMOOTHPOINT 217.281768083572,2937.82733201981 216.743019580841,2935.13276338577 218.494689822197,2943.89129161835 PathPoint;PointKind.SMOOTHPOINT 217.357889175415,2929.58949565887 217.81078016758,2881.04477405548 217.332220435143,2932.33669996262 PathPoint;PointKind.SMOOTHPOINT 218.830743789673,2783.30505609512 218.858182787895,2780.50403594971 218.353659272194,2832.08132743835 PathPoint;PointKind.SMOOTHPOINT 218.912470698357,2774.90388393402 218.770259976387,2774.58948612213 220.770946502686,2779.01088237762 PathPoint;PointKind.SMOOTHPOINT 219.104838728905,2764.25637245178 219.357690572739,2741.3596200943 219.034323453903,2770.62198400497 PathPoint;PointKind.SMOOTHPOINT 219.826513886452,2656.53357982635 219.947776556015,2632.7642083168 219.670731186867,2687.12080478668 PathPoint;PointKind.SMOOTHPOINT 219.855723142624,2585.48675537109 219.838315606117,2580.89494228363 219.94512116909,2609.04652833939 PathPoint;PointKind.SMOOTHPOINT 219.794059157372,2571.72996282578 218.689418196678,2568.35561513901 222.104835867882,2578.79022359848 PathPoint;PointKind.SMOOTHPOINT 219.733575344086,2561.12375736237 219.226101398468,2478.99865865707 219.755408525467,2564.65483188629 PathPoint;PointKind.SMOOTHPOINT 217.089105010033,2326.48810386658 217.05989575386,2323.54050636292 217.811665296555,2399.26388025284 PathPoint;PointKind.SMOOTHPOINT 217.005017757416,2317.67906427383 218.463710308075,2314.2893743515 215.843138456345,2320.37882566452 PathPoint;PointKind.SMOOTHPOINT 216.915029644966,2307.36955404282 216.604054331779,2269.51931476593 216.943058729172,2310.78945636749 PathPoint;PointKind.SMOOTHPOINT 216.919160246849,2200.68413257599 218.592054009438,2059.9443769455 216.526162981987,2233.73178005219 PathPoint;PointKind.SMOOTHPOINT 219.802615404129,1953.79333734512 219.80468070507,1946.97335958481 219.799074888229,1964.81071472168 PathPoint;PointKind.SMOOTHPOINT 219.984375,1903 220.00591313839,1902.66034650803 219.82593691349,1905.48119354248 PathPoint;PointKind.SMOOTHPOINT 218.984375,1893 217.470804452896,1888.66593647003 220.095801949501,1896.1826877594 PathPoint;PointKind.SMOOTHPOINT 220.174664616585,1869.71056938171 220.359656572342,1826.55640125275 220.128342866898,1880.44588565826 PathPoint;PointKind.SMOOTHPOINT 221.138275027275,1645.76231718063 221.463707447052,1573.38638305664 220.82405424118,1715.61457157135 PathPoint;PointKind.SMOOTHPOINT 221.601197481155,1426.0924243927 221.602967739105,1423.08416604996 221.555465817451,1497.17913866043 PathPoint;PointKind.SMOOTHPOINT 221.606803297997,1417.09550142288 223.57997085197,1412.95238497691 220.080680928009,1420.29990434647 PathPoint;PointKind.SMOOTHPOINT 221.614474415779,1403.44563245773 221.648699402809,1340.87220668793 221.612114071846,1407.97088384628 PathPoint;PointKind.SMOOTHPOINT 221.790024995804,1236.76994562149 221.950823426247,1178.55206251144 221.662271380424,1283.17194700241 PathPoint;PointKind.SMOOTHPOINT 221.790024995804,1130.90073108673 221.53717315197,1121.00829362869 221.975902080536,1138.16634178162 PathPoint;PointKind.SMOOTHPOINT 220.984375,957 221.101212024689,956.690322875977 220.148813247681,959.213530540466 PathPoint;PointKind.SMOOTHPOINT 219.802615404129,929.749388694763 219.813236951828,926.22350692749 219.780487179756,937.07141160965 PathPoint;PointKind.SMOOTHPOINT 221.460166931152,916.579141616821 221.405079494296,885.570375508543 221.469018220901,921.453723907471 PathPoint;PointKind.SMOOTHPOINT 220.411687248485,770.397792657969 220.371558650387,766.24176882238 220.978500384519,829.101286310529 PathPoint;PointKind.SMOOTHPOINT 220.984375,758 223.301483943284,754.160626476723 218.829514834402,761.57053262003 PathPoint;PointKind.SMOOTHPOINT 220.175586022304,746.612422954344 219.747447515253,704.62247095508 220.213947752965,750.374773694835 PathPoint;PointKind.SMOOTHPOINT 218.8086155653,630.428273677826 217.879525184631,563.754930496216 219.263838362398,663.087082104407 PathPoint;PointKind.SMOOTHPOINT 216.704073905945,449.828445911407 216.688436627388,445.817749500275 216.915619730949,503.93791437149 PathPoint;PointKind.SMOOTHPOINT 218.8086155653,438.901233673096 218.780291438103,423.029572963715 218.815696597099,442.849617004395 PathPoint;PointKind.SMOOTHPOINT 216.821205973625,391.741325855255 217.215678453445,348.598487377167 216.684896111488,406.645245552063 PathPoint;PointKind.SMOOTHPOINT 218.8086155653,293.571789264679 218.789142727852,288.259599208832 218.892702817917,316.637070178986 PathPoint;PointKind.SMOOTHPOINT 216.821205973625,272.231683731079 216.847169756889,264.947662353516 216.806748867035,276.184551715851 PathPoint";
	
	mask45[2] = "PointKind.SMOOTHPOINT 218.9375,259 218.715037584305,255.823921203613 219.043420433998,260.509203910828 PathPoint;PointKind.SMOOTHPOINT 226.921875,240 230.173869416692,236.758991084617 221.315428547079,245.587847324851 PathPoint;PointKind.SMOOTHPOINT 234.50701713562,231.385931968689 243.546544313431,225.935661792755 229.792230129242,234.228730201721 PathPoint;PointKind.SMOOTHPOINT 259.492142796516,226.996636390686 262.00885951519,227.047383785248 252.809714078903,226.862332820892 PathPoint;PointKind.SMOOTHPOINT 428.43907058239,225.071775913239 450.921936631203,224.510250091553 352.436881065369,226.970200538635 PathPoint;PointKind.SMOOTHPOINT 494.934384822845,223.897504806519 498.815380334854,223.854546546936 473.536096811295,224.134011268616 PathPoint;PointKind.SMOOTHPOINT 507.943420410156,226.034324169159 508.793439269066,226.055567264557 500.921397209167,225.858242511749 PathPoint;PointKind.SMOOTHPOINT 513.165976405144,225.210092067719 516.72950565815,224.589085578918 510.549535155296,225.666110515594 PathPoint;PointKind.SMOOTHPOINT 528.530635237694,223.845105171204 557.300572395325,223.84770154953 521.88951253891,223.844397068024 PathPoint;PointKind.SMOOTHPOINT 614.280455112457,224.109227657318 629.95903968811,224.628975391388 604.539610743523,223.786568641663 PathPoint;PointKind.SMOOTHPOINT 1061.41663372517,224.617173671722 1106.72461569309,224.597346782684 812.047182321548,224.727165699005 PathPoint;PointKind.SMOOTHPOINT 1203.40931892395,224.53786611557 1207.90046334267,224.53503370285 1154.25368130207,224.570438861847 PathPoint;PointKind.SMOOTHPOINT 1216.92287802696,224.528896808624 1218.93713653088,223.71505022049 1212.80555307865,226.192231178284 PathPoint;PointKind.SMOOTHPOINT 1223.47873330116,224.524412155151 1246.23333394527,224.508833885193 1221.29039943218,224.525828361511 PathPoint;PointKind.SMOOTHPOINT 1292.66218423843,224.47437286377 1373.09178888798,224.413239955902 1269.31366205215,224.492075443268 PathPoint;PointKind.SMOOTHPOINT 1541.14680171013,228.275942802429 1579.77324008942,228.239121437073 1456.70284211636,228.355958461761 PathPoint;PointKind.SMOOTHPOINT 1657.32440531254,228.16193819046 1661.79047107697,228.157217502594 1618.57404887676,228.200883865356 PathPoint;PointKind.SMOOTHPOINT 1670.72053730488,228.148248195648 1671.22978150845,227.753598690033 1667.68011927605,230.504579544067 PathPoint;PointKind.SMOOTHPOINT 1692.59827017784,228.126533031464 1724.26582455635,228.093960285187 1679.78838860989,228.139750957489 PathPoint;PointKind.SMOOTHPOINT 1817.26219534874,227.994825839996 1929.67888593674,227.874212265015 1782.78848707676,228.031883239746 PathPoint;PointKind.SMOOTHPOINT 2139.37066078186,227.636997699738 2165.88941991329,227.606785297394 2038.96103978157,227.751002311707 PathPoint;PointKind.SMOOTHPOINT 2216.96460723877,227.549192905426 2223.33399534225,227.541875839233 2191.78947389126,227.577517032623 PathPoint;PointKind.SMOOTHPOINT 2235.93233108521,227.527477741241 2239.61800813675,229.241323471069 2230.27576684952,224.897346496582 PathPoint;PointKind.SMOOTHPOINT 2245.60000479221,227.516620159149 2335.45564293861,227.415361404419 2242.39052712917,227.520396709442 PathPoint;PointKind.SMOOTHPOINT 2479.40416812897,227.262647151947 2566.90801858902,227.175550460815 2415.10662913322,227.327084541321 PathPoint;PointKind.SMOOTHPOINT 2643.63099813461,227.16304063797 2667.68939375877,227.203874588013 2625.97621560097,227.132828235626 PathPoint;PointKind.SMOOTHPOINT 2915.27590036392,227.784991264343 2985.71269392967,227.950215339661 2769.31046128273,227.44250535965 PathPoint;PointKind.SMOOTHPOINT 3147.921875,227 3191.54575157166,227.101022720337 3060.56525099277,226.797010421753 PathPoint;PointKind.SMOOTHPOINT 3317.33570575714,225.78058719635 3321.21876657009,225.836763381958 3260.9417784214,224.966504573822 PathPoint;PointKind.SMOOTHPOINT 3328.84533286095,225.937550067902 3335.84463775158,224.306552410126 3325.16349136829,226.795771121979 PathPoint;PointKind.SMOOTHPOINT 3342.80824244022,226.098761558533 3386.85963630676,226.545338630676 3338.25071334839,226.052498817444 PathPoint;PointKind.SMOOTHPOINT 3427.99246490002,223.955805301666 3435.04428744316,221.558640003204 3421.24129116535,226.250767707825 PathPoint;PointKind.SMOOTHPOINT 3934.87484931946,222.710959911346 3962.90511369705,222.810802459717 3670.45200943947,221.768946647644 PathPoint;PointKind.SMOOTHPOINT 4019.70561027527,223.033146858215 4023.737372756,223.049433231354 3991.26110553741,222.918906211853 PathPoint;PointKind.SMOOTHPOINT 4031.80502831936,223.082005977631 4036.21090531349,222.244791984558 4027.84614145756,223.834247589111 PathPoint;PointKind.SMOOTHPOINT 4040.94339489937,223.119299411774 4073.08272302151,223.251478672028 4037.8970760107,223.106789588928 PathPoint;PointKind.SMOOTHPOINT 4143.15631866455,221.524887084961 4310.07925152779,222.271935939789 4111.28370940685,221.382322311401 PathPoint;PointKind.SMOOTHPOINT 4569.88024294376,223.610486984253 4635.27386665344,223.926773071289 4468.66899013519,223.120951652527 PathPoint;PointKind.SMOOTHPOINT 4680.97219049931,223.98460149765 4686.79456889629,223.462021350861 4676.73065245152,224.36532497406 PathPoint;PointKind.SMOOTHPOINT 4714.76169407368,224.947149753571 4716.28736138344,225.641798973083 4712.7565819025,224.034404754639 PathPoint;PointKind.SMOOTHPOINT 4728.67474138737,235.534000396729 4729.51236844063,237.654297351837 4726.72804772854,230.606310367584 PathPoint;PointKind.SMOOTHPOINT 4730.54206848145,280.503981113434 4730.58809518814,283.334977626801 4730.11071562767,253.847908973694 PathPoint;PointKind.SMOOTHPOINT 4729.9375,293 4728.95618700981,297.152553081512 4730.643242836,290.014164924622 PathPoint;PointKind.SMOOTHPOINT 4730.82088410854,301.059036254883 4731.33366882801,346.084957122803 4730.77456235886,296.990983486176 PathPoint;PointKind.SMOOTHPOINT 4727.64002561569,491.835958957672 4727.70080447197,530.300595760345 4727.52377867699,417.914235591888 PathPoint;PointKind.SMOOTHPOINT 4728.63402545452,623.691143989563 4728.53931665421,673.19864988327 4728.7195879221,578.851454257965 PathPoint;PointKind.SMOOTHPOINT 4729.41264390945,772.322709560394 4729.30495321751,867.956292629242 4729.47489798069,717.258718013763 PathPoint;PointKind.SMOOTHPOINT 4731.18113160133,1072.32808828354 4730.7096529007,1142.44092464447 4731.8738925457,969.363512992859 PathPoint;PointKind.SMOOTHPOINT 4732.64867544174,1283.13748598099 4732.66058787754,1290.08995005153 4732.53154337406,1214.28743362427 PathPoint;PointKind.SMOOTHPOINT 4730.61169862747,1302.21661806107 4730.58661997318,1305.15501022339 4730.59492376432,1304.26196725796 PathPoint;PointKind.SMOOTHPOINT 4732.52770781517,1307.16437101364 4731.86651647091,1392.8085064888 4732.55042612553,1304.23778057098 PathPoint;PointKind.SMOOTHPOINT 4731.18113160133,1549.68546152115 4729.3970066309,1730.3546833992 4731.93083584309,1473.77326011658 PathPoint;PointKind.SMOOTHPOINT 4731.10884606838,1922.85937786102 4731.06990039349,1925.18006801605 4731.97007656097,1871.66162967682 PathPoint;PointKind.SMOOTHPOINT 4732.639529109,1929.73222732544 4730.07855594158,1936.72592639923 4733.31045687199,1927.89989233017 PathPoint;PointKind.SMOOTHPOINT 4730.65182447433,1943.20625066757 4730.39041638374,1947.0373249054 4730.734141469,1942.00058698654 PathPoint;PointKind.SMOOTHPOINT 4731.18113160133,2049.17861223221 4731.44903063774,2142.26207971573 4730.99997520447,1986.09299182892 PathPoint;PointKind.SMOOTHPOINT 4732.18516290188,2454.3550157547 4732.69735753536,2554.81054544449 4731.33720934391,2287.92551279068 PathPoint;PointKind.SMOOTHPOINT 4732.09724009037,2771.5878367424 4732.10078060627,2772.3747754097 4731.60687863827,2663.77912759781 PathPoint;PointKind.SMOOTHPOINT 4732.10904181004,2773.94794464111 4732.12556421757,2776.9406247139 4732.10461616516,2773.16124200821 PathPoint;PointKind.SMOOTHPOINT 4732.15831398964,2782.92527675629 4734.95001077652,2786.04871988297 4730.13608932495,2780.66288709641 PathPoint;PointKind.SMOOTHPOINT 4732.20434069633,2791.3295173645 4732.72332131863,2885.90425014496 4732.18899846077,2788.52849721909 PathPoint;PointKind.SMOOTHPOINT 4730.17739534378,3069.33767080307 4731.0589838028,3225.74892997742 4729.675822258,2980.3453874588 PathPoint;PointKind.SMOOTHPOINT 4727.64002561569,3437.88696527481 4728.0843603611,3518.02890300751 4727.10186719894,3340.71915864944 PathPoint;PointKind.SMOOTHPOINT 4726.64632081985,3603.42779874802 4726.53774499893,3642.58755683899 4726.66490852833,3596.81458711624 PathPoint;PointKind.SMOOTHPOINT 4726.65664732456,3722.01690673828 4725.3915061997,3727.67662502914 4727.80831916645,3716.8643981976 PathPoint;PointKind.SMOOTHPOINT 4717.9375,3735 4716.56462348842,3736.14018856719 4722.23270608077,3731.43278559599 PathPoint;PointKind.SMOOTHPOINT 4687.9375,3737 4678.89953195097,3737.55112305064 4697.11842299783,3736.44023920784 PathPoint;PointKind.SMOOTHPOINT 4660.4967969656,3737.24088907242 4657.31918394566,3737.33530282974 4672.75907874107,3736.87645196915 PathPoint;PointKind.SMOOTHPOINT 4650.74326574802,3737.48730897903 4645.55552482605,3739.38431739807 4655.7722735405,3735.64836502075 PathPoint;PointKind.SMOOTHPOINT 4633.65850627422,3737.75284767151 4584.12137806416,3738.27920436859 4639.47999954224,3737.69124269485 PathPoint;PointKind.SMOOTHPOINT 4508.01946401596,3738.37833881378 4498.19187700748,3739.06354665756 4527.18693196774,3737.04214811325 PathPoint;PointKind.SMOOTHPOINT 4279.74204599857,3735.21783828735 4178.35052192211,3734.76583242416 4417.12379932404,3735.82963943481 PathPoint;PointKind.SMOOTHPOINT 3913.75419676304,3733.22948455811 3769.19729292393,3732.36323833466 4051.6935813427,3734.05654907227 PathPoint;PointKind.SMOOTHPOINT 3459.00384366512,3730.40580511093 3342.77755796909,3729.6764588356 3612.249173522,3731.36788129807 PathPoint;PointKind.SMOOTHPOINT 3077.77289330959,3728.00297498703 3074.38609480858,3727.98598051071 3144.74706232548,3728.34050416946 PathPoint;PointKind.SMOOTHPOINT 3068.64544332027,3727.95954465866 3057.44583033966,3725.9500477783 3072.9904852383,3728.73941464423 PathPoint;PointKind.SMOOTHPOINT 3046.921875,3729 3049.54703457028,3728.57607577985 3040.77252355381,3729.99179586594 PathPoint;PointKind.SMOOTHPOINT 2952.24891781807,3731.38888835907 2761.4711689949,3730.36662340164 2984.90103065968,3731.56378984451 PathPoint;PointKind.SMOOTHPOINT 2612.82290399075,3730.63711881638 2599.77521777153,3731.28810167313 2627.47326374054,3729.90612030029 PathPoint;PointKind.SMOOTHPOINT 2274.02267634869,3732.32877731323 2175.6875026226,3732.56528377533 2468.39640915394,3731.86119318008 PathPoint;PointKind.SMOOTHPOINT 1937.8132212162,3732.9545044899 1790.70773601532,3733.16811561584 2061.22911453247,3732.77511835098 PathPoint;PointKind.SMOOTHPOINT 1470.44948518276,3733.46009016037 1373.60575377941,3733.5332608223 1630.87527632713,3733.33853244781 PathPoint;PointKind.SMOOTHPOINT 1182.94277667999,3734.62916851044 1179.51526224613,3734.6305847168 1277.54978716373,3734.59281921387 PathPoint;PointKind.SMOOTHPOINT 1172.66937971115,3734.63294506073 1170.51969647408,3735.62145709991 1177.70251810551,3732.31886386871 PathPoint;PointKind.SMOOTHPOINT 1165.53435504436,3734.63554143906 1124.66736018658,3734.65017557144 1167.911221385,3734.63483333588 PathPoint;PointKind.SMOOTHPOINT 1044.62514698505,3734.66858625412 914.449523687363,3734.69266176224 1084.29161190987,3734.66126918793 PathPoint;PointKind.SMOOTHPOINT 684.679188132286,3734.61689472198 617.304645776749,3734.57912921906 791.907842755318,3734.67661142349 PathPoint;PointKind.SMOOTHPOINT 477.359853982925,3734.32279586792 469.151167869568,3733.77448797226 515.801890492439,3736.89061403275 PathPoint;PointKind.SMOOTHPOINT 461.779518723488,3734.38864946365 459.721593856812,3733.70745420456 468.290232419968,3736.54387950897 PathPoint;PointKind.SMOOTHPOINT 450.372861623764,3734.36905860901 411.146305799484,3734.29824829102 454.122267961502,3734.37566757202 PathPoint;PointKind.SMOOTHPOINT 351.23045027256,3734.1188621521 309.565069079399,3733.96756410599 377.745078802109,3734.21516418457 PathPoint;PointKind.SMOOTHPOINT 258.508469462395,3732.60375738144 251.777653694153,3732.75623559952 262.053411006927,3732.52326965332 PathPoint;PointKind.SMOOTHPOINT 234.50701713562,3728.3003783226 232.33979563295,3726.86284713791 244.318671822548,3734.80902671814 PathPoint;PointKind.SMOOTHPOINT 228.149274363073,3722.49212950412 225.311489300466,3721.16577688334 232.252937817955,3724.41014114282 PathPoint;PointKind.SMOOTHPOINT 222.9375,3715 221.533390402794,3712.77608394623 224.382605496027,3717.28880508161 PathPoint;PointKind.SMOOTHPOINT 220.303352475166,3631.05420827866 220.282994508743,3628.78190517426 220.737360715866,3679.44928407669 PathPoint;PointKind.SMOOTHPOINT 220.774241089821,3623.63918781281 220.740606188774,3620.36255836487 220.798434615135,3625.99835157394 PathPoint;PointKind.SMOOTHPOINT 220.123081207275,3614.03022766113 219.98529613018,3602.81127691269 220.16527235508,3617.47090101242 PathPoint;PointKind.SMOOTHPOINT 219.535945653915,3577.84780740738 219.14412856102,3558.56733798981 219.79794383049,3590.7293844223 PathPoint;PointKind.SMOOTHPOINT 218.835808634758,3514.70978736877 218.846725225449,3514.24763202667 218.779750466347,3517.1083688736 PathPoint;PointKind.SMOOTHPOINT 219.780241250992,3505.25826215744 218.582071661949,3500.89752674103 221.280829906464,3510.71891784668 PathPoint;PointKind.SMOOTHPOINT 218.857051730156,3489.64553117752 218.854691386223,3460.58096408844 218.857641816139,3495.75126886368 PathPoint;PointKind.SMOOTHPOINT 218.87032866478,3379.6077132225 218.897767663002,3355.85958480835 218.83256316185,3412.51019954681 PathPoint;PointKind.SMOOTHPOINT 219.029946923256,3305.80400705338 219.042633771896,3301.68025016785 218.952055573463,3331.21310949326 PathPoint;PointKind.SMOOTHPOINT 219.069777727127,3293.37278366089 218.727527856827,3289.83722448349 219.59613442421,3298.81290435791 PathPoint;PointKind.SMOOTHPOINT 219.106658101082,3282.67782926559 219.148554205894,3271.02976799011 219.093971252441,3286.25658273697 PathPoint;PointKind.SMOOTHPOINT 219.245328307152,3247.30713129044 219.220839738846,3246.77676200867 219.411732554436,3250.86794614792 PathPoint;PointKind.SMOOTHPOINT 219.249163866043,3235.53255558014 219.468675851822,3235.06992816925 217.91232407093,3238.35222244263 PathPoint;PointKind.SMOOTHPOINT 219.785552024841,3221.68394565582 220.169993042946,3198.97342443466 219.643636345863,3230.06788730621 PathPoint;PointKind.SMOOTHPOINT 220.434941649437,3102.11435079575 220.443202853203,3098.80798101425 220.311318635941,3151.44695520401 PathPoint;PointKind.SMOOTHPOINT 220.459725260735,3092.17753887177 220.74709713459,3091.57329082489 218.697138428688,3095.88445901871 PathPoint;PointKind.SMOOTHPOINT 220.494245290756,3079.95638608932 220.559154748917,3056.34775400162 220.4750674963,3086.94489240646 PathPoint;PointKind.SMOOTHPOINT 216.858725547791,2980.45868396759 216.940452456474,2969.84185695648 216.690846085548,3002.22152709961 PathPoint;PointKind.SMOOTHPOINT 217.12337911129,2948.52275848389 217.154948711395,2944.96029138565 217.029260396957,2959.19434547424 PathPoint;PointKind.SMOOTHPOINT 218.9375,2939 218.398751497269,2936.30543136597 220.150421738625,2945.06395959854 PathPoint;PointKind.SMOOTHPOINT 217.295389175415,2929.58949565887 217.74828016758,2881.04477405548 217.269720435143,2932.33669996262 PathPoint;PointKind.SMOOTHPOINT 218.768243789673,2783.30505609512 218.795682787895,2780.50403594971 218.291159272194,2832.08132743835 PathPoint;PointKind.SMOOTHPOINT 218.849970698357,2774.90388393402 218.707759976387,2774.58948612213 220.708446502686,2779.01088237762 PathPoint;PointKind.SMOOTHPOINT 219.042338728905,2764.25637245178 219.295190572739,2741.3596200943 218.971823453903,2770.62198400497 PathPoint;PointKind.SMOOTHPOINT 219.764013886452,2656.53357982635 219.885276556015,2632.7642083168 219.608231186867,2687.12080478668 PathPoint;PointKind.SMOOTHPOINT 219.793223142624,2585.48675537109 219.775815606117,2580.89494228363 219.88262116909,2609.04652833939 PathPoint;PointKind.SMOOTHPOINT 219.731559157372,2571.72996282578 218.626918196678,2568.35561513901 222.042335867882,2578.79022359848 PathPoint;PointKind.SMOOTHPOINT 219.671075344086,2561.12375736237 219.163601398468,2478.99865865707 219.692908525467,2564.65483188629 PathPoint;PointKind.SMOOTHPOINT 217.026605010033,2326.48810386658 217.003074868648,2324.1136036192 217.749165296555,2399.26388025284 PathPoint;PointKind.SMOOTHPOINT 216.852529644966,2307.36955404282 216.541554331779,2269.51931476593 216.885255870183,2311.36256690312 PathPoint;PointKind.SMOOTHPOINT 216.856660246849,2200.68413257599 218.529554009438,2059.9443769455 216.463662981987,2233.73178005219 PathPoint;PointKind.SMOOTHPOINT 219.740115404129,1953.79333734512 219.74218070507,1946.97335958481 219.736574888229,1964.81071472168 PathPoint;PointKind.SMOOTHPOINT 219.921875,1903 219.755339151505,1905.62624751764 219.76343691349,1905.48119354248 PathPoint;PointKind.SMOOTHPOINT 220.112164616585,1869.71056938171 220.297156572342,1826.55640125275 220.053788470964,1883.23955717844 PathPoint;PointKind.SMOOTHPOINT 221.075775027275,1645.76231718063 221.401207447052,1573.38638305664 220.76155424118,1715.61457157135 PathPoint;PointKind.SMOOTHPOINT 221.538697481155,1426.0924243927 221.540467739105,1423.08416604996 221.492965817451,1497.17913866043 PathPoint;PointKind.SMOOTHPOINT 221.544303297997,1417.09550142288 223.51747085197,1412.95238497691 220.018180928009,1420.29990434647 PathPoint;PointKind.SMOOTHPOINT 221.551974415779,1403.44563245773 221.586199402809,1340.87220668793 221.549614071846,1407.97088384628 PathPoint;PointKind.SMOOTHPOINT 221.727524995804,1236.76994562149 221.888323426247,1178.55206251144 221.599771380424,1283.17194700241 PathPoint;PointKind.SMOOTHPOINT 221.727524995804,1130.90073108673 221.47467315197,1121.00829362869 221.913402080536,1138.16634178162 PathPoint;PointKind.SMOOTHPOINT 220.921875,957 221.038712024689,956.690322875977 220.086313247681,959.213530540466 PathPoint;PointKind.SMOOTHPOINT 219.740115404129,929.749388694763 219.750736951828,926.22350692749 219.717987179756,937.07141160965 PathPoint;PointKind.SMOOTHPOINT 221.397666931152,916.579141616821 221.342579494296,885.570375508543 221.406518220901,921.453723907471 PathPoint;PointKind.SMOOTHPOINT 220.349187248485,770.397792657969 220.309058650387,766.24176882238 220.916000384519,829.101286310529 PathPoint;PointKind.SMOOTHPOINT 220.921875,758 223.238983943284,754.160626476723 218.767014834402,761.57053262003 PathPoint;PointKind.SMOOTHPOINT 220.113086022304,746.612422954344 219.684947515253,704.62247095508 220.151447752965,750.374773694835 PathPoint;PointKind.SMOOTHPOINT 218.7461155653,630.428273677826 217.817025184631,563.754930496216 219.201338362398,663.087082104407 PathPoint;PointKind.SMOOTHPOINT 216.641573905945,449.828445911407 216.625936627388,445.817749500275 216.853119730949,503.93791437149 PathPoint;PointKind.SMOOTHPOINT 218.7461155653,438.901233673096 218.717791438103,423.029572963715 218.753196597099,442.849617004395 PathPoint;PointKind.SMOOTHPOINT 216.758705973625,391.741325855255 217.153178453445,348.598487377167 216.622396111488,406.645245552063 PathPoint;PointKind.SMOOTHPOINT 218.7461155653,293.571789264679 218.726642727852,288.259599208832 218.830202817917,316.637070178986 PathPoint;PointKind.SMOOTHPOINT 217.9375,273 217.963463783264,265.715978622437 217.92304289341,276.952867984772 PathPoint";
	
	subshadow45[0] = "PointKind.CORNERPOINT 216,256 216,256 216,256 PathPoint;PointKind.SMOOTHPOINT 228.925634992102,237.615584540196 234.97422548235,230.821395837804 221.870815722384,245.540037924338 PathPoint;PointKind.SMOOTHPOINT 240,229 240,229 239.974299598416,229.007626801374 PathPoint;PointKind.CORNERPOINT 4704.12227227109,223.000021482132 4704.12227227109,223.000021482132 4704.12227227109,223.000021482132 PathPoint;PointKind.SMOOTHPOINT 4723,230 4727.25039265446,233.47460600276 4718.74931350575,226.525157693785 PathPoint;PointKind.CORNERPOINT 4734,240 4734,240 4734,240 PathPoint;PointKind.CORNERPOINT 4731,3714 4731,3714 4731,3714 PathPoint;PointKind.SMOOTHPOINT 4723,3730 4718.79691555276,3737.00734265546 4728.75661545064,3720.40229887051 PathPoint;PointKind.CORNERPOINT 4711.09391527971,3735.99990070481 4711.09391527971,3735.99990070481 4711.09391527971,3735.99990070481 PathPoint;PointKind.CORNERPOINT 243,3733 243,3733 243,3733 PathPoint;PointKind.SMOOTHPOINT 227,3720 219.662526444906,3709.99845626586 234.352165544912,3730.02115692091 PathPoint;PointKind.CORNERPOINT 220,3706 220,3706 220,3706 PathPoint";
	
} else {

	mask45[0] = "PointKind.SMOOTHPOINT 204.265625,192.890625 204.041702443504,189.590713641117 204.3720447475,194.458916015787 PathPoint;PointKind.SMOOTHPOINT 211.849181842535,180.394027879185 215.230246980448,177.143303958517 207.015136601474,185.04171902317 PathPoint;PointKind.SMOOTHPOINT 224.265625,170.890625 233.361555711019,165.227510269902 219.521521396035,173.844297785587 PathPoint;PointKind.SMOOTHPOINT 246.265625,161.890625 248.798060445873,161.943222744681 239.541694298983,161.750971453907 PathPoint;PointKind.SMOOTHPOINT 416.265625,159.890625 438.888624977877,159.307139306661 339.789802787704,161.863066682839 PathPoint;PointKind.SMOOTHPOINT 483.175436786024,158.670494695429 487.080475308942,158.625927538721 461.643823376548,158.916229221055 PathPoint;PointKind.SMOOTHPOINT 496.265625,160.890625 497.120797626616,160.912751315195 489.2,160.7078125 PathPoint;PointKind.SMOOTHPOINT 501.520703772374,160.034412345213 505.106621194714,159.389113280141 498.887792373723,160.508214461619 PathPoint;PointKind.SMOOTHPOINT 516.981133601168,158.615977308015 545.930448132067,158.618773608541 510.298755440297,158.615331837203 PathPoint;PointKind.SMOOTHPOINT 603.265625,158.890625 619.04178975896,159.430547780703 593.463804880596,158.555167931969 PathPoint;PointKind.SMOOTHPOINT 1053.18884340949,159.418311007481 1098.77922173042,159.397543573656 802.264951237533,159.532612435055 PathPoint;PointKind.SMOOTHPOINT 1196.06638135275,159.335909611973 1200.58555485237,159.332828358386 1146.60448781362,159.369633618566 PathPoint;PointKind.SMOOTHPOINT 1209.66443268923,159.326521259329 1211.69102406936,158.481148475496 1205.52151573279,161.054698569754 PathPoint;PointKind.SMOOTHPOINT 1216.26115291147,159.321883969516 1239.15769791219,159.305696181572 1214.0591993273,159.323440744029 PathPoint;PointKind.SMOOTHPOINT 1285.87572645745,159.269889583776 1366.80685565822,159.206394365695 1262.38182757233,159.288321925546 PathPoint;PointKind.SMOOTHPOINT 1535.90939233473,159.04698466282 1574.77670205108,159.008854465027 1450.93918932175,159.130343420376 PathPoint;PointKind.SMOOTHPOINT 1652.81106505535,158.928509178752 1657.30511478791,158.923819850867 1613.81932389239,158.969195212503 PathPoint;PointKind.SMOOTHPOINT 1666.29084023109,158.914401044677 1666.80310875043,158.504429252127 1663.23146523109,161.362838544677 PathPoint;PointKind.SMOOTHPOINT 1688.30496687732,158.891932035383 1720.17002093749,158.857986156153 1675.41512812601,158.905663595628 PathPoint;PointKind.SMOOTHPOINT 1813.74568529769,158.75508634345 1926.86312666889,158.629756694952 1779.05728998835,158.793519712685 PathPoint;PointKind.SMOOTHPOINT 2137.86245718824,158.383285609867 2164.54642913221,158.352051645901 2036.82664761349,158.501549444131 PathPoint;PointKind.SMOOTHPOINT 2215.93986122885,158.291900589697 2222.34916044517,158.284408791757 2190.6076844798,158.321511244962 PathPoint;PointKind.SMOOTHPOINT 2235.0260221438,158.269607571823 2238.73470184904,160.050183221929 2229.33383602258,155.536729887891 PathPoint;PointKind.SMOOTHPOINT 2244.75385598633,158.258260561721 2335.16947676966,158.152851407565 2241.52426683308,158.262025710464 PathPoint;PointKind.SMOOTHPOINT 2480.0154741954,157.994362986869 2568.06457858262,157.903606668283 2415.31697085731,158.06105075186 PathPoint;PointKind.SMOOTHPOINT 2645.265625,157.890625 2669.47446210134,157.93322888281 2627.50080582689,157.859361611716 PathPoint;PointKind.SMOOTHPOINT 2918.6038000741,158.536972868661 2989.47962749264,158.70857855727 2771.72885397676,158.18135689658 PathPoint;PointKind.SMOOTHPOINT 3158.64676122118,159.115863554068 3202.54275966903,159.221057817489 3070.74593952845,158.90521423479 PathPoint;PointKind.SMOOTHPOINT 3325.19047244448,161.670298182759 3329.09777705656,161.728539405467 3268.44527123452,160.824469605416 PathPoint;PointKind.SMOOTHPOINT 3336.77195988728,161.833509639091 3343.81476709887,160.138746052515 3333.06709033379,162.725040221091 PathPoint;PointKind.SMOOTHPOINT 3350.82172814161,162.000823159546 3395.14787407772,162.464892991973 3346.23594371916,161.952812574292 PathPoint;PointKind.SMOOTHPOINT 3436.53711039301,159.774255757252 3443.63284654116,157.283563415952 3429.74387274718,162.158767332063 PathPoint;PointKind.SMOOTHPOINT 3946.57925666627,158.480920416706 3974.78395135547,158.584701713875 3680.50788994841,157.501890794805 PathPoint;PointKind.SMOOTHPOINT 4031.93864299582,158.815587357677 4035.99534947393,158.832390861745 4003.31672221686,158.697030946255 PathPoint;PointKind.SMOOTHPOINT 4044.11345483969,158.866366548008 4048.54683147668,157.996423013859 4040.12978157824,159.6480666109 PathPoint;PointKind.SMOOTHPOINT 4053.30894085582,158.905173175521 4085.648468891,159.042324720971 4050.24334103659,158.892172003937 PathPoint;PointKind.SMOOTHPOINT 4150.09754574424,159.334884794086 4318.06077687851,160.111080603238 4118.02586266655,159.186674344518 PathPoint;PointKind.SMOOTHPOINT 4579.48112509177,161.501784591101 4645.2824136029,161.830407129881 4477.63915267307,160.993168904574 PathPoint;PointKind.SMOOTHPOINT 4691.265625,161.890625 4697.12435274604,161.347516661498 4686.99786675752,162.28624930423 PathPoint;PointKind.SMOOTHPOINT 4725.265625,162.890625 4726.80078980279,163.612315604987 4723.24833005083,161.942281988446 PathPoint;PointKind.SMOOTHPOINT 4739.265625,173.890625 4740.10852055285,176.093716625495 4737.30664976008,168.770415347644 PathPoint;PointKind.SMOOTHPOINT 4741.14472923337,220.615150266239 4741.19087141351,223.556671236789 4740.71027316666,192.91898100817 PathPoint;PointKind.SMOOTHPOINT 4741.2775829867,229.803086674984 4740.2903289741,234.117576745424 4741.98747653207,226.700715235146 PathPoint;PointKind.SMOOTHPOINT 4741.42513442352,241.972344234493 4741.94103901157,288.754957076872 4741.37852170232,237.745467908609 PathPoint;PointKind.SMOOTHPOINT 4742.265625,432.890625 4742.32654276425,472.856231757695 4742.14855340983,356.084832922296 PathPoint;PointKind.SMOOTHPOINT 4743.265625,569.890625 4743.17055150073,621.329931743399 4743.35173405726,523.301509801406 PathPoint;PointKind.SMOOTHPOINT 4745.9684127825,723.217209297321 4745.54510795936,822.763226574266 4746.21169903209,666.005063625421 PathPoint;PointKind.SMOOTHPOINT 4744.18510728856,1036.22439577548 4743.68337066482,1109.07294752252 4744.92209205831,929.219503976593 PathPoint;PointKind.SMOOTHPOINT 4748.31543758952,1255.06714674076 4748.32310052717,1259.71888249326 4748.19759364032,1183.53075473826 PathPoint;PointKind.SMOOTHPOINT 4748.28006947872,1268.98404952943 4747.00975697872,1271.69498702943 4749.55038197872,1266.27311202943 PathPoint;PointKind.SMOOTHPOINT 4746.265625,1274.890625 4746.24053965184,1277.94384515909 4746.27084436539,1274.25535888693 PathPoint;PointKind.SMOOTHPOINT 4748.19393469346,1280.03139201859 4747.5285735011,1369.01753486896 4748.21666991054,1276.99075890309 PathPoint;PointKind.SMOOTHPOINT 4747.08056846599,1531.49849289655 4745.28525340593,1719.21722987314 4747.83490848066,1452.62445125662 PathPoint;PointKind.SMOOTHPOINT 4742.72551049283,1919.74956147083 4742.68623108968,1922.16087652912 4743.59204183074,1866.55425053301 PathPoint;PointKind.SMOOTHPOINT 4744.265625,1926.890625 4741.68885665244,1934.15730277535 4744.94064603756,1924.9870156297 PathPoint;PointKind.SMOOTHPOINT 4742.265625,1940.890625 4742.0024394011,1944.8710160488 4742.34845984202,1939.63783964594 PathPoint;PointKind.SMOOTHPOINT 4742.18038023469,2050.54685979815 4742.44963469524,2147.26240681215 4741.99789851388,1984.99986974045 PathPoint;PointKind.SMOOTHPOINT 4743.97958947121,2472.24012116018 4744.49477009736,2576.61512492713 4743.12606423253,2299.31688709142 PathPoint;PointKind.SMOOTHPOINT 4738.66919347781,2801.59379561825 4738.67279630946,2802.41131407964 4738.17553893404,2689.57865246882 PathPoint;PointKind.SMOOTHPOINT 4738.68109594244,2804.04619574804 4738.69758110597,2807.1554409624 4738.67676202924,2803.22878202538 PathPoint;PointKind.SMOOTHPOINT 4738.73058169165,2813.37369425096 4741.53978503317,2816.61900667241 4736.69575937794,2811.0229800707 PathPoint;PointKind.SMOOTHPOINT 4738.77696545548,2822.10588119782 4739.29923236794,2920.37067057857 4738.76149658393,2819.19540502333 PathPoint;PointKind.SMOOTHPOINT 4740.33460850154,3110.76129335852 4741.22177319451,3273.27541600898 4739.82984427342,3018.29670777566 PathPoint;PointKind.SMOOTHPOINT 4742.265625,3493.890625 4742.71251309518,3577.15955151293 4741.72379583742,3392.93127251768 PathPoint;PointKind.SMOOTHPOINT 4741.265625,3665.890625 4741.15625,3706.578125 4741.28409622889,3659.01932785298 PathPoint;PointKind.SMOOTHPOINT 4740.265625,3783.890625 4734.1391659328,3800.26952577148 4742.1796875,3778.7734375 PathPoint;PointKind.SMOOTHPOINT 4706.265625,3797.890625 4697.1927544078,3798.75430356936 4737.22444840576,3794.94354534792 PathPoint;PointKind.SMOOTHPOINT 4673.69355739285,3799.70887657331 4670.49589788842,3799.80698115964 4686.03220781221,3799.33032526302 PathPoint;PointKind.SMOOTHPOINT 4663.87903626965,3799.96497207822 4658.65899079482,3801.93590220076 4668.93942607407,3798.05432307231 PathPoint;PointKind.SMOOTHPOINT 4646.68795709086,3800.24094486012 4596.84192622562,3800.78767959034 4652.54569447712,3800.1766944391 PathPoint;PointKind.SMOOTHPOINT 4520.265625,3800.890625 4510.37692504667,3801.60247708493 4539.55262275752,3799.50222312408 PathPoint;PointKind.SMOOTHPOINT 4291.57558938936,3802.82256925913 4189.55202352295,3802.35321245715 4429.81340980066,3803.45852881171 PathPoint;PointKind.SMOOTHPOINT 3923.30622622898,3800.75676344282 3777.8483009661,3799.85645007931 4062.10555682888,3801.61586336439 PathPoint;PointKind.SMOOTHPOINT 3465.72137365418,3797.82300002478 3348.77036760836,3797.06500329642 3619.9221267298,3798.82242423064 PathPoint;PointKind.SMOOTHPOINT 3082.11370320409,3795.32634503409 3078.70594999892,3795.30860606408 3149.50541084861,3795.67715080217 PathPoint;PointKind.SMOOTHPOINT 3072.92971963539,3795.28129869811 3064.19483361983,3792.26183757785 3077.1416409614,3796.73726877749 PathPoint;PointKind.SMOOTHPOINT 3059.07951513497,3795.26502439829 3061.74514013497,3795.50408689829 3058.70314072533,3795.23126983517 PathPoint;PointKind.SMOOTHPOINT 2955.80731422594,3794.67165979133 2763.84055088764,3793.6095402993 2988.66296304247,3794.85344451502 PathPoint;PointKind.SMOOTHPOINT 2614.265625,3793.890625 2601.13665527549,3794.56707607168 2629.00748149547,3793.13107228306 PathPoint;PointKind.SMOOTHPOINT 2273.35353299452,3795.64820814403 2174.40547787104,3795.89405107946 2468.93902258035,3795.1622631618 PathPoint;PointKind.SMOOTHPOINT 1935.0482599041,3796.29823539251 1787.02586630146,3796.52029599644 2059.23381899826,3796.11193439047 PathPoint;PointKind.SMOOTHPOINT 1464.77120318183,3796.82367227458 1367.32391465296,3796.89984626535 1626.19712178408,3796.69748655284 PathPoint;PointKind.SMOOTHPOINT 1174.4622984749,3796.99508433491 1171.01319879377,3796.99644847439 1269.65900856309,3796.95743346879 PathPoint;PointKind.SMOOTHPOINT 1164.12484722189,3796.99909817748 1161.96149720212,3798.02620350998 1169.1892141294,3794.59466144331 PathPoint;PointKind.SMOOTHPOINT 1156.94540413579,3797.00179761706 1115.82360159479,3797.01705140349 1159.3368933763,3797.00091051426 PathPoint;PointKind.SMOOTHPOINT 1035.28241482485,3797.0361684776 904.295373532716,3797.0611867763 1075.19639294713,3797.0285449767 PathPoint;PointKind.SMOOTHPOINT 673.092678940373,3796.98230113938 605.298130552578,3796.94320406388 780.989664609053,3797.04452526646 PathPoint;PointKind.SMOOTHPOINT 464.481253059129,3796.67692943078 456.221102411524,3796.10722496563 503.162709862543,3799.34479828691 PathPoint;PointKind.SMOOTHPOINT 448.803805532525,3796.74546229265 446.732807571375,3796.03754414132 455.354807139065,3798.98475611796 PathPoint;PointKind.SMOOTHPOINT 437.326112595805,3796.7247766873 397.854790335112,3796.65138991779 441.098769371104,3796.73179097204 PathPoint;PointKind.SMOOTHPOINT 337.565459492755,3796.4649230569 295.640468804229,3796.30773892253 364.245403110983,3796.56495083923 PathPoint;PointKind.SMOOTHPOINT 244.265625,3794.890625 237.492878000653,3795.0491842943 247.832654092424,3794.8071159577 PathPoint;PointKind.SMOOTHPOINT 219.265625,3787.890625 214.836833062157,3784.85705419889 229.138306552162,3794.65307374576 PathPoint;PointKind.SMOOTHPOINT 204.265625,3773.890625 202.852794575732,3771.57997902572 207.130107841833,3778.57540926936 PathPoint;PointKind.SMOOTHPOINT 202.791839089469,3691.59494427729 202.771331822347,3689.23396711957 203.228596310852,3741.87828125474 PathPoint;PointKind.SMOOTHPOINT 203.265625,3683.890625 203.231790683799,3680.4862324825 203.289984310319,3686.34164701234 PathPoint;PointKind.SMOOTHPOINT 202.610522937203,3673.90676780778 202.471916316742,3662.24982334746 202.653029741465,3677.48162920209 PathPoint;PointKind.SMOOTHPOINT 202.019858230014,3636.31268505758 201.625439461875,3616.27964813427 202.28336696429,3649.69663285564 PathPoint;PointKind.SMOOTHPOINT 201.315229682631,3570.71085194426 201.326065796043,3570.23075191946 201.258979682631,3573.20303944426 PathPoint;PointKind.SMOOTHPOINT 202.265625,3560.890625 201.059818674364,3556.35959846539 203.775533184928,3566.56436704736 PathPoint;PointKind.SMOOTHPOINT 201.336538733199,3544.66878874087 201.334159633135,3514.47031977974 201.337038509597,3551.01256649297 PathPoint;PointKind.SMOOTHPOINT 201.349997566463,3430.33749843241 201.377542213858,3405.66275732763 201.311835324369,3464.52357568163 PathPoint;PointKind.SMOOTHPOINT 201.510476518384,3353.65402085076 201.523227780496,3349.36926014599 201.431910089249,3380.05441520539 PathPoint;PointKind.SMOOTHPOINT 201.550631326487,3340.73775352276 201.206369574176,3337.06436941414 202.080366456798,3346.39019849056 PathPoint;PointKind.SMOOTHPOINT 201.587849885666,3329.62553727427 201.629694643492,3317.52305277219 201.574992843724,3333.34409508003 PathPoint;PointKind.SMOOTHPOINT 201.727397546599,3292.87468129482 201.702506471927,3292.32382087591 201.894585046599,3296.57468129482 PathPoint;PointKind.SMOOTHPOINT 201.73125682093,3280.64088007881 201.952048005202,3280.16006303989 200.38594432093,3283.57056757881 PathPoint;PointKind.SMOOTHPOINT 202.270874753228,3266.25205971855 202.657587521801,3242.65518044532 202.128118934564,3274.96289652647 PathPoint;PointKind.SMOOTHPOINT 202.924311893985,3142.01688788437 202.932655339275,3138.5814118911 202.799827434046,3193.27429520279 PathPoint;PointKind.SMOOTHPOINT 202.94917120739,3131.69236889428 203.238290857547,3131.06445705496 201.17573370739,3135.54393139428 PathPoint;PointKind.SMOOTHPOINT 202.983852504718,3118.99434574995 203.049282027018,3094.46439749644 202.964484738283,3126.25544581219 PathPoint;PointKind.SMOOTHPOINT 203.366319647437,3018.61443310932 203.448609937275,3007.58334373052 203.197637617151,3041.22641511037 PathPoint;PointKind.SMOOTHPOINT 203.632646341637,2985.4323451047 203.664261278742,2981.73081101211 203.537942853976,2996.52040095323 PathPoint;PointKind.SMOOTHPOINT 203.72922448452,2974.31959756181 203.186945131578,2971.51988333696 204.949599728253,2980.62022824414 PathPoint;PointKind.SMOOTHPOINT 203.805729712912,2965.76027807316 204.261612476538,2915.32142781471 203.779929466252,2968.6148163048 PathPoint;PointKind.SMOOTHPOINT 205.287897752894,2813.76813057493 205.315470385207,2810.85787740695 204.807746369903,2864.44744430756 PathPoint;PointKind.SMOOTHPOINT 205.369933309663,2805.03941617228 205.226747630828,2804.7127327229 207.240245809663,2809.30660367228 PathPoint;PointKind.SMOOTHPOINT 205.563570784871,2793.9761583933 205.818108213231,2770.18595539716 205.492805053053,2800.59023922207 PathPoint;PointKind.SMOOTHPOINT 206.289878021975,2682.05031014978 206.411860923862,2657.35350650395 206.132906329167,2713.83098609108 PathPoint;PointKind.SMOOTHPOINT 206.319281775282,2608.23157240289 206.301756891544,2603.4604915665 206.409196404072,2632.71047729829 PathPoint;PointKind.SMOOTHPOINT 206.257040575294,2593.93785133771 205.145714220871,2590.43201921327 208.582480026622,2601.27377052963 PathPoint;PointKind.SMOOTHPOINT 206.196353811586,2582.9177337433 205.685653304073,2497.5885712445 206.21831245767,2586.58664116031 PathPoint;PointKind.SMOOTHPOINT 203.535415247982,2339.12725792507 203.505968338757,2336.06438808967 204.26239348007,2414.74265379099 PathPoint;PointKind.SMOOTHPOINT 203.450608668903,2329.9745538792 204.918666282298,2326.45242056298 202.281441775651,2332.77959479134 PathPoint;PointKind.SMOOTHPOINT 203.360181829963,2319.26272662573 203.04714486343,2279.93557891768 203.388465348589,2322.81601340541 PathPoint;PointKind.SMOOTHPOINT 203.364266524833,2208.41460426804 205.047657929083,2062.18333663259 202.968984911183,2242.75155721381 PathPoint;PointKind.SMOOTHPOINT 206.265625,1951.890625 206.267815413305,1944.8046379567 206.262086411123,1963.337960016 PathPoint;PointKind.SMOOTHPOINT 206.475178600938,1892.16281160872 206.496992656489,1891.80993718068 206.315803600938,1894.74093660872 PathPoint;PointKind.SMOOTHPOINT 205.265625,1883.890625 203.742480208274,1879.38745091979 206.384071631729,1887.1973098992 PathPoint;PointKind.SMOOTHPOINT 206.640044942325,1864.52729798202 206.826457452107,1819.68923842506 206.593672176004,1875.68140379047 PathPoint;PointKind.SMOOTHPOINT 207.609698932855,1631.84078397916 207.937214555762,1556.64096895074 207.293602635517,1704.41864417413 PathPoint;PointKind.SMOOTHPOINT 208.075480644059,1403.59999151534 208.077430620325,1400.47420272371 208.029403990899,1477.46031918859 PathPoint;PointKind.SMOOTHPOINT 208.081097149772,1394.2519162996 206.584841610338,1389.74132291372 209.185548008369,1397.58138015556 PathPoint;PointKind.SMOOTHPOINT 208.088927402212,1380.06945255074 208.1232827954,1315.05455103691 208.086442835981,1384.77130031983 PathPoint;PointKind.SMOOTHPOINT 208.265625,1206.890625 208.427113213178,1146.40111820711 208.136912954949,1255.10298657235 PathPoint;PointKind.SMOOTHPOINT 208.265625,1096.890625 208.011157633794,1086.61196102931 208.452514003514,1104.4396058205 PathPoint;PointKind.SMOOTHPOINT 207.72546661494,899.660228257606 207.843168008955,899.338190242756 206.88484161494,901.960228257606 PathPoint;PointKind.SMOOTHPOINT 206.265625,887.890625 206.276288173658,884.227086320549 206.24348149205,895.498453633071 PathPoint;PointKind.SMOOTHPOINT 207.933657403545,874.206572093356 207.831220120676,814.673213400079 207.942371973629,879.271208836278 PathPoint;PointKind.SMOOTHPOINT 205.265625,576.890625 204.330546140901,507.615906394699 206.452489179177,664.818697841294 PathPoint;PointKind.SMOOTHPOINT 203.14796527347,389.244063980332 203.132192962652,385.076835964082 203.360752554679,445.464939285907 PathPoint;PointKind.SMOOTHPOINT 205.265625,377.890625 205.236957637129,361.39955890101 205.272756701821,381.993177671336 PathPoint;PointKind.SMOOTHPOINT 203.265625,328.890625 203.662490930728,284.064270849511 203.128525880594,344.376090504556 PathPoint;PointKind.SMOOTHPOINT 205.265625,226.890625 205.246122918749,221.371244435699 205.350303950411,250.856033978423 PathPoint;PointKind.SMOOTHPOINT 203.265625,208.890625 203.292043587526,201.322522953265 203.251288557818,212.997568920132 PathPoint";
	
	mask45[1] = "PointKind.SMOOTHPOINT 204.265639185905,192.890610694885 204.041701555252,189.59061384201 204.372149705887,194.458823204041 PathPoint;PointKind.SMOOTHPOINT 211.849129199982,180.394005775452 215.230321884155,177.143340110779 207.015144824982,185.04175901413 PathPoint;PointKind.SMOOTHPOINT 228.000077605247,171.000072956085 237.095957994461,165.337135791779 223.255786299706,173.953807353973 PathPoint;PointKind.SMOOTHPOINT 246.265599131584,161.890561580658 248.797953128815,161.943197250366 239.54156935215,161.751065254211 PathPoint;PointKind.SMOOTHPOINT 416.265535354614,159.890642166138 438.888546824455,159.307165145874 339.789801836014,161.863181591034 PathPoint;PointKind.SMOOTHPOINT 483.175384998322,158.670580387115 487.080574035645,158.62596988678 461.64373755455,158.916292190552 PathPoint;PointKind.SMOOTHPOINT 496.99991941452,159.000084400177 497.855249047279,159.022035598755 489.934229850769,158.817157745361 PathPoint;PointKind.SMOOTHPOINT 501.520568132401,160.034387111664 505.106520652771,159.389069080353 498.887899518013,160.508108139038 PathPoint;PointKind.SMOOTHPOINT 516.981115937233,158.616056442261 545.93043923378,158.61888885498 510.29868721962,158.615348339081 PathPoint;PointKind.SMOOTHPOINT 603.265553712845,158.890564441681 619.04179751873,159.430611133575 593.463930487633,158.555159568787 PathPoint;PointKind.SMOOTHPOINT 1053.18870842457,159.418337345123 1098.77934157848,159.397566318512 802.264970541,159.532577991486 PathPoint;PointKind.SMOOTHPOINT 1196.06652259827,159.335961341858 1200.58569610119,159.332892894745 1146.60463035107,159.369714260101 PathPoint;PointKind.SMOOTHPOINT 1209.00002717972,158.00000667572 1211.02667748928,157.154531478882 1204.85703349113,159.72825050354 PathPoint;PointKind.SMOOTHPOINT 1216.26103520393,159.321799278259 1239.15755152702,159.305748939514 1214.05912935734,159.323451519012 PathPoint;PointKind.SMOOTHPOINT 1285.87583899498,159.269871711731 1366.80672168732,159.20637845993 1262.38186061382,159.288282394409 PathPoint;PointKind.SMOOTHPOINT 1535.90943217278,159.047055244446 1574.77662563324,159.008817672729 1450.93911588192,159.130375385284 PathPoint;PointKind.SMOOTHPOINT 1652.81107127666,158.928565979004 1657.3051661253,158.923845291138 1613.81936967373,158.969163894653 PathPoint;PointKind.SMOOTHPOINT 1666.29070043564,158.914403915405 1666.89701378345,159.165780544281 1661.17347478867,156.794106960297 PathPoint;PointKind.SMOOTHPOINT 1688.30503821373,158.891980648041 1720.16997635365,158.857991695404 1675.41519999504,158.905670642853 PathPoint;PointKind.SMOOTHPOINT 1813.74581158161,158.755080699921 1926.86322927475,158.629746437073 1779.05731201172,158.79355430603 PathPoint;PointKind.SMOOTHPOINT 2137.86233961582,158.383326530457 2164.54632282257,158.351933956146 2036.82663738728,158.501579761505 PathPoint;PointKind.SMOOTHPOINT 2190.93998372555,158.291981220245 2196.94292843342,158.150124549866 2165.61467349529,158.890328407288 PathPoint;PointKind.SMOOTHPOINT 2210.02601981163,158.269557952881 2213.97369503975,159.427070617676 2203.92925143242,156.48206949234 PathPoint;PointKind.SMOOTHPOINT 2219.75388228893,158.258228302002 2310.16951203346,158.152956962585 2216.52434170246,158.262004852295 PathPoint;PointKind.SMOOTHPOINT 2480.01543581486,157.994341850281 2568.06452572346,157.90370464325 2415.31693339348,158.061139583588 PathPoint;PointKind.SMOOTHPOINT 2645.2657699585,157.890722751617 2669.4743424654,157.933208942413 2627.50093638897,157.859330177307 PathPoint;PointKind.SMOOTHPOINT 2918.60392391682,158.536984920502 2989.47974145412,158.708581924438 2771.7288672924,158.181281089783 PathPoint;PointKind.SMOOTHPOINT 3158.64677131176,159.115977287292 3202.54267752171,159.221012592316 3070.74579298496,158.905198574066 PathPoint;PointKind.SMOOTHPOINT 3325.19057393074,161.670341491699 3329.097828269,161.728641986847 3268.44525039196,160.824394226074 PathPoint;PointKind.SMOOTHPOINT 3336.77189648151,161.833441257477 3343.81486773491,160.138714313507 3333.06704163551,162.724943161011 PathPoint;PointKind.SMOOTHPOINT 3350.82184374332,162.000789642334 3395.14792263508,162.464833259583 3346.23599052429,161.952874660492 PathPoint;PointKind.SMOOTHPOINT 3441.99986457825,159.99992609024 3456.54430389404,157.882697582245 3434.87546145916,161.037061214447 PathPoint;PointKind.SMOOTHPOINT 3946.57914340496,158.480808734894 3974.7840732336,158.58466386795 3680.50789833069,157.501974105835 PathPoint;PointKind.SMOOTHPOINT 4031.93862140179,158.815505504608 4035.99546253681,158.832499980927 4003.31679582596,158.697016239166 PathPoint;PointKind.SMOOTHPOINT 4044.11357045174,158.86625289917 4048.54688644409,157.996466159821 4040.12989997864,159.647998809814 PathPoint;PointKind.SMOOTHPOINT 4053.30888032913,158.905198574066 4085.64854264259,159.04233455658 4050.24338364601,158.892216682434 PathPoint;PointKind.SMOOTHPOINT 4150.09743869305,159.334781169891 4318.0606931448,160.11109828949 4118.02597045898,159.186787605286 PathPoint;PointKind.SMOOTHPOINT 4579.48117554188,161.501812934875 4645.282548666,161.830372810364 4477.63912081718,160.993158817291 PathPoint;PointKind.SMOOTHPOINT 4691.26558899879,161.890561580658 4697.12425768375,161.34744644165 4686.99779212475,162.286155223846 PathPoint;PointKind.SMOOTHPOINT 4725.2657532692,162.890639305115 4726.80086195469,163.612432479858 4723.24824929237,161.942253112793 PathPoint;PointKind.SMOOTHPOINT 4739.99990522861,175.999989509583 4740.84284305573,178.203134536743 4738.04111480713,170.87993144989 PathPoint;PointKind.SMOOTHPOINT 4741.14467203617,220.615210533142 4741.19099378586,223.556671142578 4740.71036875248,192.918934822083 PathPoint;PointKind.SMOOTHPOINT 4741.27744138241,229.803085327148 4740.29022753239,234.117558002472 4741.98760986328,226.700649261475 PathPoint;PointKind.SMOOTHPOINT 4742.00000166893,262.999906539917 4742.51573681831,309.782631397247 4741.95338487625,258.773002624512 PathPoint;PointKind.SMOOTHPOINT 4742.2655403614,432.890617847443 4742.32661426067,472.856197357178 4742.14840829372,356.084790229797 PathPoint;PointKind.SMOOTHPOINT 4743.26573610306,569.890644550323 4743.17043721676,621.329855918884 4743.35159361362,523.301467895508 PathPoint;PointKind.SMOOTHPOINT 4745.96832990646,723.217170238495 4745.54523825645,822.763259410858 4746.21174037457,666.005029678345 PathPoint;PointKind.SMOOTHPOINT 4744.185090065,1036.22450351715 4743.68351697922,1109.07297849655 4744.92210745811,929.219491481781 PathPoint;PointKind.SMOOTHPOINT 4748.31539690495,1255.06709575653 4748.32306802273,1259.7188615799 4748.19767475128,1183.53073596954 PathPoint;PointKind.SMOOTHPOINT 4748.27999174595,1268.98415565491 4747.00983166695,1271.69501066208 4749.55044686794,1266.27306461334 PathPoint;PointKind.SMOOTHPOINT 4746.26573324203,1274.89068031311 4746.24065458775,1277.94378519058 4746.27074897289,1274.25527572632 PathPoint;PointKind.SMOOTHPOINT 4747.99999594688,1286.99995279312 4747.33467400074,1375.98586320877 4748.02271425724,1283.9591217041 PathPoint;PointKind.SMOOTHPOINT 4747.08064198494,1531.49853944778 4745.28530538082,1719.21716451645 4747.83477187157,1452.62434244156 PathPoint;PointKind.SMOOTHPOINT 4742.72551238537,1919.74962472916 4742.68627166748,1922.16095209122 4743.59205365181,1866.55431747437 PathPoint;PointKind.SMOOTHPOINT 4744.26563680172,1926.89060926437 4744.65745389462,1934.99485015869 4744.16797757149,1924.87322330475 PathPoint;PointKind.SMOOTHPOINT 4742.2655403614,1940.8905172348 4742.00236201286,1944.87100124359 4742.34844744205,1939.6378827095 PathPoint;PointKind.SMOOTHPOINT 4742.18027293682,2050.54690361023 4742.44964718819,2147.26246833801 4741.99793636799,1984.9999165535 PathPoint;PointKind.SMOOTHPOINT 4743.97944509983,2472.24004983902 4744.49488520622,2576.61516666412 4743.12618076801,2299.31700468063 PathPoint;PointKind.SMOOTHPOINT 4738.66926133633,2801.593708992 4738.67280185223,2802.41133213043 4738.17565441132,2689.57863092422 PathPoint;PointKind.SMOOTHPOINT 4738.68106305599,2804.0461063385 4738.69758546352,2807.15538740158 4738.67663741112,2803.22871923447 PathPoint;PointKind.SMOOTHPOINT 4738.00010383129,2813.9999127388 4740.80920815468,2817.24514961243 4735.96519231796,2811.64924621582 PathPoint;PointKind.SMOOTHPOINT 4738.77695202827,2822.10580587387 4739.29917812347,2920.37070035934 4738.76160979271,2819.19550180435 PathPoint;PointKind.SMOOTHPOINT 4740.33448398113,3110.76123476028 4741.22167825699,3273.27539920807 4739.82996046543,3018.29664945602 PathPoint;PointKind.SMOOTHPOINT 4742.2655403614,3493.89060974121 4742.71253049374,3577.15953111649 4741.72384142876,3392.9313826561 PathPoint;PointKind.SMOOTHPOINT 4741.26563966274,3665.89052438736 4741.15617871284,3706.57813310623 4741.28422737122,3659.0193271637 PathPoint;PointKind.SMOOTHPOINT 4740.26573896408,3783.89072656631 4734.13917124271,3800.26962518692 4742.17968285084,3778.77350091934 PathPoint;PointKind.SMOOTHPOINT 4706.26557469368,3797.89063453674 4697.19270765781,3798.75428438187 4737.22443580627,3794.94350910187 PathPoint;PointKind.SMOOTHPOINT 4673.69341850281,3799.70880746841 4670.49603760242,3799.80699777603 4686.03211641312,3799.33020830154 PathPoint;PointKind.SMOOTHPOINT 4661.04610562325,3799.10337924957 4654.94402647018,3800.80613136292 4666.25597476959,3797.64964342117 PathPoint;PointKind.SMOOTHPOINT 4646.68783843517,3800.24082899094 4596.84534072876,3801.04004144669 4652.45268344879,3800.14830350876 PathPoint;PointKind.SMOOTHPOINT 4520.2657520771,3800.89063167572 4510.37679612637,3801.60251140594 4539.55271244049,3799.50227737427 PathPoint;PointKind.SMOOTHPOINT 4291.57556891441,3802.82257318497 4189.55206274986,3802.35310077667 4429.81353700161,3803.45844984055 PathPoint;PointKind.SMOOTHPOINT 3923.30615222454,3800.75680017471 3777.84818708897,3799.85656499863 4062.10558712482,3801.61596536636 PathPoint;PointKind.SMOOTHPOINT 3465.72132110596,3797.82289266586 3348.77040982246,3797.06498622894 3619.92200016975,3798.82249832153 PathPoint;PointKind.SMOOTHPOINT 3082.11379945278,3795.32635688782 3078.70605289936,3795.30865430832 3149.50545430183,3795.67710399628 PathPoint;PointKind.SMOOTHPOINT 3072.92970120907,3795.2812743187 3064.19495344162,3792.26192235947 3077.1417349577,3796.73737049103 PathPoint;PointKind.SMOOTHPOINT 3059.0794980526,3795.26498794556 3061.74521148205,3795.50409078598 3058.70302319527,3795.23123502731 PathPoint;PointKind.SMOOTHPOINT 2955.80736994743,3794.67159748077 2763.84059786797,3793.60944271088 2988.66306245327,3794.85334396362 PathPoint;PointKind.SMOOTHPOINT 2614.26560282707,3793.89055967331 2601.13677978516,3794.56703424454 2629.00742590427,3793.13100099564 PathPoint;PointKind.SMOOTHPOINT 2273.35345745087,3795.64830780029 2174.40547943115,3795.89401960373 2468.93893182278,3795.16231298447 PathPoint;PointKind.SMOOTHPOINT 1935.04831194878,3796.29834651947 1787.02583312988,3796.52021884918 2059.23367738724,3796.11187934875 PathPoint;PointKind.SMOOTHPOINT 1464.7713214159,3796.82375907898 1367.32393205166,3796.89976215363 1626.19701325893,3796.69748067856 PathPoint;PointKind.SMOOTHPOINT 1174.46229457855,3796.99512004852 1171.0132420063,3796.99653625488 1269.65909600258,3796.95735454559 PathPoint;PointKind.SMOOTHPOINT 1164.12487328053,3796.99913263321 1161.96161806583,3798.0261182785 1169.18928623199,3794.59465026855 PathPoint;PointKind.SMOOTHPOINT 1156.945297122,3797.00172901154 1115.82368016243,3797.0170712471 1159.33691561222,3797.00102090836 PathPoint;PointKind.SMOOTHPOINT 1035.28254926205,3797.03619003296 972.019430994987,3797.04822778702 1075.19626021385,3797.02863693237 PathPoint;PointKind.SMOOTHPOINT 851.738959550858,3797.04279899597 850.282627344131,3797.04256296158 910.548108816147,3797.05058813095 PathPoint;PointKind.SMOOTHPOINT 847.374978661537,3797.04209089279 845.46634554863,3795.62210798264 850.596848130226,3799.43925619125 PathPoint;PointKind.SMOOTHPOINT 840.251460671425,3797.04114675522 781.489518284798,3797.03194141388 842.621541023254,3797.04161882401 PathPoint;PointKind.SMOOTHPOINT 673.09278845787,3796.98237419128 605.29810488224,3796.94319248199 725.475311279297,3797.01258659363 PathPoint;PointKind.SMOOTHPOINT 464.481166005135,3796.67694568634 456.221142411232,3796.10715866089 503.162777423859,3799.34484243393 PathPoint;PointKind.SMOOTHPOINT 448.803761601448,3796.7453956604 446.73285484314,3796.03752851486 455.354896187782,3798.98465394974 PathPoint;PointKind.SMOOTHPOINT 437.325999140739,3796.72486066818 397.854852676392,3796.65145397186 441.098713874817,3796.73170566559 PathPoint;PointKind.SMOOTHPOINT 337.565472722054,3796.46498680115 295.640453696251,3796.3077878952 364.24532532692,3796.56506538391 PathPoint;PointKind.SMOOTHPOINT 244.265502691269,3794.89063739777 237.492790818214,3795.04925251007 247.832572460175,3794.80708122253 PathPoint;PointKind.SMOOTHPOINT 219.265624880791,3787.89056539536 214.83673453331,3784.85705137253 229.138353466988,3794.6531867981 PathPoint;PointKind.SMOOTHPOINT 204.265639185905,3773.89065742493 202.85267829895,3771.57988071442 207.130211591721,3778.57546806335 PathPoint;PointKind.SMOOTHPOINT 202.791899442673,3691.59490585327 202.771246433258,3689.23385381699 203.228563070297,3741.87825679779 PathPoint;PointKind.SMOOTHPOINT 203.265738487244,3683.89050722122 203.231808543205,3680.4861831665 203.289932012558,3686.34172439575 PathPoint;PointKind.SMOOTHPOINT 202.610448002815,3673.90672445297 202.471777796745,3662.24992990494 202.652934193611,3677.48170137405 PathPoint;PointKind.SMOOTHPOINT 202.019771933556,3636.31258249283 201.829764246941,3626.65948390961 202.283245325089,3649.69667673111 PathPoint;PointKind.SMOOTHPOINT 201.513183116913,3598.42032909393 201.497840881348,3596.88917398453 201.646247506142,3611.65548563004 PathPoint;PointKind.SMOOTHPOINT 201.469221711159,3593.9087677002 203.274294734001,3591.08792066574 200.67526102066,3595.14936447144 PathPoint;PointKind.SMOOTHPOINT 201.406672596931,3586.96321964264 201.331436634064,3578.13128471375 201.425260305405,3589.15149450302 PathPoint;PointKind.SMOOTHPOINT 201.315209269524,3570.71083545685 201.326125860214,3570.23074150085 201.294261217117,3571.63443803787 PathPoint;PointKind.SMOOTHPOINT 202.26554274559,3560.89062452316 201.059702038765,3556.35970830917 203.775572776794,3566.56441926956 PathPoint;PointKind.SMOOTHPOINT 201.336452364922,3544.66868877411 201.334092020988,3514.47021245956 201.337042450905,3551.01258516312 PathPoint;PointKind.SMOOTHPOINT 201.350024342537,3430.33740520477 201.377463340759,3405.66284179688 201.311963796616,3464.5236825943 PathPoint;PointKind.SMOOTHPOINT 201.510527729988,3353.65407943726 201.523214578629,3349.36934709549 201.432046294212,3380.05452632904 PathPoint;PointKind.SMOOTHPOINT 201.550653576851,3340.73780536652 201.206338405609,3337.06440210342 202.080255746841,3346.39012098312 PathPoint;PointKind.SMOOTHPOINT 201.587828993797,3329.62554216385 201.62972509861,3317.52311468124 201.574847102165,3333.34402799606 PathPoint;PointKind.SMOOTHPOINT 201.727384328842,3292.874751091 201.702600717545,3292.32384681702 201.894673705101,3296.57459020615 PathPoint;PointKind.SMOOTHPOINT 201.731219887733,3280.64085245132 201.951912045479,3280.16005039215 200.385823845863,3283.57051134109 PathPoint;PointKind.SMOOTHPOINT 202.27085351944,3266.25195980072 202.657654881477,3242.65512943268 202.128052711487,3274.96280908585 PathPoint;PointKind.SMOOTHPOINT 202.924373745918,3142.01690912247 202.932634949684,3138.58142852783 202.799865603447,3193.27437400818 PathPoint;PointKind.SMOOTHPOINT 202.949157357216,3131.69229269028 203.238299489021,3131.06444120407 201.175653934479,3135.54390192032 PathPoint;PointKind.SMOOTHPOINT 202.983972430229,3118.99435043335 202.986627817154,3117.96736478806 202.964499592781,3126.25547647476 PathPoint;PointKind.SMOOTHPOINT 202.992528676987,3115.76705217361 202.997544407845,3113.90875339508 202.98957824707,3116.89033985138 PathPoint;PointKind.SMOOTHPOINT 203.008756041527,3109.83385562897 204.670438170433,3107.76831865311 201.698470115662,3111.4627289772 PathPoint;PointKind.SMOOTHPOINT 203.026163578033,3103.57516765594 203.102284669876,3076.55371427536 203.019967675209,3105.7466840744 PathPoint;PointKind.SMOOTHPOINT 203.366348147392,3018.61435174942 203.448665142059,3007.58328437805 203.227382898331,3037.21834659576 PathPoint;PointKind.SMOOTHPOINT 203.632771968842,2985.43240070343 203.664341568947,2981.73090934753 203.538063168526,2996.52035236359 PathPoint;PointKind.SMOOTHPOINT 203.729251027107,2974.31966543198 203.186962008476,2971.51982545853 204.949548840523,2980.62013149261 PathPoint;PointKind.SMOOTHPOINT 203.805667161942,2965.76035022736 204.261508584023,2915.32145261765 203.779998421669,2968.61471414566 PathPoint;PointKind.SMOOTHPOINT 205.287963151932,2813.76812696457 205.315402150154,2810.85782289505 204.807633161545,2864.44754362106 PathPoint;PointKind.SMOOTHPOINT 205.369985103607,2805.03933906555 205.226889252663,2804.71266746521 207.240262627602,2809.30660486221 PathPoint;PointKind.SMOOTHPOINT 205.563533306122,2793.97617101669 205.818155407906,2770.18602848053 205.492722988129,2800.59032678604 PathPoint;PointKind.SMOOTHPOINT 206.289929151535,2682.05031394958 206.411781907082,2657.35356330872 206.132966279984,2713.83092880249 PathPoint;PointKind.SMOOTHPOINT 206.319138407707,2608.23150157928 206.301730871201,2603.4605383873 206.409126520157,2632.71039247513 PathPoint;PointKind.SMOOTHPOINT 206.257179379463,2593.93796682358 205.145752429962,2590.43191194534 208.582413196564,2601.27367973328 PathPoint;PointKind.SMOOTHPOINT 206.196400523186,2582.9177570343 205.68568110466,2497.58849143982 206.218233704567,2586.58667564392 PathPoint;PointKind.SMOOTHPOINT 203.535407781601,2339.12727355957 203.505903482437,2336.06449127197 204.262393712997,2414.74254369736 PathPoint;PointKind.SMOOTHPOINT 203.450730443001,2329.97456789017 204.918569326401,2326.45246267319 202.281475067139,2332.77960062027 PathPoint;PointKind.SMOOTHPOINT 203.360152244568,2319.26261901855 203.04711163044,2279.93551254272 203.388476371765,2322.81611680984 PathPoint;PointKind.SMOOTHPOINT 203.364282846451,2208.4144949913 205.047798156738,2062.18339920044 202.968925237656,2242.75159835815 PathPoint;PointKind.SMOOTHPOINT 206.265735626221,1951.89066410065 206.267800927162,1944.80467557907 206.262195110321,1963.33786010742 PathPoint;PointKind.SMOOTHPOINT 206.475216150284,1892.16286897659 206.497049331665,1891.80999755859 206.315892934799,1894.74083662033 PathPoint;PointKind.SMOOTHPOINT 208.999899029732,1878.99993896484 207.476887106895,1874.49687480927 210.118407011032,1882.30678081512 PathPoint;PointKind.SMOOTHPOINT 206.64014518261,1864.52725410461 206.826317310333,1819.68921661377 206.593528389931,1875.6812953949 PathPoint;PointKind.SMOOTHPOINT 207.609656453133,1631.84077262878 207.937154173851,1556.64092302322 207.293665409088,1704.41875219345 PathPoint;PointKind.SMOOTHPOINT 208.075529336929,1403.59999895096 208.077299594879,1400.47419548035 208.029502630234,1477.46035337448 PathPoint;PointKind.SMOOTHPOINT 208.08113515377,1394.25185680389 206.584972143173,1389.74123954773 209.185481071472,1397.58135795593 PathPoint;PointKind.SMOOTHPOINT 208.088806271553,1380.06949424744 208.123326301575,1315.05452871323 208.08644592762,1384.77129936218 PathPoint;PointKind.SMOOTHPOINT 208.265537023544,1206.8905878067 208.427220582962,1146.40110969543 208.13689827919,1255.10297298431 PathPoint;PointKind.SMOOTHPOINT 208.265537023544,1096.89053535461 208.011209964752,1086.61194562912 208.452594280243,1104.43962335587 PathPoint;PointKind.SMOOTHPOINT 207.725608348846,886.660130023956 207.843035459518,886.338179111481 206.884735822678,888.960049152374 PathPoint;PointKind.SMOOTHPOINT 206.265735626221,874.890511035919 208.263766765594,869.017739295959 203.815108537674,882.093100547791 PathPoint;PointKind.SMOOTHPOINT 207.933613657951,861.20641708374 207.831233739853,801.673114299774 207.942464947701,866.271243095398 PathPoint;PointKind.SMOOTHPOINT 205.265539884567,576.890716552734 204.330548644066,507.615802288055 206.452497839928,664.818720817566 PathPoint;PointKind.SMOOTHPOINT 203.14801633358,396.24415397644 203.132084012032,392.076966762543 203.360742330551,452.464950084686 PathPoint;PointKind.SMOOTHPOINT 205.000001192093,381.000108718872 203.152737021446,364.999573230743 205.470594763756,385.075478553772 PathPoint;PointKind.SMOOTHPOINT 203.265738487244,328.890559673309 203.662571310997,284.06432390213 203.128543496132,344.376068115234 PathPoint;PointKind.SMOOTHPOINT 204.000100493431,235.999932289124 203.980627655983,230.48050403595 204.084777832031,259.965212345123 PathPoint;PointKind.SMOOTHPOINT 203.265738487244,208.890674114227 203.291997313499,201.322467327118 203.251281380653,212.997672557831 PathPoint";
	
	mask45[2] = "PointKind.SMOOTHPOINT 204.265639185905,192.890610694885 204.041701555252,189.59061384201 204.372149705887,194.458823204041 PathPoint;PointKind.SMOOTHPOINT 211.849129199982,180.394005775452 215.230321884155,177.143340110779 207.015144824982,185.04175901413 PathPoint;PointKind.SMOOTHPOINT 226.999881863594,168.999917507172 236.095762252808,163.336980342865 222.255590558052,171.95365190506 PathPoint;PointKind.SMOOTHPOINT 246.265599131584,161.890561580658 248.797953128815,161.943197250366 239.54156935215,161.751065254211 PathPoint;PointKind.SMOOTHPOINT 416.265535354614,159.890642166138 438.888546824455,159.307165145874 339.789801836014,161.863181591034 PathPoint;PointKind.SMOOTHPOINT 490.175279974937,158.670580387115 494.08046901226,158.62596988678 468.643632531166,158.916292190552 PathPoint;PointKind.SMOOTHPOINT 504.000109434128,159.000084400177 504.855439066887,159.022035598755 496.934419870377,158.817157745361 PathPoint;PointKind.SMOOTHPOINT 508.520463109016,160.034387111664 512.106415629387,159.389069080353 505.887794494629,160.508108139038 PathPoint;PointKind.SMOOTHPOINT 523.981010913849,158.616056442261 552.930334210396,158.61888885498 517.298582196236,158.615348339081 PathPoint;PointKind.SMOOTHPOINT 603.265553712845,158.890564441681 619.04179751873,159.430611133575 593.463930487633,158.555159568787 PathPoint;PointKind.SMOOTHPOINT 1053.18870842457,159.418337345123 1098.77934157848,159.397566318512 802.264970541,159.532577991486 PathPoint;PointKind.SMOOTHPOINT 1187.06653118134,159.335961341858 1191.58570468426,159.332892894745 1137.60463893414,159.369714260101 PathPoint;PointKind.SMOOTHPOINT 1200.00003576279,158.00000667572 1202.02668607235,157.154531478882 1195.8570420742,159.72825050354 PathPoint;PointKind.SMOOTHPOINT 1207.261043787,159.321799278259 1230.15756011009,159.305748939514 1205.05913794041,159.323451519012 PathPoint;PointKind.SMOOTHPOINT 1285.87583899498,159.269871711731 1366.80672168732,159.20637845993 1262.38186061382,159.288282394409 PathPoint;PointKind.SMOOTHPOINT 1535.90943217278,159.047055244446 1574.77662563324,159.008817672729 1450.93911588192,159.130375385284 PathPoint;PointKind.SMOOTHPOINT 1652.81107127666,158.928565979004 1657.3051661253,158.923845291138 1613.81936967373,158.969163894653 PathPoint;PointKind.SMOOTHPOINT 1666.29070043564,158.914403915405 1666.89701378345,159.165780544281 1661.17347478867,156.794106960297 PathPoint;PointKind.SMOOTHPOINT 1688.30503821373,158.891980648041 1720.16997635365,158.857991695404 1675.41519999504,158.905670642853 PathPoint;PointKind.SMOOTHPOINT 1813.74581158161,158.755080699921 1926.86322927475,158.629746437073 1779.05731201172,158.79355430603 PathPoint;PointKind.SMOOTHPOINT 2137.86233961582,158.383326530457 2164.54632282257,158.351933956146 2036.82663738728,158.501579761505 PathPoint;PointKind.SMOOTHPOINT 2190.93998372555,158.291981220245 2196.94292843342,158.150124549866 2165.61467349529,158.890328407288 PathPoint;PointKind.SMOOTHPOINT 2210.02601981163,158.269557952881 2213.97369503975,159.427070617676 2203.92925143242,156.48206949234 PathPoint;PointKind.SMOOTHPOINT 2219.75388228893,158.258228302002 2310.16951203346,158.152956962585 2216.52434170246,158.262004852295 PathPoint;PointKind.SMOOTHPOINT 2480.01543581486,157.994341850281 2568.06452572346,157.90370464325 2415.31693339348,158.061139583588 PathPoint;PointKind.SMOOTHPOINT 2645.2657699585,157.890722751617 2669.4743424654,157.933208942413 2627.50093638897,157.859330177307 PathPoint;PointKind.SMOOTHPOINT 2918.60392391682,158.536984920502 2989.47974145412,158.708581924438 2771.7288672924,158.181281089783 PathPoint;PointKind.SMOOTHPOINT 3158.64677131176,159.115977287292 3202.54267752171,159.221012592316 3070.74579298496,158.905198574066 PathPoint;PointKind.SMOOTHPOINT 3325.19057393074,161.670341491699 3329.097828269,161.728641986847 3268.44525039196,160.824394226074 PathPoint;PointKind.SMOOTHPOINT 3336.00006401539,159.99992609024 3339.63971436024,159.93643283844 3332.18987882137,160.066487789154 PathPoint;PointKind.SMOOTHPOINT 3350.82184374332,162.000789642334 3395.14792263508,162.464833259583 3346.23599052429,161.952874660492 PathPoint;PointKind.SMOOTHPOINT 3441.99986457825,159.99992609024 3456.54430389404,157.882697582245 3434.87546145916,161.037061214447 PathPoint;PointKind.SMOOTHPOINT 3946.57914340496,158.480808734894 3974.7840732336,158.58466386795 3680.50789833069,157.501974105835 PathPoint;PointKind.SMOOTHPOINT 4031.93862140179,158.815505504608 4035.99546253681,158.832499980927 4003.31679582596,158.697016239166 PathPoint;PointKind.SMOOTHPOINT 4044.11357045174,158.86625289917 4048.54688644409,157.996466159821 4040.12989997864,159.647998809814 PathPoint;PointKind.SMOOTHPOINT 4053.30888032913,158.905198574066 4085.64854264259,159.04233455658 4050.24338364601,158.892216682434 PathPoint;PointKind.SMOOTHPOINT 4150.09743869305,159.334781169891 4318.0606931448,160.11109828949 4118.02597045898,159.186787605286 PathPoint;PointKind.SMOOTHPOINT 4579.48117554188,161.501812934875 4620.18442153931,161.705038547516 4477.63912081718,160.993158817291 PathPoint;PointKind.SMOOTHPOINT 4670.77957391739,162.026045322418 4674.22184050083,162.03831911087 4651.67140960693,161.956887245178 PathPoint;PointKind.SMOOTHPOINT 4679.99996244907,162.999923229218 4682.88813829422,162.999215126038 4677.37968564034,163.000867366791 PathPoint;PointKind.SMOOTHPOINT 4686.99071109295,162.013063430786 4689.19822275639,161.988515853882 4685.14846265316,162.033362388611 PathPoint;PointKind.SMOOTHPOINT 4691.26558899879,161.890561580658 4697.12425768375,161.34744644165 4690.6374424696,161.948862075806 PathPoint;PointKind.SMOOTHPOINT 4725.2657532692,162.890639305115 4726.80086195469,163.612432479858 4723.24824929237,161.942253112793 PathPoint;PointKind.SMOOTHPOINT 4739.99990522861,175.999989509583 4740.84284305573,178.203134536743 4738.04111480713,170.87993144989 PathPoint;PointKind.SMOOTHPOINT 4741.14467203617,220.615210533142 4741.19099378586,223.556671142578 4740.71036875248,192.918934822083 PathPoint;PointKind.SMOOTHPOINT 4741.27744138241,229.803085327148 4740.29022753239,234.117558002472 4741.98760986328,226.700649261475 PathPoint;PointKind.SMOOTHPOINT 4742.00000166893,262.999906539917 4742.51573681831,309.782631397247 4741.95338487625,258.773002624512 PathPoint;PointKind.SMOOTHPOINT 4742.2655403614,432.890617847443 4742.32661426067,472.856197357178 4742.14840829372,356.084790229797 PathPoint;PointKind.SMOOTHPOINT 4743.26573610306,569.890644550323 4743.17043721676,621.329855918884 4743.35159361362,523.301467895508 PathPoint;PointKind.SMOOTHPOINT 4745.96832990646,723.217170238495 4745.54523825645,822.763259410858 4746.21174037457,666.005029678345 PathPoint;PointKind.SMOOTHPOINT 4744.185090065,1036.22450351715 4743.68351697922,1109.07297849655 4744.92210745811,929.219491481781 PathPoint;PointKind.SMOOTHPOINT 4748.31539690495,1255.06709575653 4748.32306802273,1259.7188615799 4748.19767475128,1183.53073596954 PathPoint;PointKind.SMOOTHPOINT 4748.27999174595,1268.98415565491 4747.00983166695,1271.69501066208 4749.55044686794,1266.27306461334 PathPoint;PointKind.SMOOTHPOINT 4747.99999594688,1274.99996423721 4747.97491729259,1278.05306911469 4748.00501167774,1274.36455965042 PathPoint;PointKind.SMOOTHPOINT 4747.99999594688,1286.99995279312 4747.33467400074,1375.98586320877 4748.02271425724,1283.9591217041 PathPoint;PointKind.SMOOTHPOINT 4747.08064198494,1531.49853944778 4745.28530538082,1719.21716451645 4747.83477187157,1452.62434244156 PathPoint;PointKind.SMOOTHPOINT 4742.72551238537,1919.74962472916 4742.68627166748,1922.16095209122 4743.59205365181,1866.55431747437 PathPoint;PointKind.SMOOTHPOINT 4742.99990236759,1927.99997091293 4743.39171946049,1936.10421180725 4742.90253818035,1925.98258495331 PathPoint;PointKind.SMOOTHPOINT 4742.2655403614,1940.8905172348 4742.00236201286,1944.87100124359 4742.34844744205,1939.6378827095 PathPoint;PointKind.SMOOTHPOINT 4742.18027293682,2050.54690361023 4742.44964718819,2147.26246833801 4741.99793636799,1984.9999165535 PathPoint;PointKind.SMOOTHPOINT 4743.97944509983,2472.24004983902 4744.49488520622,2576.61516666412 4743.12618076801,2299.31700468063 PathPoint;PointKind.SMOOTHPOINT 4738.66926133633,2801.593708992 4738.67280185223,2802.41133213043 4738.17565441132,2689.57863092422 PathPoint;PointKind.SMOOTHPOINT 4738.68106305599,2804.0461063385 4738.69758546352,2807.15538740158 4738.67663741112,2803.22871923447 PathPoint;PointKind.SMOOTHPOINT 4741.00010097027,2811.99999332428 4741.20132029057,2816.74688100815 4740.86821675301,2808.89378070831 PathPoint;PointKind.SMOOTHPOINT 4738.77695202827,2822.10580587387 4739.29917812347,2920.37070035934 4738.76160979271,2819.19550180435 PathPoint;PointKind.SMOOTHPOINT 4740.33448398113,3110.76123476028 4741.22167825699,3273.27539920807 4739.82996046543,3018.29664945602 PathPoint;PointKind.SMOOTHPOINT 4742.2655403614,3493.89060974121 4742.71253049374,3577.15953111649 4741.72384142876,3392.9313826561 PathPoint;PointKind.SMOOTHPOINT 4741.26563966274,3665.89052438736 4741.15617871284,3706.57813310623 4741.28422737122,3659.0193271637 PathPoint;PointKind.SMOOTHPOINT 4740.26573896408,3783.89072656631 4734.13917124271,3800.26962518692 4742.17968285084,3778.77350091934 PathPoint;PointKind.SMOOTHPOINT 4706.26557469368,3797.89063453674 4697.19270765781,3798.75428438187 4737.22443580627,3794.94350910187 PathPoint;PointKind.SMOOTHPOINT 4673.69341850281,3799.70880746841 4670.49603760242,3799.80699777603 4686.03211641312,3799.33020830154 PathPoint;PointKind.SMOOTHPOINT 4661.04610562325,3799.10337924957 4654.94402647018,3800.80613136292 4666.25597476959,3797.64964342117 PathPoint;PointKind.SMOOTHPOINT 4646.68783843517,3800.24082899094 4596.84534072876,3801.04004144669 4652.45268344879,3800.14830350876 PathPoint;PointKind.SMOOTHPOINT 4520.2657520771,3800.89063167572 4510.37679612637,3801.60251140594 4539.55271244049,3799.50227737427 PathPoint;PointKind.SMOOTHPOINT 4291.57556891441,3802.82257318497 4189.55206274986,3802.35310077667 4429.81353700161,3803.45844984055 PathPoint;PointKind.SMOOTHPOINT 3923.30615222454,3800.75680017471 3777.84818708897,3799.85656499863 4062.10558712482,3801.61596536636 PathPoint;PointKind.SMOOTHPOINT 3465.72132110596,3797.82289266586 3348.77040982246,3797.06498622894 3619.92200016975,3798.82249832153 PathPoint;PointKind.SMOOTHPOINT 3082.11379945278,3795.32635688782 3078.70605289936,3795.30865430832 3149.50545430183,3795.67710399628 PathPoint;PointKind.SMOOTHPOINT 3072.92970120907,3795.2812743187 3064.19495344162,3792.26192235947 3077.1417349577,3796.73737049103 PathPoint;PointKind.SMOOTHPOINT 3059.0794980526,3795.26498794556 3061.74521148205,3795.50409078598 3058.70302319527,3795.23123502731 PathPoint;PointKind.SMOOTHPOINT 2955.80736994743,3794.67159748077 2763.84059786797,3793.60944271088 2988.66306245327,3794.85334396362 PathPoint;PointKind.SMOOTHPOINT 2614.26560282707,3793.89055967331 2601.13677978516,3794.56703424454 2629.00742590427,3793.13100099564 PathPoint;PointKind.SMOOTHPOINT 2273.35345745087,3795.64830780029 2174.40547943115,3795.89401960373 2468.93893182278,3795.16231298447 PathPoint;PointKind.SMOOTHPOINT 1935.04831194878,3796.29834651947 1787.02583312988,3796.52021884918 2059.23367738724,3796.11187934875 PathPoint;PointKind.SMOOTHPOINT 1464.7713214159,3796.82375907898 1367.32393205166,3796.89976215363 1626.19701325893,3796.69748067856 PathPoint;PointKind.SMOOTHPOINT 1174.46229457855,3796.99512004852 1171.0132420063,3796.99653625488 1269.65909600258,3796.95735454559 PathPoint;PointKind.SMOOTHPOINT 1164.00007009506,3794.99992132187 1161.60786151886,3795.10660886765 1169.14561986923,3794.77049589157 PathPoint;PointKind.SMOOTHPOINT 1156.945297122,3797.00172901154 1115.82368016243,3797.0170712471 1159.33691561222,3797.00102090836 PathPoint;PointKind.SMOOTHPOINT 1035.28254926205,3797.03619003296 972.019430994987,3797.04822778702 1075.19626021385,3797.02863693237 PathPoint;PointKind.SMOOTHPOINT 851.738959550858,3797.04279899597 850.282627344131,3797.04256296158 910.548108816147,3797.05058813095 PathPoint;PointKind.SMOOTHPOINT 846.999979019165,3794.99992132187 845.091345906258,3793.57993841171 850.221848487854,3797.39708662033 PathPoint;PointKind.SMOOTHPOINT 840.251460671425,3797.04114675522 781.489518284798,3797.03194141388 842.621541023254,3797.04161882401 PathPoint;PointKind.SMOOTHPOINT 673.09278845787,3796.98237419128 605.29810488224,3796.94319248199 725.475311279297,3797.01258659363 PathPoint;PointKind.SMOOTHPOINT 464.481166005135,3796.67694568634 456.221142411232,3796.10715866089 503.162777423859,3799.34484243393 PathPoint;PointKind.SMOOTHPOINT 448.803761601448,3796.7453956604 446.73285484314,3796.03752851486 455.354896187782,3798.98465394974 PathPoint;PointKind.SMOOTHPOINT 437.325999140739,3796.72486066818 397.854852676392,3796.65145397186 441.098713874817,3796.73170566559 PathPoint;PointKind.SMOOTHPOINT 337.565472722054,3796.46498680115 295.640453696251,3796.3077878952 364.24532532692,3796.56506538391 PathPoint;PointKind.SMOOTHPOINT 244.265502691269,3794.89063739777 237.492790818214,3795.04925251007 247.832572460175,3794.80708122253 PathPoint;PointKind.SMOOTHPOINT 219.265624880791,3787.89056539536 214.83673453331,3784.85705137253 229.138353466988,3794.6531867981 PathPoint;PointKind.SMOOTHPOINT 204.265639185905,3773.89065742493 202.85267829895,3771.57988071442 207.130211591721,3778.57546806335 PathPoint;PointKind.SMOOTHPOINT 202.791899442673,3691.59490585327 202.771246433258,3689.23385381699 203.228563070297,3741.87825679779 PathPoint;PointKind.SMOOTHPOINT 203.265738487244,3683.89050722122 203.231808543205,3680.4861831665 203.289932012558,3686.34172439575 PathPoint;PointKind.SMOOTHPOINT 202.610448002815,3673.90672445297 202.471777796745,3662.24992990494 202.652934193611,3677.48170137405 PathPoint;PointKind.SMOOTHPOINT 202.019771933556,3636.31258249283 201.829764246941,3626.65948390961 202.283245325089,3649.69667673111 PathPoint;PointKind.SMOOTHPOINT 201.513183116913,3598.42032909393 201.497840881348,3596.88917398453 201.646247506142,3611.65548563004 PathPoint;PointKind.SMOOTHPOINT 201.469221711159,3593.9087677002 203.274294734001,3591.08792066574 200.67526102066,3595.14936447144 PathPoint;PointKind.SMOOTHPOINT 201.406672596931,3586.96321964264 201.331436634064,3578.13128471375 201.425260305405,3589.15149450302 PathPoint;PointKind.SMOOTHPOINT 201.315209269524,3570.71083545685 201.326125860214,3570.23074150085 201.294261217117,3571.63443803787 PathPoint;PointKind.SMOOTHPOINT 202.26554274559,3560.89062452316 202.04750597477,3556.2069940567 202.531966567039,3566.61139011383 PathPoint;PointKind.SMOOTHPOINT 201.336452364922,3544.66868877411 201.334092020988,3514.47021245956 201.337042450905,3551.01258516312 PathPoint;PointKind.SMOOTHPOINT 201.350024342537,3430.33740520477 201.377463340759,3405.66284179688 201.311963796616,3464.5236825943 PathPoint;PointKind.SMOOTHPOINT 201.510527729988,3353.65407943726 201.523214578629,3349.36934709549 201.432046294212,3380.05452632904 PathPoint;PointKind.SMOOTHPOINT 201.550653576851,3340.73780536652 201.206338405609,3337.06440210342 202.080255746841,3346.39012098312 PathPoint;PointKind.SMOOTHPOINT 201.587828993797,3329.62554216385 201.62972509861,3317.52311468124 201.574847102165,3333.34402799606 PathPoint;PointKind.SMOOTHPOINT 201.727384328842,3292.874751091 201.702600717545,3292.32384681702 201.894673705101,3296.57459020615 PathPoint;PointKind.SMOOTHPOINT 201.731219887733,3280.64085245132 201.951912045479,3280.16005039215 200.385823845863,3283.57051134109 PathPoint;PointKind.SMOOTHPOINT 202.27085351944,3266.25195980072 202.657654881477,3242.65512943268 202.128052711487,3274.96280908585 PathPoint;PointKind.SMOOTHPOINT 202.924373745918,3142.01690912247 202.932634949684,3138.58142852783 202.799865603447,3193.27437400818 PathPoint;PointKind.SMOOTHPOINT 202.949157357216,3131.69229269028 203.238299489021,3131.06444120407 201.175653934479,3135.54390192032 PathPoint;PointKind.SMOOTHPOINT 202.983972430229,3118.99435043335 202.986627817154,3117.96736478806 202.964499592781,3126.25547647476 PathPoint;PointKind.SMOOTHPOINT 202.992528676987,3115.76705217361 202.997544407845,3113.90875339508 202.98957824707,3116.89033985138 PathPoint;PointKind.SMOOTHPOINT 203.008756041527,3109.83385562897 203.650179505348,3107.6309466362 202.424275875092,3111.84109210968 PathPoint;PointKind.SMOOTHPOINT 203.026163578033,3103.57516765594 203.102284669876,3076.55371427536 203.019967675209,3105.7466840744 PathPoint;PointKind.SMOOTHPOINT 203.366348147392,3018.61435174942 203.448665142059,3007.58328437805 203.227382898331,3037.21834659576 PathPoint;PointKind.SMOOTHPOINT 203.632771968842,2985.43240070343 203.664341568947,2981.73090934753 203.538063168526,2996.52035236359 PathPoint;PointKind.SMOOTHPOINT 203.729251027107,2974.31966543198 203.186962008476,2971.51982545853 204.949548840523,2980.62013149261 PathPoint;PointKind.SMOOTHPOINT 203.805667161942,2965.76035022736 204.261508584023,2915.32145261765 203.779998421669,2968.61471414566 PathPoint;PointKind.SMOOTHPOINT 205.287963151932,2813.76812696457 205.315402150154,2810.85782289505 204.807633161545,2864.44754362106 PathPoint;PointKind.SMOOTHPOINT 205.369985103607,2805.03933906555 205.226889252663,2804.71266746521 207.240262627602,2809.30660486221 PathPoint;PointKind.SMOOTHPOINT 205.563533306122,2793.97617101669 205.818155407906,2770.18602848053 205.492722988129,2800.59032678604 PathPoint;PointKind.SMOOTHPOINT 206.289929151535,2682.05031394958 206.411781907082,2657.35356330872 206.132966279984,2713.83092880249 PathPoint;PointKind.SMOOTHPOINT 206.319138407707,2608.23150157928 206.301730871201,2603.4605383873 206.409126520157,2632.71039247513 PathPoint;PointKind.SMOOTHPOINT 206.257179379463,2593.93796682358 206.054189801216,2590.26550769806 206.659027934074,2601.2127828598 PathPoint;PointKind.SMOOTHPOINT 206.196400523186,2582.9177570343 205.68568110466,2497.58849143982 206.218233704567,2586.58667564392 PathPoint;PointKind.SMOOTHPOINT 203.535407781601,2339.12727355957 203.505903482437,2336.06449127197 204.262393712997,2414.74254369736 PathPoint;PointKind.SMOOTHPOINT 203.450730443001,2329.97456789017 204.918569326401,2326.45246267319 202.281475067139,2332.77960062027 PathPoint;PointKind.SMOOTHPOINT 203.360152244568,2319.26261901855 203.04711163044,2279.93551254272 203.388476371765,2322.81611680984 PathPoint;PointKind.SMOOTHPOINT 203.364282846451,2208.4144949913 205.047798156738,2062.18339920044 202.968925237656,2242.75159835815 PathPoint;PointKind.SMOOTHPOINT 206.265735626221,1951.89066410065 206.267800927162,1944.80467557907 206.262195110321,1963.33786010742 PathPoint;PointKind.SMOOTHPOINT 206.475216150284,1892.16286897659 206.497049331665,1891.80999755859 206.315892934799,1894.74083662033 PathPoint;PointKind.SMOOTHPOINT 207.99999833107,1881.00009441376 208.32956135273,1876.25769138336 207.701414823532,1885.29757261276 PathPoint;PointKind.SMOOTHPOINT 206.64014518261,1864.52725410461 206.826317310333,1819.68921661377 206.593528389931,1875.6812953949 PathPoint;PointKind.SMOOTHPOINT 207.609656453133,1631.84077262878 207.937154173851,1556.64092302322 207.293665409088,1704.41875219345 PathPoint;PointKind.SMOOTHPOINT 208.075529336929,1403.59999895096 208.077299594879,1400.47419548035 208.029502630234,1477.46035337448 PathPoint;PointKind.SMOOTHPOINT 208.08113515377,1394.25185680389 206.584972143173,1389.74123954773 209.185481071472,1397.58135795593 PathPoint;PointKind.SMOOTHPOINT 208.088806271553,1380.06949424744 208.123326301575,1315.05452871323 208.08644592762,1384.77129936218 PathPoint;PointKind.SMOOTHPOINT 208.265537023544,1206.8905878067 208.427220582962,1146.40110969543 208.13689827919,1255.10297298431 PathPoint;PointKind.SMOOTHPOINT 208.265537023544,1096.89053535461 208.011209964752,1086.61194562912 208.452594280243,1104.43962335587 PathPoint;PointKind.SMOOTHPOINT 207.725608348846,886.660130023956 207.843035459518,886.338179111481 206.884735822678,888.960049152374 PathPoint;PointKind.SMOOTHPOINT 206.265735626221,874.890511035919 208.263766765594,869.017739295959 203.815108537674,882.093100547791 PathPoint;PointKind.SMOOTHPOINT 207.933613657951,861.20641708374 207.831233739853,801.673114299774 207.942464947701,866.271243095398 PathPoint;PointKind.SMOOTHPOINT 205.265539884567,576.890716552734 204.330548644066,507.615802288055 206.452497839928,664.818720817566 PathPoint;PointKind.SMOOTHPOINT 203.14801633358,385.244007110596 203.132084012032,381.076819896698 203.360742330551,441.464803218842 PathPoint;PointKind.SMOOTHPOINT 204.000100493431,368.999884128571 202.152541279793,352.999584674835 204.470399022102,373.075489997864 PathPoint;PointKind.SMOOTHPOINT 203.265738487244,328.890559673309 203.662571310997,284.06432390213 203.128543496132,344.376068115234 PathPoint;PointKind.SMOOTHPOINT 204.000100493431,235.999932289124 203.990364074707,233.253200054169 204.084777832031,259.965212345123 PathPoint;PointKind.SMOOTHPOINT 204.000100493431,223.999943733215 203.816288709641,218.398375511169 204.182142019272,229.549584388733 PathPoint;PointKind.SMOOTHPOINT 203.265738487244,208.890674114227 203.291997313499,201.322467327118 203.258362412453,210.953850746155 PathPoint";
	
	subshadow45[0] = "PointKind.CORNERPOINT 204,204.96875 204,204.96875 204,204.96875 PathPoint;PointKind.SMOOTHPOINT 213.999896168709,180.968814373016 221.954550266266,173.717129707336 206.045242071152,188.220499038696 PathPoint;PointKind.CORNERPOINT 243.999867558479,161.968753814697 243.999867558479,161.968753814697 243.999867558479,161.968753814697 PathPoint;PointKind.SMOOTHPOINT 352.000059604645,161.968753814697 362.583546757698,161.975834846497 278.973083615303,161.919658660889 PathPoint;PointKind.SMOOTHPOINT 392.978875756264,160.067496776581 1167.00970721245,160.587244510651 381.045566916466,160.059471607208 PathPoint;PointKind.CORNERPOINT 4725.00011813641,162.968831539154 4725.00011813641,162.968831539154 4725.00011813641,162.968831539154 PathPoint;PointKind.SMOOTHPOINT 4741.04721140862,172.01839017868 4742.99567532539,174.225075721741 4739.09874749184,169.81170463562 PathPoint;PointKind.CORNERPOINT 4746,181.96875 4746,181.96875 4746,181.96875 PathPoint;PointKind.CORNERPOINT 4745,3773.96875 4745,3773.96875 4745,3773.96875 PathPoint;PointKind.SMOOTHPOINT 4736,3794 4733.40620610049,3798.06573096282 4738.62719771534,3789.88150159337 PathPoint;PointKind.CORNERPOINT 4716,3797 4716,3797 4716,3797 PathPoint;PointKind.SMOOTHPOINT 4674.76137769222,3799.91847085953 4670.75262856483,3799.91493034363 4711.44820344448,3799.9512796402 PathPoint;PointKind.CORNERPOINT 3906,3796.96875 3906,3796.96875 3906,3796.96875 PathPoint;PointKind.CORNERPOINT 280.000128269196,3797.96882677078 280.000128269196,3797.96882677078 280.000128269196,3797.96882677078 PathPoint;PointKind.CORNERPOINT 239.99996972084,3795.96867132187 239.99996972084,3795.96867132187 239.99996972084,3795.96867132187 PathPoint;PointKind.SMOOTHPOINT 213,3782.96875 204.28681485808,3775.35128011413 220.042609089498,3789.12591848177 PathPoint;PointKind.CORNERPOINT 204,3762.96875 204,3762.96875 204,3762.96875 PathPoint";
	
}

// ---------------------------------------------------------------------



// Initial properties, settings and calculations

var doc = app.activeDocument;
app.preferences.rulerUnits = Units.PIXELS;
app.displayDialogs = DialogModes.NO;
doc.resizeImage(null, null, 72, ResampleMethod.NONE); // Necessary to resample to 72dpi for the negative to fit

var ratio = doc.height / doc.width;
var thisFormat = format();

// Calculate feathering
var feather_factor;
switch (thisFormat) {
    case "35mm":
        feather_factor = feather_factor_35mm;
        break;
    case "645":
        feather_factor = feather_factor_645;
        break;
    case "45":
        feather_factor = feather_factor_45;
        break;
    default:
        feather_factor = feather_factor_67_square;
        break;
}
var feather = (ratio > 1 ? doc.width : doc.height) / feather_factor;

// Decide the shortest side
var negative_size = ratio > 1 ? doc.width : doc.height;

// Scale
var doc_scale = negative_size.value / 3600;

// Sets up existing image layer
doc.activeLayer.isBackgroundLayer = false; // Unlocks background layer
var negativelayer = doc.activeLayer;
doc.activeLayer.name = "negative"; // Names background layer

// Colors
const myColor_white = new SolidColor();
const myColor_black = new SolidColor(); 
const myColor_shadow = new SolidColor();
const myColor_subshadow = new SolidColor();
const myColor_halation = new SolidColor();
const myColor_halation_glow = new SolidColor();

myColor_white.rgb.red = 255;  
myColor_white.rgb.green = 255;  
myColor_white.rgb.blue = 255;

if (colorCheck() == "color") {
	myColor_black.rgb.red = generateRandomInteger(1, 6); 
	myColor_black.rgb.green = generateRandomInteger(1, 6);  
	myColor_black.rgb.blue = generateRandomInteger(1, 6);

	myColor_halation.rgb.red = 50;
	myColor_halation.rgb.green = 10;
	myColor_halation.rgb.blue = 5;

	myColor_halation_glow.rgb.red = 255;
	myColor_halation_glow.rgb.green = 0;
	myColor_halation_glow.rgb.blue = 0;
	
	var minBrightness, maxBrightness, brightnessRange, minSaturation, maxSaturation, saturationRange, scaledBrightness;

	if (generateRandomInteger(1, 100) < blue_artefacts_odds) {
		myColor_shadow.hsb.hue = generateRandomInteger(190, 210);
		minBrightness = 80;
		maxBrightness = 100;
		myColor_shadow.hsb.brightness =  generateRandomInteger(minBrightness, maxBrightness);
		brightnessRange = maxBrightness - minBrightness;
		minSaturation = 2;
		maxSaturation = 4;
		saturationRange = maxSaturation - minSaturation;
		scaledBrightness = (myColor_shadow.hsb.brightness - minBrightness) / brightnessRange;
		myColor_shadow.hsb.saturation = minSaturation + (scaledBrightness * saturationRange);
	} else {
		myColor_shadow.hsb.hue = generateRandomInteger(17, 34);
		minBrightness = 70;
		maxBrightness = 100;
		myColor_shadow.hsb.brightness = generateRandomInteger(minBrightness, maxBrightness);
		brightnessRange = maxBrightness - minBrightness;
		minSaturation = 20;
		maxSaturation = 25;
		saturationRange = maxSaturation - minSaturation;
		scaledBrightness = (myColor_shadow.hsb.brightness - minBrightness) / brightnessRange;
		myColor_shadow.hsb.saturation = minSaturation + (scaledBrightness * saturationRange);
	}
} else {
	myColor_black.hsb.hue = 0;
	myColor_black.hsb.saturation = 0;
	myColor_black.hsb.brightness =  generateRandomInteger(1, 6);

	myColor_halation.rgb.red = 240;
	myColor_halation.rgb.green = 240;
	myColor_halation.rgb.blue = 240;

	myColor_halation_glow.rgb.red = 150;
	myColor_halation_glow.rgb.green = 150;
	myColor_halation_glow.rgb.blue = 150;
	 
	myColor_shadow.hsb.hue = 0;
	myColor_shadow.hsb.saturation = 0;
	myColor_shadow.hsb.brightness =  generateRandomInteger(80, 99);
}

myColor_subshadow.hsb.hue = myColor_shadow.hsb.hue;
myColor_subshadow.hsb.saturation = myColor_shadow.hsb.saturation / 1.5;
myColor_subshadow.hsb.brightness = Math.min(myColor_shadow.hsb.brightness * 1.5, 100);

// Lessen the gauge of these settings should be used
border_width_35mm = border_width_35mm/10;
border_width_645 = border_width_645/10;
border_width_67 = border_width_67/10;
border_width_45 = border_width_45/10;
border_width_square = border_width_square/10;


//
// MAIN ROUTINE
//

try {
	if (executeScript == true || legacy == true) {
		// Load paths
		const loadedpaths = loadPaths();
		var thisSubshadow = loadedpaths.subshadow;
		var thisShadow = loadedpaths.shadow;
		// Randomly decide if the scanner mask should be flipped (but not for 4x5)
		var rotate_mask = generateRandomInteger(1, 100) < mask_flip_probaility && thisFormat != "45";
		// Run fancy or crop
		fancy ? run_fancy() : run_crop();
		// Clean up
		cleanup();
		// ALL DONE!
	}
	
} catch (e) { alert(e); }